=== added directory 'checkbox-support'
=== added symlink 'checkbox-support/COPYING'
=== target is '../plainbox/COPYING'
=== added file 'checkbox-support/README.rst'
--- checkbox-support/README.rst	1970-01-01 00:00:00 +0000
+++ checkbox-support/README.rst	2014-01-07 13:39:38 +0000
@@ -0,0 +1,6 @@
+CheckBox Support
+================
+
+CheckBox Support library is a collection of python modules used by PlainBox
+providers scripts.
+They were originally provided by the checkbox python package.

=== added directory 'checkbox-support/checkbox_support'
=== added file 'checkbox-support/checkbox_support/__init__.py'
=== added directory 'checkbox-support/checkbox_support/contrib'
=== added file 'checkbox-support/checkbox_support/contrib/__init__.py'
=== added file 'checkbox-support/checkbox_support/contrib/xrandr.py'
--- checkbox-support/checkbox_support/contrib/xrandr.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/contrib/xrandr.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,1064 @@
+#!/usr/bin/python3
+# -*- coding: utf-8 -*-
+#
+# Python-XRandR provides a high level API for the XRandR extension of the
+# X.org server. XRandR allows to configure resolution, refresh rate, rotation
+# of the screen and multiple outputs of graphics cards.
+#
+# Copyright 2007 © Sebastian Heinlein <sebastian.heinlein@web.de>
+# Copyright 2007 © Michael Vogt <mvo@ubuntu.com>
+# Copyright 2007 © Canonical Ltd.
+#
+# In many aspects it follows the design of the xrand tool of the X.org, which
+# comes with the following copyright:
+#
+# Copyright © 2001 Keith Packard, member of The XFree86 Project, Inc.
+# Copyright © 2002 Hewlett Packard Company, Inc.
+# Copyright © 2006 Intel Corporation
+#
+# And can be downloaded here:
+#
+# git://anongit.freedesktop.org/git/xorg/app/xrandr
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+# MA  02110-1301  USA
+
+from ctypes import (
+    POINTER,
+    Structure,
+    byref,
+    c_char_p,
+    c_void_p,
+    c_int,
+    c_long,
+    c_ulong,
+    c_ushort,
+    cdll,
+)
+import os
+
+RR_ROTATE_0 = 1
+RR_ROTATE_90 = 2
+RR_ROTATE_180 = 4
+RR_ROTATE_270 = 8
+RR_REFLECT_X = 16
+RR_REFLECT_Y = 32
+
+RR_CONNECTED = 0
+RR_DISCONNECTED = 1
+RR_UNKOWN_CONNECTION = 2
+
+RR_BAD_OUTPUT = 0
+RR_BAD_CRTC = 1
+RR_BAD_MODE = 2
+
+RR_SET_CONFIG_SUCCESS = 0
+RR_SET_CONFIG_INVALID_CONFIG_TIME = 1
+RR_SET_CONFIG_INVALID_TIME = 2
+RR_SET_CONFIG_FAILED = 3
+
+# Flags to keep track of changes
+CHANGES_NONE = 0
+CHANGES_CRTC = 1
+CHANGES_MODE = 2
+CHANGES_RELATION = 4
+CHANGES_POSITION = 8
+CHANGES_ROTATION = 16
+CHANGES_REFLECTION = 32
+CHANGES_AUTOMATIC = 64
+CHANGES_REFRESH = 128
+CHANGES_PROPERTY = 256
+
+# Relation information
+RELATION_ABOVE = 0
+RELATION_BELOW = 1
+RELATION_RIGHT_OF = 2
+RELATION_LEFT_OF = 3
+RELATION_SAME_AS = 4
+
+# some fundamental datatypes
+RRCrtc = c_long
+RROutput = c_long
+RRMode = c_long
+Connection = c_ushort
+SubpixelOrder = c_ushort
+Time = c_ulong
+Rotation = c_ushort
+Status = c_int
+
+# load the libs
+xlib = cdll.LoadLibrary('libX11.so.6')
+rr = cdll.LoadLibrary('libXrandr.so.2')
+
+
+# query resources
+class _XRRModeInfo(Structure):
+    _fields_ = [
+        ("id", RRMode),  # XID is c_long
+        ("width", c_int),
+        ("height", c_int),
+        ("dotClock", c_long),
+        ("hSyncStart", c_int),
+        ("hSyncEnd", c_int),
+        ("hTotal", c_int),
+        ("hSkew", c_int),
+        ("vSyncStart", c_int),
+        ("vSyncEnd", c_int),
+        ("vTotal", c_int),
+        ("name", c_char_p),
+        ("nameLength", c_int),
+        ("modeFlags", c_long),
+        ]
+
+
+class _XRRScreenSize(Structure):
+    _fields_ = [
+        ("width", c_int),
+        ("height", c_int),
+        ("mwidth", c_int),
+        ("mheight", c_int)
+        ]
+
+
+class _XRRCrtcInfo(Structure):
+    _fields_ = [
+        ("timestamp", Time),
+        ("x", c_int),
+        ("y", c_int),
+        ("width", c_int),
+        ("height", c_int),
+        ("mode", RRMode),
+        ("rotation", c_int),
+        ("noutput", c_int),
+        ("outputs", POINTER(RROutput)),
+        ("rotations", Rotation),
+        ("npossible", c_int),
+        ("possible", POINTER(RROutput)),
+        ]
+
+
+class _XRRScreenResources(Structure):
+    _fields_ = [
+        ("timestamp", Time),
+        ("configTimestamp", Time),
+        ("ncrtc", c_int),
+        ("crtcs", POINTER(RRCrtc)),
+        ("noutput", c_int),
+        ("outputs", POINTER(RROutput)),
+        ("nmode", c_int),
+        ("modes", POINTER(_XRRModeInfo)),
+        ]
+
+
+class RRError(Exception):
+    """Base exception class of the module"""
+    pass
+
+
+class UnsupportedRRError(RRError):
+    """Raised if the required XRandR extension version is not available"""
+    def __init__(self, required, current):
+        self.required = required
+        self.current = current
+
+
+# XRRGetOutputInfo
+class _XRROutputInfo(Structure):
+    _fields_ = [
+        ("timestamp", Time),
+        ("crtc", c_int),
+        ("name", c_char_p),
+        ("nameLen", c_int),
+        ("mm_width", c_ulong),
+        ("mm_height", c_ulong),
+        ("connection", Connection),
+        ("subpixel_order", SubpixelOrder),
+        ("ncrtc", c_int),
+        ("crtcs", POINTER(RRCrtc)),
+        ("nclone", c_int),
+        ("clones", POINTER(RROutput)),
+        ("nmode", c_int),
+        ("npreferred", c_int),
+        ("modes", POINTER(RRMode))
+        ]
+
+
+class _XRRCrtcGamma(Structure):
+    _fields_ = [
+        ('size', c_int),
+        ('red', POINTER(c_ushort)),
+        ('green', POINTER(c_ushort)),
+        ('blue', POINTER(c_ushort)),
+        ]
+
+
+def _array_conv(array, type, conv=lambda x: x):
+    length = len(array)
+    res = (type * length)()
+    for i in range(length):
+        res[i] = conv(array[i])
+    return res
+
+
+class Output:
+    """The output is a reference to a supported output jacket of the graphics
+       card. Outputs are attached to a hardware pipe to be used. Furthermore
+       they can be a clone of another output or show a subset of the screen"""
+    def __init__(self, info, id, screen):
+        """Initializes an output instance"""
+        self._info = info
+        self.id = id
+        self._screen = screen
+        # Store changes later here
+        self._mode = None
+        self._crtc = None
+        self._rotation = RR_ROTATE_0
+        self._relation = None
+        self._relation_offset = 0
+        self._relative_to = None
+        self._position = None
+        self._reflection = None
+        self._automatic = None
+        self._rate = None
+        self._changes = CHANGES_NONE
+        self._x = 0
+        self._y = 0
+
+        self.name = self._info.contents.name
+
+    def __del__(self):
+        """Frees the internal reference to the output info if the output gets
+           removed"""
+        rr.XRRFreeOutputInfo(self._info)
+
+    def get_physical_width(self):
+        """Returns the display width reported by the connected output device"""
+        return self._info.contents.mm_width
+
+    def get_physical_height(self):
+        """
+        Returns the display height reported by the connected output device
+        """
+        return self._info.contents.mm_height
+
+    def get_crtc(self):
+        """Returns the xid of the hardware pipe to which the output is
+           attached. If the output is disabled it will return 0"""
+        return self._info.contents.crtc
+
+    def get_crtcs(self):
+        """Returns the xids of the hardware pipes to which the output could
+           be attached"""
+        crtcs = []
+        for i in range(self._info.contents.ncrtc):
+            for crtc in self._screen.crtcs:
+                if crtc.xid == self._info.contents.crtcs[i]:
+                    crtcs.append(crtc)
+        return crtcs
+
+    def get_available_rotations(self):
+        """Returns a binary flag of the supported rotations of the output or
+           0 if the output is disabled"""
+        rotations = RR_ROTATE_0
+        found = False
+        if self.is_active():
+            # Get the rotations supported by all crtcs to make assigning
+            # crtcs easier. Furthermore there don't seem to be so many
+            # cards which show another behavior
+            for crtc in self.get_crtcs():
+                # Set rotations to the value of the first found crtc and
+                # then create a subset only for all other crtcs
+                if not found:
+                    rotations = crtc.get_available_rotations()
+                    found = True
+                else:
+                    rotations = rotations & crtc.get_available_rotations()
+        return rotations
+
+    def get_available_modes(self):
+        """Returns the list of supported mode lines (resolution, refresh rate)
+           that are supported by the connected device"""
+        modes = []
+        for m in range(self._info.contents.nmode):
+            output_modes = self._info.contents.modes
+            for s in range(self._screen._resources.contents.nmode):
+                screen_modes = self._screen._resources.contents.modes
+                if screen_modes[s].id == output_modes[m]:
+                    modes.append(screen_modes[s])
+        return modes
+
+    def get_preferred_mode(self):
+        """Returns an index that refers to the list of available modes and
+           points to the preferred mode of the connected device"""
+        return self._info.contents.npreferred
+
+    def is_active(self):
+        """Returns True if the output is attached to a hardware pipe, is
+           enabled"""
+        return self._info.contents.crtc != 0
+
+    def is_connected(self):
+        """Return True if a device is detected at the output"""
+        if self._info.contents.connection in (RR_CONNECTED,
+                                              RR_UNKOWN_CONNECTION):
+            return True
+        return False
+
+    def disable(self):
+        """Disables the output"""
+        if not self.is_active():
+            return
+        self._mode = None
+        self._crtc._outputs.remove(self)
+        self._crtc = None
+        self._changes = self._changes | CHANGES_CRTC | CHANGES_MODE
+
+    def set_to_mode(self, mode):
+        modes = self.get_available_modes()
+        if mode in range(len(modes)):
+            self._mode = modes[mode].id
+            return
+        raise RRError("Mode is not available")
+
+    def set_to_preferred_mode(self):
+        modes = self.get_available_modes()
+        mode = modes[self.get_preferred_mode()]
+        if mode != None:
+            self._mode = mode.id
+            return
+        raise RRError("Preferred mode is not available")
+
+    def get_clones(self):
+        """Returns the xids of the outputs which can be clones of the output"""
+        clones = []
+        for i in range(self._info.contents.nclone):
+            id = self._info.contents.clones[i]
+            o = self._screen.get_output_by_id(id)
+            clones.append(o)
+        return clones
+
+    def set_relation(self, relative, relation, offset=0):
+        """Sets the position of the output in relation to the given one"""
+        rel = self._screen.get_output_by_name(relative)
+        if rel and relation in (RELATION_LEFT_OF, RELATION_RIGHT_OF,
+                                RELATION_ABOVE, RELATION_BELOW,
+                                RELATION_SAME_AS):
+            self._relation = relation
+            self._relative_to = rel
+            self._relation_offset = offset
+            self._changes = self._changes | CHANGES_RELATION
+        else:
+            raise RRError("The given relative output or relation is not "
+                          "available")
+
+    def has_changed(self, changes=None):
+        """Checks if the output has changed: Either for a specific change or
+           generally"""
+        if changes:
+            return self._changes & changes
+        else:
+            return self._changes != CHANGES_NONE
+
+
+class Crtc:
+    """The crtc is a reference to a hardware pipe that is provided by the
+       graphics device. Outputs can be attached to crtcs"""
+
+    def __init__(self, info, xid, screen):
+        """Initializes the hardware pipe object"""
+        self._info = info
+        self.xid = xid
+        self._screen = screen
+        self._outputs = []
+
+    def __del__(self):
+        """Frees the reference to the rendering pipe if the instance gets
+           removed"""
+        rr.XRRFreeCrtcConfigInfo(self._info)
+
+    def get_xid(self):
+        """Returns the internal id of the crtc from the X server"""
+        return self.xid
+
+    def get_available_rotations(self):
+        """Returns a binary flag that contains the supported rotations of the
+           hardware pipe"""
+        return self._info.contents.rotations
+
+    def set_config(self, x, y, mode, outputs, rotation=RR_ROTATE_0):
+        """Configures the render pipe with the given mode and outputs. X and y
+           set the position of the crtc output in the screen"""
+        rr.XRRSetCrtcConfig(self._screen._display,
+                            self._screen._resources,
+                            self.xid,
+                            self._screen.get_timestamp(),
+                            c_int(x), c_int(y),
+                            mode,
+                            rotation,
+                            _array_conv(outputs, RROutput, lambda x: x.id),
+                            len(outputs))
+
+    def apply_changes(self):
+        """Applies the stored changes"""
+        if len(self._outputs) > 0:
+            output = self._outputs[0]
+            self.set_config(output._x, output._y, output._mode,
+                            self._outputs, output._rotation)
+        else:
+            self.disable()
+
+    def disable(self):
+        """Turns off all outputs on the crtc"""
+        rr.XRRSetCrtcConfig(self._screen._display,
+                            self._screen._resources,
+                            self.xid,
+                            self._screen.get_timestamp(),
+                            0, 0,
+                            None,
+                            RR_ROTATE_0,
+                            0, 0)
+
+    #FIXME: support gamma settings
+    """
+    def get_gamma_size(self):
+        return rr.XRRGetCrtcGammaSize(self._screen._display, self.id)
+    def get_gamma(self):
+        result = rr.XRRGetCrtcGamma(self._screen._display, self.id)
+        return _from_gamma(result)
+    def set_gamma(self, gamma):
+        g = _to_gamma(gamma)
+        rr.XRRSetCrtcGamma(self._screen._display, self.id, g)
+        rr.XRRFreeGamma(g)
+        gamma = property(get_gamma, set_gamma)"""
+
+    def load_outputs(self):
+        """Get the currently assigned outputs"""
+        outputs = []
+        for i in range(self._info.contents.noutput):
+            id = self._info.contents.outputs[i]
+            o = self._screen.get_output_by_id(id)
+            outputs.append(o)
+        self._outputs = outputs
+
+    def get_outputs(self):
+        """Returns the list of attached outputs"""
+        return self._outputs
+
+    def add_output(self, output):
+        """Adds the specified output to the crtc"""
+        output._crtc = self
+        self._outputs.append(output)
+
+    def supports_output(self, output):
+        """Check if the output can be used by the crtc.
+           See check_crtc_for_output in xrandr.c"""
+        if not self.xid in [c.xid for c in output.get_crtcs()]:
+            return False
+        if len(self._outputs):
+            for other in self._outputs:
+                if other == output:
+                    continue
+                if other._x != output._x:
+                    return False
+                if other._y != output._y:
+                    return False
+                if other._mode != output._mode:
+                    return False
+                if other._rotation != output._rotation:
+                    return False
+        #FIXME: pick_crtc is still missing
+        elif self._info.contents.noutput > 0:
+            if self._info.contents.x != output._x:
+                return False
+            if self._info.contents.y != output._y:
+                return False
+            if self._info.contents.mode_info != output._mode:
+                return False
+            if self._info.rotation != output._rotation:
+                return False
+        return True
+
+    def supports_rotation(self, rotation):
+        """Check if the given rotation is supported by the crtc"""
+        rotations = self._info.contents.rotations
+        dir = rotation & (RR_ROTATE_0 | RR_ROTATE_90 | RR_ROTATE_180 |
+                          RR_ROTATE_270)
+        reflect = rotation & (RR_REFLECT_X | RR_REFLECT_Y)
+        if (((rotations & dir) != 0) and ((rotations & reflect) == reflect)):
+            return True
+        return False
+
+    def has_changed(self):
+        """Check if there are any new outputs assigned to the crtc or any
+           outputs with a changed mode or position"""
+        if len(self._outputs) != self._info.contents.noutput:
+            return True
+        for i in range(self._info.contents.noutput):
+            id = self._info.contents.outputs[i]
+            output = self._screen.get_output_by_id(id)
+            if not output in self._outputs:
+                return True
+            if output.has_changed():
+                return True
+        return False
+
+
+class Screen:
+    def __init__(self, dpy, screen=-1):
+        """Initializes the screen"""
+        # Some sane default values
+        self.outputs = {}
+        self.crtcs = []
+        self._width = 0
+        self._height = 0
+        self._width_max = 0
+        self._height_max = 0
+        self._width_min = 0
+        self._height_min = 0
+        self._width_mm = 0
+        self._height_mm = 0
+
+        self._display = dpy
+        if not -1 <= screen < xlib.XScreenCount(dpy):
+            raise RRError("The chosen screen is not available", screen)
+        elif screen == -1:
+            self._screen = xlib.XDefaultScreen(dpy)
+        else:
+            self._screen = screen
+        self._root = xlib.XDefaultRootWindow(self._display, self._screen)
+        self._id = rr.XRRRootToScreen(self._display, self._root)
+
+        self._load_resources()
+        self._load_config()
+        (self._width, self._height,
+         self._width_mm, self._height_mm) = self.get_size()
+        if XRANDR_VERSION >= (1, 2):
+            self._load_screen_size_range()
+            self._load_crtcs()
+            self._load_outputs()
+
+        # Store XRandR 1.0 changes here
+        self._rate = self.get_current_rate()
+        self._rotation = self.get_current_rotation()
+        self._size_index = self.get_current_size_index()
+
+    def __del__(self):
+        """Free the reference to the interal screen config if the screen
+           gets removed"""
+        rr.XRRFreeScreenConfigInfo(self._config)
+
+    def _load_config(self):
+        """Loads the screen configuration. Only needed privately by the
+           the bindings"""
+        class XRRScreenConfiguration(Structure):
+            " private to Xrandr "
+            pass
+        gsi = rr.XRRGetScreenInfo
+        gsi.restype = POINTER(XRRScreenConfiguration)
+        self._config = gsi(self._display, self._root)
+
+    def _load_screen_size_range(self):
+        """Detects the dimensionios of the screen"""
+        minWidth = c_int()
+        minHeight = c_int()
+        maxWidth = c_int()
+        maxHeight = c_int()
+        res = rr.XRRGetScreenSizeRange(self._display, self._root,
+                                       byref(minWidth), byref(minHeight),
+                                       byref(maxWidth), byref(maxHeight))
+        if res:
+            self._width_max = maxWidth.value
+            self._width_min = minWidth.value
+            self._height_max = maxHeight.value
+            self._height_min = minHeight.value
+
+    def _load_resources(self):
+        """Loads the screen resources. Only needed privately for the
+           bindings"""
+        gsr = rr.XRRGetScreenResources
+        gsr.restype = POINTER(_XRRScreenResources)
+        self._resources = gsr(self._display, self._root)
+
+    def _load_crtcs(self):
+        """Loads the available XRandR 1.2 crtcs (hardware pipes) of
+           the screen"""
+        gci = rr.XRRGetCrtcInfo
+        gci.restype = POINTER(_XRRCrtcInfo)
+        c = self._resources.contents.crtcs
+        for i in range(self._resources.contents.ncrtc):
+            xrrcrtcinfo = gci(self._display, self._resources, c[i])
+            self.crtcs.append(Crtc(xrrcrtcinfo, c[i], self))
+
+    def _load_outputs(self):
+        """Loads the available XRandR 1.2 outputs of the screen"""
+        goi = rr.XRRGetOutputInfo
+        goi.restype = POINTER(_XRROutputInfo)
+        o = self._resources.contents.outputs
+        for i in range(self._resources.contents.noutput):
+            xrroutputinfo = goi(self._display, self._resources, o[i])
+            output = Output(xrroutputinfo, o[i], self)
+            self.outputs[xrroutputinfo.contents.name] = output
+            # Store the mode of the crtc in the output instance
+            crtc = self.get_crtc_by_xid(output.get_crtc())
+            if crtc:
+                output._mode = crtc._info.contents.mode
+                crtc.add_output(output)
+
+    def get_size(self):
+        """Returns the current pixel and physical size of the screen"""
+        width = xlib.XDisplayWidth(self._display, self._screen)
+        width_mm = xlib.XDisplayWidthMM(self._display, self._screen)
+        height = xlib.XDisplayHeight(self._display, self._screen)
+        height_mm = xlib.XDisplayHeightMM(self._display, self._screen)
+        return width, height, width_mm, height_mm
+
+    def get_timestamp(self):
+        """Creates a X timestamp that must be used when applying changes, since
+           they can be delayed"""
+        config_timestamp = Time()
+        rr.XRRTimes.restpye = c_ulong
+        return rr.XRRTimes(self._display, self._id, byref(config_timestamp))
+
+    def get_crtc_by_xid(self, xid):
+        """Returns the crtc with the given xid or None"""
+        for crtc in self.crtcs:
+            if crtc.xid == xid:
+                return crtc
+        return None
+
+    def get_current_rate(self):
+        """Returns the currently used refresh rate"""
+        _check_required_version((1, 0))
+        xccr = rr.XRRConfigCurrentRate
+        xccr.restype = c_int
+        return xccr(self._config)
+
+    def get_available_rates_for_size_index(self, size_index):
+        """Returns the refresh rates that are supported by the screen for
+           the given resolution. See get_available_sizes for the resolution to
+           which size_index points"""
+        _check_required_version((1, 0))
+        rates = []
+        nrates = c_int()
+        rr.XRRConfigRates.restype = POINTER(c_ushort)
+        _rates = rr.XRRConfigRates(self._config, size_index, byref(nrates))
+        for r in range(nrates.value):
+            rates.append(_rates[r])
+        return rates
+
+    def get_current_rotation(self):
+        """Returns the currently used rotation. Can be RR_ROTATE_0,
+        RR_ROTATE_90, RR_ROTATE_180 or RR_ROTATE_270"""
+        _check_required_version((1, 0))
+        current = c_ushort()
+        rr.XRRConfigRotations(self._config, byref(current))
+        return current.value
+
+    def get_available_rotations(self):
+        """Returns a binary flag that holds the available resolutions"""
+        _check_required_version((1, 0))
+        current = c_ushort()
+        rotations = rr.XRRConfigRotations(self._config, byref(current))
+        return rotations
+
+    def get_current_size_index(self):
+        """Returns the position of the currently used resolution size in the
+           list of available resolutions. See get_available_sizes"""
+        _check_required_version((1, 0))
+        rotation = c_ushort()
+        size = rr.XRRConfigCurrentConfiguration(self._config,
+                                                byref(rotation))
+        return size
+
+    def get_available_sizes(self):
+        """Returns the available resolution sizes of the screen. The size
+           index points to the corresponding resolution of this list"""
+        _check_required_version((1, 0))
+        sizes = []
+        nsizes = c_int()
+        xcs = rr.XRRConfigSizes
+        xcs.restype = POINTER(_XRRScreenSize)
+        _sizes = xcs(self._config, byref(nsizes))
+        for r in range(nsizes.value):
+            sizes.append(_sizes[r])
+        return sizes
+
+    def set_config(self, size_index, rate, rotation):
+        """Configures the screen with the given resolution at the given size
+           index, rotation and refresh rate. To get in effect call
+           Screen.apply_config()"""
+        _check_required_version((1, 0))
+        self.set_size_index(size_index)
+        self.set_refresh_rate(rate)
+        self.set_rotation(rotation)
+
+    def set_size_index(self, index):
+        """Sets the reoslution of the screen. To get in effect call
+           Screen.apply_config()"""
+        if index in range(len(self.get_available_sizes())):
+            self._size_index = index
+        else:
+            raise RRError("There isn't any size associated "
+                          "to the index %s" % index)
+
+    def set_rotation(self, rotation):
+        """Sets the rotation of the screen. To get in effect call
+           Screen.apply_config()"""
+        if self.get_available_rotations() & rotation:
+            self._rotation = rotation
+        else:
+            raise RRError("The chosen rotation is not supported")
+
+    def set_refresh_rate(self, rate):
+        """Sets the refresh rate of the screen. To get in effect call
+           Screen.apply_config()"""
+        if rate in self.get_available_rates_for_size_index(self._size_index):
+            self._rate = rate
+        else:
+            raise RRError("The chosen refresh rate %s is not "
+                          "supported" % rate)
+
+    def get_mode_by_xid(self, xid):
+        """Returns the mode of the given xid"""
+        screen_modes = self._resources.contents.modes
+        for s in range(self._resources.contents.nmode):
+            if screen_modes[s].id == xid:
+                return screen_modes[s]
+        return None
+
+    def get_output_by_name(self, name):
+        """Returns the output of the screen with the given name or None"""
+        if name in self.outputs:
+            return self.outputs[name]
+        else:
+            return None
+
+    def get_output_by_id(self, id):
+        """Returns the output of the screen with the given xid or None"""
+        for o in list(self.outputs.values()):
+            if o.id == id:
+                return o
+        return None
+
+    def print_info(self, verbose=False):
+        """Prints some information about the detected screen and its outputs"""
+        _check_required_version((1, 0))
+        print("Screen %s: minimum %s x %s, current %s x %s, maximum %s x %s" %\
+              (self._screen,
+               self._width_min, self._height_min,
+               self._width, self._height,
+               self._width_max, self._height_max))
+        print("          %smm x %smm" % (self._width_mm, self._height_mm))
+        print("Crtcs: %s" % len(self.crtcs))
+        if verbose:
+            print("Modes (%s):" % self._resources.contents.nmode)
+            modes = self._resources.contents.modes
+            for i in range(self._resources.contents.nmode):
+                print("  %s - %sx%s" % (modes[i].name,
+                                       modes[i].width,
+                                       modes[i].height))
+        i = 0
+        print("Sizes @ Refresh Rates:")
+        for s in self.get_available_sizes():
+            print("  [%s] %s x %s @ %s" % (
+                i, s.width, s.height,
+                self.get_available_rates_for_size_index(i)))
+            i += 1
+        print("Rotations:")
+        rots = self.get_available_rotations()
+        if rots & RR_ROTATE_0:
+            print("normal")
+        if rots & RR_ROTATE_90:
+            print("right")
+        if rots & RR_ROTATE_180:
+            print("inverted")
+        if rots & RR_ROTATE_270:
+            print("left")
+        print("")
+        print("Outputs:")
+        for o in list(self.outputs.keys()):
+            output = self.outputs[o]
+            print("  %s" % o)
+            if output.is_connected():
+                print("(%smm x %smm)" % (output.get_physical_width(),
+                                         output.get_physical_height()))
+                modes = output.get_available_modes()
+                print("    Modes:")
+                for m in range(len(modes)):
+                    mode = modes[m]
+                    refresh = mode.dotClock / (mode.hTotal * mode.vTotal)
+                    print("      [%s] %s x %s @ %s" % (m,
+                                                       mode.width,
+                                                       mode.height,
+                                                       refresh))
+                    if mode.id == output._mode:
+                        print("*")
+                    if m == output.get_preferred_mode():
+                        print("(preferred)")
+                    print("")
+                print("    Rotations:")
+                rots = output.get_available_rotations()
+                if rots & RR_ROTATE_0:
+                    print("normal")
+                if rots & RR_ROTATE_90:
+                    print("right")
+                if rots & RR_ROTATE_180:
+                    print("inverted")
+                if rots & RR_ROTATE_270:
+                    print("left")
+                print("")
+            else:
+                print("(not connected)")
+            if verbose:
+                print("    Core properties:")
+                for (f, t) in output._info.contents._fields_:
+                    print("      %s: %s" % (
+                        f, getattr(output._info.contents, f)))
+
+    def get_outputs(self):
+        """Returns the outputs of the screen"""
+        _check_required_version((1, 2))
+        return list(self.outputs.values())
+
+    def get_output_names(self):
+        _check_required_version((1, 2))
+        return list(self.outputs.keys())
+
+    def set_size(self, width, height, width_mm, height_mm):
+        """Apply the given pixel and physical size to the screen"""
+        _check_required_version((1, 2))
+        # Check if we really need to apply the changes
+        if (width, height, width_mm, height_mm) == self.get_size():
+            return
+        rr.XRRSetScreenSize(self._display, self._root,
+                            c_int(width), c_int(height),
+                            c_int(width_mm), c_int(height_mm))
+
+    def apply_output_config(self):
+        """Used for instantly applying RandR 1.2 changes"""
+        _check_required_version((1, 2))
+        self._arrange_outputs()
+        self._calculate_size()
+        self.set_size(self._width, self._height,
+                      self._width_mm, self._height_mm)
+
+        # Assign all active outputs to crtcs
+        for output in list(self.outputs.values()):
+            if not output._mode or output._crtc:
+                continue
+            for crtc in output.get_crtcs():
+                if crtc and crtc.supports_output(output):
+                    crtc.add_output(output)
+                    output._changes = output._changes | CHANGES_CRTC
+                    break
+            if not output._crtc:
+                #FIXME: Take a look at the pick_crtc code in xrandr.c
+                raise RRError("There is no matching crtc for the output")
+
+        # Apply stored changes of crtcs
+        for crtc in self.crtcs:
+            if crtc.has_changed():
+                crtc.apply_changes()
+
+    def apply_config(self):
+        """Used for instantly applying RandR 1.0 changes"""
+        _check_required_version((1, 0))
+        status = rr.XRRSetScreenConfigAndRate(self._display,
+                                              self._config,
+                                              self._root,
+                                              self._size_index,
+                                              self._rotation,
+                                              self._rate,
+                                              self.get_timestamp())
+        return status
+
+    def _arrange_outputs(self):
+        """Arrange all output positions according to their relative position"""
+        for output in self.get_outputs():
+            # Skip not changed and not used outputs
+            if not output.has_changed(CHANGES_RELATION) or \
+               output._mode == None:
+                continue
+            relative = output._relative_to
+            mode = self.get_mode_by_xid(output._mode)
+            mode_relative = self.get_mode_by_xid(relative._mode)
+            if not relative or not relative._mode:
+                output._x = 0
+                output._y = 0
+                output._changes = output._changes | CHANGES_POSITION
+            if output._relation == RELATION_LEFT_OF:
+                output._y = relative._y + output._relation_offset
+                output._x = relative._x - \
+                            get_mode_width(mode, output._rotation)
+            elif output._relation == RELATION_RIGHT_OF:
+                output._y = relative._y + output._relation_offset
+                output._x = relative._x + get_mode_width(mode_relative,
+                                                         output._rotation)
+            elif output._relation == RELATION_ABOVE:
+                output._y = relative._y - get_mode_height(mode,
+                                                          output._rotation)
+                output._x = relative._x + output._relation_offset
+            elif output._relation == RELATION_BELOW:
+                output._y = relative._y + get_mode_height(mode_relative,
+                                                          output._rotation)
+                output._x = relative._x + output._relation_offset
+            elif output._relation == RELATION_SAME_AS:
+                output._y = relative._y + output._relation_offset
+                output._x = relative._x + output._relation_offset
+            output._changes = output._changes | CHANGES_POSITION
+        # Normalize the postions so to the upper left cornor of all outputs
+        # is at 0,0
+        min_x = 32768
+        min_y = 32768
+        for output in self.get_outputs():
+            if output._mode == None:
+                continue
+            if output._x < min_x:
+                min_x = output._x
+            if output._y < min_y:
+                min_y = output._y
+        for output in self.get_outputs():
+            if output._mode == None:
+                continue
+            output._x -= min_x
+            output._y -= min_y
+            output._changes = output._changes | CHANGES_POSITION
+
+    def _calculate_size(self):
+        """Recalculate the pixel and physical size of the screen so that
+           it covers all outputs"""
+        width = self._width
+        height = self._height
+        for output in self.get_outputs():
+            if not output._mode:
+                continue
+            mode = self.get_mode_by_xid(output._mode)
+            x = output._x
+            y = output._y
+            w = get_mode_width(mode, output._rotation)
+            h = get_mode_height(mode, output._rotation)
+            if x + w > width:
+                width = x + w
+            if y + h > height:
+                height = y + h
+        if width > self._width_max or height > self._height_max:
+            raise RRError("The required size is not supported",
+                          (width, height), (self._width_max, self._width_min))
+        else:
+            if height < self._height_min:
+                self._fb_height = self._height_min
+            else:
+                self._height = height
+            if width < self._width_min:
+                self._width = self._width_min
+            else:
+                self._width = width
+        #FIXME: Physical size is missing
+
+
+def get_current_display():
+    """Returns the currently used display"""
+    display_url = os.getenv("DISPLAY")
+    open_display = xlib.XOpenDisplay
+    # Set .argtypes and .restype, to ensure proper
+    # type check and conversion
+    open_display.restype = c_void_p
+    open_display.argtypes = [c_char_p]
+    # XOpenDisplay accepts a char*, but
+    # display_url is a unicode string therefore
+    # we convert it to a bytes string
+    dpy = open_display(display_url.encode('utf-8'))
+    return dpy
+
+
+def get_current_screen():
+    """Returns the currently used screen"""
+    screen = Screen(get_current_display())
+    return screen
+
+
+def get_screen_of_display(display, count):
+    """Returns the screen of the given display"""
+    dpy = xlib.XOpenDisplay(display)
+    return Screen(dpy, count)
+
+
+def get_version():
+    """Returns a tuple containing the major and minor version of the xrandr
+       extension or None if the extension is not available"""
+    major = c_int()
+    minor = c_int()
+    res = rr.XRRQueryVersion(get_current_display(),
+                             byref(major), byref(minor))
+    if res:
+        return (major.value, minor.value)
+    return None
+
+
+def has_extension():
+    """Returns True if the xrandr extension is available"""
+    if XRANDR_VERSION:
+        return True
+    return False
+
+
+def _to_gamma(gamma):
+    g = rr.XRRAllocGamma(len(gamma[0]))
+    for i in range(gamma[0]):
+        g.red[i] = gamma[0][i]
+        g.green[i] = gamma[1][i]
+        g.blue[i] = gamma[2][i]
+    return g
+
+
+def _from_gamma(g):
+    gamma = ([], [], [])
+    for i in range(g.size):
+        gamma[0].append(g.red[i])
+        gamma[1].append(g.green[i])
+        gamma[2].append(g.blue[i])
+    rr.XRRFreeGamma(g)
+
+
+def _check_required_version(version):
+    """Raises an exception if the given or a later version of xrandr is not
+       available"""
+    if XRANDR_VERSION == None or XRANDR_VERSION < version:
+        raise UnsupportedRRError(version, XRANDR_VERSION)
+
+
+def get_mode_height(mode, rotation):
+    """Return the height of the given mode taking the rotation into account"""
+    if rotation & (RR_ROTATE_0 | RR_ROTATE_180):
+        return mode.height
+    elif rotation & (RR_ROTATE_90 | RR_ROTATE_270):
+        return mode.width
+    else:
+        return 0
+
+
+def get_mode_width(mode, rotation):
+    """Return the width of the given mode taking the rotation into account"""
+    if rotation & (RR_ROTATE_0 | RR_ROTATE_180):
+        return mode.width
+    elif rotation & (RR_ROTATE_90 | RR_ROTATE_270):
+        return mode.height
+    else:
+        return 0
+
+
+XRANDR_VERSION = get_version()
+
+# vim:ts=4:sw=4:et

=== added directory 'checkbox-support/checkbox_support/dbus'
=== added file 'checkbox-support/checkbox_support/dbus/__init__.py'
--- checkbox-support/checkbox_support/dbus/__init__.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/dbus/__init__.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,89 @@
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+"""
+checkbox.dbus
+=============
+
+Utility modules for working with various things accessible over dbus
+"""
+
+import logging
+
+from dbus import SystemBus
+from dbus.mainloop.glib import DBusGMainLoop
+from dbus import (Array, Boolean, Byte, Dictionary, Double, Int16, Int32,
+                  Int64, ObjectPath, String, Struct, UInt16, UInt32, UInt64)
+from gi.repository import GObject
+
+
+def connect_to_system_bus():
+    """
+    Connect to the system bus properly.
+
+    Returns a tuple (system_bus, loop) where loop is a GObject.MainLoop
+    instance. The loop is there so that you can listen to signals.
+    """
+    # We'll need an event loop to observe signals. We will need the instance
+    # later below so let's keep it. Note that we're not passing it directly
+    # below as DBus needs specific API. The DBusGMainLoop class that we
+    # instantiate and pass is going to work with this instance transparently.
+    #
+    # NOTE: DBus tutorial suggests that we should create the loop _before_
+    # connecting to the bus.
+    logging.debug("Setting up glib-based event loop")
+    loop = GObject.MainLoop()
+    # Let's get the system bus object. We need that to access UDisks2 object
+    logging.debug("Connecting to DBus system bus")
+    system_bus = SystemBus(mainloop=DBusGMainLoop())
+    return system_bus, loop
+
+
+def drop_dbus_type(value):
+    """
+    Convert types from the DBus bindings to their python counterparts.
+
+    This function is mostly lossless, except for arrays of bytes (DBus
+    signature "y") that are transparently converted to strings, assuming
+    an UTF-8 encoded string.
+
+    The point of this function is to simplify printing of nested DBus data that
+    gets displayed in a rather illegible way.
+    """
+    if isinstance(value, Array) and value.signature == "y":
+        # Some other things are reported as array of bytes that are just
+        # strings but due to Unix heritage the encoding is not known.
+        # In practice it is better to treat them as UTF-8 strings
+        return bytes(value).decode("UTF-8", "replace").strip("\0")
+    elif isinstance(value, (Struct, Array)):
+        return [drop_dbus_type(item) for item in value]
+    elif isinstance(value, (Dictionary)):
+        return {drop_dbus_type(dict_key): drop_dbus_type(dict_value)
+                for dict_key, dict_value in value.items()}
+    elif isinstance(value, (String, ObjectPath)):
+        return str(value)
+    elif isinstance(value, (Byte, UInt16, UInt32, UInt64,
+                            Int16, Int32, Int64)):
+        return int(value)
+    elif isinstance(value, Boolean):
+        return bool(value)
+    elif isinstance(value, Double):
+        return float(value)
+    else:
+        return value

=== added file 'checkbox-support/checkbox_support/dbus/udisks2.py'
--- checkbox-support/checkbox_support/dbus/udisks2.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/dbus/udisks2.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,479 @@
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+checkbox.dbus.udisks2
+=====================
+
+Module for working with UDisks2 from python.
+
+There are two main classes that are interesting here.
+
+The first class is UDisksObserver, which is easy to setup and has pythonic API
+to all of the stuff that happens in UDisks2. It offers simple signal handlers
+for any changes that occur in UDisks2 that were advertised by DBus.
+
+The second class is UDisksModel, that builds on the observer class to offer
+persistent collection of objects managed by UDisks2.
+
+To work with this model you will likely want to look at:
+    http://udisks.freedesktop.org/docs/latest/ref-dbus.html
+"""
+
+import logging
+
+from dbus import Interface, PROPERTIES_IFACE
+from dbus.exceptions import DBusException
+
+from checkbox.dbus import drop_dbus_type
+
+__all__ = ['UDisks2Observer', 'UDisks2Model', 'Signal', 'is_udisks2_supported',
+           'lookup_udev_device']
+
+
+def is_udisks2_supported(system_bus):
+    """
+    Check if udisks2 is available on the system bus.
+
+    ..note::
+        Calling this _may_ trigger activation of the UDisks2 daemon but it
+        should only happen on systems where it is already expected to run all
+        the time.
+    """
+    observer = UDisks2Observer()
+    try:
+        logging.debug("Trying to connect to UDisks2...")
+        observer.connect_to_bus(system_bus)
+    except DBusException as exc:
+        if exc.get_dbus_name() == "org.freedesktop.DBus.Error.ServiceUnknown":
+            logging.debug("No UDisks2 on the system bus")
+            return False
+        else:
+            raise
+    else:
+        logging.debug("Got UDisks2 connection")
+        return True
+
+
+def map_udisks1_connection_bus(udisks1_connection_bus):
+    """
+    Map the value of udisks1 ConnectionBus property to the corresponding values
+    in udisks2. This a lossy function as some values are no longer supported.
+
+    Incorrect values raise LookupError
+    """
+    return {
+        'ata_serial_esata': '',  # gone from udisks2
+        'firewire': 'ieee1394',  # renamed
+        'scsi': '',              # gone from udisks2
+        'sdio': 'sdio',          # as-is
+        'usb': 'usb',            # as-is
+    }[udisks1_connection_bus]
+
+
+def lookup_udev_device(udisks2_object, udev_devices):
+    """
+    Find the udev_device that corresponds to the udisks2 object
+
+    Devices are matched by unix filesystem path of the special file (device).
+    The udisks2_object must implement the block device interface (so that the
+    block device path can be determined) or a ValueError is raised.
+
+    The udisks2_object must be the dictionary that maps from interface names to
+    dictionaries of properties. For compatible data see
+    UDisks2Model.managed_objects The udev_devices must be a list of udev
+    device, as returned from GUdev.
+
+    If there is no match, LookupError is raised with the unix block device
+    path.
+    """
+    try:
+        block_props = udisks2_object[UDISKS2_BLOCK_INTERFACE]
+    except KeyError:
+        raise ValueError("udisks2_object must be a block device")
+    else:
+        block_dev = block_props['Device']
+    for udev_device in udev_devices:
+        if udev_device.get_device_file() == block_dev:
+            return udev_device
+    raise LookupError(block_dev)
+
+
+# The well-known name for the ObjectManager interface, sadly it is not a part
+# of the python binding along with the rest of well-known names.
+OBJECT_MANAGER_INTERFACE = "org.freedesktop.DBus.ObjectManager"
+
+# The well-known name of the filesystem interface implemented by certain
+# objects exposed by UDisks2
+UDISKS2_FILESYSTEM_INTERFACE = "org.freedesktop.UDisks2.Filesystem"
+
+# The well-known name of the block (device) interface implemented by certain
+# objects exposed by UDisks2
+UDISKS2_BLOCK_INTERFACE = "org.freedesktop.UDisks2.Block"
+
+# The well-known name of the drive interface implemented by certain objects
+# exposed by UDisks2
+UDISKS2_DRIVE_INTERFACE = "org.freedesktop.UDisks2.Drive"
+
+
+class Signal:
+    """
+    Basic signal that supports arbitrary listeners.
+
+    While this class can be used directly it is best used with the helper
+    decorator Signal.define on a member function. The function body is ignored,
+    apart from the documentation.
+
+    The function name then becomes a unique (per encapsulating class instance)
+    object (an instance of this Signal class) that is created on demand.
+
+    In practice you just have a documentation and use
+    object.signal_name.connect() and object.signal_name(*args, **kwargs) to
+    fire it.
+    """
+
+    def __init__(self, signal_name):
+        """
+        Construct a signal with the given name
+        """
+        self._listeners = []
+        self._signal_name = signal_name
+
+    def connect(self, listener):
+        """
+        Connect a new listener to this signal
+
+        That listener will be called whenever fire() is invoked on the signal
+        """
+        self._listeners.append(listener)
+
+    def disconnect(self, listener):
+        """
+        Disconnect an existing listener from this signal
+        """
+        self._listeners.remove(listener)
+
+    def fire(self, args, kwargs):
+        """
+        Fire this signal with the specified arguments and keyword arguments.
+
+        Typically this is used by using __call__() on this object which is more
+        natural as it does all the argument packing/unpacking transparently.
+        """
+        for listener in self._listeners:
+            listener(*args, **kwargs)
+
+    def __call__(self, *args, **kwargs):
+        """
+        Call fire() with all arguments forwarded transparently
+        """
+        self.fire(args, kwargs)
+
+    @classmethod
+    def define(cls, dummy_func):
+        """
+        Helper decorator to define a signal descriptor in a class
+
+        The decorated function is never called but is used to get
+        documentation.
+        """
+        return _SignalDescriptor(dummy_func)
+
+
+class _SignalDescriptor:
+    """
+    Descriptor for convenient signal access.
+
+    Typically this class is used indirectly, when accessed from Signal.define
+    method decorator. It is used to do all the magic required when accessing
+    signal name on a class or instance.
+    """
+
+    def __init__(self, dummy_func):
+        self.signal_name = dummy_func.__name__
+        self.__doc__ = dummy_func.__doc__
+
+    def __repr__(self):
+        return "<SignalDecorator for signal: %r>" % self.signal_name
+
+    def __get__(self, instance, owner):
+        if instance is None:
+            return self
+        # Ensure that the instance has __signals__ property
+        if not hasattr(instance, "__signals__"):
+            instance.__signals__ = {}
+        if self.signal_name not in instance.__signals__:
+            instance.__signals__[self.signal_name] = Signal(self.signal_name)
+        return instance.__signals__[self.signal_name]
+
+    def __set__(self, instance, value):
+        raise AttributeError("You cannot overwrite signals")
+
+    def __delete__(self, instance):
+        raise AttributeError("You cannot delete signals")
+
+
+class UDisks2Observer:
+    """
+    Class for observing ongoing changes in UDisks2
+    """
+
+    def __init__(self):
+        """
+        Create a UDisks2 model.
+
+        The model must be connected to a bus before it is first used, see
+        connect()
+        """
+        # Proxy to the UDisks2 object
+        self._udisks2_obj = None
+        # Proxy to the ObjectManager interface exposed by UDisks2 object
+        self._udisks2_obj_manager = None
+
+    @Signal.define
+    def on_initial_objects(self, managed_objects):
+        """
+        Signal fired when the initial list of objects becomes available
+        """
+
+    @Signal.define
+    def on_interfaces_added(self, object_path, interfaces_and_properties):
+        """
+        Signal fired when one or more interfaces gets added to a specific
+        object.
+        """
+
+    @Signal.define
+    def on_interfaces_removed(self, object_path, interfaces):
+        """
+        Signal fired when one or more interface gets removed from a specific
+        object
+        """
+
+    @Signal.define
+    def on_properties_changed(self, interface_name, changed_properties,
+                              invalidated_properties, sender=None):
+        """
+        Signal fired when one or more property changes value or becomes
+        invalidated.
+        """
+
+    def connect_to_bus(self, bus):
+        """
+        Establish initial connection to UDisks2 on the specified DBus bus.
+
+        This will also load the initial set of objects from UDisks2 and thus
+        fire the on_initial_objects() signal from the model. Please call this
+        method only after connecting that signal if you want to observe that
+        event.
+        """
+        # Once everything is ready connect to udisks2
+        self._connect_to_udisks2(bus)
+        # And read all the initial objects and setup
+        # change event handlers
+        self._get_initial_objects()
+
+    def _connect_to_udisks2(self, bus):
+        """
+        Setup the initial connection to UDisks2
+
+        This step can fail if UDisks2 is not available and cannot be
+        service-activated.
+        """
+        # Access the /org/freedesktop/UDisks2 object sitting on the
+        # org.freedesktop.UDisks2 bus name. This will trigger the necessary
+        # activation if udisksd is not running for any reason
+        logging.debug("Accessing main UDisks2 object")
+        self._udisks2_obj = bus.get_object(
+            "org.freedesktop.UDisks2", "/org/freedesktop/UDisks2")
+        # Now extract the standard ObjectManager interface so that we can
+        # observe and iterate the collection of objects that UDisks2 provides.
+        logging.debug("Accessing ObjectManager interface on UDisks2 object")
+        self._udisks2_obj_manager = Interface(
+            self._udisks2_obj, OBJECT_MANAGER_INTERFACE)
+        # Connect to the PropertiesChanged signal. Here unlike before we want
+        # to listen to all signals, regardless of who was sending them in the
+        # first place.
+        logging.debug("Setting up DBus signal handler for PropertiesChanged")
+        bus.add_signal_receiver(
+            self._on_properties_changed,
+            signal_name="PropertiesChanged",
+            dbus_interface=PROPERTIES_IFACE,
+            # Use the sender_keyword keyword argument to indicate that we wish
+            # to know the sender of each signal. For consistency with other
+            # signals we choose to use the 'object_path' keyword argument.
+            sender_keyword='sender')
+
+    def _get_initial_objects(self):
+        """
+        Get the initial collection of objects.
+
+        Needs to be called before the first signals from DBus are observed.
+        Requires a working connection to UDisks2.
+        """
+        # Having this interface we can now peek at the existing objects.
+        # We can use the standard method GetManagedObjects() to do that
+        logging.debug("Accessing GetManagedObjects() on UDisks2 object")
+        managed_objects = self._udisks2_obj_manager.GetManagedObjects()
+        managed_objects = drop_dbus_type(managed_objects)
+        # Fire the public signal for getting initial objects
+        self.on_initial_objects(managed_objects)
+        # Connect our internal handles to the DBus signal handlers
+        logging.debug("Setting up DBus signal handler for InterfacesAdded")
+        self._udisks2_obj_manager.connect_to_signal(
+            "InterfacesAdded", self._on_interfaces_added)
+        logging.debug("Setting up DBus signal handler for InterfacesRemoved")
+        self._udisks2_obj_manager.connect_to_signal(
+            "InterfacesRemoved", self._on_interfaces_removed)
+
+    def _on_interfaces_added(self, object_path, interfaces_and_properties):
+        """
+        Internal callback that is called by DBus
+
+        This function is responsible for firing the public signal
+        """
+        # Convert from dbus types
+        object_path = drop_dbus_type(object_path)
+        interfaces_and_properties = drop_dbus_type(interfaces_and_properties)
+        # Log what's going on
+        logging.debug("The object %r has gained the following interfaces and "
+                      "properties: %r", object_path, interfaces_and_properties)
+        # Call the signal handler
+        self.on_interfaces_added(object_path, interfaces_and_properties)
+
+    def _on_interfaces_removed(self, object_path, interfaces):
+        """
+        Internal callback that is called by DBus
+
+        This function is responsible for firing the public signal
+        """
+        # Convert from dbus types
+        object_path = drop_dbus_type(object_path)
+        interfaces = drop_dbus_type(interfaces)
+        # Log what's going on
+        logging.debug("The object %r has lost the following interfaces: %r",
+                      object_path, interfaces)
+        # Call the signal handler
+        self.on_interfaces_removed(object_path, interfaces)
+
+    def _on_properties_changed(self, interface_name, changed_properties,
+                               invalidated_properties, sender=None):
+        """
+        Internal callback that is called by DBus
+
+        This function is responsible for firing the public signal
+        """
+        # Convert from dbus types
+        interface_name = drop_dbus_type(interface_name)
+        changed_properties = drop_dbus_type(changed_properties)
+        invalidated_properties = drop_dbus_type(invalidated_properties)
+        sender = drop_dbus_type(sender)
+        # Log what's going on
+        logging.debug("Some object with the interface %r has changed "
+                      "properties: %r and invalidated properties %r "
+                      "(sender: %s)",
+                      interface_name, changed_properties,
+                      invalidated_properties, sender)
+        # Call the signal handler
+        self.on_properties_changed(interface_name, changed_properties,
+                                   invalidated_properties, sender)
+
+
+class UDisks2Model:
+    """
+    Model for working with UDisks2
+
+    This class maintains a persistent model of what UDisks2 knows about, based
+    on the UDisks2Observer class and the signals it offers.
+    """
+
+    def __init__(self, observer):
+        """
+        Create a UDisks2 model.
+
+        The model will track changes using the specified observer (which is
+        expected to be a UDisks2Observer instance)
+
+        You should only connect the observer to the bus after creating the
+        model otherwise the initial objects will not be detected.
+        """
+        # Local state, everything that UDisks2 tells us
+        self._managed_objects = {}
+        self._observer = observer
+        # Connect all the signals to the observer
+        self._observer.on_initial_objects.connect(self._on_initial_objects)
+        self._observer.on_interfaces_added.connect(self._on_interfaces_added)
+        self._observer.on_interfaces_removed.connect(
+            self._on_interfaces_removed)
+        self._observer.on_properties_changed.connect(
+            self._on_properties_changed)
+
+    @Signal.define
+    def on_change(self):
+        """
+        Signal sent whenever the collection of managed object changes
+
+        Note that this signal is fired _after_ the change has occurred
+        """
+
+    @property
+    def managed_objects(self):
+        """
+        A collection of objects that is managed by this model. All changes as
+        well as the initial state, are reflected here.
+        """
+        return self._managed_objects
+
+    def _on_initial_objects(self, managed_objects):
+        """
+        Internal callback called when we get the initial collection of objects
+        """
+        self._managed_objects = drop_dbus_type(managed_objects)
+
+    def _on_interfaces_added(self, object_path, interfaces_and_properties):
+        """
+        Internal callback called when an interface is added to certain object
+        """
+        # Update internal state
+        if object_path not in self._managed_objects:
+            self._managed_objects[object_path] = {}
+        obj = self._managed_objects[object_path]
+        obj.update(interfaces_and_properties)
+        # Fire the change signal
+        self.on_change()
+
+    def _on_interfaces_removed(self, object_path, interfaces):
+        """
+        Internal callback called when an interface is removed from a certain
+        object
+        """
+        # Update internal state
+        if object_path in self._managed_objects:
+            obj = self._managed_objects[object_path]
+            for interface in interfaces:
+                if interface in obj:
+                    del obj[interface]
+        # Fire the change signal
+        self.on_change()
+
+    def _on_properties_changed(self, interface_name, changed_properties,
+                               invalidated_properties, sender=None):
+        # XXX: This is a workaround the fact that we cannot
+        # properly track changes to all properties :-(
+        self._managed_objects = drop_dbus_type(
+            self._observer._udisks2_obj_manager.GetManagedObjects())
+        # Fire the change signal()
+        self.on_change()

=== added directory 'checkbox-support/checkbox_support/heuristics'
=== added file 'checkbox-support/checkbox_support/heuristics/__init__.py'
--- checkbox-support/checkbox_support/heuristics/__init__.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/heuristics/__init__.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,56 @@
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+checkbox.heuristics
+===================
+
+This module contains implementations behind various heuristics used throughout
+the code. The intent of this module is twofold:
+
+    1) To encourage code reuse so that developers can use one implementation of
+       "guesswork" that is sometimes needed in our test. This reduces duplicate
+       bugs where many scripts do similar things in a different way.
+
+    2) To identify missing features in plumbing layer APIs such as
+       udev/udisks/dbus etc. Ideally no program should have to guess this, the
+       plumbing layer should be able to provide this meta data to allow
+       application developers deliver consistent behavior across userspace.
+
+Heuristics should be reusable from both python and shell. To make that possible
+each heuristics needs to be constrained to serializable input and output. This
+levels the playing field and allows both shell developers and python developers
+to reuse the same function.
+
+Additionally heuristics should try to avoid accessing thick APIs (such as
+objects returned by various libraries. This is meant to decrease the likelihood
+that updates to those libraries break this code. As an added side effect this
+also should make the implementation more explicit and easier to understand.
+
+In the long term each heuristic should be discussed with upstream developers of
+the particular problem area (udev, udisks, etc) to see if that subsystem can
+provide the required information directly, without us having to guess and fill
+the gaps.
+
+Things to consider when adding entries to this package:
+
+    1) File a bug on the upstream package about missing feature.
+
+    2) File a bug on checkbox to de-duplicate similar heuristics
+"""

=== added directory 'checkbox-support/checkbox_support/heuristics/tests'
=== added file 'checkbox-support/checkbox_support/heuristics/tests/__init__.py'
=== added file 'checkbox-support/checkbox_support/heuristics/tests/test_udisks2.py'
--- checkbox-support/checkbox_support/heuristics/tests/test_udisks2.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/heuristics/tests/test_udisks2.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,40 @@
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+
+checkbox.heuristics.tests.test_udisks2
+======================================
+
+Unit tests for checkbox.heuristics.udisks2 module
+"""
+
+from unittest import TestCase
+
+from checkbox.heuristics.udisks2 import is_memory_card
+
+
+class TestIsMemoryCard(TestCase):
+
+    def test_generic(self):
+        """
+        Device with vendor string "GENERIC" is a memory card
+        """
+        self.assertTrue(
+            is_memory_card(vendor="Generic", model="", udisks2_media=None))

=== added file 'checkbox-support/checkbox_support/heuristics/udev.py'
--- checkbox-support/checkbox_support/heuristics/udev.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/heuristics/udev.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,44 @@
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+checkbox.heuristics.dev
+=======================
+
+Heuristics for udev.
+
+    Documentation: http://udisks.freedesktop.org/docs/latest/
+    Source code: http://cgit.freedesktop.org/systemd/systemd/ (src/udev)
+    Bug tracker: http://bugs.freedesktop.org/ (using systemd product)
+"""
+
+
+def is_virtual_device(device_file):
+    """
+    Given a device name like /dev/ramX, /dev/sdX or /dev/loopX determine if
+    this is a virtual device. Virtual devices are typically uninteresting to
+    users. The only exception may be nonempty loopback device.
+
+    Possible prior art: gnome-disks, palimpset (precursor, suffering from this
+    flaw and showing all the /dev/ram devices by default)
+    """
+    for part in device_file.split("/"):
+        if part.startswith("ram") or part.startswith("loop"):
+            return True
+    return False

=== added file 'checkbox-support/checkbox_support/heuristics/udisks2.py'
--- checkbox-support/checkbox_support/heuristics/udisks2.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/heuristics/udisks2.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,62 @@
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+checkbox.heuristics.udisks2
+===========================
+
+Heuristics for udisks2.
+
+    Documentation: http://udisks.freedesktop.org/docs/latest/
+    Source code: http://cgit.freedesktop.org/systemd/systemd/ (src/udev)
+    Bug tracker: http://bugs.freedesktop.org/ (using systemd product)
+"""
+
+from checkbox.parsers.udevadm import CARD_READER_RE, GENERIC_RE, FLASH_RE
+
+
+def is_memory_card(vendor, model, udisks2_media):
+    """
+    Check if the device seems to be a memory card
+
+    The vendor and model arguments are _strings_, not integers.
+    The udisks2_media argument is the value of org.freedesktop.UDisks2.Drive/
+
+
+    This is rather fuzzy, sadly udev and udisks2 don't do a very good job and
+    mostly don't specify the "media" property (it has a few useful values, such
+    as flash_cf, flash_ms, flash_sm, flash_sd, flash_sdhc, flash_sdxc and
+    flash_mmc but I have yet to see a device that reports such values)
+    """
+    # Treat any udisks2_media that contains 'flash' as a memory card
+    if udisks2_media is not None and FLASH_RE.search(udisks2_media):
+        return True
+    # Treat any device that match model name to the following regular
+    # expression as a memory card reader.
+    if CARD_READER_RE.search(model):
+        return True
+    # Treat any device that contains the word 'Generic' in the vendor string as
+    # a memory card reader.
+    #
+    # XXX: This seems odd but strangely enough seems to gets the job done. I
+    # guess if I should start filing tons of bugs/patches on udev/udisks2 to
+    # just have a few more rules and make this rule obsolete.
+    if GENERIC_RE.search(vendor):
+        return True
+    return False

=== added directory 'checkbox-support/checkbox_support/lib'
=== added file 'checkbox-support/checkbox_support/lib/__init__.py'
=== added file 'checkbox-support/checkbox_support/lib/bit.py'
--- checkbox-support/checkbox_support/lib/bit.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/bit.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,46 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+from struct import calcsize
+
+
+def get_bitmask(key):
+    bitmask = []
+    for value in reversed(key.split()):
+        value = int(value, 16)
+        bitmask.append(value)
+
+    return bitmask
+
+def get_bitcount(bitmask):
+    bitcount = 0
+    for value in bitmask:
+        while value:
+            bitcount += 1
+            value &= (value - 1)
+
+    return bitcount
+
+def test_bit(bit, bitmask, bits=None):
+    if bits is None:
+        bits = calcsize("l") * 8
+    offset = bit % bits
+    long = int(bit / bits)
+    if long >= len(bitmask):
+        return 0
+    return (bitmask[long] >> offset) & 1

=== added file 'checkbox-support/checkbox_support/lib/conversion.py'
--- checkbox-support/checkbox_support/lib/conversion.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/conversion.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,172 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+
+from datetime import (
+    datetime,
+    timedelta,
+    )
+
+from checkbox.lib.tz import tzutc
+
+
+DATETIME_RE = re.compile(r"""
+    ^(?P<year>\d\d\d\d)-?(?P<month>\d\d)-?(?P<day>\d\d)
+    T(?P<hour>\d\d):?(?P<minute>\d\d):?(?P<second>\d\d)
+    (?:\.(?P<second_fraction>\d{0,6}))?
+    (?P<tz>
+        (?:(?P<tz_sign>[-+])(?P<tz_hour>\d\d):(?P<tz_minute>\d\d))
+        | Z)?$
+    """, re.VERBOSE)
+
+TYPE_FORMATS = (
+    (r"(yes|true)", lambda v: True),
+    (r"(no|false)", lambda v: False),
+    (r"-?\d+", lambda v: int(v.group(0))),
+    (r"-?\d+\.\d+", lambda v: float(v.group(0))),
+    (r"(-?\d+) ?([kmgt]?b?)", lambda v: int(v.group(1))),
+    (r"(-?\d+\.\d+) ?([kmgt]?b?)", lambda v: float(v.group(1))),
+    (r"(-?\d+) ?([kmgt]?hz)", lambda v: int(v.group(1))),
+    (r"(-?\d+\.\d+) ?([kmgt]?hz)", lambda v: float(v.group(1))))
+TYPE_FORMATS = tuple(
+    (re.compile(r"^%s$" % pattern, re.IGNORECASE), format)
+    for pattern, format in TYPE_FORMATS)
+
+TYPE_MULTIPLIERS = (
+    (r"b", 1),
+    (r"kb?", 1024),
+    (r"mb?", 1024 * 1024),
+    (r"gb?", 1024 * 1024 * 1024),
+    (r"tb?", 1024 * 1024 * 1024 * 1024),
+    (r"hz", 1),
+    (r"khz?", 1024),
+    (r"mhz?", 1024 * 1024),
+    (r"ghz?", 1024 * 1024 * 1024),
+    (r"thz?", 1024 * 1024 * 1024 * 1024))
+TYPE_MULTIPLIERS = tuple(
+    (re.compile(r"^%s$" % pattern, re.IGNORECASE), multiplier)
+    for pattern, multiplier in TYPE_MULTIPLIERS)
+
+
+def datetime_to_string(dt):
+    """Return a consistent string representation for a given datetime.
+
+    :param dt: The datetime object.
+    """
+    return dt.isoformat()
+
+
+def string_to_datetime(string):
+    """Return a datetime object from a consistent string representation.
+
+    :param string: The string representation.
+    """
+    # we cannot use time.strptime: this function accepts neither fractions
+    # of a second nor a time zone given e.g. as '+02:30'.
+    match = DATETIME_RE.match(string)
+
+    # The Relax NG schema allows a leading minus sign and year numbers
+    # with more than four digits, which are not "covered" by _time_regex.
+    if not match:
+        raise ValueError("Datetime with unreasonable value: %s" % string)
+
+    time_parts = match.groupdict()
+
+    year = int(time_parts['year'])
+    month = int(time_parts['month'])
+    day = int(time_parts['day'])
+    hour = int(time_parts['hour'])
+    minute = int(time_parts['minute'])
+    second = int(time_parts['second'])
+    second_fraction = time_parts['second_fraction']
+    if second_fraction is not None:
+        milliseconds = second_fraction + '0' * (6 - len(second_fraction))
+        milliseconds = int(milliseconds)
+    else:
+        milliseconds = 0
+
+    # The Relax NG validator accepts leap seconds, but the datetime
+    # constructor rejects them. The time values submitted by the HWDB
+    # client are not necessarily very precise, hence we can round down
+    # to 59.999999 seconds without losing any real precision.
+    if second > 59:
+        second = 59
+        milliseconds = 999999
+
+    dt = datetime(
+        year, month, day, hour, minute, second, milliseconds, tzinfo=tzutc)
+
+    tz_sign = time_parts['tz_sign']
+    tz_hour = time_parts['tz_hour']
+    tz_minute = time_parts['tz_minute']
+    if tz_sign in ('-', '+'):
+        delta = timedelta(hours=int(tz_hour), minutes=int(tz_minute))
+        if tz_sign == '-':
+            dt = dt + delta
+        else:
+            dt = dt - delta
+
+    return dt
+
+
+def sizeof_bytes(bytes):
+    for x in ["bytes", "KB", "MB", "GB", "TB"]:
+        string = "%3.1f%s" % (bytes, x)
+        if bytes < 1024.0:
+            break
+        bytes /= 1024.0
+
+    return string
+
+
+def sizeof_hertz(hertz):
+    for x in ["Hz", "KHz", "MHz", "GHz"]:
+        string = "%3.1f%s" % (hertz, x)
+        if hertz < 1000.0:
+            break
+        hertz /= 1000.0
+
+    return string
+
+
+def string_to_type(string):
+    """Return a typed representation for the given string.
+
+    The result might be a bool, int or float. The string might also be
+    supplemented by a multiplier like KB which would return an int or
+    float multiplied by 1024 for example.
+
+    :param string: The string representation.
+    """
+    for regex, formatter in TYPE_FORMATS:
+        match = regex.match(string)
+        if match:
+            string = formatter(match)
+            if len(match.groups()) > 1:
+                unit = match.group(2)
+                for regex, multiplier in TYPE_MULTIPLIERS:
+                    match = regex.match(unit)
+                    if match:
+                        string *= multiplier
+                        break
+                else:
+                    raise ValueError("Unknown multiplier: %s" % unit)
+            break
+
+    return string

=== added file 'checkbox-support/checkbox_support/lib/dmi.py'
--- checkbox-support/checkbox_support/lib/dmi.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/dmi.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,241 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import os
+
+from checkbox.lib.conversion import string_to_type
+
+# See also 3.3.4.1 of the "System Management BIOS Reference Specification,
+# Version 2.6.1" (Preliminary Standard) document, available from
+# http://www.dmtf.org/standards/smbios.
+class Dmi:
+    chassis = (
+        ("Undefined",             "unknown"),  # 0x00
+        ("Other",                 "unknown"),
+        ("Unknown",               "unknown"),
+        ("Desktop",               "desktop"),
+        ("Low Profile Desktop",   "desktop"),
+        ("Pizza Box",             "server"),
+        ("Mini Tower",            "desktop"),
+        ("Tower",                 "desktop"),
+        ("Portable",              "laptop"),
+        ("Laptop",                "laptop"),
+        ("Notebook",              "laptop"),
+        ("Hand Held",             "handheld"),
+        ("Docking Station",       "laptop"),
+        ("All In One",            "unknown"),
+        ("Sub Notebook",          "laptop"),
+        ("Space-saving",          "desktop"),
+        ("Lunch Box",             "unknown"),
+        ("Main Server Chassis",   "server"),
+        ("Expansion Chassis",     "unknown"),
+        ("Sub Chassis",           "unknown"),
+        ("Bus Expansion Chassis", "unknown"),
+        ("Peripheral Chassis",    "unknown"),
+        ("RAID Chassis",          "unknown"),
+        ("Rack Mount Chassis",    "unknown"),
+        ("Sealed-case PC",        "unknown"),
+        ("Multi-system",          "unknown"),
+        ("CompactPCI",            "unknonw"),
+        ("AdvancedTCA",           "unknown"),
+        ("Blade",                 "server"),
+        ("Blade Enclosure",       "unknown"))
+
+    chassis_names = tuple(c[0] for c in chassis)
+    chassis_types = tuple(c[1] for c in chassis)
+    chassis_name_to_type = dict(chassis)
+
+    type_names = (
+        "BIOS",  # 0x00
+        "System",
+        "Base Board",
+        "Chassis",
+        "Processor",
+        "Memory Controller",
+        "Memory Module",
+        "Cache",
+        "Port Connector",
+        "System Slots",
+        "On Board Devices",
+        "OEM Strings",
+        "System Configuration Options",
+        "BIOS Language",
+        "Group Associations",
+        "System Event Log",
+        "Physical Memory Array",
+        "Memory Device",
+        "32-bit Memory Error",
+        "Memory Array Mapped Address",
+        "Memory Device Mapped Address",
+        "Built-in Pointing Device",
+        "Portable Battery",
+        "System Reset",
+        "Hardware Security",
+        "System Power Controls",
+        "Voltage Probe",
+        "Cooling Device",
+        "Temperature Probe",
+        "Electrical Current Probe",
+        "Out-of-band Remote Access",
+        "Boot Integrity Services",
+        "System Boot",
+        "64-bit Memory Error",
+        "Management Device",
+        "Management Device Component",
+        "Management Device Threshold Data",
+        "Memory Channel",
+        "IPMI Device",
+        "Power Supply",
+        )
+
+
+class DmiDevice:
+
+    bus = "dmi"
+    driver = None
+    product_id = None
+    vendor_id = None
+
+    _product_blacklist = (
+        "<BAD INDEX>",
+        "N/A",
+        "Not Available",
+        "INVALID",
+        "OEM",
+        "Product Name",
+        "System Product Name",
+        "To be filled by O.E.M.",
+        "To Be Filled By O.E.M.",
+        "To Be Filled By O.E.M. by More String",
+        "Unknown",
+        "Uknown",
+        "Unknow",
+        "xxxxxxxxxxxxxx",
+        )
+    _vendor_blacklist = (
+        "<BAD INDEX>",
+        "Not Available",
+        "OEM",
+        "OEM Manufacturer",
+        "System manufacturer",
+        "System Manufacturer",
+        "System Name",
+        "To be filled by O.E.M.",
+        "To Be Filled By O.E.M.",
+        "To Be Filled By O.E.M. by More String",
+        "Unknow",  # XXX This is correct mispelling
+        "Unknown",
+        )
+    _serial_blacklist = (
+       "0",
+       "00000000",
+       "00 00 00 00 00 00 00 00",
+       "0123456789",
+       "Base Board Serial Number",
+       "Chassis Serial Number",
+       "N/A",
+       "None",
+       "Not Applicable",
+       "Not Available",
+       "Not Specified",
+       "OEM",
+       "System Serial Number",
+       )
+    _version_blacklist = (
+        "-1",
+        "<BAD INDEX>",
+        "N/A",
+        "None",
+        "Not Applicable",
+        "Not Available",
+        "Not Specified",
+        "OEM",
+        "System Version",
+        "Unknown",
+        "x.x",
+        )
+
+    def __init__(self, attributes, category):
+        self._attributes = attributes
+        self.category = category
+
+    @property
+    def path(self):
+        path = "/devices/virtual/dmi/id"
+        return os.path.join(path, self.category.lower())
+
+    @property
+    def product(self):
+        if self.category == "CHASSIS":
+            type_string = self._attributes.get("chassis_type", "0")
+            try:
+                type_index = int(type_string)
+                return Dmi.chassis_names[type_index]
+            except ValueError:
+                return type_string
+
+        for name in "name", "version":
+            attribute = "%s_%s" % (self.category.lower(), name)
+            product = self._attributes.get(attribute)
+            if product and product not in self._product_blacklist:
+                return product
+
+        return None
+
+    @property
+    def vendor(self):
+        for name in "manufacturer", "vendor":
+            attribute = "%s_%s" % (self.category.lower(), name)
+            vendor = self._attributes.get(attribute)
+            if vendor and vendor not in self._vendor_blacklist:
+                return vendor
+
+        return None
+
+    @property
+    def serial(self):
+        attribute = "%s_serial" % self.category.lower()
+        serial = self._attributes.get(attribute)
+        if serial and serial not in self._serial_blacklist:
+            return serial
+
+        return None
+
+    @property
+    def version(self):
+        attribute = "%s_version" % self.category.lower()
+        version = self._attributes.get(attribute)
+        if version and version not in self._version_blacklist:
+            return version
+
+        return None
+
+    @property
+    def size(self):
+        attribute = "%s_size" % self.category.lower()
+        size = self._attributes.get(attribute)
+
+        if size:
+            size = string_to_type(size)
+
+        return size
+
+    @property
+    def form(self):
+        attribute = "%s_form" % self.category.lower()
+        return self._attributes.get(attribute)

=== added file 'checkbox-support/checkbox_support/lib/input.py'
--- checkbox-support/checkbox_support/lib/input.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/input.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,585 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+# See linux/input.h
+class Input:
+    KEY_RESERVED            = 0
+    KEY_ESC                 = 1
+    KEY_1                   = 2
+    KEY_2                   = 3
+    KEY_3                   = 4
+    KEY_4                   = 5
+    KEY_5                   = 6
+    KEY_6                   = 7
+    KEY_7                   = 8
+    KEY_8                   = 9
+    KEY_9                   = 10
+    KEY_0                   = 11
+    KEY_MINUS               = 12
+    KEY_EQUAL               = 13
+    KEY_BACKSPACE           = 14
+    KEY_TAB                 = 15
+    KEY_Q                   = 16
+    KEY_W                   = 17
+    KEY_E                   = 18
+    KEY_R                   = 19
+    KEY_T                   = 20
+    KEY_Y                   = 21
+    KEY_U                   = 22
+    KEY_I                   = 23
+    KEY_O                   = 24
+    KEY_P                   = 25
+    KEY_LEFTBRACE           = 26
+    KEY_RIGHTBRACE          = 27
+    KEY_ENTER               = 28
+    KEY_LEFTCTRL            = 29
+    KEY_A                   = 30
+    KEY_S                   = 31
+    KEY_D                   = 32
+    KEY_F                   = 33
+    KEY_G                   = 34
+    KEY_H                   = 35
+    KEY_J                   = 36
+    KEY_K                   = 37
+    KEY_L                   = 38
+    KEY_SEMICOLON           = 39
+    KEY_APOSTROPHE          = 40
+    KEY_GRAVE               = 41
+    KEY_LEFTSHIFT           = 42
+    KEY_BACKSLASH           = 43
+    KEY_Z                   = 44
+    KEY_X                   = 45
+    KEY_C                   = 46
+    KEY_V                   = 47
+    KEY_B                   = 48
+    KEY_N                   = 49
+    KEY_M                   = 50
+    KEY_COMMA               = 51
+    KEY_DOT                 = 52
+    KEY_SLASH               = 53
+    KEY_RIGHTSHIFT          = 54
+    KEY_KPASTERISK          = 55
+    KEY_LEFTALT             = 56
+    KEY_SPACE               = 57
+    KEY_CAPSLOCK            = 58
+    KEY_F1                  = 59
+    KEY_F2                  = 60
+    KEY_F3                  = 61
+    KEY_F4                  = 62
+    KEY_F5                  = 63
+    KEY_F6                  = 64
+    KEY_F7                  = 65
+    KEY_F8                  = 66
+    KEY_F9                  = 67
+    KEY_F10                 = 68
+    KEY_NUMLOCK             = 69
+    KEY_SCROLLLOCK          = 70
+    KEY_KP7                 = 71
+    KEY_KP8                 = 72
+    KEY_KP9                 = 73
+    KEY_KPMINUS             = 74
+    KEY_KP4                 = 75
+    KEY_KP5                 = 76
+    KEY_KP6                 = 77
+    KEY_KPPLUS              = 78
+    KEY_KP1                 = 79
+    KEY_KP2                 = 80
+    KEY_KP3                 = 81
+    KEY_KP0                 = 82
+    KEY_KPDOT               = 83
+
+    KEY_ZENKAKUHANKAKU      = 85
+    KEY_102ND               = 86
+    KEY_F11                 = 87
+    KEY_F12                 = 88
+    KEY_RO                  = 89
+    KEY_KATAKANA            = 90
+    KEY_HIRAGANA            = 91
+    KEY_HENKAN              = 92
+    KEY_KATAKANAHIRAGANA    = 93
+    KEY_MUHENKAN            = 94
+    KEY_KPJPCOMMA           = 95
+    KEY_KPENTER             = 96
+    KEY_RIGHTCTRL           = 97
+    KEY_KPSLASH             = 98
+    KEY_SYSRQ               = 99
+    KEY_RIGHTALT            = 100
+    KEY_LINEFEED            = 101
+    KEY_HOME                = 102
+    KEY_UP                  = 103
+    KEY_PAGEUP              = 104
+    KEY_LEFT                = 105
+    KEY_RIGHT               = 106
+    KEY_END                 = 107
+    KEY_DOWN                = 108
+    KEY_PAGEDOWN            = 109
+    KEY_INSERT              = 110
+    KEY_DELETE              = 111
+    KEY_MACRO               = 112
+    KEY_MUTE                = 113
+    KEY_VOLUMEDOWN          = 114
+    KEY_VOLUMEUP            = 115
+    KEY_POWER               = 116     # SC System Power Down
+    KEY_KPEQUAL             = 117
+    KEY_KPPLUSMINUS         = 118
+    KEY_PAUSE               = 119
+    KEY_SCALE               = 120     # AL Compiz Scale (Expose)
+
+    KEY_KPCOMMA             = 121
+    KEY_HANGEUL             = 122
+    KEY_HANGUEL             = KEY_HANGEUL
+    KEY_HANJA               = 123
+    KEY_YEN                 = 124
+    KEY_LEFTMETA            = 125
+    KEY_RIGHTMETA           = 126
+    KEY_COMPOSE             = 127
+
+    KEY_STOP                = 128     # AC Stop
+    KEY_AGAIN               = 129
+    KEY_PROPS               = 130     # AC Properties
+    KEY_UNDO                = 131     # AC Undo
+    KEY_FRONT               = 132
+    KEY_COPY                = 133     # AC Copy
+    KEY_OPEN                = 134     # AC Open
+    KEY_PASTE               = 135     # AC Paste
+    KEY_FIND                = 136     # AC Search
+    KEY_CUT                 = 137     # AC Cut
+    KEY_HELP                = 138     # AL Integrated Help Center
+    KEY_MENU                = 139     # Menu (show menu)
+    KEY_CALC                = 140     # AL Calculator
+    KEY_SETUP               = 141
+    KEY_SLEEP               = 142     # SC System Sleep
+    KEY_WAKEUP              = 143     # System Wake Up
+    KEY_FILE                = 144     # AL Local Machine Browser
+    KEY_SENDFILE            = 145
+    KEY_DELETEFILE          = 146
+    KEY_XFER                = 147
+    KEY_PROG1               = 148
+    KEY_PROG2               = 149
+    KEY_WWW                 = 150     # AL Internet Browser
+    KEY_MSDOS               = 151
+    KEY_COFFEE              = 152     # AL Terminal Lock/Screensaver
+    KEY_SCREENLOCK          = KEY_COFFEE
+    KEY_DIRECTION           = 153
+    KEY_CYCLEWINDOWS        = 154
+    KEY_MAIL                = 155
+    KEY_BOOKMARKS           = 156     # AC Bookmarks
+    KEY_COMPUTER            = 157
+    KEY_BACK                = 158     # AC Back
+    KEY_FORWARD             = 159     # AC Forward
+    KEY_CLOSECD             = 160
+    KEY_EJECTCD             = 161
+    KEY_EJECTCLOSECD        = 162
+    KEY_NEXTSONG            = 163
+    KEY_PLAYPAUSE           = 164
+    KEY_PREVIOUSSONG        = 165
+    KEY_STOPCD              = 166
+    KEY_RECORD              = 167
+    KEY_REWIND              = 168
+    KEY_PHONE               = 169     # Media Select Telephone
+    KEY_ISO                 = 170
+    KEY_CONFIG              = 171     # AL Consumer Control Configuration
+    KEY_HOMEPAGE            = 172     # AC Home
+    KEY_REFRESH             = 173     # AC Refresh
+    KEY_EXIT                = 174     # AC Exit
+    KEY_MOVE                = 175
+    KEY_EDIT                = 176
+    KEY_SCROLLUP            = 177
+    KEY_SCROLLDOWN          = 178
+    KEY_KPLEFTPAREN         = 179
+    KEY_KPRIGHTPAREN        = 180
+    KEY_NEW                 = 181     # AC New
+    KEY_REDO                = 182     # AC Redo/Repeat
+
+    KEY_F13                 = 183
+    KEY_F14                 = 184
+    KEY_F15                 = 185
+    KEY_F16                 = 186
+    KEY_F17                 = 187
+    KEY_F18                 = 188
+    KEY_F19                 = 189
+    KEY_F20                 = 190
+    KEY_F21                 = 191
+    KEY_F22                 = 192
+    KEY_F23                 = 193
+    KEY_F24                 = 194
+
+    KEY_PLAYCD              = 200
+    KEY_PAUSECD             = 201
+    KEY_PROG3               = 202
+    KEY_PROG4               = 203
+    KEY_DASHBOARD           = 204     # AL Dashboard
+    KEY_SUSPEND             = 205
+    KEY_CLOSE               = 206     # AC Close
+    KEY_PLAY                = 207
+    KEY_FASTFORWARD         = 208
+    KEY_BASSBOOST           = 209
+    KEY_PRINT               = 210     # AC Print
+    KEY_HP                  = 211
+    KEY_CAMERA              = 212
+    KEY_SOUND               = 213
+    KEY_QUESTION            = 214
+    KEY_EMAIL               = 215
+    KEY_CHAT                = 216
+    KEY_SEARCH              = 217
+    KEY_CONNECT             = 218
+    KEY_FINANCE             = 219     # AL Checkbook/Finance
+    KEY_SPORT               = 220
+    KEY_SHOP                = 221
+    KEY_ALTERASE            = 222
+    KEY_CANCEL              = 223     # AC Cancel
+    KEY_BRIGHTNESSDOWN      = 224
+    KEY_BRIGHTNESSUP        = 225
+    KEY_MEDIA               = 226
+
+    KEY_SWITCHVIDEOMODE     = 227     # Cycle between available video
+                                      # outputs (Monitor/LCD/TV-out/etc)
+    KEY_KBDILLUMTOGGLE      = 228
+    KEY_KBDILLUMDOWN        = 229
+    KEY_KBDILLUMUP          = 230
+
+    KEY_SEND                = 231     # AC Send
+    KEY_REPLY               = 232     # AC Reply
+    KEY_FORWARDMAIL         = 233     # AC Forward Msg
+    KEY_SAVE                = 234     # AC Save
+    KEY_DOCUMENTS           = 235
+
+    KEY_BATTERY             = 236
+
+    KEY_BLUETOOTH           = 237
+    KEY_WLAN                = 238
+    KEY_UWB                 = 239
+
+    KEY_UNKNOWN             = 240
+
+    KEY_VIDEO_NEXT          = 241     # drive next video source
+    KEY_VIDEO_PREV          = 242     # drive previous video source
+    KEY_BRIGHTNESS_CYCLE    = 243     # brightness up, after max is min
+    KEY_BRIGHTNESS_ZERO     = 244     # brightness off, use ambient
+    KEY_DISPLAY_OFF         = 245     # display device to off state
+
+    KEY_WIMAX               = 246
+
+    # Range = 248 - 255 is reserved for special needs of AT keyboard driver
+
+    BTN_MISC                = 0x100
+    BTN_0                   = 0x100
+    BTN_1                   = 0x101
+    BTN_2                   = 0x102
+    BTN_3                   = 0x103
+    BTN_4                   = 0x104
+    BTN_5                   = 0x105
+    BTN_6                   = 0x106
+    BTN_7                   = 0x107
+    BTN_8                   = 0x108
+    BTN_9                   = 0x109
+
+    BTN_MOUSE               = 0x110
+    BTN_LEFT                = 0x110
+    BTN_RIGHT               = 0x111
+    BTN_MIDDLE              = 0x112
+    BTN_SIDE                = 0x113
+    BTN_EXTRA               = 0x114
+    BTN_FORWARD             = 0x115
+    BTN_BACK                = 0x116
+    BTN_TASK                = 0x117
+
+    BTN_JOYSTICK            = 0x120
+    BTN_TRIGGER             = 0x120
+    BTN_THUMB               = 0x121
+    BTN_THUMB2              = 0x122
+    BTN_TOP                 = 0x123
+    BTN_TOP2                = 0x124
+    BTN_PINKIE              = 0x125
+    BTN_BASE                = 0x126
+    BTN_BASE2               = 0x127
+    BTN_BASE3               = 0x128
+    BTN_BASE4               = 0x129
+    BTN_BASE5               = 0x12a
+    BTN_BASE6               = 0x12b
+    BTN_DEAD                = 0x12f
+
+    BTN_GAMEPAD             = 0x130
+    BTN_A                   = 0x130
+    BTN_B                   = 0x131
+    BTN_C                   = 0x132
+    BTN_X                   = 0x133
+    BTN_Y                   = 0x134
+    BTN_Z                   = 0x135
+    BTN_TL                  = 0x136
+    BTN_TR                  = 0x137
+    BTN_TL2                 = 0x138
+    BTN_TR2                 = 0x139
+    BTN_SELECT              = 0x13a
+    BTN_START               = 0x13b
+    BTN_MODE                = 0x13c
+    BTN_THUMBL              = 0x13d
+    BTN_THUMBR              = 0x13e
+
+    BTN_DIGI                = 0x140
+    BTN_TOOL_PEN            = 0x140
+    BTN_TOOL_RUBBER         = 0x141
+    BTN_TOOL_BRUSH          = 0x142
+    BTN_TOOL_PENCIL         = 0x143
+    BTN_TOOL_AIRBRUSH       = 0x144
+    BTN_TOOL_FINGER         = 0x145
+    BTN_TOOL_MOUSE          = 0x146
+    BTN_TOOL_LENS           = 0x147
+    BTN_TOUCH               = 0x14a
+    BTN_STYLUS              = 0x14b
+    BTN_STYLUS2             = 0x14c
+    BTN_TOOL_DOUBLETAP      = 0x14d
+    BTN_TOOL_TRIPLETAP      = 0x14e
+
+    BTN_WHEEL               = 0x150
+    BTN_GEAR_DOWN           = 0x150
+    BTN_GEAR_UP             = 0x151
+
+    KEY_OK                  = 0x160
+    KEY_SELECT              = 0x161
+    KEY_GOTO                = 0x162
+    KEY_CLEAR               = 0x163
+    KEY_POWER2              = 0x164
+    KEY_OPTION              = 0x165
+    KEY_INFO                = 0x166   # AL OEM Features/Tips/Tutorial
+    KEY_TIME                = 0x167
+    KEY_VENDOR              = 0x168
+    KEY_ARCHIVE             = 0x169
+    KEY_PROGRAM             = 0x16a   # Media Select Program Guide
+    KEY_CHANNEL             = 0x16b
+    KEY_FAVORITES           = 0x16c
+    KEY_EPG                 = 0x16d
+    KEY_PVR                 = 0x16e   # Media Select Home
+    KEY_MHP                 = 0x16f
+    KEY_LANGUAGE            = 0x170
+    KEY_TITLE               = 0x171
+    KEY_SUBTITLE            = 0x172
+    KEY_ANGLE               = 0x173
+    KEY_ZOOM                = 0x174
+    KEY_MODE                = 0x175
+    KEY_KEYBOARD            = 0x176
+    KEY_SCREEN              = 0x177
+    KEY_PC                  = 0x178   # Media Select Computer
+    KEY_TV                  = 0x179   # Media Select TV
+    KEY_TV2                 = 0x17a   # Media Select Cable
+    KEY_VCR                 = 0x17b   # Media Select VCR
+    KEY_VCR2                = 0x17c   # VCR Plus
+    KEY_SAT                 = 0x17d   # Media Select Satellite
+    KEY_SAT2                = 0x17e
+    KEY_CD                  = 0x17f   # Media Select CD
+    KEY_TAPE                = 0x180   # Media Select Tape
+    KEY_RADIO               = 0x181
+    KEY_TUNER               = 0x182   # Media Select Tuner
+    KEY_PLAYER              = 0x183
+    KEY_TEXT                = 0x184
+    KEY_DVD                 = 0x185   # Media Select DVD
+    KEY_AUX                 = 0x186
+    KEY_MP3                 = 0x187
+    KEY_AUDIO               = 0x188
+    KEY_VIDEO               = 0x189
+    KEY_DIRECTORY           = 0x18a
+    KEY_LIST                = 0x18b
+    KEY_MEMO                = 0x18c   # Media Select Messages
+    KEY_CALENDAR            = 0x18d
+    KEY_RED                 = 0x18e
+    KEY_GREEN               = 0x18f
+    KEY_YELLOW              = 0x190
+    KEY_BLUE                = 0x191
+    KEY_CHANNELUP           = 0x192   # Channel Increment
+    KEY_CHANNELDOWN         = 0x193   # Channel Decrement
+    KEY_FIRST               = 0x194
+    KEY_LAST                = 0x195   # Recall Last
+    KEY_AB                  = 0x196
+    KEY_NEXT                = 0x197
+    KEY_RESTART             = 0x198
+    KEY_SLOW                = 0x199
+    KEY_SHUFFLE             = 0x19a
+    KEY_BREAK               = 0x19b
+    KEY_PREVIOUS            = 0x19c
+    KEY_DIGITS              = 0x19d
+    KEY_TEEN                = 0x19e
+    KEY_TWEN                = 0x19f
+    KEY_VIDEOPHONE          = 0x1a0   # Media Select Video Phone
+    KEY_GAMES               = 0x1a1   # Media Select Games
+    KEY_ZOOMIN              = 0x1a2   # AC Zoom In
+    KEY_ZOOMOUT             = 0x1a3   # AC Zoom Out
+    KEY_ZOOMRESET           = 0x1a4   # AC Zoom
+    KEY_WORDPROCESSOR       = 0x1a5   # AL Word Processor
+    KEY_EDITOR              = 0x1a6   # AL Text Editor
+    KEY_SPREADSHEET         = 0x1a7   # AL Spreadsheet
+    KEY_GRAPHICSEDITOR      = 0x1a8   # AL Graphics Editor
+    KEY_PRESENTATION        = 0x1a9   # AL Presentation App
+    KEY_DATABASE            = 0x1aa   # AL Database App
+    KEY_NEWS                = 0x1ab   # AL Newsreader
+    KEY_VOICEMAIL           = 0x1ac   # AL Voicemail
+    KEY_ADDRESSBOOK         = 0x1ad   # AL Contacts/Address Book
+    KEY_MESSENGER           = 0x1ae   # AL Instant Messaging
+    KEY_DISPLAYTOGGLE       = 0x1af   # Turn display (LCD) on and off
+    KEY_SPELLCHECK          = 0x1b0   # AL Spell Check
+    KEY_LOGOFF              = 0x1b1   # AL Logoff
+
+    KEY_DOLLAR              = 0x1b2
+    KEY_EURO                = 0x1b3
+
+    KEY_FRAMEBACK           = 0x1b4   # Consumer - transport controls
+    KEY_FRAMEFORWARD        = 0x1b5
+    KEY_CONTEXT_MENU        = 0x1b6   # GenDesc - system context menu
+    KEY_MEDIA_REPEAT        = 0x1b7   # Consumer - transport control
+
+    KEY_DEL_EOL             = 0x1c0
+    KEY_DEL_EOS             = 0x1c1
+    KEY_INS_LINE            = 0x1c2
+    KEY_DEL_LINE            = 0x1c3
+
+    KEY_FN                  = 0x1d0
+    KEY_FN_ESC              = 0x1d1
+    KEY_FN_F1               = 0x1d2
+    KEY_FN_F2               = 0x1d3
+    KEY_FN_F3               = 0x1d4
+    KEY_FN_F4               = 0x1d5
+    KEY_FN_F5               = 0x1d6
+    KEY_FN_F6               = 0x1d7
+    KEY_FN_F7               = 0x1d8
+    KEY_FN_F8               = 0x1d9
+    KEY_FN_F9               = 0x1da
+    KEY_FN_F10              = 0x1db
+    KEY_FN_F11              = 0x1dc
+    KEY_FN_F12              = 0x1dd
+    KEY_FN_1                = 0x1de
+    KEY_FN_2                = 0x1df
+    KEY_FN_D                = 0x1e0
+    KEY_FN_E                = 0x1e1
+    KEY_FN_F                = 0x1e2
+    KEY_FN_S                = 0x1e3
+    KEY_FN_B                = 0x1e4
+
+    KEY_BRL_DOT1            = 0x1f1
+    KEY_BRL_DOT2            = 0x1f2
+    KEY_BRL_DOT3            = 0x1f3
+    KEY_BRL_DOT4            = 0x1f4
+    KEY_BRL_DOT5            = 0x1f5
+    KEY_BRL_DOT6            = 0x1f6
+    KEY_BRL_DOT7            = 0x1f7
+    KEY_BRL_DOT8            = 0x1f8
+    KEY_BRL_DOT9            = 0x1f9
+    KEY_BRL_DOT10           = 0x1fa
+
+    KEY_NUMERIC_0           = 0x200   # used by phones, remote controls,
+    KEY_NUMERIC_1           = 0x201   # and other keypads
+    KEY_NUMERIC_2           = 0x202
+    KEY_NUMERIC_3           = 0x203
+    KEY_NUMERIC_4           = 0x204
+    KEY_NUMERIC_5           = 0x205
+    KEY_NUMERIC_6           = 0x206
+    KEY_NUMERIC_7           = 0x207
+    KEY_NUMERIC_8           = 0x208
+    KEY_NUMERIC_9           = 0x209
+    KEY_NUMERIC_STAR        = 0x20a
+    KEY_NUMERIC_POUND       = 0x20b
+
+    # Relative axes
+
+    REL_X                   = 0x00
+    REL_Y                   = 0x01
+    REL_Z                   = 0x02
+    REL_RX                  = 0x03
+    REL_RY                  = 0x04
+    REL_RZ                  = 0x05
+    REL_HWHEEL              = 0x06
+    REL_DIAL                = 0x07
+    REL_WHEEL               = 0x08
+    REL_MISC                = 0x09
+    REL_MAX                 = 0x0f
+    REL_CNT                 = REL_MAX+1
+
+    # Absolute axes
+
+    ABS_X                   = 0x00
+    ABS_Y                   = 0x01
+    ABS_Z                   = 0x02
+    ABS_RX                  = 0x03
+    ABS_RY                  = 0x04
+    ABS_RZ                  = 0x05
+    ABS_THROTTLE            = 0x06
+    ABS_RUDDER              = 0x07
+    ABS_WHEEL               = 0x08
+    ABS_GAS                 = 0x09
+    ABS_BRAKE               = 0x0a
+    ABS_HAT0X               = 0x10
+    ABS_HAT0Y               = 0x11
+    ABS_HAT1X               = 0x12
+    ABS_HAT1Y               = 0x13
+    ABS_HAT2X               = 0x14
+    ABS_HAT2Y               = 0x15
+    ABS_HAT3X               = 0x16
+    ABS_HAT3Y               = 0x17
+    ABS_PRESSURE            = 0x18
+    ABS_DISTANCE            = 0x19
+    ABS_TILT_X              = 0x1a
+    ABS_TILT_Y              = 0x1b
+    ABS_TOOL_WIDTH          = 0x1c
+    ABS_VOLUME              = 0x20
+    ABS_MISC                = 0x28
+    ABS_MAX                 = 0x3f
+    ABS_CNT                 = ABS_MAX+1
+
+    # Switch events
+
+    SW_LID                  = 0x00  # set = lid shut
+    SW_TABLET_MODE          = 0x01  # set = tablet mode
+    SW_HEADPHONE_INSERT     = 0x02  # set = inserted
+    SW_RFKILL_ALL           = 0x03  # rfkill master switch, type "any"
+                                    # set = radio enabled
+    SW_RADIO                = SW_RFKILL_ALL   # deprecated
+    SW_MICROPHONE_INSERT    = 0x04  # set = inserted
+    SW_DOCK                 = 0x05  # set = plugged into dock
+    SW_MAX                  = 0x0f
+    SW_CNT                  = SW_MAX+1
+
+    # Misc events
+
+    MSC_SERIAL              = 0x00
+    MSC_PULSELED            = 0x01
+    MSC_GESTURE             = 0x02
+    MSC_RAW                 = 0x03
+    MSC_SCAN                = 0x04
+    MSC_MAX                 = 0x07
+    MSC_CNT                 = MSC_MAX+1
+
+    # LEDs
+
+    LED_NUML                = 0x00
+    LED_CAPSL               = 0x01
+    LED_SCROLLL             = 0x02
+    LED_COMPOSE             = 0x03
+    LED_KANA                = 0x04
+    LED_SLEEP               = 0x05
+    LED_SUSPEND             = 0x06
+    LED_MUTE                = 0x07
+    LED_MISC                = 0x08
+    LED_MAIL                = 0x09
+    LED_CHARGING            = 0x0a
+    LED_MAX                 = 0x0f
+    LED_CNT                 = LED_MAX+1
+
+    # Autorepeat values
+
+    REP_DELAY               = 0x00
+    REP_PERIOD              = 0x01
+    REP_MAX                 = 0x01

=== added file 'checkbox-support/checkbox_support/lib/path.py'
--- checkbox-support/checkbox_support/lib/path.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/path.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,62 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import os
+
+from glob import glob
+
+
+def path_split(path):
+    return path.split(os.path.sep)
+
+def path_common(l1, l2, common=[]):
+    if len(l1) < 1:
+        return (common, l1, l2)
+
+    if len(l2) < 1:
+        return (common, l1, l2)
+
+    if l1[0] != l2[0]:
+        return (common, l1, l2)
+
+    return path_common(l1[1:], l2[1:], common + [l1[0]])
+
+def path_relative(p1, p2):
+    (common, l1, l2) = path_common(path_split(p1), path_split(p2))
+    p = []
+    if len(l1) > 0:
+        p = ["..%s" % os.path.sep * len(l1)]
+
+    p = p + l2
+    return os.path.join( *p )
+
+def path_expand(path):
+    path = os.path.expanduser(path)
+    return glob(path)
+
+def path_expand_recursive(path):
+    paths = []
+    for path in path_expand(path):
+        if os.path.isdir(path):
+            for dirpath, dirnames, filenames in os.walk(path):
+                for filename in filenames:
+                    paths.append(os.path.join(dirpath, filename))
+        else:
+            paths.append(path)
+
+    return paths

=== added file 'checkbox-support/checkbox_support/lib/pci.py'
--- checkbox-support/checkbox_support/lib/pci.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/pci.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,89 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+# See http://pciids.sourceforge.net/pci.ids.bz2
+class Pci:
+
+    BASE_CLASS_STORAGE              = 1
+    CLASS_STORAGE_SCSI              = 0
+    CLASS_STORAGE_IDE               = 1
+    CLASS_STORAGE_FLOPPY            = 2
+    CLASS_STORAGE_IPI               = 3
+    CLASS_STORAGE_RAID              = 4
+    CLASS_STORAGE_OTHER             = 80
+
+    BASE_CLASS_NETWORK              = 2
+    CLASS_NETWORK_ETHERNET          = 0
+    CLASS_NETWORK_TOKEN_RING        = 1
+    CLASS_NETWORK_FDDI              = 2
+    CLASS_NETWORK_ATM               = 3
+    CLASS_NETWORK_OTHER             = 80
+    CLASS_NETWORK_WIRELESS          = 128
+
+    BASE_CLASS_DISPLAY              = 3
+    CLASS_DISPLAY_VGA               = 0
+    CLASS_DISPLAY_XGA               = 1
+    CLASS_DISPLAY_3D                = 2
+    CLASS_DISPLAY_OTHER             = 80
+
+    BASE_CLASS_MULTIMEDIA           = 4
+    CLASS_MULTIMEDIA_VIDEO          = 0
+    CLASS_MULTIMEDIA_AUDIO          = 1
+    CLASS_MULTIMEDIA_PHONE          = 2
+    CLASS_MULTIMEDIA_AUDIO_DEVICE   = 3
+    CLASS_MULTIMEDIA_OTHER          = 80
+
+    BASE_CLASS_BRIDGE               = 6
+    CLASS_BRIDGE_HOST               = 0
+    CLASS_BRIDGE_ISA                = 1
+    CLASS_BRIDGE_EISA               = 2
+    CLASS_BRIDGE_MC                 = 3
+    CLASS_BRIDGE_PCI                = 4
+    CLASS_BRIDGE_PCMCIA             = 5
+    CLASS_BRIDGE_NUBUS              = 6
+    CLASS_BRIDGE_CARDBUS            = 7
+    CLASS_BRIDGE_RACEWAY            = 8
+    CLASS_BRIDGE_OTHER              = 80
+
+    BASE_CLASS_COMMUNICATION        = 7
+    CLASS_COMMUNICATION_SERIAL      = 0
+    CLASS_COMMUNICATION_PARALLEL    = 1
+    CLASS_COMMUNICATION_MULTISERIAL = 2
+    CLASS_COMMUNICATION_MODEM       = 3
+    CLASS_COMMUNICATION_OTHER       = 80
+
+    BASE_CLASS_INPUT                = 9
+    CLASS_INPUT_KEYBOARD            = 0
+    CLASS_INPUT_PEN                 = 1
+    CLASS_INPUT_MOUSE               = 2
+    CLASS_INPUT_SCANNER             = 3
+    CLASS_INPUT_GAMEPORT            = 4
+    CLASS_INPUT_OTHER               = 80
+
+    BASE_CLASS_SERIAL               = 12
+    CLASS_SERIAL_FIREWIRE           = 0
+    CLASS_SERIAL_ACCESS             = 1
+
+    BASE_CLASS_WIRELESS             = 13
+    CLASS_WIRELESS_BLUETOOTH        = 17
+
+    CLASS_SERIAL_SSA                = 2
+    CLASS_SERIAL_USB                = 3
+    CLASS_SERIAL_FIBER              = 4
+    CLASS_SERIAL_SMBUS              = 5

=== added file 'checkbox-support/checkbox_support/lib/template.py'
--- checkbox-support/checkbox_support/lib/template.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/template.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,143 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+import logging
+
+
+EXTENDED_STRING = "_extended"
+
+
+class Template:
+
+    def _reader(self, file, size=4096, delimiter=r"\n{2,}"):
+        buffer_old = ""
+        while True:
+            buffer_new = file.read(size)
+            if not buffer_new:
+                break
+
+            lines = re.split(delimiter, buffer_old + buffer_new)
+            buffer_old = lines.pop(-1)
+
+            for line in lines:
+                yield line
+
+        yield buffer_old
+
+    def dump_file(self, elements, file, filename="<stream>"):
+        for element in elements:
+            for long_key in list(element.keys()):
+                if long_key.endswith(EXTENDED_STRING):
+                    short_key = long_key.replace(EXTENDED_STRING, "")
+                    del element[short_key]
+
+            for key, value in element.items():
+                if key.endswith(EXTENDED_STRING):
+                    key = key.replace(EXTENDED_STRING, "")
+                    file.write("%s:\n" % key)
+                    for line in value.split("\n"):
+                        file.write(" %s\n" % line)
+                elif isinstance(value, (list, tuple)):
+                    file.write("%s:\n" % key)
+                    for v in value:
+                        file.write(" %s\n" % v)
+                else:
+                    file.write("%s: %s\n" % (key, value))
+
+            file.write("\n")
+
+    def dump_filename(self, elements, filename):
+        logging.info("Dumping elements to filename: %s", filename)
+
+        with open(filename, "w") as stream:
+            return self.dump_file(elements, stream, filename)
+
+    def load_file(self, file, filename="<stream>"):
+        elements = []
+        for string in self._reader(file):
+            if not string:
+                break
+
+            element = {}
+
+            def _save(field, value, extended):
+                extended = extended.rstrip("\n")
+                if field:
+                    if field in element:
+                        raise Exception("Template %s has a duplicate "
+                            "field '%s' with a new value '%s'." 
+                                % (filename, field, value))
+                    element[field] = value
+                    if extended:
+                        element["%s%s" % (field, EXTENDED_STRING)] = extended
+
+            string = string.strip("\n")
+            field = value = extended = ""
+            for line in string.split("\n"):
+                line.strip()
+                if line.startswith("#"):
+                    continue
+
+                match = re.search(r"^([-_.A-Za-z0-9@]*):\s?(.*)", line)
+                if match:
+                    _save(field, value, extended)
+                    field = match.groups()[0]
+                    value = match.groups()[1].rstrip()
+                    extended = ""
+                    continue
+
+                if re.search(r"^\s\.$", line):
+                    extended += "\n\n"
+                    continue
+
+                match = re.search(r"^\s(\s+.*)", line)
+                if match:
+                    bit = match.groups()[0].rstrip()
+                    if len(extended) and not re.search(r"[\n ]$", extended):
+                        extended += "\n"
+
+                    extended += bit + "\n"
+                    continue
+
+                match = re.search(r"^\s(.*)", line)
+                if match:
+                    bit = match.groups()[0].rstrip()
+                    if len(extended) and not re.search(r"[\n ]$", extended):
+                        if extended.endswith("\\"):
+                            extended = extended[:-1].rstrip() + " "
+                        else:
+                            extended += "\n"
+
+                    extended += bit
+                    continue
+
+                raise Exception("Template %s parse error at: %s" \
+                    % (filename, line))
+
+            _save(field, value, extended)
+
+            elements.append(element)
+
+        return elements
+
+    def load_filename(self, filename):
+        logging.info("Loading elements from filename: %s", filename)
+
+        with open(filename, "r", encoding="utf-8") as stream:
+            return self.load_file(stream, filename)

=== added file 'checkbox-support/checkbox_support/lib/tz.py'
--- checkbox-support/checkbox_support/lib/tz.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/tz.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,55 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+__all__ = [
+    "tzutc",
+    ]
+
+from datetime import (
+    timedelta,
+    tzinfo,
+    )
+
+
+ZERO = timedelta(0)
+
+
+class _tzutc(tzinfo):
+
+    def utcoffset(self, dt):
+        return ZERO
+
+    def dst(self, dt):
+        return ZERO
+
+    def tzname(self, dt):
+        return "UTC"
+
+    def __eq__(self, other):
+        return isinstance(other, tzutc)
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __repr__(self):
+        return "%s()" % self.__class__.__name__
+
+    __reduce__ = object.__reduce__
+
+
+tzutc = _tzutc()

=== added file 'checkbox-support/checkbox_support/lib/usb.py'
--- checkbox-support/checkbox_support/lib/usb.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/lib/usb.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,59 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2008 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+# See http://www.linux-usb.org/usb.ids
+class Usb:
+
+    BASE_CLASS_INTERFACE             = 0
+
+    BASE_CLASS_AUDIO                 = 1
+    CLASS_AUDIO_CONTROL_DEVICE       = 1
+    CLASS_AUDIO_STREAMING            = 2
+    CLASS_AUDIO_MIDI_STREAMING       = 3
+
+    BASE_CLASS_COMMUNICATIONS        = 2
+    CLASS_COMMUNICATIONS_DIRECT_LINE = 1
+    CLASS_COMMUNICATIONS_ABSTRACT    = 2
+    CLASS_COMMUNICATIONS_TELEPHONE   = 3
+
+    BASE_CLASS_PRINTER               = 7
+    CLASS_PRINTER_OTHER              = 1
+
+    BASE_CLASS_STORAGE               = 8
+    CLASS_STORAGE_RBC                = 1
+    CLASS_STORAGE_SFF                = 2
+    CLASS_STORAGE_QIC                = 3
+    CLASS_STORAGE_FLOPPY             = 4
+    CLASS_STORAGE_SFF                = 5
+    CLASS_STORAGE_SCSI               = 6
+
+    BASE_CLASS_HUB                   = 9
+    CLASS_HUB_UNUSED                 = 0
+
+    BASE_CLASS_VIDEO                 = 14
+    CLASS_VIDEO_UNDEFINED            = 0
+    CLASS_VIDEO_CONTROL              = 1
+    CLASS_VIDEO_STREAMING            = 2
+    CLASS_VIDEO_INTERFACE_COLLECTION = 3
+
+    BASE_CLASS_WIRELESS              = 224
+    CLASS_WIRELESS_RADIO_FREQUENCY   = 1
+    CLASS_WIRELESS_USB_ADAPTER       = 2
+    
+    PROTOCOL_BLUETOOTH               = 1

=== added directory 'checkbox-support/checkbox_support/parsers'
=== added file 'checkbox-support/checkbox_support/parsers/__init__.py'
=== added file 'checkbox-support/checkbox_support/parsers/cpuinfo.py'
--- checkbox-support/checkbox_support/parsers/cpuinfo.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/cpuinfo.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,180 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2011 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+
+from os import uname
+
+from checkbox.lib.conversion import string_to_type
+
+
+class CpuinfoParser:
+    """Parser for the /proc/cpuinfo file."""
+
+    def __init__(self, stream, machine=None):
+        self.stream = stream
+        self.machine = machine or uname()[4].lower()
+
+    def getAttributes(self):
+        count = 0
+        attributes = {}
+        cpuinfo = self.stream.read()
+        for block in re.split(r"\n{2,}", cpuinfo):
+            block = block.strip()
+            if not block:
+                continue
+
+            for line in block.split("\n"):
+                if not line:
+                    continue
+                key, value = line.split(":", 1)
+                key, value = key.strip(), value.strip()
+                
+                if key == 'processor':
+                    count += 1
+
+                # Handle bogomips on sparc
+                if key.endswith("Bogo"):
+                    key = "bogomips"
+
+                attributes[key] = value
+
+        if attributes:
+            attributes["count"] = count
+
+        return attributes
+
+    def run(self, result):
+        attributes = self.getAttributes()
+        if not attributes:
+            return
+
+        # Default values
+        machine = self.machine
+        processor = {
+            "platform": machine,
+            "count": 1,
+            "type": machine,
+            "model": machine,
+            "model_number": "",
+            "model_version": "",
+            "model_revision": "",
+            "cache": 0,
+            "bogomips": 0,
+            "speed": -1,
+            "other": ""}
+
+        # Conversion table
+        platform_to_conversion = {
+            ("i386", "i486", "i586", "i686", "x86_64",): {
+                "type": "vendor_id",
+                "model": "model name",
+                "model_number": "cpu family",
+                "model_version": "model",
+                "model_revision": "stepping",
+                "cache": "cache size",
+                "other": "flags",
+                "speed": "cpu MHz"},
+            ("alpha", "alphaev6",): {
+                "count": "cpus detected",
+                "type": "cpu",
+                "model": "cpu model",
+                "model_number": "cpu variation",
+                "model_version": ("system type", "system variation",),
+                "model_revision": "cpu revision",
+                "other": "platform string",
+                "speed": "cycle frequency [Hz]"},
+            ("armv7l",): {
+                "type": "Hardware",
+                "model": "Processor",
+                "model_number": "CPU variant",
+                "model_version": "CPU architecture",
+                "model_revision": "CPU revision",
+                "other": "Features",
+                "bogomips": "BogoMIPS"},
+            ("ia64",): {
+                "type": "vendor",
+                "model": "family",
+                "model_version": "archrev",
+                "model_revision": "revision",
+                "other": "features",
+                "speed": "cpu mhz"},
+            ("ppc64", "ppc",): {
+                "type": "platform",
+                "model": "cpu",
+                "model_version": "revision",
+                "speed": "clock"},
+            ("sparc64", "sparc",): {
+                "count": "ncpus probed",
+                "type": "type",
+                "model": "cpu",
+                "model_version": "type",
+                "speed": "bogomips"}}
+
+        for key in processor:
+            if attributes.get(key):
+                processor[key] = attributes.get(key)
+
+        for platform, conversion in platform_to_conversion.items():
+            if machine in platform:
+                for pkey, ckey in conversion.items():
+                    if isinstance(ckey, (list, tuple)):
+                        processor[pkey] = "/".join([attributes[k]
+                                                    for k in ckey])
+                    elif ckey in attributes:
+                        processor[pkey] = attributes[ckey]
+
+        # Adjust platform
+        if machine[0] == "i" and machine[-2:] == "86":
+            processor["platform"] = "i386"
+        elif machine[:5] == "alpha":
+            processor["platform"] = "alpha"
+
+        # Adjust cache
+        if processor["cache"]:
+            processor["cache"] = string_to_type(processor["cache"])
+
+        # Adjust speed
+        try:
+            if machine[:5] == "alpha":
+                speed = processor["speed"].split()[0]
+                processor["speed"] = int(round(float(speed))) / 1000000
+            elif machine[:5] == "sparc":
+                speed = processor["speed"]
+                processor["speed"] = int(round(float(speed))) / 2
+            elif machine[:3] == "ppc":
+                # String is appended with "mhz"
+                speed = processor["speed"][:-3]
+        except ValueError:
+            processor["speed"] = -1
+
+        # Make sure speed and bogomips are integers    
+        processor["speed"] = int(round(float(processor["speed"])) - 1)
+        processor["bogomips"] = int(round(float(processor["bogomips"])))
+
+        # Adjust count
+        try:
+            processor["count"] = int(processor["count"])
+        except ValueError:
+            processor["count"] = 1
+        else:
+            # There is at least one processor
+            if processor["count"] == 0:
+                processor["count"] = 1
+
+        result.setProcessor(processor)

=== added file 'checkbox-support/checkbox_support/parsers/dmidecode.py'
--- checkbox-support/checkbox_support/parsers/dmidecode.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/dmidecode.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,126 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2011 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+
+from string import (
+    hexdigits,
+    ascii_uppercase,
+    )
+
+from checkbox.lib.dmi import (
+    Dmi,
+    DmiDevice,
+    )
+
+
+HANDLE_RE = re.compile(
+    r"^Handle (?P<handle>0x[%s]{4}), "
+    r"DMI type (?P<type>\d+), "
+    r"(?P<size>\d+) bytes$"
+    % hexdigits)
+KEY_VALUE_RE = re.compile(
+    r"^\t(?P<key>[%s].+):( (?P<value>.+))?$"
+    % ascii_uppercase)
+
+
+class DmidecodeParser:
+    """Parser for the dmidecode command."""
+
+    _key_map = {
+        "ID": "serial",
+        "Manufacturer": "vendor",
+        "Product Name": "name",
+        "Serial Number": "serial",
+        "Type": "type",
+        "Vendor": "vendor",
+        "Version": "version",
+        "Size": "size",
+        "Form Factor": "form",
+        }
+
+    def __init__(self, stream):
+        self.stream = stream
+
+    def _parseKey(self, key):
+        return self._key_map.get(key)
+
+    def _parseValue(self, value):
+        if value is not None:
+            value = value.strip()
+            if not value:
+                value = None
+
+        return value
+
+    def run(self, result):
+        output = self.stream.read()
+        for record in re.split(r"\n{2,}", output):
+            record = record.strip()
+            # Skip empty records
+            if not record:
+                continue
+
+            # Skip header record
+            lines = record.split("\n")
+            line = lines.pop(0)
+            if line.startswith("#"):
+                continue
+
+            # Skip records with an unsupported handle
+            match = HANDLE_RE.match(line)
+            if not match:
+                continue
+
+            # Skip records that are empty or inactive
+            if not lines or lines.pop(0) == "Inactive":
+                continue
+
+            # Skip disabled entries and end-of-table marker
+            type_index = int(match.group("type"))
+            if type_index >= len(Dmi.type_names):
+                continue
+
+            category = Dmi.type_names[type_index]
+            category = category.upper().split(" ")[-1]
+            if category not in (
+                "BOARD", "BIOS", "CHASSIS", "DEVICE", "PROCESSOR", "SYSTEM"):
+                continue
+
+            # Parse attributes
+            attributes = {}
+
+            for line in lines:
+                # Skip lines with an unsupported key/value pair
+                match = KEY_VALUE_RE.match(line)
+                if not match:
+                    continue
+
+                # Skip lines with an unsupported key
+                key = self._parseKey(match.group("key"))
+                if not key:
+                    continue
+
+                key = "%s_%s" % (category.lower(), key)
+                value = self._parseValue(match.group("value"))
+                attributes[key] = value
+
+            device = DmiDevice(attributes, category)
+            result.addDmiDevice(device)
+
+        return result

=== added file 'checkbox-support/checkbox_support/parsers/efi.py'
--- checkbox-support/checkbox_support/parsers/efi.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/efi.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,52 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2011 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+
+
+class EfiDevice:
+
+    path = "/sys/class/dmi/id/bios_version"
+    category = "EFI"
+
+    def __init__(self, product, vendor=None):
+        self.product = product
+        self.vendor = vendor
+
+
+class EfiParser:
+    """Parser for EFI information."""
+
+    def __init__(self, stream):
+        self.stream = stream
+
+    def run(self, result):
+        vendor_product_pattern = re.compile(
+            r"^(?P<vendor>.*)\s+by\s+(?P<product>.*)$")
+
+        for line in self.stream.readlines():
+            line = line.strip()
+            match = vendor_product_pattern.match(line)
+            if match:
+                product = match.group("product")
+                vendor = match.group("vendor")
+                device = EfiDevice(product, vendor)
+            else:
+                device = EfiDevice(line)
+
+            result.setEfiDevice(device)

=== added file 'checkbox-support/checkbox_support/parsers/lshwjson.py'
--- checkbox-support/checkbox_support/parsers/lshwjson.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/lshwjson.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,23 @@
+import sys
+import json
+
+class LshwJsonParser:
+
+    def __init__(self, stream_or_string):
+        self.stream_or_string = stream_or_string
+
+    def _parse_lshw(self, lshw, result):
+        if 'children' in lshw.keys():
+            for child in lshw['children']:
+                self._parse_lshw(child, result)
+            del lshw['children']
+
+        result.addHardware(lshw)
+
+    def run(self, result):
+        try:
+            lshw = json.loads(self.stream_or_string)
+        except:
+            print('not valid json')
+
+        self._parse_lshw(lshw, result)

=== added file 'checkbox-support/checkbox_support/parsers/meminfo.py'
--- checkbox-support/checkbox_support/parsers/meminfo.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/meminfo.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,46 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2011 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+
+
+class MeminfoParser:
+    """Parser for the /proc/meminfo file."""
+
+    def __init__(self, stream):
+        self.stream = stream
+
+    def run(self, result):
+        key_value_pattern = re.compile(r"(?P<key>.*):\s+(?P<value>.*)")
+        meminfo_map = {
+            "MemTotal": "total",
+            "SwapTotal": "swap"}
+
+        meminfo = {}
+        for line in self.stream.readlines():
+            line = line.strip()
+            match = key_value_pattern.match(line)
+            if match:
+                key = match.group("key")
+                if key in meminfo_map:
+                    key = meminfo_map[key]
+                    value = match.group("value")
+                    (integer, factor) = value.split()
+                    meminfo[key] = int(integer) * 1024
+
+        result.setMemory(meminfo)

=== added file 'checkbox-support/checkbox_support/parsers/modinfo.py'
--- checkbox-support/checkbox_support/parsers/modinfo.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/modinfo.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,89 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2011 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+
+class ModinfoParser:
+    """
+    Parser for modinfo information.
+    This will take the stdout for modinfo output and return a dict populated
+    with each field.
+
+    Basic usage in your script:
+    try:
+        output = subprocess.check_output('/sbin/modinfo e1000e',
+                                         stderr=subprocess.STDOUT,
+                                         universal_newlines=True)
+    except CalledProcessError as err:
+        print("Error while running modinfo")
+        print(err.output)
+        return err.returncode
+
+    parser = ModinfoParser(output)
+    all_fields = parser.get_all()
+    one_field = parser.get_field(field)
+    """
+
+    def __init__(self, stream):
+        self._modinfo = {'alias': [],
+                         'author': '',
+                         'depends': [],
+                         'description': '',
+                         'filename': '',
+                         'firmware': [],
+                         'intree': '',
+                         'license': '',
+                         'parm': [],
+                         'srcversion': '',
+                         'vermagic': '',
+                         'version': ''}
+        self._get_info(stream)
+
+    def _get_info(self, stream):
+        for line in stream.splitlines():
+            # At this point, stream should be the stdout from the modinfo
+            # command, in a list.
+            try:
+                key, data = line.split(':', 1)
+            except ValueError:
+                # Most likely this will be caused by a blank line in the
+                # stream, so we just ignore it and move on.
+                continue                
+            else:
+                key = key.strip()
+                data = data.strip()
+                # First, we need to handle alias, parm, firmware, and depends
+                # because there can be multiple lines of output for these.
+                if key in ('alias', 'depend', 'firmware', 'parm',):
+                    self._modinfo[key].append(data)
+                # Now handle unknown keys
+                elif key not in self._modinfo.keys():
+                    self._modinfo[key] = ("WARNING: Unknown Key %s providing "
+                                     "data: %s") % (key, data)
+                # And finally known keys
+                else:
+                    self._modinfo[key] = data
+
+    def get_all(self):
+        return self._modinfo
+
+    def get_field(self, field):
+        if field not in self._modinfo.keys():
+            raise Exception("Key not found: %s" % field)
+        else:
+            return self._modinfo[field]

=== added file 'checkbox-support/checkbox_support/parsers/pactl.py'
--- checkbox-support/checkbox_support/parsers/pactl.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/pactl.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,543 @@
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+:mod:`checkbox.parsers.pactl` -- `pactl list` parser
+====================================================
+
+Parser for the output of ``pactl list`` syntax.
+
+The abstract syntax tree of 'pactl list' is as follows::
+
+    Document: Record + ('\n' + Record)*
+
+    Record: RECORD-NAME ':' Attribute+
+
+    Attribute: ATTRIBUTE-NAME ':' AttributeValue
+
+    AttributeValue: SIMPLE-VALUE '\n'
+                    | PropertyValue
+                    | VOLUME-VALUE
+                    | BASE-VOLUME-VALUE
+                    | PORT+
+                    | PORT-WITH-PROFILE+
+
+    PropertyValue: PROPERTY-NAME '=' PROPERTY-VALUE
+
+    (other all-upsercase values are not specified in detail)
+
+Some parts of the output  are always localized while others depend on the
+locale of the current user. This is caused by the fact that ``pactl`` talks to
+pulse audio server over DBus. Some of the data obtained from pulse that was is
+localized and it is difficult to influence. This should be of no problem for
+the parser but actual usage of the data can be more difficult.
+"""
+
+from collections import OrderedDict
+from inspect import isroutine
+
+from checkbox.parsers import pyparsing as p
+
+
+# Enable packrat paring.
+#
+# This reduces the complexity of the parser
+# from O(2**N) to O(N) at the cost of memory O(N) vs O(1).
+p.ParserElement.enablePackrat()
+
+# XXX: Hack, changes global stuff
+#
+# This makes pyparsing not so ignorant to whitespace. Normally pyparsing is
+# happily treating newlines, tabs, spaces and carriage returns as irrelevant
+# spacers between tokens. Because pactl syntax is so whitespace-sensitive this
+# is globally turned off. A proper solution would apply this on a
+# per-ParserElement level
+p.ParserElement.DEFAULT_WHITE_CHARS = " "
+
+
+class NodeMeta(type):
+    """
+    Metaclass for all Node types.
+
+    Helps to setup the `Syntax` attribute using the special `__syntax__`
+    attribute. It also calls from_tokens() with the appropriate class.
+    """
+
+    def __new__(mcls, name, bases, ns):
+        cls = type.__new__(mcls, name, bases, ns)
+        if hasattr(cls, '__syntax__'):
+            cls.Syntax = (
+                cls.__syntax__
+            ).setParseAction(
+                cls.from_tokens
+            ).parseWithTabs()
+        return cls
+
+
+class Node(metaclass=NodeMeta):
+    """
+    Base class for things parsed by pyparsing.
+
+    Defines sensible __repr__(), __init__() and from_tokens(). That
+    last class method uses __fragments__ to pick things from pyparsing
+    ParseResults and assign them to attributes of the Node instance.
+
+    This serves as a buffer between pyparsing and external code, so that
+    anything we do to the syntax is irrelevant as long as the tree of
+    Nodes remains the same.
+    """
+
+    __fragments__ = {}
+
+    def __init__(self, **kwargs):
+        for attr, value in kwargs.items():
+            setattr(self, attr, value)
+
+    def __repr__(self):
+        return "{}({})".format(
+            type(self).__name__, ", ".join([
+                "{}={!r}".format(attr, getattr(self, attr))
+                for attr in self.__fragments__]))
+
+    @classmethod
+    def from_tokens(cls, tokens):
+        """
+        Create a node from tokens that were matched from __syntax__
+        """
+        data = {
+            attr: mapper(tokens) if isroutine(mapper) else tokens[mapper]
+            for attr, mapper in cls.__fragments__.items()
+        }
+        return cls(**data)
+
+
+class Property(Node):
+    """
+    A key=value pair.
+
+    A list of properties is a possible syntax for Attribute value.
+    """
+
+    __fragments__ = {
+        'name': 'property-name',
+        'value': 'property-value'
+    }
+
+    __syntax__ = (
+        p.Word(p.alphanums + "-_.").setResultsName("property-name")
+        + p.Suppress('=')
+        + p.QuotedString('"').setResultsName("property-value")
+    ).setResultsName('property')
+
+
+class Profile(Node):
+    """
+    Description of a pulseaudio profile.
+    """
+
+    __fragments__ = {
+        'name': 'profile-name',
+        'label': 'profile-label',
+        'sink_cnt': 'profile-sink-count',
+        'source_cnt': 'profile-source-count',
+        'priority': 'profile-priority',
+    }
+
+    __syntax__ = (
+        p.Word(p.alphanums + "+-:").setParseAction(
+            lambda t: t[0].rstrip(':')
+        ).setResultsName("profile-name")
+        + p.delimitedList(
+            p.Literal("(HDMI)") | p.Literal("(IEC958)") | p.Regex('[^ (\n]+'),
+            ' ', combine=True
+        ).setResultsName('profile-label')
+        + p.Suppress('(')
+        + p.Keyword('sinks').suppress()
+        + p.Suppress(':')
+        + p.Word(p.nums).setParseAction(
+            lambda t: int(t[0])
+        ).setResultsName('profile-sink-count')
+        + p.Suppress(',')
+        + p.Keyword('sources').suppress()
+        + p.Suppress(':')
+        + p.Word(p.nums).setParseAction(
+            lambda t: int(t[0])
+        ).setResultsName('profile-source-count')
+        + p.Suppress(',')
+        + p.Keyword('priority').suppress()
+        + p.MatchFirst([
+            p.Suppress('.'),
+            # http://cgit.freedesktop.org/pulseaudio/pulseaudio/commit/src/utils/pactl.c?id=83c3cf0a65fb05900f81bd2dbb38e6956eb23935
+            p.Suppress(':'),
+        ])
+        + p.Word(p.nums).setParseAction(
+            lambda t: int(t[0])
+        ).setResultsName('profile-priority')
+        + p.Suppress(')')
+    ).setResultsName("profile")
+
+
+class Port(Node):
+    """
+    Description of a port on a sink
+    """
+
+    __fragments__ = {
+        'name': 'port-name',
+        'label': 'port-label',
+        'priority': 'port-priority',
+        'availability': 'port-availability'
+    }
+
+    __syntax__ = (
+        p.Word(p.alphanums + "-;").setResultsName('port-name')
+        + p.Suppress(':')
+        # This part was very tricky to write. The label is basically
+        # arbitrary localized Unicode text.  We want to grab all of it in
+        # one go but without consuming the upcoming '(' character or the
+        # space that comes immediately before.
+        #
+        # The syntax here combines a sequence of words, as defined by
+        # anything other than a space and '(', delimited by a single
+        # whitespace.
+        + p.delimitedList(
+            p.Regex('[^ (\n]+'), ' ', combine=True
+        ).setResultsName('port-label')
+        + p.Suppress('(')
+        + p.Keyword('priority').suppress()
+        + p.Suppress(':')
+        + p.Word(p.nums).setParseAction(
+            lambda t: int(t[0])
+        ).setResultsName('port-priority')
+        + p.MatchFirst([
+            p.Suppress(',') + p.Literal('not available'),
+            p.Suppress(',') + p.Literal('available'),
+            p.Empty().setParseAction(lambda t: '')
+        ]).setResultsName('port-availability')
+        + p.Suppress(')')
+    ).setResultsName("port")
+
+
+# =================
+# Shared Attributes
+# =================
+
+PropertyAttributeValue = (
+    p.Group(
+        p.OneOrMore(
+            p.LineStart().suppress()
+            + p.Optional(p.White('\t')).suppress()
+            + p.Optional(Property.Syntax)
+            + p.LineEnd().suppress()
+        )
+    ).setResultsName("attribute-value"))
+
+
+class PortWithProfile(Node):
+    """
+    Variant of :class:`Port` that is used by "card" records inside
+    the "Ports" property. It differs from the normal port syntax by having
+    different entries inside the last section. Availability is not listed
+    here, only priority. Priority does not have a colon before the actual
+    number. This port is followed by profile assignment.
+    """
+    __fragments__ = {
+        'name': 'port-name',
+        'label': 'port-label',
+        'priority': 'port-priority',
+        'latency_offset': 'port-latency-offset',
+        'availability': 'port-availability',
+        'properties': lambda t: t['port-properties'].asList(),
+        'profile_list': lambda t: t['port-profile-list'].asList(),
+    }
+
+    __syntax__ = (
+        p.Word(p.alphanums + "-;").setResultsName('port-name')
+        + p.Suppress(':')
+        # This part was very tricky to write. The label is basically arbitrary
+        # localized Unicode text. We want to grab all of it in one go but
+        # without consuming the upcoming and latest '(' character or the space
+        # that comes immediately before.
+        #
+        # The syntax here combines a sequence of words, as defined by anything
+        # other than a space and '(', delimited by a single whitespace.
+        + p.Combine(
+            p.OneOrMore(
+                ~p.FollowedBy(
+                    p.Regex('\(.+?\)')
+                    + p.LineEnd()
+                )
+                + p.Regex('[^ \n]+')
+                + p.White().suppress()
+            ),
+            ' '
+        ).setResultsName('port-label')
+        + p.Suppress('(')
+        + p.Keyword('priority').suppress()
+        + p.Optional(
+            p.Suppress(':')
+        )
+        + p.Word(p.nums).setParseAction(
+            lambda t: int(t[0])
+        ).setResultsName('port-priority')
+        + p.Optional(
+            p.MatchFirst([
+                p.Suppress(',') + p.Keyword('latency offset:').suppress()
+                + p.Word(p.nums).setParseAction(lambda t: int(t[0]))
+                + p.Literal("usec").suppress(),
+                p.Empty().setParseAction(lambda t: '')
+            ]).setResultsName('port-latency-offset')
+        )
+        + p.Optional(
+            p.MatchFirst([
+                p.Suppress(',') + p.Literal('not available'),
+                p.Suppress(',') + p.Literal('available'),
+                p.Empty().setParseAction(lambda t: '')
+            ]).setResultsName('port-availability')
+        )
+        + p.Suppress(')')
+        + p.LineEnd().suppress()
+        + p.Optional(
+            p.MatchFirst([
+                p.LineStart().suppress()
+                + p.NotAny(p.White(' '))
+                + p.White('\t').suppress()
+                + p.Keyword('Properties:').suppress()
+                + p.LineEnd().suppress()
+                + PropertyAttributeValue,
+                p.Empty().setParseAction(lambda t: [])
+            ]).setResultsName('port-properties')
+        )
+        + p.White('\t', max=3).suppress()
+        + p.Literal("Part of profile(s)").suppress()
+        + p.Suppress(":")
+        + p.delimitedList(
+            p.Word(p.alphanums + "+-:"), ", "
+        ).setResultsName("port-profile-list")
+    ).setResultsName("port")
+
+
+# =========================
+# Non-collection attributes
+# =========================
+
+AttributeName = p.Regex("[a-zA-Z][^:\n]+").setResultsName("attribute-name")
+
+
+VolumeAttributeValue = (
+    p.Combine(
+        p.Or([
+            p.Literal("(invalid)"),
+            p.Regex("([0-9]+: +[0-9]+% ?)+")
+        ])
+        + p.LineEnd()
+        + p.Optional(p.White('\t').suppress())
+        + p.Or([
+            p.Literal("(invalid)"),
+            p.Regex("([0-9]+: -?[0-9]+\.[0-9]+ dB ?)+")
+        ])
+        + p.LineEnd()
+        + p.Optional(p.White('\t').suppress())
+        + p.Regex("balance [0-9]+\.[0-9]+")
+        + p.LineEnd(),
+        adjacent=False
+    ).setResultsName("attribute-value")
+)
+
+
+BaseVolumeAttributeValue = (
+    p.Combine(
+        p.Regex("[0-9]+%")
+        + p.LineEnd()
+        + p.Optional(p.White('\t').suppress())
+        + p.Regex("-?[0-9]+\.[0-9]+ dB")
+        + p.LineEnd(),
+        adjacent=False
+    ).setResultsName("attribute-value")
+)
+
+
+SimpleAttributeValue = (
+    p.Regex("[^\n]*").setResultsName("attribute-value")
+    + p.LineEnd().suppress())
+
+# simple values
+GenericSimpleAttributeValue = p.MatchFirst([
+    VolumeAttributeValue,
+    BaseVolumeAttributeValue,
+    SimpleAttributeValue,
+])
+
+
+class GenericSimpleAttribute(Node):
+
+    __fragments__ = {
+        'name': 'attribute-name',
+        'value': 'attribute-value',
+    }
+
+    __syntax__ = (
+        p.LineStart().suppress()
+        + p.NotAny(p.White(' '))
+        + p.Optional(p.White('\t')).suppress()
+        + AttributeName
+        + p.Literal(':').suppress()
+        + GenericSimpleAttributeValue
+    ).setResultsName("attribute")
+
+
+# =====================
+# Collection Attributes
+# =====================
+
+PortsAttributeValue = (
+    p.Group(
+        p.OneOrMore(
+            p.LineStart().suppress()
+            + p.Optional(p.White('\t')).suppress()
+            + Port.Syntax
+            + p.LineEnd().suppress())
+    ).setResultsName("attribute-value"))
+
+PortsWithProfilesAttributeValue = (
+    p.Group(
+        p.OneOrMore(
+            p.LineStart().suppress()
+            + p.Optional(p.White('\t')).suppress()
+            + PortWithProfile.Syntax
+            + p.LineEnd().suppress())
+    ).setResultsName("attribute-value"))
+
+FormatsAttributeValue = (
+    p.Group(
+        p.OneOrMore(
+            p.LineStart().suppress()
+            + p.Optional(p.White('\t')).suppress()
+            + p.Word(p.alphas)
+            + p.LineEnd().suppress())
+    ).setResultsName("attribute-value"))
+
+ProfilesAttributeValue = (
+    p.Group(
+        p.OneOrMore(
+            p.LineStart().suppress()
+            + p.Optional(p.White('\t')).suppress()
+            + Profile.Syntax
+            + p.LineEnd().suppress())
+    ).setResultsName("attribute-value"))
+
+
+GenericListAttributeValue = p.MatchFirst([
+    PortsAttributeValue,
+    PropertyAttributeValue,
+    PortsWithProfilesAttributeValue,
+    ProfilesAttributeValue,
+    FormatsAttributeValue,
+])
+
+
+class GenericListAttribute(Node):
+
+    __fragments__ = {
+        'name': 'attribute-name',
+        'value': lambda t: t['attribute-value'].asList()
+    }
+
+    __syntax__ = (
+        p.LineStart().suppress()
+        + p.NotAny(p.White(' '))
+        + p.Optional(p.White('\t')).suppress()
+        + AttributeName
+        + p.Literal(':').suppress()
+        + p.LineEnd().suppress()
+        + GenericListAttributeValue
+    ).setResultsName("attribute")
+
+
+class Record(Node):
+    """
+    Single standalone entry of `pactl list`.
+
+    The record is composed of a name and a list of attributes.  Pulseaudio
+    exposes objects such as cards, sinks and sources as separate records.
+
+    Each attribute may be of a different type. Some attributes are simple
+    values while others have finer structure, including lits and even
+    additional recursive attributes.
+    """
+
+    __fragments__ = {
+        'name': 'record-name',
+        'attribute_list': lambda t: t['record-attributes'].asList(),
+        'attribute_map': lambda t: OrderedDict(
+            (attr.name, attr)
+            for attr in t['record-attributes'].asList()),
+    }
+
+    __syntax__ = (
+        p.LineStart()
+        + p.NotAny(p.White(' \t'))
+        + p.Regex("[A-Z][a-zA-Z ]+ #[0-9]+").setResultsName("record-name")
+        + p.LineEnd().suppress()
+        + p.OneOrMore(
+            p.Or([
+                GenericListAttribute.Syntax,
+                GenericSimpleAttribute.Syntax,
+            ])
+        ).setResultsName("record-attributes")
+    ).setResultsName("record")
+
+    def as_json(self):
+        return {
+            'name': self.name,
+            'attribute_list': self.attribute_list,
+        }
+
+    def __repr__(self):
+        # Custom __repr__ that skips attribute_map
+        return "{}({})".format(
+            type(self).__name__, ", ".join([
+                "{}={!r}".format(attr, getattr(self, attr))
+                for attr in ['name', 'attribute_list']]))
+
+
+class Document(Node):
+    """
+    Encompasses whole output of `pactl list`
+    The document is composed of a list of :class:`Record` objects
+    """
+
+    __fragments__ = {
+        'record_list': lambda t: t['record-list'].asList(),
+    }
+
+    __syntax__ = (
+        p.OneOrMore(
+            Record.Syntax + p.Optional("\n").suppress()
+        ).setResultsName("record-list")
+    ).parseWithTabs()
+
+
+def parse_pactl_output(output):
+    """
+    Parse output of `LANG=C pactl list`
+
+    :returns: :class:`Document` object that corresponds to the parsed input
+    """
+    return Document.Syntax.parseString(output, parseAll=True)[0]

=== added directory 'checkbox-support/checkbox_support/parsers/tests'
=== added file 'checkbox-support/checkbox_support/parsers/tests/__init__.py'
=== added directory 'checkbox-support/checkbox_support/parsers/tests/fixtures'
=== added file 'checkbox-support/checkbox_support/parsers/tests/fixtures/xinput_quantal.txt'
--- checkbox-support/checkbox_support/parsers/tests/fixtures/xinput_quantal.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/fixtures/xinput_quantal.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,143 @@
+⎡ Virtual core pointer id=2 [master pointer (3)]
+Reporting 4 classes:
+Class originated from: 10. Type: XIButtonClass
+Buttons supported: 10
+Button labels: "Button Unknown" "Button Unknown" "Button Unknown" 
+"Button Wheel Up" "Button Wheel Down" "Button Horiz Wheel Left" "Button 
+Horiz Wheel Right" None None None
+Button state:
+Class originated from: 10. Type: XIValuatorClass
+Detail for Valuator 0:
+Label: Abs MT Position X
+Range: 0.000000 - 1919.000000
+Resolution: 0 units/m
+Mode: absolute
+Current value: 1664.000000
+Class originated from: 10. Type: XIValuatorClass
+Detail for Valuator 1:
+Label: Abs MT Position Y
+Range: 0.000000 - 1079.000000
+Resolution: 0 units/m
+Mode: absolute
+Current value: 932.000000
+Class originated from: 0. Type: XITouchClass
+Touch mode: direct
+Max number of touches: 17
+
+⎜ ↳ Virtual core XTEST pointer id=4 [slave pointer (2)]
+Reporting 3 classes:
+Class originated from: 4. Type: XIButtonClass
+Buttons supported: 10
+Button labels: "Button Left" "Button Middle" "Button Right" "Button 
+Wheel Up" "Button Wheel Down" "Button Horiz Wheel Left" "Button Horiz 
+Wheel Right" None None None
+Button state:
+Class originated from: 4. Type: XIValuatorClass
+Detail for Valuator 0:
+Label: Rel X
+Range: -1.000000 - -1.000000
+Resolution: 0 units/m
+Mode: relative
+Class originated from: 4. Type: XIValuatorClass
+Detail for Valuator 1:
+Label: Rel Y
+Range: -1.000000 - -1.000000
+Resolution: 0 units/m
+Mode: relative
+
+⎜ ↳ Quanta OpticalTouchScreen id=10 [slave pointer (2)]
+Reporting 4 classes:
+Class originated from: 10. Type: XIButtonClass
+Buttons supported: 5
+Button labels: "Button Unknown" "Button Unknown" "Button Unknown" 
+"Button Wheel Up" "Button Wheel Down"
+Button state:
+Class originated from: 10. Type: XIValuatorClass
+Detail for Valuator 0:
+Label: Abs MT Position X
+Range: 0.000000 - 1919.000000
+Resolution: 0 units/m
+Mode: absolute
+Current value: 1664.000000
+Class originated from: 10. Type: XIValuatorClass
+Detail for Valuator 1:
+Label: Abs MT Position Y
+Range: 0.000000 - 1079.000000
+Resolution: 0 units/m
+Mode: absolute
+Current value: 932.000000
+Class originated from: 0. Type: XITouchClass
+Touch mode: direct
+Max number of touches: 9
+
+⎜ ↳ MCE IR Keyboard/Mouse (nuvoton-cir) id=12 [slave pointer (2)]
+Reporting 4 classes:
+Class originated from: 12. Type: XIButtonClass
+Buttons supported: 5
+Button labels: "Button Left" "Button Unknown" "Button Right" "Button 
+Wheel Up" "Button Wheel Down"
+Button state:
+Class originated from: 12. Type: XIKeyClass
+Keycodes supported: 248
+Class originated from: 12. Type: XIValuatorClass
+Detail for Valuator 0:
+Label: Rel X
+Range: -1.000000 - -1.000000
+Resolution: 1 units/m
+Mode: relative
+Class originated from: 12. Type: XIValuatorClass
+Detail for Valuator 1:
+Label: Rel Y
+Range: -1.000000 - -1.000000
+Resolution: 1 units/m
+Mode: relative
+
+⎣ Virtual core keyboard id=3 [master keyboard (2)]
+Reporting 1 classes:
+Class originated from: 14. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Virtual core XTEST keyboard id=5 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 5. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Power Button id=6 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 6. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Power Button id=7 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 7. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Laptop_Integrated_Webcam_2M id=8 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 8. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ HID 413c:8161 id=9 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 9. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Nuvoton w836x7hg Infrared Remote Transceiver id=11 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 11. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Dell AIO WMI hotkeys id=13 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 13. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Chicony USB Keyboard id=14 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 14. Type: XIKeyClass
+Keycodes supported: 248
+
+↳ Chicony USB Keyboard id=15 [slave keyboard (3)]
+Reporting 1 classes:
+Class originated from: 15. Type: XIKeyClass
+Keycodes supported: 248

=== added file 'checkbox-support/checkbox_support/parsers/tests/fixtures/xinput_toshiba.txt'
--- checkbox-support/checkbox_support/parsers/tests/fixtures/xinput_toshiba.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/fixtures/xinput_toshiba.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,166 @@
+⎡ Virtual core pointer                    	id=2	[master pointer  (3)]
+	Reporting 8 classes:
+		Class originated from: 12. Type: XIButtonClass
+		Buttons supported: 12
+		Button labels: "Button Left" "Button Middle" "Button Right" "Button Wheel Up" "Button Wheel Down" "Button Horiz Wheel Left" "Button Horiz Wheel Right" None None None None None
+		Button state:
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 0:
+		  Label: Rel X
+		  Range: 0.000000 - 2000.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 1:
+		  Label: Rel Y
+		  Range: 0.000000 - 1400.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 2:
+		  Label: Rel Horiz Scroll
+		  Range: 0.000000 - -1.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 3:
+		  Label: Rel Vert Scroll
+		  Range: 0.000000 - -1.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIScrollClass
+		Scroll info for Valuator 2
+		  type: 2 (horizontal)
+		  increment: 48.000000
+		  flags: 0x0
+		Class originated from: 12. Type: XIScrollClass
+		Scroll info for Valuator 3
+		  type: 1 (vertical)
+		  increment: 48.000000
+		  flags: 0x0
+		Class originated from: 0. Type: XITouchClass
+		Touch mode: dependent
+		Max number of touches: 2
+
+⎜   ↳ Virtual core XTEST pointer              	id=4	[slave  pointer  (2)]
+	Reporting 3 classes:
+		Class originated from: 4. Type: XIButtonClass
+		Buttons supported: 10
+		Button labels: "Button Left" "Button Middle" "Button Right" "Button Wheel Up" "Button Wheel Down" "Button Horiz Wheel Left" "Button Horiz Wheel Right" None None None
+		Button state:
+		Class originated from: 4. Type: XIValuatorClass
+		Detail for Valuator 0:
+		  Label: Rel X
+		  Range: -1.000000 - -1.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 4. Type: XIValuatorClass
+		Detail for Valuator 1:
+		  Label: Rel Y
+		  Range: -1.000000 - -1.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+
+⎜   ↳ DualPoint Stick                         	id=11	[slave  pointer  (2)]
+	Reporting 3 classes:
+		Class originated from: 11. Type: XIButtonClass
+		Buttons supported: 7
+		Button labels: "Button Left" "Button Middle" "Button Right" "Button Wheel Up" "Button Wheel Down" "Button Horiz Wheel Left" "Button Horiz Wheel Right"
+		Button state:
+		Class originated from: 11. Type: XIValuatorClass
+		Detail for Valuator 0:
+		  Label: Rel X
+		  Range: -1.000000 - -1.000000
+		  Resolution: 1 units/m
+		  Mode: relative
+		Class originated from: 11. Type: XIValuatorClass
+		Detail for Valuator 1:
+		  Label: Rel Y
+		  Range: -1.000000 - -1.000000
+		  Resolution: 1 units/m
+		  Mode: relative
+
+⎜   ↳ AlpsPS/2 ALPS DualPoint TouchPad        	id=12	[slave  pointer  (2)]
+	Reporting 8 classes:
+		Class originated from: 12. Type: XIButtonClass
+		Buttons supported: 12
+		Button labels: "Button Left" "Button Middle" "Button Right" "Button Wheel Up" "Button Wheel Down" "Button Horiz Wheel Left" "Button Horiz Wheel Right" None None None None None
+		Button state:
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 0:
+		  Label: Rel X
+		  Range: 0.000000 - 2000.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 1:
+		  Label: Rel Y
+		  Range: 0.000000 - 1400.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 2:
+		  Label: Rel Horiz Scroll
+		  Range: 0.000000 - -1.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIValuatorClass
+		Detail for Valuator 3:
+		  Label: Rel Vert Scroll
+		  Range: 0.000000 - -1.000000
+		  Resolution: 0 units/m
+		  Mode: relative
+		Class originated from: 12. Type: XIScrollClass
+		Scroll info for Valuator 2
+		  type: 2 (horizontal)
+		  increment: 48.000000
+		  flags: 0x0
+		Class originated from: 12. Type: XIScrollClass
+		Scroll info for Valuator 3
+		  type: 1 (vertical)
+		  increment: 48.000000
+		  flags: 0x0
+		Class originated from: 0. Type: XITouchClass
+		Touch mode: dependent
+		Max number of touches: 2
+
+⎣ Virtual core keyboard                   	id=3	[master keyboard (2)]
+	Reporting 1 classes:
+		Class originated from: 10. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ Virtual core XTEST keyboard             	id=5	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 5. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ Power Button                            	id=6	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 6. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ Video Bus                               	id=7	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 7. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ Power Button                            	id=8	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 8. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ CNF9055                                 	id=9	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 9. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ AT Translated Set 2 keyboard            	id=10	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 10. Type: XIKeyClass
+		Keycodes supported: 248
+
+    ↳ Toshiba input device                    	id=13	[slave  keyboard (3)]
+	Reporting 1 classes:
+		Class originated from: 13. Type: XIKeyClass
+		Keycodes supported: 248
+

=== added directory 'checkbox-support/checkbox_support/parsers/tests/pactl_data'
=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-0.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-0.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-0.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,33 @@
+Card #0
+	Name: alsa_card.pci-0000_02_00.1
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "2"
+		alsa.card_name = "HDA NVidia"
+		alsa.long_card_name = "HDA NVidia at 0xfbdfc000 irq 34"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:02:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:03.0/0000:02:00.1/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "10de"
+		device.vendor.name = "NVIDIA Corporation"
+		device.string = "2"
+		device.description = "HDA NVidia"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:hdmi-stereo: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5400)
+		output:hdmi-surround: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 300)
+		output:hdmi-stereo-extra1: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5200)
+		output:hdmi-stereo-extra2: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5200)
+		output:hdmi-surround-extra2: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 100)
+		off: Wyłącz (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:hdmi-stereo-extra1
+	Ports:
+		hdmi-output-0: HDMI / DisplayPort (priority 5900)
+			Part of profile(s): output:hdmi-stereo, output:hdmi-surround
+		hdmi-output-1: HDMI / DisplayPort 2 (priority 5800)
+			Part of profile(s): output:hdmi-stereo-extra1
+		hdmi-output-2: HDMI / DisplayPort 3 (priority 5700)
+			Part of profile(s): output:hdmi-stereo-extra2, output:hdmi-surround-extra2

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-1.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-1.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-1.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,51 @@
+Card #1
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 5
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xf9ff8000 irq 70"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		device.description = "Wbudowany dźwięk"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:analog-stereo: Wyjście Analogowe stereo (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Analogowy dupleks stereo (sinks: 1, sources: 1, priority. 6060)
+		output:analog-surround-40: Wyjście Analogowe surround 4.0 (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-40+input:analog-stereo: Wyjście Analogowe surround 4.0 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 760)
+		output:analog-surround-41: Wyjście Analogowe surround 4.1 (sinks: 1, sources: 0, priority. 800)
+		output:analog-surround-41+input:analog-stereo: Wyjście Analogowe surround 4.1 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 860)
+		output:analog-surround-50: Wyjście Analogowe surround 5.0 (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-50+input:analog-stereo: Wyjście Analogowe surround 5.0 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 760)
+		output:analog-surround-51: Wyjście Analogowe surround 5.1 (sinks: 1, sources: 0, priority. 800)
+		output:analog-surround-51+input:analog-stereo: Wyjście Analogowe surround 5.1 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 860)
+		output:analog-surround-71: Wyjście Analog Surround 7.1 (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-71+input:analog-stereo: Wyjście Analog Surround 7.1 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 760)
+		output:iec958-stereo: Wyjście Cyfrowe stereo (IEC958) (sinks: 1, sources: 0, priority. 5500)
+		output:iec958-stereo+input:analog-stereo: Wyjście Cyfrowe stereo (IEC958) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 5560)
+		input:analog-stereo: Wejście Analogowe stereo (sinks: 0, sources: 1, priority. 60)
+		off: Wyłącz (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-output: Wyjście analogowe (priority 9900)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo, output:analog-surround-40, output:analog-surround-40+input:analog-stereo, output:analog-surround-41, output:analog-surround-41+input:analog-stereo, output:analog-surround-50, output:analog-surround-50+input:analog-stereo, output:analog-surround-51, output:analog-surround-51+input:analog-stereo, output:analog-surround-71, output:analog-surround-71+input:analog-stereo
+		analog-output-headphones: Słuchawki (priority 9000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-input-microphone-front: Przedni mikrofon (priority 8500)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:analog-surround-71+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		analog-input-microphone-rear: Tylny mikrofon (priority 8200)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:analog-surround-71+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		analog-input-linein: Wejście liniowe (priority 8100)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:analog-surround-71+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		iec958-stereo-output: Wyjście cyfrowe (S/PDIF) (priority 0)
+			Part of profile(s): output:iec958-stereo, output:iec958-stereo+input:analog-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-2.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-2.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise-2.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,30 @@
+Card #2
+	Name: alsa_card.usb-046d_0825_0E3A8A10-02-U0x46d0x825
+	Driver: module-alsa-card.c
+	Owner Module: 6
+	Properties:
+		alsa.card = "1"
+		alsa.card_name = "USB Device 0x46d:0x825"
+		alsa.long_card_name = "USB Device 0x46d:0x825 at usb-0000:00:1d.7-1, high speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1d.7-usb-0:1:1.2"
+		sysfs.path = "/devices/pci0000:00/0000:00:1d.7/usb2/2-1/2-1:1.2/sound/card1"
+		udev.id = "usb-046d_0825_0E3A8A10-02-U0x46d0x825"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0825"
+		device.product.name = "Webcam C270"
+		device.serial = "046d_0825_0E3A8A10"
+		device.form_factor = "webcam"
+		device.string = "1"
+		device.description = "Webcam C270"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "camera-web-usb"
+	Profiles:
+		input:analog-mono: Wejście Analogowe mono (sinks: 0, sources: 1, priority. 1)
+		off: Wyłącz (sinks: 0, sources: 0, priority. 0)
+	Active Profile: input:analog-mono
+	Ports:
+		analog-input-microphone: Mikrofon (priority 8700)
+			Part of profile(s): input:analog-mono

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/cards-desktop-precise.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,41 @@
+Card #0
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xe0610000 irq 46"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "Panther Point High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		device.description = "Wbudowany dźwięk"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:analog-stereo: Wyjście Analogowe stereo (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Analogowy dupleks stereo (sinks: 1, sources: 1, priority. 6060)
+		output:hdmi-stereo: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5400)
+		output:hdmi-stereo+input:analog-stereo: Wyjście Digital Stereo (HDMI) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 5460)
+		output:hdmi-surround: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 300)
+		output:hdmi-surround+input:analog-stereo: Wyjście Digital Surround 5.1 (HDMI) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 360)
+		input:analog-stereo: Wejście Analogowe stereo (sinks: 0, sources: 1, priority. 60)
+		off: Wyłącz (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-output-speaker: Głośniki (priority 10000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-output-headphones: Słuchawki (priority 9000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-input-microphone-internal: Wewnętrzny mikrofon (priority 8900)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		analog-input-microphone: Mikrofon (priority 8700)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		hdmi-output-0: HDMI / DisplayPort (priority 5900)
+			Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround, output:hdmi-surround+input:analog-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-radeon-hdmi-available.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-radeon-hdmi-available.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-radeon-hdmi-available.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,608 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "1.1"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "1.1"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "1.1"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "1.1"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="1" name="pci-0000_01_00.1" card_name="alsa_card.pci-0000_01_00.1" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #5
+	Name: module-alsa-card
+	Argument: device_id="0" name="pci-0000_00_1b.0" card_name="alsa_card.pci-0000_00_1b.0" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #6
+	Name: module-udev-detect
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "1.1"
+
+Module #7
+	Name: module-bluetooth-discover
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Joao Paulo Rechi Vita"
+		module.description = "Detect available bluetooth audio devices and load bluetooth audio drivers"
+		module.version = "1.1"
+
+Module #8
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Module #9
+	Name: module-gconf
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "GConf Adapter"
+		module.version = "1.1"
+
+Module #10
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "1.1"
+
+Module #11
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "1.1"
+
+Module #12
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Garde toujours au moins une destination même si elle est vide"
+		module.version = "1.1"
+
+Module #13
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "1.1"
+
+Module #14
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "1.1"
+
+Module #15
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "1.1"
+
+Module #16
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "1.1"
+
+Module #17
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "1.1"
+
+Module #18
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "1.1"
+
+Module #19
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #20
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "1.1"
+
+Module #21
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "1.1"
+
+Module #22
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "1.1"
+
+Module #23
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/sylvain-Desktop:@/tmp/.ICE-unix/1693,unix/sylvain-Desktop:/tmp/.ICE-unix/1693
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "1.1"
+
+Sink #0
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_01_00.1.hdmi-stereo
+	Description: RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_01_00.1.hdmi-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE DECIBEL_VOLUME LATENCY SET_FORMATS 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "HDMI 0"
+		alsa.id = "HDMI 0"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "3"
+		alsa.card = "1"
+		alsa.card_name = "HDA ATI HDMI"
+		alsa.long_card_name = "HDA ATI HDMI at 0xfe9fc000 irq 44"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:01:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1"
+		device.bus = "pci"
+		device.vendor.id = "1002"
+		device.vendor.name = "Advanced Micro Devices [AMD] nee ATI"
+		device.product.name = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		device.string = "hdmi:1"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "hdmi-stereo"
+		device.profile.description = "Digital Stereo (HDMI)"
+		device.description = "RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)"
+		alsa.mixer_name = "ATI R6xx HDMI"
+		alsa.components = "HDA:1002aa01,00aa0100,00100100"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		hdmi-output-0: HDMI / DisplayPort (priority: 5900, available)
+	Active Port: hdmi-output-0
+	Formats:
+		pcm
+
+Sink #1
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Audio interne Stéréo analogique
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: yes
+	Volume: 0:  47% 1:  47%
+	        0: -19.50 dB 1: -19.50 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC1200 Analog"
+		alsa.id = "ALC1200 Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Stéréo analogique"
+		device.description = "Audio interne Stéréo analogique"
+		alsa.mixer_name = "Realtek ALC1200"
+		alsa.components = "HDA:10ec0888,104382fe,00100101"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output: Sortie analogique (priority: 9900)
+	Active Port: analog-output
+	Formats:
+		pcm
+
+Source #0
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_01_00.1.hdmi-stereo.monitor
+	Description: Monitor of RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_01_00.1.hdmi-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)"
+		device.class = "monitor"
+		alsa.card = "1"
+		alsa.card_name = "HDA ATI HDMI"
+		alsa.long_card_name = "HDA ATI HDMI at 0xfe9fc000 irq 44"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:01:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1"
+		device.bus = "pci"
+		device.vendor.id = "1002"
+		device.vendor.name = "Advanced Micro Devices [AMD] nee ATI"
+		device.product.name = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		device.string = "1"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #1
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Description: Monitor of Audio interne Stéréo analogique
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of Audio interne Stéréo analogique"
+		device.class = "monitor"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #2
+	State: SUSPENDED
+	Name: alsa_input.pci-0000_00_1b.0.analog-stereo
+	Description: Audio interne Stéréo analogique
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0:  16% 1:  16%
+	        0: -48.00 dB 1: -48.00 dB
+	        balance 0.00
+	Base Volume:  10%
+	             -60.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC1200 Analog"
+		alsa.id = "ALC1200 Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Stéréo analogique"
+		device.description = "Audio interne Stéréo analogique"
+		alsa.mixer_name = "Realtek ALC1200"
+		alsa.components = "HDA:10ec0888,104382fe,00100101"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-input-microphone-front: Front Microphone (priority: 8500)
+		analog-input-microphone: Microphone (priority: 8700)
+		analog-input-linein: Entrée-ligne (priority: 8100)
+	Active Port: analog-input-microphone
+	Formats:
+		pcm
+
+Client #0
+	Driver: module-console-kit.c
+	Owner Module: 15
+	Properties:
+		application.name = "ConsoleKit Session /org/freedesktop/ConsoleKit/Session2"
+		console-kit.session = "/org/freedesktop/ConsoleKit/Session2"
+
+Client #1
+	Driver: protocol-native.c
+	Owner Module: 8
+	Properties:
+		application.name = "GNOME Volume Control Media Keys"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.4.2"
+		application.process.id = "1747"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Desktop"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "fr_FR.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "4ca4098bd7fb4b50861c728c00000006"
+		application.process.session_id = "4ca4098bd7fb4b50861c728c00000006-1370257395.99092-1975316763"
+
+Client #2
+	Driver: protocol-native.c
+	Owner Module: 8
+	Properties:
+		application.name = "Indicator Sound"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "com.canonical.indicator.sound"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "0.8.5.0"
+		application.process.id = "1865"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Desktop"
+		application.process.binary = "indicator-sound-service"
+		application.language = "fr_FR.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "4ca4098bd7fb4b50861c728c00000006"
+		application.process.session_id = "4ca4098bd7fb4b50861c728c00000006-1370257395.99092-1975316763"
+
+Client #7
+	Driver: module-x11-xsmp.c
+	Owner Module: 23
+	Properties:
+		application.name = "XSMP Session on gnome-session as 10638a3fc4330dbdf3137025740380403100000016930035"
+		xsmp.vendor = "gnome-session"
+		xsmp.client.id = "10638a3fc4330dbdf3137025740380403100000016930035"
+
+Client #10
+	Driver: protocol-native.c
+	Owner Module: 8
+	Properties:
+		application.name = "pactl"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "2219"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Desktop"
+		application.process.binary = "pactl"
+		application.language = "C"
+		window.x11.display = ":0"
+		application.process.machine_id = "4ca4098bd7fb4b50861c728c00000006"
+		application.process.session_id = "4ca4098bd7fb4b50861c728c00000006-1370257395.99092-1975316763"
+
+Card #0
+	Name: alsa_card.pci-0000_01_00.1
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "1"
+		alsa.card_name = "HDA ATI HDMI"
+		alsa.long_card_name = "HDA ATI HDMI at 0xfe9fc000 irq 44"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:01:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1"
+		device.bus = "pci"
+		device.vendor.id = "1002"
+		device.vendor.name = "Advanced Micro Devices [AMD] nee ATI"
+		device.product.name = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		device.string = "1"
+		device.description = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:hdmi-stereo: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5400)
+		off: Éteint (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:hdmi-stereo
+	Ports:
+		hdmi-output-0: HDMI / DisplayPort (priority 5900)
+			Part of profile(s): output:hdmi-stereo
+
+Card #1
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 5
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		device.description = "Audio interne"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:analog-stereo: Stéréo analogique Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Duplex stéréo analogique (sinks: 1, sources: 1, priority. 6060)
+		output:analog-stereo+input:iec958-stereo: Stéréo analogique Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 6055)
+		output:analog-surround-40: Surround analogique 4.0 Output (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-40+input:analog-stereo: Surround analogique 4.0 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 760)
+		output:analog-surround-40+input:iec958-stereo: Surround analogique 4.0 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 755)
+		output:analog-surround-41: Surround analogique 4.1 Output (sinks: 1, sources: 0, priority. 800)
+		output:analog-surround-41+input:analog-stereo: Surround analogique 4.1 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 860)
+		output:analog-surround-41+input:iec958-stereo: Surround analogique 4.1 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 855)
+		output:analog-surround-50: Surround analogique 5.0 Output (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-50+input:analog-stereo: Surround analogique 5.0 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 760)
+		output:analog-surround-50+input:iec958-stereo: Surround analogique 5.0 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 755)
+		output:analog-surround-51: Surround analogique 5.1 Output (sinks: 1, sources: 0, priority. 800)
+		output:analog-surround-51+input:analog-stereo: Surround analogique 5.1 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 860)
+		output:analog-surround-51+input:iec958-stereo: Surround analogique 5.1 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 855)
+		output:iec958-stereo: Stéréo numérique (IEC958) Output (sinks: 1, sources: 0, priority. 5500)
+		output:iec958-stereo+input:analog-stereo: Stéréo numérique (IEC958) Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 5560)
+		output:iec958-stereo+input:iec958-stereo: Duplex stéréo numérique (IEC958) (sinks: 1, sources: 1, priority. 5555)
+		input:analog-stereo: Stéréo analogique Input (sinks: 0, sources: 1, priority. 60)
+		input:iec958-stereo: Stéréo numérique (IEC958) Input (sinks: 0, sources: 1, priority. 55)
+		off: Éteint (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-output: Sortie analogique (priority 9900)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo, output:analog-stereo+input:iec958-stereo, output:analog-surround-40, output:analog-surround-40+input:analog-stereo, output:analog-surround-40+input:iec958-stereo, output:analog-surround-41, output:analog-surround-41+input:analog-stereo, output:analog-surround-41+input:iec958-stereo, output:analog-surround-50, output:analog-surround-50+input:analog-stereo, output:analog-surround-50+input:iec958-stereo, output:analog-surround-51, output:analog-surround-51+input:analog-stereo, output:analog-surround-51+input:iec958-stereo
+		analog-input-microphone-front: Front Microphone (priority 8500)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		analog-input-microphone: Microphone (priority 8700)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		analog-input-linein: Entrée-ligne (priority 8100)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		iec958-stereo-input: iec958-stereo-input (priority 0)
+			Part of profile(s): output:analog-stereo+input:iec958-stereo, output:analog-surround-40+input:iec958-stereo, output:analog-surround-41+input:iec958-stereo, output:analog-surround-50+input:iec958-stereo, output:analog-surround-51+input:iec958-stereo, output:iec958-stereo+input:iec958-stereo, input:iec958-stereo
+		iec958-stereo-output: Digital Output (S/PDIF) (priority 0)
+			Part of profile(s): output:iec958-stereo, output:iec958-stereo+input:analog-stereo, output:iec958-stereo+input:iec958-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-radeon.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-radeon.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-radeon.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,608 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "1.1"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "1.1"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "1.1"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "1.1"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="1" name="pci-0000_01_00.1" card_name="alsa_card.pci-0000_01_00.1" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #5
+	Name: module-alsa-card
+	Argument: device_id="0" name="pci-0000_00_1b.0" card_name="alsa_card.pci-0000_00_1b.0" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #6
+	Name: module-udev-detect
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "1.1"
+
+Module #7
+	Name: module-bluetooth-discover
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Joao Paulo Rechi Vita"
+		module.description = "Detect available bluetooth audio devices and load bluetooth audio drivers"
+		module.version = "1.1"
+
+Module #8
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Module #9
+	Name: module-gconf
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "GConf Adapter"
+		module.version = "1.1"
+
+Module #10
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "1.1"
+
+Module #11
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "1.1"
+
+Module #12
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Garde toujours au moins une destination même si elle est vide"
+		module.version = "1.1"
+
+Module #13
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "1.1"
+
+Module #14
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "1.1"
+
+Module #15
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "1.1"
+
+Module #16
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "1.1"
+
+Module #17
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "1.1"
+
+Module #18
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "1.1"
+
+Module #19
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #20
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "1.1"
+
+Module #21
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "1.1"
+
+Module #22
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "1.1"
+
+Module #23
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/sylvain-Desktop:@/tmp/.ICE-unix/1693,unix/sylvain-Desktop:/tmp/.ICE-unix/1693
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "1.1"
+
+Sink #0
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_01_00.1.hdmi-stereo
+	Description: RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_01_00.1.hdmi-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE DECIBEL_VOLUME LATENCY SET_FORMATS 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "HDMI 0"
+		alsa.id = "HDMI 0"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "3"
+		alsa.card = "1"
+		alsa.card_name = "HDA ATI HDMI"
+		alsa.long_card_name = "HDA ATI HDMI at 0xfe9fc000 irq 44"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:01:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1"
+		device.bus = "pci"
+		device.vendor.id = "1002"
+		device.vendor.name = "Advanced Micro Devices [AMD] nee ATI"
+		device.product.name = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		device.string = "hdmi:1"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "hdmi-stereo"
+		device.profile.description = "Digital Stereo (HDMI)"
+		device.description = "RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)"
+		alsa.mixer_name = "ATI R6xx HDMI"
+		alsa.components = "HDA:1002aa01,00aa0100,00100100"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		hdmi-output-0: HDMI / DisplayPort (priority: 5900, not available)
+	Active Port: hdmi-output-0
+	Formats:
+		pcm
+
+Sink #1
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Audio interne Stéréo analogique
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: yes
+	Volume: 0:  47% 1:  47%
+	        0: -19.50 dB 1: -19.50 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC1200 Analog"
+		alsa.id = "ALC1200 Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Stéréo analogique"
+		device.description = "Audio interne Stéréo analogique"
+		alsa.mixer_name = "Realtek ALC1200"
+		alsa.components = "HDA:10ec0888,104382fe,00100101"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output: Sortie analogique (priority: 9900)
+	Active Port: analog-output
+	Formats:
+		pcm
+
+Source #0
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_01_00.1.hdmi-stereo.monitor
+	Description: Monitor of RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_01_00.1.hdmi-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of RV770 HDMI Audio [Radeon HD 4850/4870] Digital Stereo (HDMI)"
+		device.class = "monitor"
+		alsa.card = "1"
+		alsa.card_name = "HDA ATI HDMI"
+		alsa.long_card_name = "HDA ATI HDMI at 0xfe9fc000 irq 44"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:01:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1"
+		device.bus = "pci"
+		device.vendor.id = "1002"
+		device.vendor.name = "Advanced Micro Devices [AMD] nee ATI"
+		device.product.name = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		device.string = "1"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #1
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Description: Monitor of Audio interne Stéréo analogique
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of Audio interne Stéréo analogique"
+		device.class = "monitor"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #2
+	State: SUSPENDED
+	Name: alsa_input.pci-0000_00_1b.0.analog-stereo
+	Description: Audio interne Stéréo analogique
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0:  16% 1:  16%
+	        0: -48.00 dB 1: -48.00 dB
+	        balance 0.00
+	Base Volume:  10%
+	             -60.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC1200 Analog"
+		alsa.id = "ALC1200 Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Stéréo analogique"
+		device.description = "Audio interne Stéréo analogique"
+		alsa.mixer_name = "Realtek ALC1200"
+		alsa.components = "HDA:10ec0888,104382fe,00100101"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-input-microphone-front: Front Microphone (priority: 8500)
+		analog-input-microphone: Microphone (priority: 8700)
+		analog-input-linein: Entrée-ligne (priority: 8100)
+	Active Port: analog-input-microphone
+	Formats:
+		pcm
+
+Client #0
+	Driver: module-console-kit.c
+	Owner Module: 15
+	Properties:
+		application.name = "ConsoleKit Session /org/freedesktop/ConsoleKit/Session2"
+		console-kit.session = "/org/freedesktop/ConsoleKit/Session2"
+
+Client #1
+	Driver: protocol-native.c
+	Owner Module: 8
+	Properties:
+		application.name = "GNOME Volume Control Media Keys"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.4.2"
+		application.process.id = "1747"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Desktop"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "fr_FR.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "4ca4098bd7fb4b50861c728c00000006"
+		application.process.session_id = "4ca4098bd7fb4b50861c728c00000006-1370257395.99092-1975316763"
+
+Client #2
+	Driver: protocol-native.c
+	Owner Module: 8
+	Properties:
+		application.name = "Indicator Sound"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "com.canonical.indicator.sound"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "0.8.5.0"
+		application.process.id = "1865"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Desktop"
+		application.process.binary = "indicator-sound-service"
+		application.language = "fr_FR.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "4ca4098bd7fb4b50861c728c00000006"
+		application.process.session_id = "4ca4098bd7fb4b50861c728c00000006-1370257395.99092-1975316763"
+
+Client #7
+	Driver: module-x11-xsmp.c
+	Owner Module: 23
+	Properties:
+		application.name = "XSMP Session on gnome-session as 10638a3fc4330dbdf3137025740380403100000016930035"
+		xsmp.vendor = "gnome-session"
+		xsmp.client.id = "10638a3fc4330dbdf3137025740380403100000016930035"
+
+Client #10
+	Driver: protocol-native.c
+	Owner Module: 8
+	Properties:
+		application.name = "pactl"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "2219"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Desktop"
+		application.process.binary = "pactl"
+		application.language = "C"
+		window.x11.display = ":0"
+		application.process.machine_id = "4ca4098bd7fb4b50861c728c00000006"
+		application.process.session_id = "4ca4098bd7fb4b50861c728c00000006-1370257395.99092-1975316763"
+
+Card #0
+	Name: alsa_card.pci-0000_01_00.1
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "1"
+		alsa.card_name = "HDA ATI HDMI"
+		alsa.long_card_name = "HDA ATI HDMI at 0xfe9fc000 irq 44"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:01:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1"
+		device.bus = "pci"
+		device.vendor.id = "1002"
+		device.vendor.name = "Advanced Micro Devices [AMD] nee ATI"
+		device.product.name = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		device.string = "1"
+		device.description = "RV770 HDMI Audio [Radeon HD 4850/4870]"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:hdmi-stereo: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5400)
+		off: Éteint (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:hdmi-stereo
+	Ports:
+		hdmi-output-0: HDMI / DisplayPort (priority 5900)
+			Part of profile(s): output:hdmi-stereo
+
+Card #1
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 5
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xfe8f8000 irq 43"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		device.description = "Audio interne"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:analog-stereo: Stéréo analogique Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Duplex stéréo analogique (sinks: 1, sources: 1, priority. 6060)
+		output:analog-stereo+input:iec958-stereo: Stéréo analogique Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 6055)
+		output:analog-surround-40: Surround analogique 4.0 Output (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-40+input:analog-stereo: Surround analogique 4.0 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 760)
+		output:analog-surround-40+input:iec958-stereo: Surround analogique 4.0 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 755)
+		output:analog-surround-41: Surround analogique 4.1 Output (sinks: 1, sources: 0, priority. 800)
+		output:analog-surround-41+input:analog-stereo: Surround analogique 4.1 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 860)
+		output:analog-surround-41+input:iec958-stereo: Surround analogique 4.1 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 855)
+		output:analog-surround-50: Surround analogique 5.0 Output (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-50+input:analog-stereo: Surround analogique 5.0 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 760)
+		output:analog-surround-50+input:iec958-stereo: Surround analogique 5.0 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 755)
+		output:analog-surround-51: Surround analogique 5.1 Output (sinks: 1, sources: 0, priority. 800)
+		output:analog-surround-51+input:analog-stereo: Surround analogique 5.1 Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 860)
+		output:analog-surround-51+input:iec958-stereo: Surround analogique 5.1 Output + Stéréo numérique (IEC958) Input (sinks: 1, sources: 1, priority. 855)
+		output:iec958-stereo: Stéréo numérique (IEC958) Output (sinks: 1, sources: 0, priority. 5500)
+		output:iec958-stereo+input:analog-stereo: Stéréo numérique (IEC958) Output + Stéréo analogique Input (sinks: 1, sources: 1, priority. 5560)
+		output:iec958-stereo+input:iec958-stereo: Duplex stéréo numérique (IEC958) (sinks: 1, sources: 1, priority. 5555)
+		input:analog-stereo: Stéréo analogique Input (sinks: 0, sources: 1, priority. 60)
+		input:iec958-stereo: Stéréo numérique (IEC958) Input (sinks: 0, sources: 1, priority. 55)
+		off: Éteint (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-output: Sortie analogique (priority 9900)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo, output:analog-stereo+input:iec958-stereo, output:analog-surround-40, output:analog-surround-40+input:analog-stereo, output:analog-surround-40+input:iec958-stereo, output:analog-surround-41, output:analog-surround-41+input:analog-stereo, output:analog-surround-41+input:iec958-stereo, output:analog-surround-50, output:analog-surround-50+input:analog-stereo, output:analog-surround-50+input:iec958-stereo, output:analog-surround-51, output:analog-surround-51+input:analog-stereo, output:analog-surround-51+input:iec958-stereo
+		analog-input-microphone-front: Front Microphone (priority 8500)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		analog-input-microphone: Microphone (priority 8700)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		analog-input-linein: Entrée-ligne (priority 8100)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:analog-surround-41+input:analog-stereo, output:analog-surround-50+input:analog-stereo, output:analog-surround-51+input:analog-stereo, output:iec958-stereo+input:analog-stereo, input:analog-stereo
+		iec958-stereo-input: iec958-stereo-input (priority 0)
+			Part of profile(s): output:analog-stereo+input:iec958-stereo, output:analog-surround-40+input:iec958-stereo, output:analog-surround-41+input:iec958-stereo, output:analog-surround-50+input:iec958-stereo, output:analog-surround-51+input:iec958-stereo, output:iec958-stereo+input:iec958-stereo, input:iec958-stereo
+		iec958-stereo-output: Digital Output (S/PDIF) (priority 0)
+			Part of profile(s): output:iec958-stereo, output:iec958-stereo+input:analog-stereo, output:iec958-stereo+input:iec958-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-xps1340.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-xps1340.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise-xps1340.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,466 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "1.1"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "1.1"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "1.1"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "1.1"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="0" name="pci-0000_00_08.0" card_name="alsa_card.pci-0000_00_08.0" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #5
+	Name: module-udev-detect
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "1.1"
+
+Module #7
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Module #8
+	Name: module-gconf
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "GConf Adapter"
+		module.version = "1.1"
+
+Module #9
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "1.1"
+
+Module #10
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "1.1"
+
+Module #11
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Always keeps at least one sink loaded even if it's a null one"
+		module.version = "1.1"
+
+Module #12
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "1.1"
+
+Module #13
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "1.1"
+
+Module #14
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "1.1"
+
+Module #15
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "1.1"
+
+Module #16
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "1.1"
+
+Module #17
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "1.1"
+
+Module #18
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #19
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "1.1"
+
+Module #20
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "1.1"
+
+Module #21
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "1.1"
+
+Module #22
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/sylvain-Studio-XPS-1340:@/tmp/.ICE-unix/2468,unix/sylvain-Studio-XPS-1340:/tmp/.ICE-unix/2468
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "1.1"
+
+Module #23
+	Name: module-cli-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Command line interface protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Sink #8
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_08.0.analog-stereo
+	Description: Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0:  86% 1:  86%
+	        0: -3.93 dB 1: -3.93 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_08.0.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "STAC92xx Analog"
+		alsa.id = "STAC92xx Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA NVidia"
+		alsa.long_card_name = "HDA NVidia at 0xf0880000 irq 17"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:08.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:08.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "10de"
+		device.vendor.name = "NVIDIA Corporation"
+		device.product.name = "MCP79 High Definition Audio"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "Built-in Audio Analog Stereo"
+		alsa.mixer_name = "Nvidia MCP79/7A HDMI"
+		alsa.components = "HDA:111d7675,10280271,00100103 HDA:10de0007,10280271,00100100"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output-speaker: Speakers (priority: 10000)
+		analog-output-headphones: Headphones (priority: 9000)
+	Active Port: analog-output-headphones
+	Formats:
+		pcm
+
+Source #8
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_08.0.analog-stereo.monitor
+	Description: Monitor of Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0:  10% 1:  10%
+	        0: -60.00 dB 1: -60.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_00_08.0.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of Built-in Audio Analog Stereo"
+		device.class = "monitor"
+		alsa.card = "0"
+		alsa.card_name = "HDA NVidia"
+		alsa.long_card_name = "HDA NVidia at 0xf0880000 irq 17"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:08.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:08.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "10de"
+		device.vendor.name = "NVIDIA Corporation"
+		device.product.name = "MCP79 High Definition Audio"
+		device.form_factor = "internal"
+		device.string = "0"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Client #0
+	Driver: module-console-kit.c
+	Owner Module: 14
+	Properties:
+		application.name = "ConsoleKit Session /org/freedesktop/ConsoleKit/Session2"
+		console-kit.session = "/org/freedesktop/ConsoleKit/Session2"
+
+Client #1
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "GNOME Volume Control Media Keys"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.4.2"
+		application.process.id = "2524"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Studio-XPS-1340"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "6d1c164900a6e0373e5ce43b00000009"
+		application.process.session_id = "6d1c164900a6e0373e5ce43b00000009-1370247689.39634-22016034"
+
+Client #2
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "Blueman"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "2556"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Studio-XPS-1340"
+		application.process.binary = "python2.7"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "6d1c164900a6e0373e5ce43b00000009"
+		application.process.session_id = "6d1c164900a6e0373e5ce43b00000009-1370247689.39634-22016034"
+		application.icon_name = "/usr/share/pixmaps/python2.7.xpm"
+
+Client #3
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "Indicator Sound"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "com.canonical.indicator.sound"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "0.8.5.0"
+		application.process.id = "2690"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Studio-XPS-1340"
+		application.process.binary = "indicator-sound-service"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "6d1c164900a6e0373e5ce43b00000009"
+		application.process.session_id = "6d1c164900a6e0373e5ce43b00000009-1370247689.39634-22016034"
+
+Client #8
+	Driver: module-x11-xsmp.c
+	Owner Module: 22
+	Properties:
+		application.name = "XSMP Session on gnome-session as 104f2e9b2d67a69372137024769973390800000024680040"
+		xsmp.vendor = "gnome-session"
+		xsmp.client.id = "104f2e9b2d67a69372137024769973390800000024680040"
+
+Client #11
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "GNOME Volume Control Dialog"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.4.2"
+		application.process.id = "3567"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Studio-XPS-1340"
+		application.process.binary = "gnome-control-center"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "6d1c164900a6e0373e5ce43b00000009"
+		application.process.session_id = "6d1c164900a6e0373e5ce43b00000009-1370247689.39634-22016034"
+
+Client #142
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "gnome-settings-daemon"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		window.x11.display = ":0"
+		window.x11.screen = "0"
+		application.process.id = "2524"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Studio-XPS-1340"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		application.process.machine_id = "6d1c164900a6e0373e5ce43b00000009"
+		application.process.session_id = "6d1c164900a6e0373e5ce43b00000009-1370247689.39634-22016034"
+
+Client #145
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "pactl"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "4805"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-Studio-XPS-1340"
+		application.process.binary = "pactl"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "6d1c164900a6e0373e5ce43b00000009"
+		application.process.session_id = "6d1c164900a6e0373e5ce43b00000009-1370247689.39634-22016034"
+
+Card #0
+	Name: alsa_card.pci-0000_00_08.0
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "HDA NVidia"
+		alsa.long_card_name = "HDA NVidia at 0xf0880000 irq 17"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:08.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:08.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "10de"
+		device.vendor.name = "NVIDIA Corporation"
+		device.product.name = "MCP79 High Definition Audio"
+		device.form_factor = "internal"
+		device.string = "0"
+		device.description = "Built-in Audio"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:analog-stereo: Analog Stereo Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Analog Stereo Duplex (sinks: 1, sources: 1, priority. 6060)
+		output:analog-surround-40: Analog Surround 4.0 Output (sinks: 1, sources: 0, priority. 700)
+		output:analog-surround-40+input:analog-stereo: Analog Surround 4.0 Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 760)
+		output:hdmi-stereo: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5400)
+		output:hdmi-stereo+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5460)
+		output:hdmi-surround: Digital Surround 5.1 (HDMI) Output (sinks: 1, sources: 0, priority. 300)
+		output:hdmi-surround+input:analog-stereo: Digital Surround 5.1 (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 360)
+		input:analog-stereo: Analog Stereo Input (sinks: 0, sources: 1, priority. 60)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo
+	Ports:
+		analog-output-speaker: Speakers (priority 10000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo, output:analog-surround-40, output:analog-surround-40+input:analog-stereo
+		analog-output-headphones: Headphones (priority 9000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-input-microphone-internal: Internal Microphone (priority 8900)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		analog-input-microphone: Microphone (priority 8700)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		analog-input-linein: Line In (priority 8100)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:analog-surround-40+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		hdmi-output-0: HDMI / DisplayPort (priority 5900)
+			Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround, output:hdmi-surround+input:analog-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-precise.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,696 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "1.1"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "1.1"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "1.1"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "1.1"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="0" name="pci-0000_00_1b.0" card_name="alsa_card.pci-0000_00_1b.0" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 2
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #5
+	Name: module-udev-detect
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "1.1"
+
+Module #6
+	Name: module-bluetooth-discover
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Joao Paulo Rechi Vita"
+		module.description = "Detect available bluetooth audio devices and load bluetooth audio drivers"
+		module.version = "1.1"
+
+Module #7
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Module #8
+	Name: module-gconf
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "GConf Adapter"
+		module.version = "1.1"
+
+Module #9
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "1.1"
+
+Module #10
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "1.1"
+
+Module #11
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Utrzymywanie zawsze co najmniej jednego wczytanego odpływu nawet, jeśli to pusty odpływ"
+		module.version = "1.1"
+
+Module #12
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "1.1"
+
+Module #13
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "1.1"
+
+Module #14
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "1.1"
+
+Module #15
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "1.1"
+
+Module #16
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "1.1"
+
+Module #17
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "1.1"
+
+Module #18
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #19
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "1.1"
+
+Module #20
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "1.1"
+
+Module #21
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "1.1"
+
+Module #22
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/g580:@/tmp/.ICE-unix/2788,unix/g580:/tmp/.ICE-unix/2788
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "1.1"
+
+Module #23
+	Name: module-cli-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Command line interface protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Sink #0
+	State: RUNNING
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Wbudowany dźwięk Analogowe stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0:  64% 1:  64%
+	        0: -11.67 dB 1: -11.67 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 86152 usec, configured 86000 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "CONEXANT Analog"
+		alsa.id = "CONEXANT Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xe0610000 irq 46"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "Panther Point High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analogowe stereo"
+		device.description = "Wbudowany dźwięk Analogowe stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:14f1506e,17aac023,00100003 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output-speaker: Głośniki (priority: 10000, not available)
+		analog-output-headphones: Słuchawki (priority: 9000, available)
+	Active Port: analog-output-headphones
+	Formats:
+		pcm
+
+Source #0
+	State: IDLE
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Description: Monitor of Wbudowany dźwięk Analogowe stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Latency: 0 usec, configured 371519 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of Wbudowany dźwięk Analogowe stereo"
+		device.class = "monitor"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xe0610000 irq 46"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "Panther Point High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #1
+	State: RUNNING
+	Name: alsa_input.pci-0000_00_1b.0.analog-stereo
+	Description: Wbudowany dźwięk Analogowe stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume:  17%
+	             -46.00 dB
+	Monitor of Sink: n/a
+	Latency: 3425 usec, configured 56000 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "CONEXANT Analog"
+		alsa.id = "CONEXANT Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xe0610000 irq 46"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "Panther Point High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analogowe stereo"
+		device.description = "Wbudowany dźwięk Analogowe stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:14f1506e,17aac023,00100003 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-input-microphone-internal: Wewnętrzny mikrofon (priority: 8900)
+		analog-input-microphone: Mikrofon (priority: 8700, not available)
+	Active Port: analog-input-microphone-internal
+	Formats:
+		pcm
+
+Sink Input #1249
+	Driver: protocol-native.c
+	Owner Module: 7
+	Client: 173
+	Sink: 0
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Format: pcm, format.sample_format = "\"s16le\""  format.rate = "44100"  format.channels = "2"  format.channel_map = "\"front-left,front-right\""
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Buffer Latency: 82811 usec
+	Sink Latency: 85934 usec
+	Resample method: n/a
+	Properties:
+		media.name = "playStream"
+		application.name = "WEBRTC VoiceEngine"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "32440"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "GoogleTalkPlugin"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+		module-stream-restore.id = "sink-input-by-application-name:WEBRTC VoiceEngine"
+
+Source Output #11
+	Driver: protocol-native.c
+	Owner Module: 7
+	Client: 173
+	Source: 1
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Format: pcm, format.sample_format = "\"s16le\""  format.rate = "44100"  format.channels = "2"  format.channel_map = "\"front-left,front-right\""
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Buffer Latency: 0 usec
+	Source Latency: 3551 usec
+	Resample method: n/a
+	Properties:
+		media.name = "recStream"
+		application.name = "WEBRTC VoiceEngine"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "32440"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "GoogleTalkPlugin"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+		module-stream-restore.id = "source-output-by-application-name:WEBRTC VoiceEngine"
+
+Client #0
+	Driver: module-console-kit.c
+	Owner Module: 14
+	Properties:
+		application.name = "ConsoleKit Session /org/freedesktop/ConsoleKit/Session2"
+		console-kit.session = "/org/freedesktop/ConsoleKit/Session2"
+
+Client #1
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "GNOME Volume Control Media Keys"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.4.2"
+		application.process.id = "2834"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #2
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "Indicator Sound"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.id = "com.canonical.indicator.sound"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "0.8.5.0"
+		application.process.id = "2949"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "indicator-sound-service"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #7
+	Driver: module-x11-xsmp.c
+	Owner Module: 22
+	Properties:
+		application.name = "XSMP Session on gnome-session as 104cd3b730ce810ec6136981133027539500000027880053"
+		xsmp.vendor = "gnome-session"
+		xsmp.client.id = "104cd3b730ce810ec6136981133027539500000027880053"
+
+Client #9
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "Gala"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		window.x11.display = ":0"
+		window.x11.screen = "0"
+		application.process.id = "2860"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gala"
+		application.language = "pl_PL.UTF-8"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #10
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "gnome-settings-daemon"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		window.x11.display = ":0"
+		window.x11.screen = "0"
+		application.process.id = "2834"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "pl_PL.UTF-8"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #63
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.version = "0.28"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2834"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #101
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "Chrome input"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "32091"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "chrome"
+		window.x11.display = ":0"
+		application.language = "pl_PL.UTF-8"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #173
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "WEBRTC VoiceEngine"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "32440"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "GoogleTalkPlugin"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #175
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "WEBRTC VoiceEngine"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "32440"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "GoogleTalkPlugin"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Client #195
+	Driver: protocol-native.c
+	Owner Module: 7
+	Properties:
+		application.name = "pactl"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.process.id = "2078"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "pactl"
+		application.language = "C"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Sample #0
+	Name: bell-window-system
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Volume: (invalid)
+	        (invalid)
+	        balance 0.00
+	Duration: 0.8s
+	Size: 138.3 KiB
+	Lazy: no
+	Filename: n/a
+	Properties:
+		media.role = "event"
+		application.process.id = "3036"
+		application.name = "pantheon-terminal"
+		event.description = "Zdarzenie sygnału dźwiękowego"
+		event.id = "bell-window-system"
+		media.name = "bell-window-system"
+		media.filename = "/usr/share//sounds/freedesktop/stereo/bell.oga"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		window.x11.display = ":0"
+		window.x11.screen = "0"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gala"
+		application.language = "pl_PL.UTF-8"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Sample #1
+	Name: audio-volume-change
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Volume: (invalid)
+	        (invalid)
+	        balance 0.00
+	Duration: 0.1s
+	Size: 11.5 KiB
+	Lazy: no
+	Filename: n/a
+	Properties:
+		media.role = "event"
+		event.description = "volume changed through key press"
+		event.id = "audio-volume-change"
+		media.name = "audio-volume-change"
+		media.filename = "/usr/share//sounds/freedesktop/stereo/audio-volume-change.oga"
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.version = "0.28"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2834"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Card #0
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xe0610000 irq 46"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "Panther Point High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "0"
+		device.description = "Wbudowany dźwięk"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		output:analog-stereo: Wyjście Analogowe stereo (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Analogowy dupleks stereo (sinks: 1, sources: 1, priority. 6060)
+		output:hdmi-stereo: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5400)
+		output:hdmi-stereo+input:analog-stereo: Wyjście Digital Stereo (HDMI) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 5460)
+		output:hdmi-surround: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 300)
+		output:hdmi-surround+input:analog-stereo: Wyjście Digital Surround 5.1 (HDMI) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 360)
+		input:analog-stereo: Wejście Analogowe stereo (sinks: 0, sources: 1, priority. 60)
+		off: Wyłącz (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-output-speaker: Głośniki (priority 10000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-output-headphones: Słuchawki (priority 9000)
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-input-microphone-internal: Wewnętrzny mikrofon (priority 8900)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		analog-input-microphone: Mikrofon (priority 8700)
+			Part of profile(s): output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround+input:analog-stereo, input:analog-stereo
+		hdmi-output-0: HDMI / DisplayPort (priority 5900)
+			Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround, output:hdmi-surround+input:analog-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-raring-t430s-dp-available.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-raring-t430s-dp-available.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-raring-t430s-dp-available.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,889 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "3.0"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "3.0"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "3.0"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "3.0"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="1" name="usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920" card_name="alsa_card.usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920" namereg_fail=false tsched=yes fixed_latency_range=no ignore_dB=no deferred_volume=yes use_ucm=no card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "3.0"
+
+Module #5
+	Name: module-alsa-card
+	Argument: device_id="0" name="usb-Logitech_Logitech_USB_Headset-00-Headset" card_name="alsa_card.usb-Logitech_Logitech_USB_Headset-00-Headset" namereg_fail=false tsched=yes fixed_latency_range=no ignore_dB=no deferred_volume=yes use_ucm=no card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "3.0"
+
+Module #6
+	Name: module-alsa-card
+	Argument: device_id="2" name="pci-0000_00_1b.0" card_name="alsa_card.pci-0000_00_1b.0" namereg_fail=false tsched=yes fixed_latency_range=no ignore_dB=no deferred_volume=yes use_ucm=no card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "3.0"
+
+Module #7
+	Name: module-udev-detect
+	Argument: use_ucm=0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "3.0"
+
+Module #8
+	Name: module-bluetooth-policy
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Frédéric Dalleau"
+		module.description = "When a bluetooth sink or source is added, load module-loopback"
+		module.version = "3.0"
+
+Module #9
+	Name: module-bluetooth-discover
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Joao Paulo Rechi Vita"
+		module.description = "Detect available bluetooth audio devices and load bluetooth audio drivers"
+		module.version = "3.0"
+
+Module #10
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "3.0"
+
+Module #11
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "3.0"
+
+Module #12
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "3.0"
+
+Module #13
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Always keeps at least one sink loaded even if it's a null one"
+		module.version = "3.0"
+
+Module #14
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "3.0"
+
+Module #15
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "3.0"
+
+Module #16
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "3.0"
+
+Module #17
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "3.0"
+
+Module #18
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "3.0"
+
+Module #19
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "3.0"
+
+Module #20
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #21
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "3.0"
+
+Module #22
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "3.0"
+
+Module #23
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "3.0"
+
+Module #24
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/sylvain-ThinkPad-T430s:@/tmp/.ICE-unix/2338,unix/sylvain-ThinkPad-T430s:/tmp/.ICE-unix/2338
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "3.0"
+
+Sink #0
+	State: SUSPENDED
+	Name: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo
+	Description: ClearChat Pro USB Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0:  46% 1:  46%
+	        0: -20.23 dB 1: -20.23 dB
+	        balance 0.00
+	Base Volume:  89%
+	             -3.00 dB
+	Monitor Source: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "USB Audio"
+		alsa.id = "USB Audio"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "front:0"
+		device.buffering.buffer_size = "352800"
+		device.buffering.fragment_size = "176400"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "ClearChat Pro USB Analog Stereo"
+		alsa.mixer_name = "USB Mixer"
+		alsa.components = "USB046d:0a0b"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Ports:
+		analog-output-headphones: Headphones (priority: 9000)
+	Active Port: analog-output-headphones
+	Formats:
+		pcm
+
+Sink #1
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 6
+	Mute: no
+	Volume: 0:  16% 1:  16%
+	        0: -47.54 dB 1: -47.54 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC269VC Analog"
+		alsa.id = "ALC269VC Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:2"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "Built-in Audio Analog Stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:10ec0269,17aa21fb,00100203 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output-speaker: Speakers (priority: 10000)
+		analog-output-headphones: Headphones (priority: 9000, not available)
+	Active Port: analog-output-speaker
+	Formats:
+		pcm
+
+Source #0
+	State: SUSPENDED
+	Name: alsa_input.usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920.iec958-stereo
+	Description: HD Pro Webcam C920 Digital Stereo (IEC958)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 32000Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "USB Audio"
+		alsa.id = "USB Audio"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "1"
+		alsa.card_name = "HD Pro Webcam C920"
+		alsa.long_card_name = "HD Pro Webcam C920 at usb-0000:00:14.0-1, high speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:14.0-usb-0:1:1.2"
+		sysfs.path = "/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/sound/card1"
+		udev.id = "usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "082d"
+		device.product.name = "HD Pro Webcam C920"
+		device.serial = "046d_HD_Pro_Webcam_C920_73BD39DF"
+		device.form_factor = "webcam"
+		device.string = "iec958:1"
+		device.buffering.buffer_size = "256000"
+		device.buffering.fragment_size = "128000"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "iec958-stereo"
+		device.profile.description = "Digital Stereo (IEC958)"
+		device.description = "HD Pro Webcam C920 Digital Stereo (IEC958)"
+		alsa.mixer_name = "USB Mixer"
+		alsa.components = "USB046d:082d"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "camera-web-usb"
+	Ports:
+		iec958-stereo-input: Digital Input (S/PDIF) (priority: 0)
+	Active Port: iec958-stereo-input
+	Formats:
+		pcm
+
+Source #1
+	State: SUSPENDED
+	Name: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo.monitor
+	Description: Monitor of ClearChat Pro USB Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of ClearChat Pro USB Analog Stereo"
+		device.class = "monitor"
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "0"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Formats:
+		pcm
+
+Source #2
+	State: SUSPENDED
+	Name: alsa_input.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-mono
+	Description: ClearChat Pro USB Analog Mono
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 1ch 44100Hz
+	Channel Map: mono
+	Owner Module: 5
+	Mute: no
+	Volume: 0: 100%
+	        0: 0.00 dB
+	        balance 0.00
+	Base Volume:  33%
+	             -29.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "USB Audio"
+		alsa.id = "USB Audio"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "hw:0"
+		device.buffering.buffer_size = "176400"
+		device.buffering.fragment_size = "88200"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-mono"
+		device.profile.description = "Analog Mono"
+		device.description = "ClearChat Pro USB Analog Mono"
+		alsa.mixer_name = "USB Mixer"
+		alsa.components = "USB046d:0a0b"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Ports:
+		analog-input-microphone: Microphone (priority: 8700)
+	Active Port: analog-input-microphone
+	Formats:
+		pcm
+
+Source #3
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Description: Monitor of Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 6
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of Built-in Audio Analog Stereo"
+		device.class = "monitor"
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "2"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #4
+	State: SUSPENDED
+	Name: alsa_input.pci-0000_00_1b.0.analog-stereo
+	Description: Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 6
+	Mute: no
+	Volume: 0:  25% 1:  25%
+	        0: -35.69 dB 1: -35.69 dB
+	        balance 0.00
+	Base Volume:  10%
+	             -60.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC269VC Analog"
+		alsa.id = "ALC269VC Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:2"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "Built-in Audio Analog Stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:10ec0269,17aa21fb,00100203 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-input-microphone-internal: Internal Microphone (priority: 8900)
+		analog-input-microphone-dock: Dock Microphone (priority: 7800, not available)
+		analog-input-microphone: Microphone (priority: 8700, not available)
+	Active Port: analog-input-microphone-internal
+	Formats:
+		pcm
+
+Client #0
+	Driver: module-console-kit.c
+	Owner Module: 16
+	Properties:
+		application.name = "ConsoleKit Session /org/freedesktop/ConsoleKit/Session2"
+		console-kit.session = "/org/freedesktop/ConsoleKit/Session2"
+
+Client #5
+	Driver: module-x11-xsmp.c
+	Owner Module: 24
+	Properties:
+		application.name = "XSMP Session on gnome-session as 109ee05a0d9d9a2996137084790972133100000023380031"
+		xsmp.vendor = "gnome-session"
+		xsmp.client.id = "109ee05a0d9d9a2996137084790972133100000023380031"
+
+Client #6
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "GNOME Volume Control Media Keys"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.6.4"
+		application.process.id = "2416"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #7
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "Indicator Sound"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.id = "com.canonical.indicator.sound"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "12.10.1"
+		application.process.id = "2572"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "indicator-sound-service"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #10
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "Thunderbird"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.icon_name = "thunderbird"
+		application.version = "17.0.6"
+		application.process.id = "2733"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "thunderbird"
+		window.x11.display = ":0"
+		application.language = "en_US.UTF-8"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #47
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.version = "0.30"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2416"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #51
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "Firefox"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.icon_name = "firefox"
+		application.version = "21.0"
+		application.process.id = "2753"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "firefox"
+		window.x11.display = ":0"
+		application.language = "en_US.UTF-8"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #63
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "pactl"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.process.id = "5565"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "pactl"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Sample #0
+	Name: audio-volume-change
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Volume: (invalid)
+	        (invalid)
+	        balance 0.00
+	Duration: 0.1s
+	Size: 11.5 KiB
+	Lazy: no
+	Filename: n/a
+	Properties:
+		media.role = "event"
+		event.description = "volume changed through key press"
+		event.id = "audio-volume-change"
+		media.name = "audio-volume-change"
+		media.filename = "/usr/share//sounds/freedesktop/stereo/audio-volume-change.oga"
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.version = "0.30"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2416"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Card #0
+	Name: alsa_card.usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "1"
+		alsa.card_name = "HD Pro Webcam C920"
+		alsa.long_card_name = "HD Pro Webcam C920 at usb-0000:00:14.0-1, high speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:14.0-usb-0:1:1.2"
+		sysfs.path = "/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/sound/card1"
+		udev.id = "usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "082d"
+		device.product.name = "HD Pro Webcam C920"
+		device.serial = "046d_HD_Pro_Webcam_C920_73BD39DF"
+		device.form_factor = "webcam"
+		device.string = "1"
+		device.description = "HD Pro Webcam C920"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "camera-web-usb"
+	Profiles:
+		input:analog-stereo: Analog Stereo Input (sinks: 0, sources: 1, priority. 60)
+		input:iec958-stereo: Digital Stereo (IEC958) Input (sinks: 0, sources: 1, priority. 55)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: input:iec958-stereo
+	Ports:
+		analog-input-microphone: Microphone (priority: 8700, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo
+		iec958-stereo-input: Digital Input (S/PDIF) (priority: 0, latency offset: 0 usec)
+			Part of profile(s): input:iec958-stereo
+
+Card #1
+	Name: alsa_card.usb-Logitech_Logitech_USB_Headset-00-Headset
+	Driver: module-alsa-card.c
+	Owner Module: 5
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "0"
+		device.description = "ClearChat Pro USB"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Profiles:
+		input:analog-mono: Analog Mono Input (sinks: 0, sources: 1, priority. 1)
+		output:analog-mono: Analog Mono Output (sinks: 1, sources: 0, priority. 100)
+		output:analog-mono+input:analog-mono: Analog Mono Duplex (sinks: 1, sources: 1, priority. 101)
+		output:analog-stereo: Analog Stereo Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-mono: Analog Stereo Output + Analog Mono Input (sinks: 1, sources: 1, priority. 6001)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-mono
+	Ports:
+		analog-input-microphone: Microphone (priority: 8700, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-mono, output:analog-mono+input:analog-mono, output:analog-stereo+input:analog-mono
+		analog-output-headphones: Headphones (priority: 9000, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-headphones"
+			Part of profile(s): output:analog-mono, output:analog-mono+input:analog-mono, output:analog-stereo, output:analog-stereo+input:analog-mono
+
+Card #2
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 6
+	Properties:
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "2"
+		device.description = "Built-in Audio"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		input:analog-stereo: Analog Stereo Input (sinks: 0, sources: 1, priority. 60)
+		output:analog-stereo: Analog Stereo Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Analog Stereo Duplex (sinks: 1, sources: 1, priority. 6060)
+		output:hdmi-stereo: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5400)
+		output:hdmi-stereo+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5460)
+		output:hdmi-stereo-extra1: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5200)
+		output:hdmi-stereo-extra1+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5260)
+		output:hdmi-surround-extra1: Digital Surround 5.1 (HDMI) Output (sinks: 1, sources: 0, priority. 100)
+		output:hdmi-surround-extra1+input:analog-stereo: Digital Surround 5.1 (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 160)
+		output:hdmi-stereo-extra2: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5200)
+		output:hdmi-stereo-extra2+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5260)
+		output:hdmi-surround-extra2: Digital Surround 5.1 (HDMI) Output (sinks: 1, sources: 0, priority. 100)
+		output:hdmi-surround-extra2+input:analog-stereo: Digital Surround 5.1 (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 160)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-input-microphone-internal: Internal Microphone (priority: 8900, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo, output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1+input:analog-stereo, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2+input:analog-stereo
+		analog-input-microphone-dock: Dock Microphone (priority: 7800, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo, output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1+input:analog-stereo, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2+input:analog-stereo
+		analog-input-microphone: Microphone (priority: 8700, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo, output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1+input:analog-stereo, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2+input:analog-stereo
+		analog-output-speaker: Speakers (priority: 10000, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-speakers"
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-output-headphones: Headphones (priority: 9000, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "audio-headphones"
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		hdmi-output-0: HDMI / DisplayPort (priority: 5900, latency offset: 0 usec, available)
+			Properties:
+				device.icon_name = "video-display"
+			Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo
+		hdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "video-display"
+			Part of profile(s): output:hdmi-stereo-extra1, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1, output:hdmi-surround-extra1+input:analog-stereo
+		hdmi-output-2: HDMI / DisplayPort 3 (priority: 5700, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "video-display"
+			Part of profile(s): output:hdmi-stereo-extra2, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2, output:hdmi-surround-extra2+input:analog-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-raring-t430s.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-raring-t430s.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/desktop-raring-t430s.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,889 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "3.0"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "3.0"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "3.0"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "3.0"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="1" name="usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920" card_name="alsa_card.usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920" namereg_fail=false tsched=yes fixed_latency_range=no ignore_dB=no deferred_volume=yes use_ucm=no card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "3.0"
+
+Module #5
+	Name: module-alsa-card
+	Argument: device_id="0" name="usb-Logitech_Logitech_USB_Headset-00-Headset" card_name="alsa_card.usb-Logitech_Logitech_USB_Headset-00-Headset" namereg_fail=false tsched=yes fixed_latency_range=no ignore_dB=no deferred_volume=yes use_ucm=no card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "3.0"
+
+Module #6
+	Name: module-alsa-card
+	Argument: device_id="2" name="pci-0000_00_1b.0" card_name="alsa_card.pci-0000_00_1b.0" namereg_fail=false tsched=yes fixed_latency_range=no ignore_dB=no deferred_volume=yes use_ucm=no card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "3.0"
+
+Module #7
+	Name: module-udev-detect
+	Argument: use_ucm=0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "3.0"
+
+Module #8
+	Name: module-bluetooth-policy
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Frédéric Dalleau"
+		module.description = "When a bluetooth sink or source is added, load module-loopback"
+		module.version = "3.0"
+
+Module #9
+	Name: module-bluetooth-discover
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Joao Paulo Rechi Vita"
+		module.description = "Detect available bluetooth audio devices and load bluetooth audio drivers"
+		module.version = "3.0"
+
+Module #10
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "3.0"
+
+Module #11
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "3.0"
+
+Module #12
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "3.0"
+
+Module #13
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Always keeps at least one sink loaded even if it's a null one"
+		module.version = "3.0"
+
+Module #14
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "3.0"
+
+Module #15
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "3.0"
+
+Module #16
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "3.0"
+
+Module #17
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "3.0"
+
+Module #18
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "3.0"
+
+Module #19
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "3.0"
+
+Module #20
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #21
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "3.0"
+
+Module #22
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "3.0"
+
+Module #23
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "3.0"
+
+Module #24
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/sylvain-ThinkPad-T430s:@/tmp/.ICE-unix/2338,unix/sylvain-ThinkPad-T430s:/tmp/.ICE-unix/2338
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "3.0"
+
+Sink #0
+	State: SUSPENDED
+	Name: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo
+	Description: ClearChat Pro USB Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0:  46% 1:  46%
+	        0: -20.23 dB 1: -20.23 dB
+	        balance 0.00
+	Base Volume:  89%
+	             -3.00 dB
+	Monitor Source: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "USB Audio"
+		alsa.id = "USB Audio"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "front:0"
+		device.buffering.buffer_size = "352800"
+		device.buffering.fragment_size = "176400"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "ClearChat Pro USB Analog Stereo"
+		alsa.mixer_name = "USB Mixer"
+		alsa.components = "USB046d:0a0b"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Ports:
+		analog-output-headphones: Headphones (priority: 9000)
+	Active Port: analog-output-headphones
+	Formats:
+		pcm
+
+Sink #1
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 6
+	Mute: no
+	Volume: 0:  16% 1:  16%
+	        0: -47.54 dB 1: -47.54 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC269VC Analog"
+		alsa.id = "ALC269VC Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:2"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "Built-in Audio Analog Stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:10ec0269,17aa21fb,00100203 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output-speaker: Speakers (priority: 10000)
+		analog-output-headphones: Headphones (priority: 9000, not available)
+	Active Port: analog-output-speaker
+	Formats:
+		pcm
+
+Source #0
+	State: SUSPENDED
+	Name: alsa_input.usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920.iec958-stereo
+	Description: HD Pro Webcam C920 Digital Stereo (IEC958)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 32000Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "USB Audio"
+		alsa.id = "USB Audio"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "1"
+		alsa.card_name = "HD Pro Webcam C920"
+		alsa.long_card_name = "HD Pro Webcam C920 at usb-0000:00:14.0-1, high speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:14.0-usb-0:1:1.2"
+		sysfs.path = "/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/sound/card1"
+		udev.id = "usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "082d"
+		device.product.name = "HD Pro Webcam C920"
+		device.serial = "046d_HD_Pro_Webcam_C920_73BD39DF"
+		device.form_factor = "webcam"
+		device.string = "iec958:1"
+		device.buffering.buffer_size = "256000"
+		device.buffering.fragment_size = "128000"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "iec958-stereo"
+		device.profile.description = "Digital Stereo (IEC958)"
+		device.description = "HD Pro Webcam C920 Digital Stereo (IEC958)"
+		alsa.mixer_name = "USB Mixer"
+		alsa.components = "USB046d:082d"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "camera-web-usb"
+	Ports:
+		iec958-stereo-input: Digital Input (S/PDIF) (priority: 0)
+	Active Port: iec958-stereo-input
+	Formats:
+		pcm
+
+Source #1
+	State: SUSPENDED
+	Name: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo.monitor
+	Description: Monitor of ClearChat Pro USB Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of ClearChat Pro USB Analog Stereo"
+		device.class = "monitor"
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "0"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Formats:
+		pcm
+
+Source #2
+	State: SUSPENDED
+	Name: alsa_input.usb-Logitech_Logitech_USB_Headset-00-Headset.analog-mono
+	Description: ClearChat Pro USB Analog Mono
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 1ch 44100Hz
+	Channel Map: mono
+	Owner Module: 5
+	Mute: no
+	Volume: 0: 100%
+	        0: 0.00 dB
+	        balance 0.00
+	Base Volume:  33%
+	             -29.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "USB Audio"
+		alsa.id = "USB Audio"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "hw:0"
+		device.buffering.buffer_size = "176400"
+		device.buffering.fragment_size = "88200"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-mono"
+		device.profile.description = "Analog Mono"
+		device.description = "ClearChat Pro USB Analog Mono"
+		alsa.mixer_name = "USB Mixer"
+		alsa.components = "USB046d:0a0b"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Ports:
+		analog-input-microphone: Microphone (priority: 8700)
+	Active Port: analog-input-microphone
+	Formats:
+		pcm
+
+Source #3
+	State: SUSPENDED
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Description: Monitor of Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 6
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor of Sink: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Latency: 0 usec, configured 0 usec
+	Flags: DECIBEL_VOLUME LATENCY 
+	Properties:
+		device.description = "Monitor of Built-in Audio Analog Stereo"
+		device.class = "monitor"
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "2"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Formats:
+		pcm
+
+Source #4
+	State: SUSPENDED
+	Name: alsa_input.pci-0000_00_1b.0.analog-stereo
+	Description: Built-in Audio Analog Stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 6
+	Mute: no
+	Volume: 0:  25% 1:  25%
+	        0: -35.69 dB 1: -35.69 dB
+	        balance 0.00
+	Base Volume:  10%
+	             -60.00 dB
+	Monitor of Sink: n/a
+	Latency: 0 usec, configured 0 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC269VC Analog"
+		alsa.id = "ALC269VC Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:2"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analog Stereo"
+		device.description = "Built-in Audio Analog Stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:10ec0269,17aa21fb,00100203 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-input-microphone-internal: Internal Microphone (priority: 8900)
+		analog-input-microphone-dock: Dock Microphone (priority: 7800, not available)
+		analog-input-microphone: Microphone (priority: 8700, not available)
+	Active Port: analog-input-microphone-internal
+	Formats:
+		pcm
+
+Client #0
+	Driver: module-console-kit.c
+	Owner Module: 16
+	Properties:
+		application.name = "ConsoleKit Session /org/freedesktop/ConsoleKit/Session2"
+		console-kit.session = "/org/freedesktop/ConsoleKit/Session2"
+
+Client #5
+	Driver: module-x11-xsmp.c
+	Owner Module: 24
+	Properties:
+		application.name = "XSMP Session on gnome-session as 109ee05a0d9d9a2996137084790972133100000023380031"
+		xsmp.vendor = "gnome-session"
+		xsmp.client.id = "109ee05a0d9d9a2996137084790972133100000023380031"
+
+Client #6
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "GNOME Volume Control Media Keys"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.id = "org.gnome.VolumeControl"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "3.6.4"
+		application.process.id = "2416"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #7
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "Indicator Sound"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.id = "com.canonical.indicator.sound"
+		application.icon_name = "multimedia-volume-control"
+		application.version = "12.10.1"
+		application.process.id = "2572"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "indicator-sound-service"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #10
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "Thunderbird"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.icon_name = "thunderbird"
+		application.version = "17.0.6"
+		application.process.id = "2733"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "thunderbird"
+		window.x11.display = ":0"
+		application.language = "en_US.UTF-8"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #47
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.version = "0.30"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2416"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #51
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "Firefox"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.icon_name = "firefox"
+		application.version = "21.0"
+		application.process.id = "2753"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "firefox"
+		window.x11.display = ":0"
+		application.language = "en_US.UTF-8"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Client #64
+	Driver: protocol-native.c
+	Owner Module: 10
+	Properties:
+		application.name = "pactl"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.process.id = "5569"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "pactl"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Sample #0
+	Name: audio-volume-change
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Volume: (invalid)
+	        (invalid)
+	        balance 0.00
+	Duration: 0.1s
+	Size: 11.5 KiB
+	Lazy: no
+	Filename: n/a
+	Properties:
+		media.role = "event"
+		event.description = "volume changed through key press"
+		event.id = "audio-volume-change"
+		media.name = "audio-volume-change"
+		media.filename = "/usr/share//sounds/freedesktop/stereo/audio-volume-change.oga"
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "27"
+		application.version = "0.30"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2416"
+		application.process.user = "sylvain"
+		application.process.host = "sylvain-ThinkPad-T430s"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "en_US.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "d8124ed0afb10dc2d2ba1e0d517d0d27"
+
+Card #0
+	Name: alsa_card.usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920
+	Driver: module-alsa-card.c
+	Owner Module: 4
+	Properties:
+		alsa.card = "1"
+		alsa.card_name = "HD Pro Webcam C920"
+		alsa.long_card_name = "HD Pro Webcam C920 at usb-0000:00:14.0-1, high speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:14.0-usb-0:1:1.2"
+		sysfs.path = "/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/sound/card1"
+		udev.id = "usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "082d"
+		device.product.name = "HD Pro Webcam C920"
+		device.serial = "046d_HD_Pro_Webcam_C920_73BD39DF"
+		device.form_factor = "webcam"
+		device.string = "1"
+		device.description = "HD Pro Webcam C920"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "camera-web-usb"
+	Profiles:
+		input:analog-stereo: Analog Stereo Input (sinks: 0, sources: 1, priority. 60)
+		input:iec958-stereo: Digital Stereo (IEC958) Input (sinks: 0, sources: 1, priority. 55)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: input:iec958-stereo
+	Ports:
+		analog-input-microphone: Microphone (priority: 8700, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo
+		iec958-stereo-input: Digital Input (S/PDIF) (priority: 0, latency offset: 0 usec)
+			Part of profile(s): input:iec958-stereo
+
+Card #1
+	Name: alsa_card.usb-Logitech_Logitech_USB_Headset-00-Headset
+	Driver: module-alsa-card.c
+	Owner Module: 5
+	Properties:
+		alsa.card = "0"
+		alsa.card_name = "Logitech USB Headset"
+		alsa.long_card_name = "Logitech Logitech USB Headset at usb-0000:00:1a.0-1.2.3, full speed"
+		alsa.driver_name = "snd_usb_audio"
+		device.bus_path = "pci-0000:00:1a.0-usb-0:1.2.3:1.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2.3/1-1.2.3:1.0/sound/card0"
+		udev.id = "usb-Logitech_Logitech_USB_Headset-00-Headset"
+		device.bus = "usb"
+		device.vendor.id = "046d"
+		device.vendor.name = "Logitech, Inc."
+		device.product.id = "0a0b"
+		device.product.name = "ClearChat Pro USB"
+		device.serial = "Logitech_Logitech_USB_Headset"
+		device.form_factor = "headset"
+		device.string = "0"
+		device.description = "ClearChat Pro USB"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-headset-usb"
+		device.intended_roles = "phone"
+	Profiles:
+		input:analog-mono: Analog Mono Input (sinks: 0, sources: 1, priority. 1)
+		output:analog-mono: Analog Mono Output (sinks: 1, sources: 0, priority. 100)
+		output:analog-mono+input:analog-mono: Analog Mono Duplex (sinks: 1, sources: 1, priority. 101)
+		output:analog-stereo: Analog Stereo Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-mono: Analog Stereo Output + Analog Mono Input (sinks: 1, sources: 1, priority. 6001)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-mono
+	Ports:
+		analog-input-microphone: Microphone (priority: 8700, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-mono, output:analog-mono+input:analog-mono, output:analog-stereo+input:analog-mono
+		analog-output-headphones: Headphones (priority: 9000, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-headphones"
+			Part of profile(s): output:analog-mono, output:analog-mono+input:analog-mono, output:analog-stereo, output:analog-stereo+input:analog-mono
+
+Card #2
+	Name: alsa_card.pci-0000_00_1b.0
+	Driver: module-alsa-card.c
+	Owner Module: 6
+	Properties:
+		alsa.card = "2"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xd2530000 irq 48"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "7 Series/C210 Series Chipset Family High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "2"
+		device.description = "Built-in Audio"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Profiles:
+		input:analog-stereo: Analog Stereo Input (sinks: 0, sources: 1, priority. 60)
+		output:analog-stereo: Analog Stereo Output (sinks: 1, sources: 0, priority. 6000)
+		output:analog-stereo+input:analog-stereo: Analog Stereo Duplex (sinks: 1, sources: 1, priority. 6060)
+		output:hdmi-stereo: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5400)
+		output:hdmi-stereo+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5460)
+		output:hdmi-stereo-extra1: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5200)
+		output:hdmi-stereo-extra1+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5260)
+		output:hdmi-surround-extra1: Digital Surround 5.1 (HDMI) Output (sinks: 1, sources: 0, priority. 100)
+		output:hdmi-surround-extra1+input:analog-stereo: Digital Surround 5.1 (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 160)
+		output:hdmi-stereo-extra2: Digital Stereo (HDMI) Output (sinks: 1, sources: 0, priority. 5200)
+		output:hdmi-stereo-extra2+input:analog-stereo: Digital Stereo (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 5260)
+		output:hdmi-surround-extra2: Digital Surround 5.1 (HDMI) Output (sinks: 1, sources: 0, priority. 100)
+		output:hdmi-surround-extra2+input:analog-stereo: Digital Surround 5.1 (HDMI) Output + Analog Stereo Input (sinks: 1, sources: 1, priority. 160)
+		off: Off (sinks: 0, sources: 0, priority. 0)
+	Active Profile: output:analog-stereo+input:analog-stereo
+	Ports:
+		analog-input-microphone-internal: Internal Microphone (priority: 8900, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo, output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1+input:analog-stereo, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2+input:analog-stereo
+		analog-input-microphone-dock: Dock Microphone (priority: 7800, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo, output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1+input:analog-stereo, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2+input:analog-stereo
+		analog-input-microphone: Microphone (priority: 8700, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "audio-input-microphone"
+			Part of profile(s): input:analog-stereo, output:analog-stereo+input:analog-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1+input:analog-stereo, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2+input:analog-stereo
+		analog-output-speaker: Speakers (priority: 10000, latency offset: 0 usec)
+			Properties:
+				device.icon_name = "audio-speakers"
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		analog-output-headphones: Headphones (priority: 9000, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "audio-headphones"
+			Part of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo
+		hdmi-output-0: HDMI / DisplayPort (priority: 5900, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "video-display"
+			Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo
+		hdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "video-display"
+			Part of profile(s): output:hdmi-stereo-extra1, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1, output:hdmi-surround-extra1+input:analog-stereo
+		hdmi-output-2: HDMI / DisplayPort 3 (priority: 5700, latency offset: 0 usec, not available)
+			Properties:
+				device.icon_name = "video-display"
+			Part of profile(s): output:hdmi-stereo-extra2, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2, output:hdmi-surround-extra2+input:analog-stereo

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/modules-desktop-precise-0.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/modules-desktop-precise-0.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/modules-desktop-precise-0.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,8 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "1.1"

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/modules-desktop-precise.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/modules-desktop-precise.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/modules-desktop-precise.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,213 @@
+Module #0
+	Name: module-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute state of devices"
+		module.version = "1.1"
+
+Module #1
+	Name: module-stream-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the volume/mute/device state of streams"
+		module.version = "1.1"
+
+Module #2
+	Name: module-card-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore profile of cards"
+		module.version = "1.1"
+
+Module #3
+	Name: module-augment-properties
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Augment the property sets of streams with additional static information"
+		module.version = "1.1"
+
+Module #4
+	Name: module-alsa-card
+	Argument: device_id="0" name="pci-0000_00_1b.0" card_name="alsa_card.pci-0000_00_1b.0" namereg_fail=false tsched=yes ignore_dB=no deferred_volume=yes card_properties="module-udev-detect.discovered=1"
+	Usage counter: 0
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "ALSA Card"
+		module.version = "1.1"
+
+Module #5
+	Name: module-udev-detect
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Detect available audio hardware and load matching drivers"
+		module.version = "1.1"
+
+Module #6
+	Name: module-bluetooth-discover
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Joao Paulo Rechi Vita"
+		module.description = "Detect available bluetooth audio devices and load bluetooth audio drivers"
+		module.version = "1.1"
+
+Module #7
+	Name: module-native-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Native protocol (UNIX sockets)"
+		module.version = "1.1"
+
+Module #8
+	Name: module-gconf
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "GConf Adapter"
+		module.version = "1.1"
+
+Module #9
+	Name: module-default-device-restore
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically restore the default sink and source"
+		module.version = "1.1"
+
+Module #10
+	Name: module-rescue-streams
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is removed, try to move their streams to the default sink/source"
+		module.version = "1.1"
+
+Module #11
+	Name: module-always-sink
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Utrzymywanie zawsze co najmniej jednego wczytanego odpływu nawet, jeśli to pusty odpływ"
+		module.version = "1.1"
+
+Module #12
+	Name: module-intended-roles
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Automatically set device of streams based of intended roles of devices"
+		module.version = "1.1"
+
+Module #13
+	Name: module-suspend-on-idle
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "When a sink/source is idle for too long, suspend it"
+		module.version = "1.1"
+
+Module #14
+	Name: module-console-kit
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Create a client for each ConsoleKit session of this user"
+		module.version = "1.1"
+
+Module #15
+	Name: module-position-event-sounds
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Position event sounds between L and R depending on the position on screen of the widget triggering them."
+		module.version = "1.1"
+
+Module #16
+	Name: module-filter-heuristics
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Detect when various filters are desirable"
+		module.version = "1.1"
+
+Module #17
+	Name: module-filter-apply
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Colin Guthrie"
+		module.description = "Load filter sinks automatically when needed"
+		module.version = "1.1"
+
+Module #18
+	Name: module-switch-on-port-available
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		
+
+Module #19
+	Name: module-x11-publish
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 credential publisher"
+		module.version = "1.1"
+
+Module #20
+	Name: module-x11-bell
+	Argument: display=:0 sample=bell.ogg
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 bell interceptor"
+		module.version = "1.1"
+
+Module #21
+	Name: module-x11-cork-request
+	Argument: display=:0
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Synthesize X11 media key events when cork/uncork is requested"
+		module.version = "1.1"
+
+Module #22
+	Name: module-x11-xsmp
+	Argument: display=:0 session_manager=local/g580:@/tmp/.ICE-unix/2788,unix/g580:/tmp/.ICE-unix/2788
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "X11 session management"
+		module.version = "1.1"
+
+Module #23
+	Name: module-cli-protocol-unix
+	Argument: 
+	Usage counter: n/a
+	Properties:
+		module.author = "Lennart Poettering"
+		module.description = "Command line interface protocol (UNIX sockets)"
+		module.version = "1.1"

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/samples-desktop-precise.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/samples-desktop-precise.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/samples-desktop-precise.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,60 @@
+Sample #0
+	Name: bell-window-system
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Volume: (invalid)
+	        (invalid)
+	        balance 0.00
+	Duration: 0.8s
+	Size: 138.3 KiB
+	Lazy: no
+	Filename: n/a
+	Properties:
+		media.role = "event"
+		application.process.id = "3036"
+		application.name = "pantheon-terminal"
+		event.description = "Zdarzenie sygnału dźwiękowego"
+		event.id = "bell-window-system"
+		media.name = "bell-window-system"
+		media.filename = "/usr/share//sounds/freedesktop/stereo/bell.oga"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		window.x11.display = ":0"
+		window.x11.screen = "0"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gala"
+		application.language = "pl_PL.UTF-8"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"
+
+Sample #1
+	Name: audio-volume-change
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Volume: (invalid)
+	        (invalid)
+	        balance 0.00
+	Duration: 0.1s
+	Size: 11.5 KiB
+	Lazy: no
+	Filename: n/a
+	Properties:
+		media.role = "event"
+		event.description = "volume changed through key press"
+		event.id = "audio-volume-change"
+		media.name = "audio-volume-change"
+		media.filename = "/usr/share//sounds/freedesktop/stereo/audio-volume-change.oga"
+		application.name = "libcanberra"
+		native-protocol.peer = "UNIX socket client"
+		native-protocol.version = "26"
+		application.version = "0.28"
+		application.id = "org.freedesktop.libcanberra"
+		application.process.id = "2834"
+		application.process.user = "zyga"
+		application.process.host = "g580"
+		application.process.binary = "gnome-settings-daemon"
+		application.language = "pl_PL.UTF-8"
+		window.x11.display = ":0"
+		application.process.machine_id = "71e162f888790906f342d4960000000b"
+		application.process.session_id = "71e162f888790906f342d4960000000b-1369811321.802895-1218540690"

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise-0.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise-0.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise-0.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,53 @@
+Sink #0
+	State: RUNNING
+	Name: alsa_output.pci-0000_02_00.1.hdmi-stereo-extra1
+	Description: HDA NVidia Digital Stereo (HDMI)
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0: 100% 1: 100%
+	        0: 0.00 dB 1: 0.00 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_02_00.1.hdmi-stereo-extra1.monitor
+	Latency: 64486 usec, configured 90000 usec
+	Flags: HARDWARE DECIBEL_VOLUME LATENCY SET_FORMATS 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "HDMI 1"
+		alsa.id = "HDMI 1"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "7"
+		alsa.card = "2"
+		alsa.card_name = "HDA NVidia"
+		alsa.long_card_name = "HDA NVidia at 0xfbdfc000 irq 34"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:02:00.1"
+		sysfs.path = "/devices/pci0000:00/0000:00:03.0/0000:02:00.1/sound/card2"
+		device.bus = "pci"
+		device.vendor.id = "10de"
+		device.vendor.name = "NVIDIA Corporation"
+		device.string = "hdmi:2,1"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "hdmi-stereo-extra1"
+		device.profile.description = "Digital Stereo (HDMI)"
+		device.description = "HDA NVidia Digital Stereo (HDMI)"
+		alsa.mixer_name = "Nvidia GPU 42 HDMI/DP"
+		alsa.components = "HDA:10de0042,14622804,00100100"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		hdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, available)
+	Active Port: hdmi-output-1
+	Formats:
+		pcm

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise-1.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise-1.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise-1.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,56 @@
+Sink #1
+	State: RUNNING
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Wbudowany dźwięk Analogowe stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 5
+	Mute: no
+	Volume: 0:  46% 1:  46%
+	        0: -20.23 dB 1: -20.23 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 85065 usec, configured 90000 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "ALC1200 Analog"
+		alsa.id = "ALC1200 Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel"
+		alsa.long_card_name = "HDA Intel at 0xf9ff8000 irq 70"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "82801JI (ICH10 Family) HD Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analogowe stereo"
+		device.description = "Wbudowany dźwięk Analogowe stereo"
+		alsa.mixer_name = "Realtek ALC1200"
+		alsa.components = "HDA:10ec0888,104383c0,00100101"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output: Wyjście analogowe (priority: 9900)
+		analog-output-headphones: Słuchawki (priority: 9000, available)
+	Active Port: analog-output
+	Formats:
+		pcm

=== added file 'checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise.txt'
--- checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/pactl_data/sinks-desktop-precise.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,56 @@
+Sink #0
+	State: RUNNING
+	Name: alsa_output.pci-0000_00_1b.0.analog-stereo
+	Description: Wbudowany dźwięk Analogowe stereo
+	Driver: module-alsa-card.c
+	Sample Specification: s16le 2ch 44100Hz
+	Channel Map: front-left,front-right
+	Owner Module: 4
+	Mute: no
+	Volume: 0:  64% 1:  64%
+	        0: -11.67 dB 1: -11.67 dB
+	        balance 0.00
+	Base Volume: 100%
+	             0.00 dB
+	Monitor Source: alsa_output.pci-0000_00_1b.0.analog-stereo.monitor
+	Latency: 60668 usec, configured 66000 usec
+	Flags: HARDWARE HW_MUTE_CTRL HW_VOLUME_CTRL DECIBEL_VOLUME LATENCY 
+	Properties:
+		alsa.resolution_bits = "16"
+		device.api = "alsa"
+		device.class = "sound"
+		alsa.class = "generic"
+		alsa.subclass = "generic-mix"
+		alsa.name = "CONEXANT Analog"
+		alsa.id = "CONEXANT Analog"
+		alsa.subdevice = "0"
+		alsa.subdevice_name = "subdevice #0"
+		alsa.device = "0"
+		alsa.card = "0"
+		alsa.card_name = "HDA Intel PCH"
+		alsa.long_card_name = "HDA Intel PCH at 0xe0610000 irq 46"
+		alsa.driver_name = "snd_hda_intel"
+		device.bus_path = "pci-0000:00:1b.0"
+		sysfs.path = "/devices/pci0000:00/0000:00:1b.0/sound/card0"
+		device.bus = "pci"
+		device.vendor.id = "8086"
+		device.vendor.name = "Intel Corporation"
+		device.product.name = "Panther Point High Definition Audio Controller"
+		device.form_factor = "internal"
+		device.string = "front:0"
+		device.buffering.buffer_size = "65536"
+		device.buffering.fragment_size = "32768"
+		device.access_mode = "mmap+timer"
+		device.profile.name = "analog-stereo"
+		device.profile.description = "Analogowe stereo"
+		device.description = "Wbudowany dźwięk Analogowe stereo"
+		alsa.mixer_name = "Intel PantherPoint HDMI"
+		alsa.components = "HDA:14f1506e,17aac023,00100003 HDA:80862806,80860101,00100000"
+		module-udev-detect.discovered = "1"
+		device.icon_name = "audio-card-pci"
+	Ports:
+		analog-output-speaker: Głośniki (priority: 10000, not available)
+		analog-output-headphones: Słuchawki (priority: 9000, available)
+	Active Port: analog-output-headphones
+	Formats:
+		pcm

=== added file 'checkbox-support/checkbox_support/parsers/tests/test_dmi.py'
--- checkbox-support/checkbox_support/parsers/tests/test_dmi.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/test_dmi.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,80 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+class DmiResult:
+
+    def __init__(self):
+        self.devices = []
+
+    def addDmiDevice(self, device):
+        self.devices.append(device)
+
+    def getDevice(self, category):
+        for device in self.devices:
+            if device.category == category:
+                return device
+
+        return None
+
+
+class TestDmiMixin:
+
+    def getParser(self):
+        raise NotImplementedError()
+
+    def getResult(self):
+        parser = self.getParser()
+        result = DmiResult()
+        parser.run(result)
+        return result
+
+    def test_devices(self):
+        result = self.getResult()
+        self.assertEqual(len(result.devices), 4)
+
+    def test_bios(self):
+        result = self.getResult()
+        device = result.getDevice("BIOS")
+        self.assertTrue(device)
+        self.assertEqual(device.product, "BIOS PRODUCT")
+        self.assertEqual(device.vendor, "BIOS VENDOR")
+        self.assertEqual(device.serial, None)
+
+    def test_board(self):
+        result = self.getResult()
+        device = result.getDevice("BOARD")
+        self.assertTrue(device)
+        self.assertEqual(device.product, None)
+        self.assertEqual(device.vendor, None)
+        self.assertEqual(device.serial, None)
+
+    def test_chassis(self):
+        result = self.getResult()
+        device = result.getDevice("CHASSIS")
+        self.assertTrue(device)
+        self.assertEqual(device.product, "Notebook")
+        self.assertEqual(device.vendor, "CHASSIS VENDOR")
+        self.assertEqual(device.serial, None)
+
+    def test_system(self):
+        result = self.getResult()
+        device = result.getDevice("SYSTEM")
+        self.assertTrue(device)
+        self.assertEqual(device.product, "SYSTEM PRODUCT")
+        self.assertEqual(device.vendor, "SYSTEM VENDOR")
+        self.assertEqual(device.serial, "SYSTEM SERIAL")

=== added file 'checkbox-support/checkbox_support/parsers/tests/test_dmidecode.py'
--- checkbox-support/checkbox_support/parsers/tests/test_dmidecode.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/test_dmidecode.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,60 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+from io import StringIO
+
+from unittest import TestCase
+
+from checkbox.parsers.dmidecode import DmidecodeParser
+from checkbox.parsers.tests.test_dmi import TestDmiMixin
+
+
+FAKE_DMIDECODE = """\
+# dmidecode 2.9
+SMBIOS 2.4 present.
+
+Handle 0x0000, DMI type 0, 24 bytes
+BIOS Information
+\tVendor: BIOS VENDOR
+\tVersion: BIOS PRODUCT
+
+Handle 0x0001, DMI type 1, 27 bytes
+System Information
+\tManufacturer: SYSTEM VENDOR
+\tProduct Name: SYSTEM PRODUCT
+\tSerial Number: SYSTEM SERIAL
+
+Handle 0x0002, DMI type 2, 8 bytes
+Base Board Information
+\tManufacturer: Not Available
+\tProduct Name: Not Available
+\tSerial Number: Not Available
+
+Handle 0x0003, DMI type 3, 13 bytes
+Chassis Information
+\tManufacturer: CHASSIS VENDOR
+\tType: Notebook
+\tSerial Number: Not Available
+"""
+
+
+class TestDmidecodeParser(TestCase, TestDmiMixin):
+
+    def getParser(self):
+        stream = StringIO(FAKE_DMIDECODE)
+        return DmidecodeParser(stream)

=== added file 'checkbox-support/checkbox_support/parsers/tests/test_efi.py'
--- checkbox-support/checkbox_support/parsers/tests/test_efi.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/test_efi.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,63 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+from io import StringIO
+
+from unittest import TestCase
+
+from checkbox.parsers.efi import EfiParser
+
+
+class EfiResult:
+
+    def __init__(self):
+        self.device = None
+
+    def setEfiDevice(self, device):
+        self.device = device
+
+
+class TestCputableParser(TestCase):
+
+    def getParser(self, string):
+        stream = StringIO(string)
+        return EfiParser(stream)
+
+    def getResult(self, string):
+        parser = self.getParser(string)
+        result = EfiResult()
+        parser.run(result)
+        return result
+
+    def test_empty(self):
+        result = self.getResult("")
+        self.assertEqual(result.device, None)
+
+    def test_product(self):
+        result = self.getResult("""
+Foo Bar
+""")
+        self.assertEqual(result.device.vendor, None)
+        self.assertEqual(result.device.product, "Foo Bar")
+
+    def test_vendor_product(self):
+        result = self.getResult("""
+Foo by Bar
+""")
+        self.assertEqual(result.device.vendor, "Foo")
+        self.assertEqual(result.device.product, "Bar")

=== added file 'checkbox-support/checkbox_support/parsers/tests/test_pactl.py'
--- checkbox-support/checkbox_support/parsers/tests/test_pactl.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/test_pactl.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,561 @@
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+:mod:`checkbox.parsers.tests.test_pactl` -- tests for pactl parser
+==================================================================
+"""
+
+from math import log10, floor, ceil
+from unittest import TestCase
+
+from pkg_resources import resource_filename
+
+from checkbox.parsers import pyparsing as p
+from checkbox.parsers import pactl
+
+
+class ParsingMixIn:
+    """
+    Mix-in class for writing tests that parse stuff.
+
+    This mix-in adds the assertParse() method which displays helpful data in
+    case of problems.
+    """
+
+    def parse(self, syntax, text):
+        return syntax.parseString(text, parseAll=True)
+
+    def assertParses(self, syntax, text):
+        try:
+            return self.parse(syntax, text)
+        except p.ParseBaseException as exc:
+            if hasattr(exc, 'col') and hasattr(exc, 'lineno'):
+                lineno = exc.lineno
+                col = exc.col
+            else:
+                lineno = p.lineno(exc.loc, text)
+                col = p.col(exc.loc, text)
+            print()
+            print("Parse error on line {} column {}: {}".format(
+                lineno, col, exc))
+            self._show_text(text, lineno, col, context=3)
+            raise
+
+    def _show_text(self, text, hl_line=None, hl_col=None, context=None):
+        """
+        Show a body of text, with line and column markers.
+
+        If both hl_line and hl_col are provided, they will be used
+        to highlight the particular spot in the text.
+        """
+        lines = text.splitlines(True)
+        if hl_line is not None and hl_col is not None and context is not None:
+            window = slice(
+                max(0, hl_line - context),
+                min(hl_line + context, len(lines)))
+        else:
+            window = slice(0, len(lines))
+        lines = lines[window]
+        num_lines = len(lines)
+        num_cols = max(len(line) for line in lines)
+        col_lines_needed = floor(log10(num_cols))
+        line_cols_needed = ceil(log10(window.start + num_lines))
+
+        def print_col_ruler():
+            for ndigit in range(col_lines_needed, -1, -1):
+                print(" " * (line_cols_needed + 2), end='')
+                print_it = False
+                for colno in range(1, num_cols + 1):
+                    digit = (colno // 10 ** ndigit) % 10
+                    if digit > 0:
+                        print_it = True
+                    print(digit if print_it else ' ', end='')
+                print("")
+            print(" " * (line_cols_needed + 1) + "+-" + "-" * num_cols)
+        print_col_ruler()
+        for lineno, line in enumerate(lines, window.start + 1):
+            print(("{:" + str(line_cols_needed) + "d} |").format(lineno),
+                  end='')
+            for c in line:
+                if c.isprintable():
+                    print(c, end='')
+                elif c == '\t':
+                    print('\x1B[33mT\x1B[0m', end='')
+                elif c == '\n':
+                    print('\x1B[32;1m\\n\x1B[0m', end='')
+                else:
+                    print('\x1B[33m%r\x1B[0m' % c, end='')
+            print()
+            if lineno == hl_line:
+                print('\x1B[37;1m' + '_' * (line_cols_needed + 1) +
+                      hl_col * '_' + '^\x1B[0m')
+
+
+class PactlDataMixIn:
+    """
+    Mix in with a helper method to load sample pactl data
+    """
+
+    def get_text(self, name):
+        resource = 'parsers/tests/pactl_data/{}.txt'.format(name)
+        filename = resource_filename('checkbox', resource)
+        with open(filename, 'rt', encoding='UTF-8') as stream:
+            return stream.read()
+
+
+class ParsingTestCase(TestCase, ParsingMixIn):
+    """
+    Vanilla TestCase with the ParsingMixIn class added
+    """
+
+
+class PropertyTests(ParsingTestCase):
+
+    def test_smoke(self):
+        prop = self.assertParses(
+            pactl.Property.Syntax, 'device.vendor.name = "Intel Corporation"'
+        )['property']
+        self.assertEqual(prop.name, 'device.vendor.name')
+        self.assertEqual(prop.value, 'Intel Corporation')
+
+    def test_underscore(self):
+        prop = self.assertParses(
+            pactl.Property.Syntax, 'alsa.resolution_bits = "16"'
+        )['property']
+        self.assertEqual(prop.name, 'alsa.resolution_bits')
+        self.assertEqual(prop.value, '16')
+
+    def test_dash(self):
+        prop = self.assertParses(
+            pactl.Property.Syntax, 'module-udev-detect.discovered = "1"'
+        )['property']
+        self.assertEqual(prop.name, 'module-udev-detect.discovered')
+        self.assertEqual(prop.value, '1')
+
+
+class PortTests(ParsingTestCase):
+
+    def test_port(self):
+        port = self.assertParses(
+            pactl.Port.Syntax, (
+                'hdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, available)')
+        )['port']
+        self.assertEqual(port.name, 'hdmi-output-1')
+        self.assertEqual(port.label, 'HDMI / DisplayPort 2')
+        self.assertEqual(port.priority, 5800)
+        self.assertEqual(port.availability, 'available')
+
+    def test_port_not_available(self):
+        port = self.assertParses(
+            pactl.Port.Syntax, (
+                'analog-output-headphones: Słuchawki (priority: 9000, not available)')
+        )['port']
+        self.assertEqual(port.name, 'analog-output-headphones')
+        self.assertEqual(port.label, 'Słuchawki')
+        self.assertEqual(port.priority, 9000)
+        self.assertEqual(port.availability, 'not available')
+
+    def test_port_no_availability_info(self):
+        port = self.assertParses(
+            pactl.Port.Syntax, (
+                'analog-output: Wyjście analogowe (priority: 9900)')
+        )['port']
+        self.assertEqual(port.name, 'analog-output')
+        self.assertEqual(port.label, 'Wyjście analogowe')
+        self.assertEqual(port.priority, 9900)
+        self.assertEqual(port.availability, '')
+
+    def test_chinese_label(self):
+        port = self.assertParses(
+            pactl.Port.Syntax, (
+                'analog-output;output-amplifier-on: 模拟输出 / 均衡器 (priority: 9910)')
+        )['port']
+        self.assertEqual(port.name, 'analog-output;output-amplifier-on')
+        self.assertEqual(port.label, '模拟输出 / 均衡器')
+        self.assertEqual(port.priority, 9910)
+        self.assertEqual(port.availability, '')
+
+
+class ProfileTests(ParsingTestCase):
+
+    def test_smoke(self):
+        profiles = (
+            'input:analog-stereo: Wejście Analogowe stereo (sinks: 0, sources: 1, priority. 60)',
+            'off: Wyłącz (sinks: 0, sources: 0, priority. 0)',
+            'output:analog-stereo+input:analog-stereo: Analogowy dupleks stereo (sinks: 1, sources: 1, priority. 6060)',
+            'output:analog-stereo: Wyjście Analogowe stereo (sinks: 1, sources: 0, priority. 6000)',
+            'output:analog-surround-40+input:analog-stereo: Wyjście Analogowe surround 4.0 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 760)',
+            'output:analog-surround-40: Wyjście Analogowe surround 4.0 (sinks: 1, sources: 0, priority. 700)',
+            'output:analog-surround-41+input:analog-stereo: Wyjście Analogowe surround 4.1 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 860)',
+            'output:analog-surround-41: Wyjście Analogowe surround 4.1 (sinks: 1, sources: 0, priority. 800)',
+            'output:analog-surround-50+input:analog-stereo: Wyjście Analogowe surround 5.0 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 760)',
+            'output:analog-surround-50: Wyjście Analogowe surround 5.0 (sinks: 1, sources: 0, priority. 700)',
+            'output:analog-surround-51+input:analog-stereo: Wyjście Analogowe surround 5.1 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 860)',
+            'output:analog-surround-51: Wyjście Analogowe surround 5.1 (sinks: 1, sources: 0, priority. 800)',
+            'output:analog-surround-71+input:analog-stereo: Wyjście Analog Surround 7.1 + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 760)',
+            'output:analog-surround-71: Wyjście Analog Surround 7.1 (sinks: 1, sources: 0, priority. 700)',
+            'output:hdmi-stereo-extra1: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5200)',
+            'output:hdmi-stereo-extra2: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5200)',
+            'output:hdmi-stereo: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5400)',
+            'output:hdmi-surround-extra2: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 100)',
+            'output:hdmi-surround: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 300)',
+            'output:iec958-stereo+input:analog-stereo: Wyjście Cyfrowe stereo (IEC958) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 5560)',
+            'output:iec958-stereo: Wyjście Cyfrowe stereo (IEC958) (sinks: 1, sources: 0, priority. 5500)',
+        )
+        for profile_text in profiles:
+            profile = self.assertParses(
+                pactl.Profile.Syntax, profile_text,
+            )['profile']
+            self.assertNotEqual(profile.name, "")
+            self.assertNotEqual(profile.label, "")
+            self.assertNotEqual(profile.sink_cnt, "")
+            self.assertNotEqual(profile.source_cnt, "")
+
+    def test_HDMI_in_label(self):
+        # This checks that '(HDMI)' does not confuse the parser to parse
+        # '(' before 'sinks'
+        profile = self.assertParses(
+            pactl.Profile.Syntax,
+            'output:hdmi-stereo-extra1: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5200)'
+        )['profile']
+        self.assertEqual(profile.name, "output:hdmi-stereo-extra1")
+        self.assertEqual(profile.label, "Wyjście Digital Stereo (HDMI)")
+        self.assertEqual(profile.sink_cnt, 1)
+        self.assertEqual(profile.source_cnt, 0)
+        self.assertEqual(profile.priority, 5200)
+
+    def test_IEC985_in_label(self):
+        # This checks that '(IEC985)' does not confuse the parser to parse
+        # '(' before 'sinks'
+        profile = self.assertParses(
+            pactl.Profile.Syntax,
+            'output:iec958-stereo: Wyjście Cyfrowe stereo (IEC958) (sinks: 1, sources: 0, priority. 5500)'
+        )['profile']
+        self.assertEqual(profile.name, "output:iec958-stereo")
+        self.assertEqual(profile.label, "Wyjście Cyfrowe stereo (IEC958)")
+        self.assertEqual(profile.sink_cnt, 1)
+        self.assertEqual(profile.source_cnt, 0)
+        self.assertEqual(profile.priority, 5500)
+        self.assertNotEqual(profile.priority, "")
+
+    def test_colon_after_priority(self):
+        # This checks that : can be parsed correctly after priority
+        profile = self.assertParses(
+            pactl.Profile.Syntax,
+            'output:hdmi-stereo-extra1: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority: 5800)'
+        )['profile']
+        self.assertEqual(profile.priority, 5800)
+
+
+class AttributeTests(ParsingTestCase):
+
+    def test_simple(self):
+        attr = self.assertParses(
+            pactl.GenericSimpleAttribute.Syntax,
+            'Sample Specification: s16le 2ch 44100Hz'
+        )['attribute']
+        self.assertEqual(attr.name, 'Sample Specification')
+        self.assertEqual(attr.value, 's16le 2ch 44100Hz')
+
+    def test_leading_space(self):
+        with self.assertRaises(p.ParseBaseException):
+            self.parse(pactl.GenericSimpleAttribute.Syntax, ' attr: value')
+
+    def test_empty_value(self):
+        attr = self.assertParses(
+            pactl.GenericSimpleAttribute.Syntax, 'Argument:'
+        )['attribute']
+        self.assertEqual(attr.name, 'Argument')
+        self.assertEqual(attr.value, '')
+
+    def test_properties(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Properties:\n'
+                '\talsa.resolution_bits = "16"\n'
+                '\tdevice.api = "alsa"\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Properties')
+        self.assertIsInstance(attr.value, list)
+        self.assertIsInstance(attr.value[0], pactl.Property)
+        self.assertIsInstance(attr.value[1], pactl.Property)
+        self.assertEqual(attr.value[0].name, 'alsa.resolution_bits')
+        self.assertEqual(attr.value[0].value, '16')
+        self.assertEqual(attr.value[1].name, 'device.api')
+        self.assertEqual(attr.value[1].value, 'alsa')
+
+    def test_volume(self):
+        # NOTE: both of those are a bit odd as they use spaces for the extra
+        # indent. Most of the typical output uses tabs. Localized values have
+        # incorrect, inconsistent, amount of space indents
+        attr = self.assertParses(
+            pactl.GenericSimpleAttribute.Syntax, (
+                'Volume: 0:  60% 1:  60%\n'
+                '        0: -13.40 dB 1: -13.40 dB\n'
+                '        balance 0.00\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Volume')
+        self.assertEqual(attr.value, (
+            '0:  60% 1:  60%\n'
+            '0: -13.40 dB 1: -13.40 dB\n'
+            'balance 0.00\n'))
+
+    def test_volume_with_tabs(self):
+        attr = self.assertParses(
+            pactl.GenericSimpleAttribute.Syntax, (
+                '\tVolume: 0:  60% 1:  60%\n'
+                '\t        0: -13.40 dB 1: -13.40 dB\n'
+                '\t        balance 0.00\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Volume')
+        self.assertEqual(attr.value, (
+            '0:  60% 1:  60%\n'
+            '0: -13.40 dB 1: -13.40 dB\n'
+            'balance 0.00\n'))
+
+    def test_base_volume(self):
+        attr = self.assertParses(
+            pactl.GenericSimpleAttribute.Syntax, (
+                'Base Volume: 100%\n'
+                '             0.00 dB\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Base Volume')
+        self.assertEqual(attr.value, '100%\n0.00 dB\n')
+
+    def test_one_port(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Ports:\n'
+                '\thdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, available)\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Ports')
+        self.assertEqual(attr.value[0].name, 'hdmi-output-1')
+        self.assertEqual(attr.value[0].label, 'HDMI / DisplayPort 2')
+        self.assertEqual(attr.value[0].priority, 5800)
+        self.assertEqual(attr.value[0].availability, 'available')
+
+    def test_many_ports(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Ports:\n'
+                '\tanalog-output: Wyjście analogowe (priority: 9900)\n'
+                '\tanalog-output-headphones: Słuchawki (priority: 9000, not available)\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Ports')
+        self.assertEqual(attr.value[0].name, 'analog-output')
+        self.assertEqual(attr.value[0].label, 'Wyjście analogowe')
+        self.assertEqual(attr.value[0].priority, 9900)
+        self.assertEqual(attr.value[0].availability, '')
+        self.assertEqual(attr.value[1].name, 'analog-output-headphones')
+        self.assertEqual(attr.value[1].label, 'Słuchawki')
+        self.assertEqual(attr.value[1].priority, 9000)
+        self.assertEqual(attr.value[1].availability, 'not available')
+
+    def test_chinese_ports(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Ports:\n'
+                '\tanalog-output;output-amplifier-on: 模拟输出 / 均衡器 (priority: 9910)\n'
+                '\tanalog-output;output-amplifier-off: 模拟输出 / 无均衡器 (priority: 9900)\n'
+                '\tanalog-output-mono;output-amplifier-on: 模拟单声道输出 / 均衡器 (priority: 5010)\n'
+                '\tanalog-output-mono;output-amplifier-off: 模拟单声道输出 / 无均衡器 (priority: 5000)\n')
+        )['attribute']
+        self.assertEqual(attr.name, 'Ports')
+        self.assertEqual(len(attr.value), 4)
+        self.assertEqual(attr.value[1].name, 'analog-output;output-amplifier-off')
+        self.assertEqual(attr.value[1].label, '模拟输出 / 无均衡器')
+
+    def test_with_profile_association(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Ports:\n'
+                '\tanalog-output-speaker: Głośniki (priority 10000)\n'
+                '\t\tPart of profile(s): output:analog-stereo, output:analog-stereo+input:analog-stereo\n'
+            )
+        )['attribute']
+        self.assertEqual(attr.name, 'Ports')
+        self.assertEqual(attr.value[0].name, 'analog-output-speaker')
+        self.assertEqual(attr.value[0].label, 'Głośniki')
+        self.assertEqual(attr.value[0].priority, 10000)
+        self.assertEqual(attr.value[0].profile_list, [
+            'output:analog-stereo', 'output:analog-stereo+input:analog-stereo'])
+
+    def test_with_ports_properties(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Ports:\n'
+                '\tanalog-input-microphone-internal: Internal Microphone (priority: 98903, latency offset: 982 usec)\n'
+                '\t\tProperties:\n'
+                '\t\t\tdevice.icon_name = "audio-input-microphone"\n'
+                '\t\t\tdevice.display_name = "Microphone"\n'
+                '\t\tPart of profile(s): input:analog-stereo\n'
+            )
+        )['attribute']
+        self.assertEqual(attr.name, 'Ports')
+        self.assertEqual(attr.value[0].latency_offset, 982)
+        self.assertEqual(attr.value[0].properties[0].name, 'device.icon_name')
+        self.assertEqual(attr.value[0].properties[0].value, 'audio-input-microphone')
+        self.assertEqual(attr.value[0].properties[1].name, 'device.display_name')
+        self.assertEqual(attr.value[0].properties[1].value, 'Microphone')
+
+    def test_SPDIF_in_port_label(self):
+        # This checks that '(S/PDIF)' does not confuse the parser to parse
+        # '(' before port properties
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Ports:\n'
+                '\tiec958-stereo-input: Digital Input (S/PDIF) (priority: 0, latency offset: 0 usec)\n'
+                '\t\tPart of profile(s): input:iec958-stereo\n'
+            )
+        )['attribute']
+        self.assertEqual(attr.name, 'Ports')
+        self.assertEqual(attr.value[0].name, 'iec958-stereo-input')
+        self.assertEqual(attr.value[0].label, 'Digital Input (S/PDIF)')
+        self.assertEqual(attr.value[0].priority, 0)
+        self.assertEqual(attr.value[0].latency_offset, 0)
+        self.assertEqual(attr.value[0].profile_list, ['input:iec958-stereo'])
+
+    def test_profiles(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, (
+                'Profiles:\n'
+                '\toutput:analog-stereo: Wyjście Analogowe stereo (sinks: 1, sources: 0, priority. 6000)\n'
+                '\toutput:analog-stereo+input:analog-stereo: Analogowy dupleks stereo (sinks: 1, sources: 1, priority. 6060)\n'
+                '\toutput:hdmi-stereo: Wyjście Digital Stereo (HDMI) (sinks: 1, sources: 0, priority. 5400)\n'
+                '\toutput:hdmi-stereo+input:analog-stereo: Wyjście Digital Stereo (HDMI) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 5460)\n'
+                '\toutput:hdmi-surround: Wyjście Digital Surround 5.1 (HDMI) (sinks: 1, sources: 0, priority. 300)\n'
+                '\toutput:hdmi-surround+input:analog-stereo: Wyjście Digital Surround 5.1 (HDMI) + Wejście Analogowe stereo (sinks: 1, sources: 1, priority. 360)\n'
+                '\tinput:analog-stereo: Wejście Analogowe stereo (sinks: 0, sources: 1, priority. 60)\n'
+                '\toff: Wyłącz (sinks: 0, sources: 0, priority. 0)\n'
+            )
+        )['attribute']
+        self.assertEqual(attr.name, 'Profiles')
+        self.assertEqual(attr.value[0].name, 'output:analog-stereo')
+        self.assertEqual(attr.value[0].label, 'Wyjście Analogowe stereo')
+        self.assertEqual(attr.value[0].priority, 6000) 
+        self.assertEqual(attr.value[-3].label, 'Wyjście Digital Surround 5.1 (HDMI) + Wejście Analogowe stereo') 
+        self.assertEqual(attr.value[-3].priority, 360) 
+        self.assertEqual(attr.value[-1].name, 'off')
+
+    def test_format(self):
+        attr = self.assertParses(
+            pactl.GenericListAttribute.Syntax, 'Formats:\n' '\tpcm\n'
+        )['attribute']
+        self.assertEqual(attr.name, 'Formats')
+        self.assertEqual(attr.value, ['pcm'])
+
+
+class RecordTests(ParsingTestCase, PactlDataMixIn):
+
+    def test_sinks(self):
+        record = self.assertParses(
+            pactl.Record.Syntax, self.get_text("sinks-desktop-precise-0")
+        )['record']
+        self.assertEqual(record.name, "Sink #0")
+        self.assertEqual(record.attribute_list[0].name, "State")
+        self.assertIs(record.attribute_map['State'], record.attribute_list[0])
+        # Probe some random things
+        self.assertEqual(
+            record.attribute_map['Ports'].value[0].name, "hdmi-output-1")
+        self.assertEqual(
+            record.attribute_map['Properties'].value[2].value, "sound")
+        self.assertEqual(
+            record.attribute_map['Formats'].value, ['pcm'])
+
+    def test_modules(self):
+        record = self.assertParses(
+            pactl.Record.Syntax, self.get_text("modules-desktop-precise-0")
+        )['record']
+        self.assertEqual(record.name, "Module #0")
+        self.assertEqual(record.attribute_list[0].name, "Name")
+        self.assertEqual(record.attribute_list[0].value,
+                         "module-device-restore")
+        self.assertEqual(record.attribute_list[1].name, "Argument")
+        self.assertEqual(record.attribute_list[1].value, "")
+        self.assertEqual(record.attribute_list[2].name, "Usage counter")
+        self.assertEqual(record.attribute_list[2].value, "n/a")
+        self.assertEqual(record.attribute_list[3].name, "Properties")
+        self.assertEqual(record.attribute_list[3].value[0].name,
+                         "module.author")
+        self.assertEqual(record.attribute_list[3].value[0].value,
+                         "Lennart Poettering")
+        # Skip the second property because it's pretty long
+        self.assertEqual(record.attribute_list[3].value[2].name,
+                         "module.version")
+        self.assertEqual(record.attribute_list[3].value[2].value, "1.1")
+
+
+class DocumentTests(ParsingTestCase, PactlDataMixIn):
+
+    def test_pactl_list_modules(self):
+        document = self.assertParses(
+            pactl.Document.Syntax, self.get_text("modules-desktop-precise")
+        )[0]
+        self.assertEqual(len(document.record_list), 24)
+        self.assertEqual(document.record_list[0].name, "Module #0")
+        self.assertEqual(document.record_list[0].attribute_map['Argument'].value, "")
+        self.assertEqual(document.record_list[23].name, "Module #23")
+
+    def test_pactl_list_sinks(self):
+        document = self.assertParses(
+            pactl.Document.Syntax, self.get_text("sinks-desktop-precise")
+        )[0]
+        self.assertEqual(len(document.record_list), 1)
+
+    def test_pactl_list_cards(self):
+        document = self.assertParses(
+            pactl.Document.Syntax, self.get_text("cards-desktop-precise")
+        )[0]
+        self.assertEqual(len(document.record_list), 1)
+
+    def test_pactl_list_cards_xps1340(self):
+        document = self.assertParses(
+            pactl.Document.Syntax, self.get_text("desktop-precise-xps1340")
+        )[0]
+        self.assertEqual(len(document.record_list), 34)
+
+    def test_pactl_list(self):
+        document = self.assertParses(
+            pactl.Document.Syntax, self.get_text("desktop-precise")
+        )[0]
+        for i in range(24):
+            self.assertEqual(
+                document.record_list[i].name,
+                "Module #{}".format(i))
+        self.assertEqual(document.record_list[24].name, "Sink #0")
+        self.assertEqual(document.record_list[25].name, "Source #0")
+        self.assertEqual(document.record_list[26].name, "Source #1")
+        self.assertEqual(document.record_list[27].name, "Sink Input #1249")
+        self.assertEqual(document.record_list[28].name, "Source Output #11")
+        self.assertEqual(document.record_list[29].name, "Client #0")
+        self.assertEqual(document.record_list[30].name, "Client #1")
+        self.assertEqual(document.record_list[31].name, "Client #2")
+        self.assertEqual(document.record_list[32].name, "Client #7")
+        self.assertEqual(document.record_list[33].name, "Client #9")
+        self.assertEqual(document.record_list[34].name, "Client #10")
+        self.assertEqual(document.record_list[35].name, "Client #63")
+        self.assertEqual(document.record_list[36].name, "Client #101")
+        self.assertEqual(document.record_list[37].name, "Client #173")
+        self.assertEqual(document.record_list[38].name, "Client #175")
+        self.assertEqual(document.record_list[39].name, "Client #195")
+        self.assertEqual(document.record_list[40].name, "Sample #0")
+        self.assertEqual(document.record_list[41].name, "Sample #1")
+        self.assertEqual(document.record_list[42].name, "Card #0")
+        self.assertEqual(len(document.record_list), 43)

=== added file 'checkbox-support/checkbox_support/parsers/tests/test_udevadm.py'
--- checkbox-support/checkbox_support/parsers/tests/test_udevadm.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/test_udevadm.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,628 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012-2013 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+from io import StringIO
+
+from pkg_resources import resource_filename
+from unittest import TestCase
+
+from checkbox.parsers.udevadm import UdevadmParser, decode_id
+from checkbox.parsers.udevadm import parse_udevadm_output
+
+
+class DeviceResult:
+
+    def __init__(self):
+        self.devices = []
+
+    def addDevice(self, device):
+        self.devices.append(device)
+
+    def getDevice(self, category):
+        for device in self.devices:
+            if device.category == category:
+                return device
+
+        return None
+
+
+class UdevadmDataMixIn:
+    """
+    Mix in with a helper method to load sample udevadm data
+    """
+
+    def get_text(self, name):
+        resource = 'parsers/tests/udevadm_data/{}.txt'.format(name)
+        filename = resource_filename('checkbox', resource)
+        with open(filename, 'rt', encoding='UTF-8') as stream:
+            return stream.read()
+
+
+class TestUdevadmParser(TestCase, UdevadmDataMixIn):
+
+    def getParser(self, string):
+        stream = StringIO(string)
+        return UdevadmParser(stream)
+
+    def getResult(self, string):
+        parser = self.getParser(string)
+        result = DeviceResult()
+        parser.run(result)
+        return result
+
+    def parse(self, name):
+        # Uncomment only for debugging purpose
+        #attributes = ("path", "driver", "bus", "product_id", "vendor_id",
+        #    "product", "vendor", "interface",)
+        #
+        #devices = parse_udevadm_output(self.get_text(name), 64)["device_list"]
+        #for i,j in enumerate(devices):
+            #print(i, j.category, [getattr(j, a) for a in attributes])
+        return parse_udevadm_output(self.get_text(name), 64)["device_list"]
+
+    def count(self, devices, category):
+        return len([d for d in devices if d.category == category])
+
+    def test_usb_capture(self):
+        result = self.getResult("""
+P: /devices/pci0000:00/0000:00:1a.7/usb1/1-6/1-6:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.7/usb1/1-6/1-6:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: PRODUCT=17ef/480c/3134
+E: TYPE=239/2/1
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v17EFp480Cd3134dcEFdsc02dp01ic0Eisc01ip00
+E: SUBSYSTEM=usb
+""")
+        device = result.getDevice("CAPTURE")
+        self.assertTrue(device)
+
+    def test_openfirmware_network(self):
+        result = self.getResult("""
+P: /devices/soc.0/ffe64000.ethernet
+E: DEVPATH=/devices/soc.0/ffe64000.ethernet
+E: DRIVER=XXXXX
+E: MODALIAS=of:NethernetTXXXXXCXXXXX,XXXXX
+E: OF_COMPATIBLE_0=XXXXX,XXXXX
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=ethernet
+E: OF_TYPE=XXXXX
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe64000.ethernet/net/eth1
+E: DEVPATH=/devices/soc.0/ffe64000.ethernet/net/eth1
+E: IFINDEX=3
+E: INTERFACE=eth1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+""")
+        device = result.getDevice("NETWORK")
+        self.assertTrue(device)
+
+    def _test_DELL_INSPIRON3521_TOUCHSCREEN(self):
+        """
+        Check devices category having the ID_INPUT_TOUCHSCREEN property
+        """
+        devices = self.parse("DELL_INSPIRON3521_TOUCHSCREEN")
+        self.assertEqual(len(devices), 59)
+        # Check the Accelerometer device category/product
+        self.assertEqual(devices[36].category, "TOUCHSCREEN")
+        self.assertEqual(devices[36].product, "ELAN Touchscreen")
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 1)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 2)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+
+    def test_DELL_LATITUDEE4310(self):
+        devices = self.parse("DELL_LATITUDEE4310")
+        self.assertEqual(len(devices), 75)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 1)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 3)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+
+    def test_DELL_LATITUDEE6430(self):
+        devices = self.parse("DELL_LATITUDEE6430")
+        self.assertEqual(len(devices), 78)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 2)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 1)
+        self.assertEqual(self.count(devices, "DISK"), 3)
+        # Check that a Bluetooth device is properly detected
+        # See https://bugs.launchpad.net/checkbox/+bug/1075052
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+
+    def test_DELL_OPTIPLEX9020AIO(self):
+        devices = self.parse("DELL_OPTIPLEX9020AIO")
+        self.assertEqual(len(devices), 62)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 4)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 3)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 1)
+        # At least one network device must be detected to solve
+        # https://bugs.launchpad.net/checkbox/+bug/1167733
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "DISK"), 3)
+
+    def test_DELL_VOSTRO3460_FINGERPRINT(self):
+        """
+        This system has a fingerprint reader
+
+        usb.ids:
+        138a  Validity Sensors, Inc.
+                0011  VFS5011 Fingerprint Reader
+        """
+        devices = self.parse("DELL_VOSTRO3460_FINGERPRINT")
+        self.assertEqual(len(devices), 76)
+        self.assertEqual(devices[35].category, "OTHER")
+        self.assertEqual(devices[35].vendor_id, 0x0138a)
+        self.assertEqual(devices[35].product_id, 0x0011)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 2)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+
+    def test_DELL_VOSTROV131(self):
+        devices = self.parse("DELL_VOSTROV131")
+        expected_devices = [("RTL8111/8168 PCI Express Gigabit "
+                            "Ethernet controller",
+                            "NETWORK", "pci", 0x10EC, 0x8168),
+                            ("AR9285 Wireless Network Adapter (PCI-Express)",
+                            "WIRELESS", "pci", 0x168C, 0x002B)
+                            ]
+        self.assertEqual(len(devices), 63)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 0)
+        self.assertEqual(self.count(devices, "CDROM"), 0)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 3)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 2)
+        self.verify_devices(devices, expected_devices)
+
+    def test_DELL_XPS1340(self):
+        devices = self.parse("DELL_XPS1340")
+        self.assertEqual(len(devices), 76)
+        self.assertEqual(self.count(devices, "VIDEO"), 2)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 3)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 1)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+
+    def test_HOME_MADE(self):
+        devices = self.parse("HOME_MADE")
+        self.assertEqual(len(devices), 72)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 4)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 2)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 2)
+        self.assertEqual(self.count(devices, "FLOPPY"), 2)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 1)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 0)
+        self.assertEqual(self.count(devices, "WIRELESS"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 2)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+
+    def test_HP_PAVILIONSLEEKBOOK14_ACCELEROMETER(self):
+        devices = self.parse("HP_PAVILIONSLEEKBOOK14_ACCELEROMETER")
+        self.assertEqual(len(devices), 58)
+        self.assertEqual(devices[56].product, "ST LIS3LV02DL Accelerometer")
+        self.assertEqual(devices[56].category, "ACCELEROMETER")
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 0)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 1)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        # Check that a Bluetooth device is properly detected on PCI bus
+        # See https://bugs.launchpad.net/checkbox/+bug/1036124
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+
+    def test_HP_PRO2110(self):
+        devices = self.parse("HP_PRO2110")
+        self.assertEqual(len(devices), 60)
+        # Check that the Avocent IBM 73P5832 is not a CAPTURE device
+        # See https://bugs.launchpad.net/checkbox/+bug/1065064
+        self.assertEqual(devices[33].product, "Avocent IBM 73P5832")
+        self.assertNotEqual(devices[33].category, "CAPTURE")
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 4)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 0)
+        self.assertEqual(self.count(devices, "WIRELESS"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 3)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+
+    def test_HP_PROBOOK6550B_ACCELEROMETER(self):
+        devices = self.parse("HP_PROBOOK6550B_ACCELEROMETER")
+        expected_devices = [("Centrino Advanced-N 6200",
+                             "WIRELESS", "pci", 0x8086, 0x4239),
+                            ("82577LC Gigabit Network Connection",
+                             "NETWORK", "pci", 0x8086, 0x10EB)
+                            ]
+        self.assertEqual(len(devices), 80)
+        # Check the accelerometer device category/product
+        self.assertEqual(devices[78].product, "ST LIS3LV02DL Accelerometer")
+        self.assertEqual(devices[78].category, "ACCELEROMETER")
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 1)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 1)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 3)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.verify_devices(devices, expected_devices)
+
+    def test_LENOVO_E431(self):
+        devices = self.parse("LENOVO_E431")
+        self.assertEqual(len(devices), 65)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+
+    def test_LENOVO_E445(self):
+        devices = self.parse("LENOVO_E445")
+        self.assertEqual(len(devices), 78)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 4)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+
+    def test_LENOVO_T430S(self):
+        devices = self.parse("LENOVO_T430S")
+        expected_devices = [("Centrino Ultimate-N 6300",
+                             "WIRELESS", "pci", 0x8086, 0x4238),
+                            ("82579LM Gigabit Network Connection",
+                             "NETWORK", "pci", 0x8086, 0x1502),
+                            ("H5321 gw",
+                             "NETWORK", "usb", 0x0bdb, 0x1926)
+                            ]
+        self.assertEqual(len(devices), 103)
+        # Check that the Thinkpad hotkeys are not a CAPTURE device
+        self.assertEqual(devices[102].product, "ThinkPad Extra Buttons")
+        self.assertEqual(devices[102].category, "OTHER")
+        # Check that the Ericsson MBM module is set as a NETWORK device with
+        # proper vendor/product names
+        self.assertEqual(devices[54].product, "H5321 gw")
+        self.assertEqual(
+            devices[54].vendor,
+            "Ericsson Business Mobile Networks BV")
+        self.assertEqual(devices[54].category, "NETWORK")
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 9)
+        # Logitech Illuminated keyboard + T430S keyboard + KVM
+        self.assertEqual(self.count(devices, "KEYBOARD"), 3)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 1)
+        self.assertEqual(self.count(devices, "CDROM"), 1)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 1)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 2)
+        self.assertEqual(self.count(devices, "CAPTURE"), 2)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.verify_devices(devices, expected_devices)
+
+    def test_PANDABOARD(self):
+        devices = self.parse("PANDABOARD")
+        self.assertEqual(len(devices), 14)
+        # Check that the wireless product name is extracted from the platform
+        # modalias
+        self.assertEqual(devices[2].product, "wl12xx")
+        self.assertEqual(self.count(devices, "VIDEO"), 0)
+        self.assertEqual(self.count(devices, "AUDIO"), 0)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 0)
+        self.assertEqual(self.count(devices, "CDROM"), 0)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 2)
+
+    def test_SAMSUNG_N310(self):
+        devices = self.parse("SAMSUNG_N310")
+        self.assertEqual(len(devices), 57)
+        self.assertEqual(self.count(devices, "VIDEO"), 1)
+        self.assertEqual(self.count(devices, "AUDIO"), 2)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 1)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 1)
+        self.assertEqual(self.count(devices, "CARDREADER"), 0)
+        self.assertEqual(self.count(devices, "CDROM"), 0)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        # Check that wireless device are properly detected even if the usb
+        # modalias is wrong.
+        # The PCI_CLASS is 20000 for the Atheros cards in this Samsung netbook
+        # but 28000 anywhere else.
+        # See https://bugs.launchpad.net/checkbox/+bug/855382
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.assertEqual(self.count(devices, "CAPTURE"), 1)
+
+    def test_LENOVO_T420(self):
+        devices = self.parse("LENOVO_T420")
+        expected_devices = [("Centrino Advanced-N 6205 [Taylor Peak]",
+                             "WIRELESS", "pci", 0x8086, 0x85),
+                            ("82579LM Gigabit Network Connection",
+                             "NETWORK", "pci", 0x8086, 0x1502)
+                            ]
+        self.assertEqual(len(devices), 65)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.verify_devices(devices, expected_devices)
+
+    def test_HP_ENVY_15_MEDIATEK_BT(self):
+        devices = self.parse("HP_ENVY_15_MEDIATEK_BT")
+        expected_devices = [
+            (None, "WIRELESS", "pci", 0x14C3, 0x7630),
+            ("RTL8111/8168B PCI Express Gigabit "
+             "Ethernet controller", "NETWORK", "pci",
+             0x10EC, 0x8168),
+            (None, "BLUETOOTH", "usb", 0x0e8d, 0x763f)]
+        self.assertEqual(len(devices), 63)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+        self.verify_devices(devices, expected_devices)
+
+    def test_HP_PAVILION14_NOTEBOOK_MEDIATEK_BT(self):
+        devices = self.parse("HP_PAVILION14_NOTEBOOK_MEDIATEK_BT")
+        expected_devices = [
+            (None, "WIRELESS", "pci", 0x14C3, 0x7630),
+            ("RTL8101E/RTL8102E PCI Express Fast "
+             "Ethernet controller", "NETWORK", "pci",
+             0x10EC, 0x8136),
+            (None, "BLUETOOTH", "usb", 0x0e8d, 0x763f)]
+        self.assertEqual(len(devices), 67)
+        self.verify_devices(devices, expected_devices)
+        self.assertEqual(self.count(devices, "WIRELESS"), 1)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 1)
+        self.assertEqual(self.count(devices, "NETWORK"), 1)
+
+    def test_CALXEDA_HIGHBANK(self):
+        #This is a very bare-bones SoC meant for server use
+        devices = self.parse("CALXEDA_HIGHBANK")
+        self.assertEqual(len(devices), 3)
+        self.assertEqual(self.count(devices, "VIDEO"), 0)
+        self.assertEqual(self.count(devices, "AUDIO"), 0)
+        self.assertEqual(self.count(devices, "KEYBOARD"), 0)
+        self.assertEqual(self.count(devices, "TOUCHPAD"), 0)
+        self.assertEqual(self.count(devices, "CARDREADER"), 0)
+        self.assertEqual(self.count(devices, "CDROM"), 0)
+        self.assertEqual(self.count(devices, "FIREWIRE"), 0)
+        self.assertEqual(self.count(devices, "MOUSE"), 0)
+        self.assertEqual(self.count(devices, "ACCELEROMETER"), 0)
+        self.assertEqual(self.count(devices, "TOUCHSCREEN"), 0)
+        self.assertEqual(self.count(devices, "WIRELESS"), 0)
+        self.assertEqual(self.count(devices, "NETWORK"), 2)
+        self.assertEqual(self.count(devices, "BLUETOOTH"), 0)
+        self.assertEqual(self.count(devices, "CAPTURE"), 0)
+        self.assertEqual(self.count(devices, "RAID"), 0)
+        self.assertEqual(self.count(devices, "DISK"), 1)
+
+    def verify_devices(self, devices, expected_device_list):
+        """
+        Verify we have exactly one of each device given in the list,
+        and that product name, category, bus, vendor_id and
+        product_id match.
+        The list contains a tuple with product name, category, bus,
+        vendor and product.
+        They look like:
+        [(name, category, bus, vendor_id, product_id)]
+        Note that name can be None, in which case we don't need the
+        name to match. All other attributes must have a value and match.
+        """
+        # See this bug, that prompted for closer inspection of
+        # devices and IDs:
+        # https://bugs.launchpad.net/checkbox/+bug/1211521
+        for device in expected_device_list:
+            # Match by product and vendor ID
+            indices = [idx for idx, elem in enumerate(devices)
+                       if elem.product_id == device[4] and
+                       elem.vendor_id == device[3]]
+            # If we have a name to match, eliminate everyhing without
+            # that name (as they are bogus, uninteresting devices)
+            if device[0] is not None:
+                indices = [idx for idx in indices
+                           if devices[idx].product == device[0]]
+            # Now do my validation checks
+            self.assertEqual(len(indices), 1,
+                             "{} items of {} (id {}:{}) found".format(
+                                 len(indices),
+                                 device[0],
+                                 device[3],
+                                 device[4]))
+            if device[0] is not None:
+                self.assertEqual(devices[indices[0]].product, device[0],
+                                 "Bad product name for {}".format(device[0]))
+            self.assertEqual(devices[indices[0]].category, device[1],
+                             "Bad category for {}".format(device[0]))
+            self.assertEqual(devices[indices[0]].bus, device[2],
+                             "Bad bus for {}".format(device[0]))
+            self.assertEqual(devices[indices[0]].vendor_id, device[3],
+                             "Bad vendor_id for {}".format(device[0]))
+            self.assertEqual(devices[indices[0]].product_id, device[4],
+                             "Bad product_id for {}".format(device[0]))
+
+
+class TestDecodeId(TestCase):
+
+    def test_string(self):
+        self.assertEqual("USB 2.0", decode_id("USB 2.0"))
+
+    def test_escape(self):
+        self.assertEqual("USB 2.0", decode_id("USB\\x202.0"))
+
+    def test_strip_whitespace(self):
+        self.assertEqual("USB 2.0", decode_id("  USB 2.0  "))

=== added file 'checkbox-support/checkbox_support/parsers/tests/test_xinput.py'
--- checkbox-support/checkbox_support/parsers/tests/test_xinput.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/test_xinput.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,130 @@
+# -*- coding: utf-8 -*-
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import os
+
+from unittest import TestCase
+
+from checkbox.parsers.xinput import (
+    DEVICE_RE,
+    ATTRIBUTE_RE,
+    CLASS_VALUE_RE,
+    LIST_VALUE_RE,
+    IXinputResult,
+    XinputParser,
+    )
+
+
+class TestDeviceRe(TestCase):
+
+    def test_string(self):
+        match = DEVICE_RE.match(
+            """⎡ Virtual core pointer                      """
+            """id=2    [master pointer  (3)]""")
+        self.assertTrue(match)
+        self.assertEqual(match.group("name"), "Virtual core pointer")
+        self.assertEqual(match.group("id"), "2")
+
+
+class TestAttributeRe(TestCase):
+
+    def test_string(self):
+        match = ATTRIBUTE_RE.match("""Buttons supported: 12""")
+        self.assertTrue(match)
+        self.assertEqual(match.group("key"), "Buttons supported")
+        self.assertEqual(match.group("value"), "12")
+
+
+class TestClassValueRe(TestCase):
+
+    def test_string(self):
+        match = CLASS_VALUE_RE.match("""12. Type: XIButtonClass""")
+        self.assertTrue(match)
+        self.assertEqual(match.group("class"), "XIButtonClass")
+
+
+class TestListValueRe(TestCase):
+
+    def test_string(self):
+        elements = LIST_VALUE_RE.split(
+            """"Button Horiz Wheel Right" None None""")[1::2]
+        self.assertTrue(elements)
+        self.assertEqual(len(elements), 3)
+        self.assertEqual(elements[0], '"Button Horiz Wheel Right"')
+        self.assertEqual(elements[1], "None")
+        self.assertEqual(elements[2], "None")
+
+
+class XinputResult(IXinputResult):
+
+    def __init__(self):
+        self.devices = {}
+
+    def addXinputDevice(self, device):
+        self.devices[device["id"]] = device
+
+    def addXinputDeviceClass(self, device, device_class):
+        self.devices[device["id"]].setdefault("classes", [])
+        self.devices[device["id"]]["classes"].append(device_class)
+
+
+class TestXinputParser(TestCase):
+
+
+    def getResult(self, name):
+        fixture = os.path.join(os.path.dirname(__file__), "fixtures", name)
+        result = XinputResult()
+        with open(fixture, encoding="utf-8") as stream:
+            parser = XinputParser(stream)
+            parser.run(result)
+        return result
+
+    def test_number_of_devices_with_spaces(self):
+        """The toshiba xinput with spaces contains 12 devices."""
+        result = self.getResult("xinput_toshiba.txt")
+        self.assertEqual(len(result.devices), 12)
+
+    def test_number_of_devices_without_spaces(self):
+        """The quantal xinput without spaces contains 14 devices."""
+        result = self.getResult("xinput_quantal.txt")
+        self.assertEqual(len(result.devices), 14)
+
+    def test_multitouch_touchpad_device(self):
+        """The toshiba xinput contains a multitouch touchpad device."""
+        result = self.getResult("xinput_toshiba.txt")
+        devices = [device for device in result.devices.values()
+            if device["name"] == "AlpsPS/2 ALPS DualPoint TouchPad"]
+        self.assertEqual(len(devices), 1)
+
+        classes = [cls for cls in devices[0]["classes"]
+            if cls["device_class"] == "XITouchClass"]
+        self.assertEqual(len(classes), 1)
+        self.assertEqual(classes[0]["touch_mode"], "dependent")
+
+    def test_multitouch_touchscreen_device(self):
+        """The quantal xinput contains a multitouch touchscreen device."""
+        result = self.getResult("xinput_quantal.txt")
+        devices = [device for device in result.devices.values()
+            if device["name"] == "Quanta OpticalTouchScreen"]
+        self.assertEqual(len(devices), 1)
+
+        classes = [cls for cls in devices[0]["classes"]
+            if cls["device_class"] == "XITouchClass"]
+        self.assertEqual(len(classes), 1)
+        self.assertEqual(classes[0]["touch_mode"], "direct")

=== added directory 'checkbox-support/checkbox_support/parsers/tests/udevadm_data'
=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/CALXEDA_HIGHBANK.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/CALXEDA_HIGHBANK.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/CALXEDA_HIGHBANK.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,6826 @@
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/fff8a000.ramoops
+E: DEVPATH=/devices/fff8a000.ramoops
+E: MODALIAS=of:NramoopsT<NULL>Cramoops
+E: OF_COMPATIBLE_0=ramoops
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=ramoops
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/ipmi_bmc.0000.0
+E: DEVPATH=/devices/platform/ipmi_bmc.0000.0
+E: DRIVER=ipmi
+E: MODALIAS=platform:ipmi_bmc.0000
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/psci.2
+E: DEVPATH=/devices/psci.2
+E: MODALIAS=of:NpsciT<NULL>Carm,psci
+E: OF_COMPATIBLE_0=arm,psci
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=psci
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0
+E: DEVPATH=/devices/soc.0
+E: MODALIAS=of:NsocT<NULL>Csimple-bus
+E: OF_COMPATIBLE_0=simple-bus
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=soc
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata
+E: DEVPATH=/devices/soc.0/ffe08000.sata
+E: DRIVER=ahci
+E: MODALIAS=of:NsataT<NULL>Ccalxeda,hb-ahci
+E: OF_COMPATIBLE_0=calxeda,hb-ahci
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=sata
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata1/ata_port/ata1
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata2/ata_port/ata2
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata3/ata_port/ata3
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata4/ata_port/ata4
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata5/ata_port/ata5
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host0/scsi_host/host0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host1
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host1/scsi_host/host1
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/scsi_host/host2
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+S: disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+S: disk/by-id/wwn-0x500253805002c1e3
+S: disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354 /dev/disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354 /dev/disk/by-id/wwn-0x500253805002c1e3 /dev/disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=6
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=0
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=SAMSUNG_MZ7PC256HAFU-000DA
+E: ID_MODEL_ENC=SAMSUNG\x20MZ7PC256HAFU-000DA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ffe08000.sata-scsi-2:0:0:0
+E: ID_PATH_TAG=platform-ffe08000_sata-scsi-2_0_0_0
+E: ID_REVISION=CXM02WQ1
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+E: ID_SERIAL=SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+E: ID_SERIAL_SHORT=S0WYN6AC500354
+E: ID_TYPE=disk
+E: ID_WWN=0x500253805002c1e3
+E: ID_WWN_WITH_EXTENSION=0x500253805002c1e3
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=5
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13157915
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part1
+S: disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part1
+S: disk/by-id/wwn-0x500253805002c1e3-part1
+S: disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part1
+S: disk/by-uuid/9a734395-0a6b-40c5-82c4-99d0731e5cb3
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part1 /dev/disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part1 /dev/disk/by-id/wwn-0x500253805002c1e3-part1 /dev/disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part1 /dev/disk/by-uuid/9a734395-0a6b-40c5-82c4-99d0731e5cb3
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=6
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=0
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext3
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=9a734395-0a6b-40c5-82c4-99d0731e5cb3
+E: ID_FS_UUID_ENC=9a734395-0a6b-40c5-82c4-99d0731e5cb3
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=SAMSUNG_MZ7PC256HAFU-000DA
+E: ID_MODEL_ENC=SAMSUNG\x20MZ7PC256HAFU-000DA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=497664
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ffe08000.sata-scsi-2:0:0:0
+E: ID_PATH_TAG=platform-ffe08000_sata-scsi-2_0_0_0
+E: ID_REVISION=CXM02WQ1
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+E: ID_SERIAL=SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+E: ID_SERIAL_SHORT=S0WYN6AC500354
+E: ID_TYPE=disk
+E: ID_WWN=0x500253805002c1e3
+E: ID_WWN_WITH_EXTENSION=0x500253805002c1e3
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=254803968
+E: UDISKS_PARTITION_SLAVE=/sys/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13271653
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part2
+S: disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part2
+S: disk/by-id/wwn-0x500253805002c1e3-part2
+S: disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part2
+S: disk/by-uuid/e2f90877-6cdd-4710-ba9d-ee03e92bbc7b
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part2 /dev/disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part2 /dev/disk/by-id/wwn-0x500253805002c1e3-part2 /dev/disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part2 /dev/disk/by-uuid/e2f90877-6cdd-4710-ba9d-ee03e92bbc7b
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=6
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=0
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=e2f90877-6cdd-4710-ba9d-ee03e92bbc7b
+E: ID_FS_UUID_ENC=e2f90877-6cdd-4710-ba9d-ee03e92bbc7b
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=SAMSUNG_MZ7PC256HAFU-000DA
+E: ID_MODEL_ENC=SAMSUNG\x20MZ7PC256HAFU-000DA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=499712
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=195311616
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ffe08000.sata-scsi-2:0:0:0
+E: ID_PATH_TAG=platform-ffe08000_sata-scsi-2_0_0_0
+E: ID_REVISION=CXM02WQ1
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+E: ID_SERIAL=SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+E: ID_SERIAL_SHORT=S0WYN6AC500354
+E: ID_TYPE=disk
+E: ID_WWN=0x500253805002c1e3
+E: ID_WWN_WITH_EXTENSION=0x500253805002c1e3
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=255852544
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=99999547392
+E: UDISKS_PARTITION_SLAVE=/sys/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13270768
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part3
+S: disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part3
+S: disk/by-id/wwn-0x500253805002c1e3-part3
+S: disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part3
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part3 /dev/disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part3 /dev/disk/by-id/wwn-0x500253805002c1e3-part3 /dev/disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part3
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=6
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=0
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=SAMSUNG_MZ7PC256HAFU-000DA
+E: ID_MODEL_ENC=SAMSUNG\x20MZ7PC256HAFU-000DA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=195813374
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=304304130
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ffe08000.sata-scsi-2:0:0:0
+E: ID_PATH_TAG=platform-ffe08000_sata-scsi-2_0_0_0
+E: ID_REVISION=CXM02WQ1
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+E: ID_SERIAL=SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+E: ID_SERIAL_SHORT=S0WYN6AC500354
+E: ID_TYPE=disk
+E: ID_WWN=0x500253805002c1e3
+E: ID_WWN_WITH_EXTENSION=0x500253805002c1e3
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=100256447488
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=155803714560
+E: UDISKS_PARTITION_SLAVE=/sys/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13278258
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part5
+S: disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part5
+S: disk/by-id/wwn-0x500253805002c1e3-part5
+S: disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part5
+S: disk/by-uuid/92423a77-1db5-4768-bbac-d0d80f3bdfbd
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part5 /dev/disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part5 /dev/disk/by-id/wwn-0x500253805002c1e3-part5 /dev/disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part5 /dev/disk/by-uuid/92423a77-1db5-4768-bbac-d0d80f3bdfbd
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=6
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=0
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=92423a77-1db5-4768-bbac-d0d80f3bdfbd
+E: ID_FS_UUID_ENC=92423a77-1db5-4768-bbac-d0d80f3bdfbd
+E: ID_FS_VERSION=2
+E: ID_MODEL=SAMSUNG_MZ7PC256HAFU-000DA
+E: ID_MODEL_ENC=SAMSUNG\x20MZ7PC256HAFU-000DA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=195813376
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=2146304
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ffe08000.sata-scsi-2:0:0:0
+E: ID_PATH_TAG=platform-ffe08000_sata-scsi-2_0_0_0
+E: ID_REVISION=CXM02WQ1
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+E: ID_SERIAL=SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+E: ID_SERIAL_SHORT=S0WYN6AC500354
+E: ID_TYPE=disk
+E: ID_WWN=0x500253805002c1e3
+E: ID_WWN_WITH_EXTENSION=0x500253805002c1e3
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=100256448512
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=1098907648
+E: UDISKS_PARTITION_SLAVE=/sys/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13291220
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda6
+N: sda6
+S: disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part6
+S: disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part6
+S: disk/by-id/wwn-0x500253805002c1e3-part6
+S: disk/by-label/TEST
+S: disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part6
+S: disk/by-uuid/dba8986f-076b-4ecf-8e67-2a6864911d06
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354-part6 /dev/disk/by-id/scsi-SATA_SAMSUNG_MZ7PC25S0WYN6AC500354-part6 /dev/disk/by-id/wwn-0x500253805002c1e3-part6 /dev/disk/by-label/TEST /dev/disk/by-path/platform-ffe08000.sata-scsi-2:0:0:0-part6 /dev/disk/by-uuid/dba8986f-076b-4ecf-8e67-2a6864911d06
+E: DEVNAME=/dev/sda6
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda/sda6
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=6
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=0
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=TEST
+E: ID_FS_LABEL_ENC=TEST
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=dba8986f-076b-4ecf-8e67-2a6864911d06
+E: ID_FS_UUID_ENC=dba8986f-076b-4ecf-8e67-2a6864911d06
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=SAMSUNG_MZ7PC256HAFU-000DA
+E: ID_MODEL_ENC=SAMSUNG\x20MZ7PC256HAFU-000DA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=6
+E: ID_PART_ENTRY_OFFSET=197961728
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=39059456
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ffe08000.sata-scsi-2:0:0:0
+E: ID_PATH_TAG=platform-ffe08000_sata-scsi-2_0_0_0
+E: ID_REVISION=CXM02WQ1
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_MZ7PC25S0WYN6AC500354
+E: ID_SERIAL=SAMSUNG_MZ7PC256HAFU-000DA_S0WYN6AC500354
+E: ID_SERIAL_SHORT=S0WYN6AC500354
+E: ID_TYPE=disk
+E: ID_WWN=0x500253805002c1e3
+E: ID_WWN_WITH_EXTENSION=0x500253805002c1e3
+E: MAJOR=8
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=6
+E: UDISKS_PARTITION_OFFSET=101356404736
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=19998441472
+E: UDISKS_PARTITION_SLAVE=/sys/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13290974
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+N: bsg/2:0:0:0
+E: DEVNAME=/dev/bsg/2:0:0:0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/scsi_disk/2:0:0:0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/scsi_disk/2:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host2/target2:0:0/2:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host3
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host3/scsi_host/host3
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host4
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/ffe08000.sata/host4/scsi_host/host4
+E: DEVPATH=/devices/soc.0/ffe08000.sata/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff00000.memory-controller
+E: DEVPATH=/devices/soc.0/fff00000.memory-controller
+E: DRIVER=hb_mc_edac
+E: MODALIAS=of:Nmemory-controllerT<NULL>Ccalxeda,hb-ddr-ctrl
+E: OF_COMPATIBLE_0=calxeda,hb-ddr-ctrl
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=memory-controller
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff10600.timer
+E: DEVPATH=/devices/soc.0/fff10600.timer
+E: MODALIAS=of:NtimerT<NULL>Carm,cortex-a9-twd-timerCarm,smp-twd
+E: OF_COMPATIBLE_0=arm,cortex-a9-twd-timer
+E: OF_COMPATIBLE_1=arm,smp-twd
+E: OF_COMPATIBLE_N=2
+E: OF_NAME=timer
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff10620.watchdog
+E: DEVPATH=/devices/soc.0/fff10620.watchdog
+E: MODALIAS=of:NwatchdogT<NULL>Carm,cortex-a9-twd-wdt
+E: OF_COMPATIBLE_0=arm,cortex-a9-twd-wdt
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=watchdog
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff11000.interrupt-controller
+E: DEVPATH=/devices/soc.0/fff11000.interrupt-controller
+E: MODALIAS=of:Ninterrupt-controllerT<NULL>Carm,cortex-a9-gic
+E: OF_COMPATIBLE_0=arm,cortex-a9-gic
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=interrupt-controller
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff12000.l2-cache
+E: DEVPATH=/devices/soc.0/fff12000.l2-cache
+E: MODALIAS=of:Nl2-cacheT<NULL>Carm,pl310-cache
+E: OF_COMPATIBLE_0=arm,pl310-cache
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=l2-cache
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff20000.ipc
+E: AMBA_ID=00041320
+E: DEVPATH=/devices/soc.0/fff20000.ipc
+E: DRIVER=pl320
+E: MODALIAS=amba:d00041320
+E: SUBSYSTEM=amba
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff34000.timer
+E: AMBA_ID=00141804
+E: DEVPATH=/devices/soc.0/fff34000.timer
+E: MODALIAS=amba:d00141804
+E: SUBSYSTEM=amba
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff35000.rtc
+E: AMBA_ID=00041031
+E: DEVPATH=/devices/soc.0/fff35000.rtc
+E: DRIVER=rtc-pl031
+E: MODALIAS=amba:d00041031
+E: SUBSYSTEM=amba
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff35000.rtc/rtc/rtc0
+N: rtc0
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/soc.0/fff35000.rtc/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff36000.serial
+E: AMBA_ID=00341011
+E: DEVPATH=/devices/soc.0/fff36000.serial
+E: DRIVER=uart-pl011
+E: MODALIAS=amba:d00341011
+E: SUBSYSTEM=amba
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff36000.serial/tty/ttyAMA0
+N: ttyAMA0
+E: DEVNAME=/dev/ttyAMA0
+E: DEVPATH=/devices/soc.0/fff36000.serial/tty/ttyAMA0
+E: MAJOR=204
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff3a000.smic
+E: DEVPATH=/devices/soc.0/fff3a000.smic
+E: DRIVER=ipmi_si
+E: MODALIAS=of:NsmicTipmiCipmi-smic
+E: OF_COMPATIBLE_0=ipmi-smic
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=smic
+E: OF_TYPE=ipmi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff3a000.smic/ipmi/ipmi0
+N: ipmi0
+E: DEVNAME=/dev/ipmi0
+E: DEVPATH=/devices/soc.0/fff3a000.smic/ipmi/ipmi0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=ipmi
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff3c000.sregs
+E: DEVPATH=/devices/soc.0/fff3c000.sregs
+E: MODALIAS=of:NsregsT<NULL>Ccalxeda,hb-sregs
+E: OF_COMPATIBLE_0=calxeda,hb-sregs
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=sregs
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff3c200.sregs
+E: DEVPATH=/devices/soc.0/fff3c200.sregs
+E: DRIVER=hb_l2_edac
+E: MODALIAS=of:NsregsT<NULL>Ccalxeda,hb-sregs-l2-ecc
+E: OF_COMPATIBLE_0=calxeda,hb-sregs-l2-ecc
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=sregs
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff50000.ethernet
+E: DEVPATH=/devices/soc.0/fff50000.ethernet
+E: DRIVER=calxedaxgmac
+E: MODALIAS=of:NethernetT<NULL>Ccalxeda,hb-xgmac
+E: OF_COMPATIBLE_0=calxeda,hb-xgmac
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=ethernet
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff50000.ethernet/net/eth0
+E: DEVPATH=/devices/soc.0/fff50000.ethernet/net/eth0
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff51000.ethernet
+E: DEVPATH=/devices/soc.0/fff51000.ethernet
+E: DRIVER=calxedaxgmac
+E: MODALIAS=of:NethernetT<NULL>Ccalxeda,hb-xgmac
+E: OF_COMPATIBLE_0=calxeda,hb-xgmac
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=ethernet
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff51000.ethernet/net/eth1
+E: DEVPATH=/devices/soc.0/fff51000.ethernet/net/eth1
+E: IFINDEX=3
+E: INTERFACE=eth1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff58000.combo-phy
+E: DEVPATH=/devices/soc.0/fff58000.combo-phy
+E: MODALIAS=of:Ncombo-phyT<NULL>Ccalxeda,hb-combophy
+E: OF_COMPATIBLE_0=calxeda,hb-combophy
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=combo-phy
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/fff5d000.combo-phy
+E: DEVPATH=/devices/soc.0/fff5d000.combo-phy
+E: MODALIAS=of:Ncombo-phyT<NULL>Ccalxeda,hb-combophy
+E: OF_COMPATIBLE_0=calxeda,hb-combophy
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=combo-phy
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/soc.0/pmu.1
+E: DEVPATH=/devices/soc.0/pmu.1
+E: DRIVER=arm-pmu
+E: MODALIAS=of:NpmuT<NULL>Carm,cortex-a9-pmu
+E: OF_COMPATIBLE_0=arm,cortex-a9-pmu
+E: OF_COMPATIBLE_N=1
+E: OF_NAME=pmu
+E: OF_TYPE=<NULL>
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13158927
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13159467
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13160139
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13160780
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13161363
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13162028
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13162704
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=13163393
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13164084
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13164707
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13165303
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13165918
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13166559
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13167168
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13167782
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13194486
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13168640
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13169156
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13169756
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13175825
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13176486
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13177040
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13177620
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13178231
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya0
+N: ptya0
+E: DEVNAME=/dev/ptya0
+E: DEVPATH=/devices/virtual/tty/ptya0
+E: MAJOR=2
+E: MINOR=176
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya1
+N: ptya1
+E: DEVNAME=/dev/ptya1
+E: DEVPATH=/devices/virtual/tty/ptya1
+E: MAJOR=2
+E: MINOR=177
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya2
+N: ptya2
+E: DEVNAME=/dev/ptya2
+E: DEVPATH=/devices/virtual/tty/ptya2
+E: MAJOR=2
+E: MINOR=178
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya3
+N: ptya3
+E: DEVNAME=/dev/ptya3
+E: DEVPATH=/devices/virtual/tty/ptya3
+E: MAJOR=2
+E: MINOR=179
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya4
+N: ptya4
+E: DEVNAME=/dev/ptya4
+E: DEVPATH=/devices/virtual/tty/ptya4
+E: MAJOR=2
+E: MINOR=180
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya5
+N: ptya5
+E: DEVNAME=/dev/ptya5
+E: DEVPATH=/devices/virtual/tty/ptya5
+E: MAJOR=2
+E: MINOR=181
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya6
+N: ptya6
+E: DEVNAME=/dev/ptya6
+E: DEVPATH=/devices/virtual/tty/ptya6
+E: MAJOR=2
+E: MINOR=182
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya7
+N: ptya7
+E: DEVNAME=/dev/ptya7
+E: DEVPATH=/devices/virtual/tty/ptya7
+E: MAJOR=2
+E: MINOR=183
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya8
+N: ptya8
+E: DEVNAME=/dev/ptya8
+E: DEVPATH=/devices/virtual/tty/ptya8
+E: MAJOR=2
+E: MINOR=184
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptya9
+N: ptya9
+E: DEVNAME=/dev/ptya9
+E: DEVPATH=/devices/virtual/tty/ptya9
+E: MAJOR=2
+E: MINOR=185
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyaa
+N: ptyaa
+E: DEVNAME=/dev/ptyaa
+E: DEVPATH=/devices/virtual/tty/ptyaa
+E: MAJOR=2
+E: MINOR=186
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyab
+N: ptyab
+E: DEVNAME=/dev/ptyab
+E: DEVPATH=/devices/virtual/tty/ptyab
+E: MAJOR=2
+E: MINOR=187
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyac
+N: ptyac
+E: DEVNAME=/dev/ptyac
+E: DEVPATH=/devices/virtual/tty/ptyac
+E: MAJOR=2
+E: MINOR=188
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyad
+N: ptyad
+E: DEVNAME=/dev/ptyad
+E: DEVPATH=/devices/virtual/tty/ptyad
+E: MAJOR=2
+E: MINOR=189
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyae
+N: ptyae
+E: DEVNAME=/dev/ptyae
+E: DEVPATH=/devices/virtual/tty/ptyae
+E: MAJOR=2
+E: MINOR=190
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyaf
+N: ptyaf
+E: DEVNAME=/dev/ptyaf
+E: DEVPATH=/devices/virtual/tty/ptyaf
+E: MAJOR=2
+E: MINOR=191
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb0
+N: ptyb0
+E: DEVNAME=/dev/ptyb0
+E: DEVPATH=/devices/virtual/tty/ptyb0
+E: MAJOR=2
+E: MINOR=192
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb1
+N: ptyb1
+E: DEVNAME=/dev/ptyb1
+E: DEVPATH=/devices/virtual/tty/ptyb1
+E: MAJOR=2
+E: MINOR=193
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb2
+N: ptyb2
+E: DEVNAME=/dev/ptyb2
+E: DEVPATH=/devices/virtual/tty/ptyb2
+E: MAJOR=2
+E: MINOR=194
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb3
+N: ptyb3
+E: DEVNAME=/dev/ptyb3
+E: DEVPATH=/devices/virtual/tty/ptyb3
+E: MAJOR=2
+E: MINOR=195
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb4
+N: ptyb4
+E: DEVNAME=/dev/ptyb4
+E: DEVPATH=/devices/virtual/tty/ptyb4
+E: MAJOR=2
+E: MINOR=196
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb5
+N: ptyb5
+E: DEVNAME=/dev/ptyb5
+E: DEVPATH=/devices/virtual/tty/ptyb5
+E: MAJOR=2
+E: MINOR=197
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb6
+N: ptyb6
+E: DEVNAME=/dev/ptyb6
+E: DEVPATH=/devices/virtual/tty/ptyb6
+E: MAJOR=2
+E: MINOR=198
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb7
+N: ptyb7
+E: DEVNAME=/dev/ptyb7
+E: DEVPATH=/devices/virtual/tty/ptyb7
+E: MAJOR=2
+E: MINOR=199
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb8
+N: ptyb8
+E: DEVNAME=/dev/ptyb8
+E: DEVPATH=/devices/virtual/tty/ptyb8
+E: MAJOR=2
+E: MINOR=200
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyb9
+N: ptyb9
+E: DEVNAME=/dev/ptyb9
+E: DEVPATH=/devices/virtual/tty/ptyb9
+E: MAJOR=2
+E: MINOR=201
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyba
+N: ptyba
+E: DEVNAME=/dev/ptyba
+E: DEVPATH=/devices/virtual/tty/ptyba
+E: MAJOR=2
+E: MINOR=202
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptybb
+N: ptybb
+E: DEVNAME=/dev/ptybb
+E: DEVPATH=/devices/virtual/tty/ptybb
+E: MAJOR=2
+E: MINOR=203
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptybc
+N: ptybc
+E: DEVNAME=/dev/ptybc
+E: DEVPATH=/devices/virtual/tty/ptybc
+E: MAJOR=2
+E: MINOR=204
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptybd
+N: ptybd
+E: DEVNAME=/dev/ptybd
+E: DEVPATH=/devices/virtual/tty/ptybd
+E: MAJOR=2
+E: MINOR=205
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptybe
+N: ptybe
+E: DEVNAME=/dev/ptybe
+E: DEVPATH=/devices/virtual/tty/ptybe
+E: MAJOR=2
+E: MINOR=206
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptybf
+N: ptybf
+E: DEVNAME=/dev/ptybf
+E: DEVPATH=/devices/virtual/tty/ptybf
+E: MAJOR=2
+E: MINOR=207
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc0
+N: ptyc0
+E: DEVNAME=/dev/ptyc0
+E: DEVPATH=/devices/virtual/tty/ptyc0
+E: MAJOR=2
+E: MINOR=208
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc1
+N: ptyc1
+E: DEVNAME=/dev/ptyc1
+E: DEVPATH=/devices/virtual/tty/ptyc1
+E: MAJOR=2
+E: MINOR=209
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc2
+N: ptyc2
+E: DEVNAME=/dev/ptyc2
+E: DEVPATH=/devices/virtual/tty/ptyc2
+E: MAJOR=2
+E: MINOR=210
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc3
+N: ptyc3
+E: DEVNAME=/dev/ptyc3
+E: DEVPATH=/devices/virtual/tty/ptyc3
+E: MAJOR=2
+E: MINOR=211
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc4
+N: ptyc4
+E: DEVNAME=/dev/ptyc4
+E: DEVPATH=/devices/virtual/tty/ptyc4
+E: MAJOR=2
+E: MINOR=212
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc5
+N: ptyc5
+E: DEVNAME=/dev/ptyc5
+E: DEVPATH=/devices/virtual/tty/ptyc5
+E: MAJOR=2
+E: MINOR=213
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc6
+N: ptyc6
+E: DEVNAME=/dev/ptyc6
+E: DEVPATH=/devices/virtual/tty/ptyc6
+E: MAJOR=2
+E: MINOR=214
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc7
+N: ptyc7
+E: DEVNAME=/dev/ptyc7
+E: DEVPATH=/devices/virtual/tty/ptyc7
+E: MAJOR=2
+E: MINOR=215
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc8
+N: ptyc8
+E: DEVNAME=/dev/ptyc8
+E: DEVPATH=/devices/virtual/tty/ptyc8
+E: MAJOR=2
+E: MINOR=216
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyc9
+N: ptyc9
+E: DEVNAME=/dev/ptyc9
+E: DEVPATH=/devices/virtual/tty/ptyc9
+E: MAJOR=2
+E: MINOR=217
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyca
+N: ptyca
+E: DEVNAME=/dev/ptyca
+E: DEVPATH=/devices/virtual/tty/ptyca
+E: MAJOR=2
+E: MINOR=218
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptycb
+N: ptycb
+E: DEVNAME=/dev/ptycb
+E: DEVPATH=/devices/virtual/tty/ptycb
+E: MAJOR=2
+E: MINOR=219
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptycc
+N: ptycc
+E: DEVNAME=/dev/ptycc
+E: DEVPATH=/devices/virtual/tty/ptycc
+E: MAJOR=2
+E: MINOR=220
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptycd
+N: ptycd
+E: DEVNAME=/dev/ptycd
+E: DEVPATH=/devices/virtual/tty/ptycd
+E: MAJOR=2
+E: MINOR=221
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyce
+N: ptyce
+E: DEVNAME=/dev/ptyce
+E: DEVPATH=/devices/virtual/tty/ptyce
+E: MAJOR=2
+E: MINOR=222
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptycf
+N: ptycf
+E: DEVNAME=/dev/ptycf
+E: DEVPATH=/devices/virtual/tty/ptycf
+E: MAJOR=2
+E: MINOR=223
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd0
+N: ptyd0
+E: DEVNAME=/dev/ptyd0
+E: DEVPATH=/devices/virtual/tty/ptyd0
+E: MAJOR=2
+E: MINOR=224
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd1
+N: ptyd1
+E: DEVNAME=/dev/ptyd1
+E: DEVPATH=/devices/virtual/tty/ptyd1
+E: MAJOR=2
+E: MINOR=225
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd2
+N: ptyd2
+E: DEVNAME=/dev/ptyd2
+E: DEVPATH=/devices/virtual/tty/ptyd2
+E: MAJOR=2
+E: MINOR=226
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd3
+N: ptyd3
+E: DEVNAME=/dev/ptyd3
+E: DEVPATH=/devices/virtual/tty/ptyd3
+E: MAJOR=2
+E: MINOR=227
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd4
+N: ptyd4
+E: DEVNAME=/dev/ptyd4
+E: DEVPATH=/devices/virtual/tty/ptyd4
+E: MAJOR=2
+E: MINOR=228
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd5
+N: ptyd5
+E: DEVNAME=/dev/ptyd5
+E: DEVPATH=/devices/virtual/tty/ptyd5
+E: MAJOR=2
+E: MINOR=229
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd6
+N: ptyd6
+E: DEVNAME=/dev/ptyd6
+E: DEVPATH=/devices/virtual/tty/ptyd6
+E: MAJOR=2
+E: MINOR=230
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd7
+N: ptyd7
+E: DEVNAME=/dev/ptyd7
+E: DEVPATH=/devices/virtual/tty/ptyd7
+E: MAJOR=2
+E: MINOR=231
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd8
+N: ptyd8
+E: DEVNAME=/dev/ptyd8
+E: DEVPATH=/devices/virtual/tty/ptyd8
+E: MAJOR=2
+E: MINOR=232
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyd9
+N: ptyd9
+E: DEVNAME=/dev/ptyd9
+E: DEVPATH=/devices/virtual/tty/ptyd9
+E: MAJOR=2
+E: MINOR=233
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyda
+N: ptyda
+E: DEVNAME=/dev/ptyda
+E: DEVPATH=/devices/virtual/tty/ptyda
+E: MAJOR=2
+E: MINOR=234
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptydb
+N: ptydb
+E: DEVNAME=/dev/ptydb
+E: DEVPATH=/devices/virtual/tty/ptydb
+E: MAJOR=2
+E: MINOR=235
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptydc
+N: ptydc
+E: DEVNAME=/dev/ptydc
+E: DEVPATH=/devices/virtual/tty/ptydc
+E: MAJOR=2
+E: MINOR=236
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptydd
+N: ptydd
+E: DEVNAME=/dev/ptydd
+E: DEVPATH=/devices/virtual/tty/ptydd
+E: MAJOR=2
+E: MINOR=237
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyde
+N: ptyde
+E: DEVNAME=/dev/ptyde
+E: DEVPATH=/devices/virtual/tty/ptyde
+E: MAJOR=2
+E: MINOR=238
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptydf
+N: ptydf
+E: DEVNAME=/dev/ptydf
+E: DEVPATH=/devices/virtual/tty/ptydf
+E: MAJOR=2
+E: MINOR=239
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye0
+N: ptye0
+E: DEVNAME=/dev/ptye0
+E: DEVPATH=/devices/virtual/tty/ptye0
+E: MAJOR=2
+E: MINOR=240
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye1
+N: ptye1
+E: DEVNAME=/dev/ptye1
+E: DEVPATH=/devices/virtual/tty/ptye1
+E: MAJOR=2
+E: MINOR=241
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye2
+N: ptye2
+E: DEVNAME=/dev/ptye2
+E: DEVPATH=/devices/virtual/tty/ptye2
+E: MAJOR=2
+E: MINOR=242
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye3
+N: ptye3
+E: DEVNAME=/dev/ptye3
+E: DEVPATH=/devices/virtual/tty/ptye3
+E: MAJOR=2
+E: MINOR=243
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye4
+N: ptye4
+E: DEVNAME=/dev/ptye4
+E: DEVPATH=/devices/virtual/tty/ptye4
+E: MAJOR=2
+E: MINOR=244
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye5
+N: ptye5
+E: DEVNAME=/dev/ptye5
+E: DEVPATH=/devices/virtual/tty/ptye5
+E: MAJOR=2
+E: MINOR=245
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye6
+N: ptye6
+E: DEVNAME=/dev/ptye6
+E: DEVPATH=/devices/virtual/tty/ptye6
+E: MAJOR=2
+E: MINOR=246
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye7
+N: ptye7
+E: DEVNAME=/dev/ptye7
+E: DEVPATH=/devices/virtual/tty/ptye7
+E: MAJOR=2
+E: MINOR=247
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye8
+N: ptye8
+E: DEVNAME=/dev/ptye8
+E: DEVPATH=/devices/virtual/tty/ptye8
+E: MAJOR=2
+E: MINOR=248
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptye9
+N: ptye9
+E: DEVNAME=/dev/ptye9
+E: DEVPATH=/devices/virtual/tty/ptye9
+E: MAJOR=2
+E: MINOR=249
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyea
+N: ptyea
+E: DEVNAME=/dev/ptyea
+E: DEVPATH=/devices/virtual/tty/ptyea
+E: MAJOR=2
+E: MINOR=250
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyeb
+N: ptyeb
+E: DEVNAME=/dev/ptyeb
+E: DEVPATH=/devices/virtual/tty/ptyeb
+E: MAJOR=2
+E: MINOR=251
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyec
+N: ptyec
+E: DEVNAME=/dev/ptyec
+E: DEVPATH=/devices/virtual/tty/ptyec
+E: MAJOR=2
+E: MINOR=252
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyed
+N: ptyed
+E: DEVNAME=/dev/ptyed
+E: DEVPATH=/devices/virtual/tty/ptyed
+E: MAJOR=2
+E: MINOR=253
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyee
+N: ptyee
+E: DEVNAME=/dev/ptyee
+E: DEVPATH=/devices/virtual/tty/ptyee
+E: MAJOR=2
+E: MINOR=254
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyef
+N: ptyef
+E: DEVNAME=/dev/ptyef
+E: DEVPATH=/devices/virtual/tty/ptyef
+E: MAJOR=2
+E: MINOR=255
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp0
+N: ptyp0
+E: DEVNAME=/dev/ptyp0
+E: DEVPATH=/devices/virtual/tty/ptyp0
+E: MAJOR=2
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp1
+N: ptyp1
+E: DEVNAME=/dev/ptyp1
+E: DEVPATH=/devices/virtual/tty/ptyp1
+E: MAJOR=2
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp2
+N: ptyp2
+E: DEVNAME=/dev/ptyp2
+E: DEVPATH=/devices/virtual/tty/ptyp2
+E: MAJOR=2
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp3
+N: ptyp3
+E: DEVNAME=/dev/ptyp3
+E: DEVPATH=/devices/virtual/tty/ptyp3
+E: MAJOR=2
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp4
+N: ptyp4
+E: DEVNAME=/dev/ptyp4
+E: DEVPATH=/devices/virtual/tty/ptyp4
+E: MAJOR=2
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp5
+N: ptyp5
+E: DEVNAME=/dev/ptyp5
+E: DEVPATH=/devices/virtual/tty/ptyp5
+E: MAJOR=2
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp6
+N: ptyp6
+E: DEVNAME=/dev/ptyp6
+E: DEVPATH=/devices/virtual/tty/ptyp6
+E: MAJOR=2
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp7
+N: ptyp7
+E: DEVNAME=/dev/ptyp7
+E: DEVPATH=/devices/virtual/tty/ptyp7
+E: MAJOR=2
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp8
+N: ptyp8
+E: DEVNAME=/dev/ptyp8
+E: DEVPATH=/devices/virtual/tty/ptyp8
+E: MAJOR=2
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyp9
+N: ptyp9
+E: DEVNAME=/dev/ptyp9
+E: DEVPATH=/devices/virtual/tty/ptyp9
+E: MAJOR=2
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptypa
+N: ptypa
+E: DEVNAME=/dev/ptypa
+E: DEVPATH=/devices/virtual/tty/ptypa
+E: MAJOR=2
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptypb
+N: ptypb
+E: DEVNAME=/dev/ptypb
+E: DEVPATH=/devices/virtual/tty/ptypb
+E: MAJOR=2
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptypc
+N: ptypc
+E: DEVNAME=/dev/ptypc
+E: DEVPATH=/devices/virtual/tty/ptypc
+E: MAJOR=2
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptypd
+N: ptypd
+E: DEVNAME=/dev/ptypd
+E: DEVPATH=/devices/virtual/tty/ptypd
+E: MAJOR=2
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptype
+N: ptype
+E: DEVNAME=/dev/ptype
+E: DEVPATH=/devices/virtual/tty/ptype
+E: MAJOR=2
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptypf
+N: ptypf
+E: DEVNAME=/dev/ptypf
+E: DEVPATH=/devices/virtual/tty/ptypf
+E: MAJOR=2
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq0
+N: ptyq0
+E: DEVNAME=/dev/ptyq0
+E: DEVPATH=/devices/virtual/tty/ptyq0
+E: MAJOR=2
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq1
+N: ptyq1
+E: DEVNAME=/dev/ptyq1
+E: DEVPATH=/devices/virtual/tty/ptyq1
+E: MAJOR=2
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq2
+N: ptyq2
+E: DEVNAME=/dev/ptyq2
+E: DEVPATH=/devices/virtual/tty/ptyq2
+E: MAJOR=2
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq3
+N: ptyq3
+E: DEVNAME=/dev/ptyq3
+E: DEVPATH=/devices/virtual/tty/ptyq3
+E: MAJOR=2
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq4
+N: ptyq4
+E: DEVNAME=/dev/ptyq4
+E: DEVPATH=/devices/virtual/tty/ptyq4
+E: MAJOR=2
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq5
+N: ptyq5
+E: DEVNAME=/dev/ptyq5
+E: DEVPATH=/devices/virtual/tty/ptyq5
+E: MAJOR=2
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq6
+N: ptyq6
+E: DEVNAME=/dev/ptyq6
+E: DEVPATH=/devices/virtual/tty/ptyq6
+E: MAJOR=2
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq7
+N: ptyq7
+E: DEVNAME=/dev/ptyq7
+E: DEVPATH=/devices/virtual/tty/ptyq7
+E: MAJOR=2
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq8
+N: ptyq8
+E: DEVNAME=/dev/ptyq8
+E: DEVPATH=/devices/virtual/tty/ptyq8
+E: MAJOR=2
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyq9
+N: ptyq9
+E: DEVNAME=/dev/ptyq9
+E: DEVPATH=/devices/virtual/tty/ptyq9
+E: MAJOR=2
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyqa
+N: ptyqa
+E: DEVNAME=/dev/ptyqa
+E: DEVPATH=/devices/virtual/tty/ptyqa
+E: MAJOR=2
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyqb
+N: ptyqb
+E: DEVNAME=/dev/ptyqb
+E: DEVPATH=/devices/virtual/tty/ptyqb
+E: MAJOR=2
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyqc
+N: ptyqc
+E: DEVNAME=/dev/ptyqc
+E: DEVPATH=/devices/virtual/tty/ptyqc
+E: MAJOR=2
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyqd
+N: ptyqd
+E: DEVNAME=/dev/ptyqd
+E: DEVPATH=/devices/virtual/tty/ptyqd
+E: MAJOR=2
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyqe
+N: ptyqe
+E: DEVNAME=/dev/ptyqe
+E: DEVPATH=/devices/virtual/tty/ptyqe
+E: MAJOR=2
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyqf
+N: ptyqf
+E: DEVNAME=/dev/ptyqf
+E: DEVPATH=/devices/virtual/tty/ptyqf
+E: MAJOR=2
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr0
+N: ptyr0
+E: DEVNAME=/dev/ptyr0
+E: DEVPATH=/devices/virtual/tty/ptyr0
+E: MAJOR=2
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr1
+N: ptyr1
+E: DEVNAME=/dev/ptyr1
+E: DEVPATH=/devices/virtual/tty/ptyr1
+E: MAJOR=2
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr2
+N: ptyr2
+E: DEVNAME=/dev/ptyr2
+E: DEVPATH=/devices/virtual/tty/ptyr2
+E: MAJOR=2
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr3
+N: ptyr3
+E: DEVNAME=/dev/ptyr3
+E: DEVPATH=/devices/virtual/tty/ptyr3
+E: MAJOR=2
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr4
+N: ptyr4
+E: DEVNAME=/dev/ptyr4
+E: DEVPATH=/devices/virtual/tty/ptyr4
+E: MAJOR=2
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr5
+N: ptyr5
+E: DEVNAME=/dev/ptyr5
+E: DEVPATH=/devices/virtual/tty/ptyr5
+E: MAJOR=2
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr6
+N: ptyr6
+E: DEVNAME=/dev/ptyr6
+E: DEVPATH=/devices/virtual/tty/ptyr6
+E: MAJOR=2
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr7
+N: ptyr7
+E: DEVNAME=/dev/ptyr7
+E: DEVPATH=/devices/virtual/tty/ptyr7
+E: MAJOR=2
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr8
+N: ptyr8
+E: DEVNAME=/dev/ptyr8
+E: DEVPATH=/devices/virtual/tty/ptyr8
+E: MAJOR=2
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyr9
+N: ptyr9
+E: DEVNAME=/dev/ptyr9
+E: DEVPATH=/devices/virtual/tty/ptyr9
+E: MAJOR=2
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyra
+N: ptyra
+E: DEVNAME=/dev/ptyra
+E: DEVPATH=/devices/virtual/tty/ptyra
+E: MAJOR=2
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyrb
+N: ptyrb
+E: DEVNAME=/dev/ptyrb
+E: DEVPATH=/devices/virtual/tty/ptyrb
+E: MAJOR=2
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyrc
+N: ptyrc
+E: DEVNAME=/dev/ptyrc
+E: DEVPATH=/devices/virtual/tty/ptyrc
+E: MAJOR=2
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyrd
+N: ptyrd
+E: DEVNAME=/dev/ptyrd
+E: DEVPATH=/devices/virtual/tty/ptyrd
+E: MAJOR=2
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyre
+N: ptyre
+E: DEVNAME=/dev/ptyre
+E: DEVPATH=/devices/virtual/tty/ptyre
+E: MAJOR=2
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyrf
+N: ptyrf
+E: DEVNAME=/dev/ptyrf
+E: DEVPATH=/devices/virtual/tty/ptyrf
+E: MAJOR=2
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys0
+N: ptys0
+E: DEVNAME=/dev/ptys0
+E: DEVPATH=/devices/virtual/tty/ptys0
+E: MAJOR=2
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys1
+N: ptys1
+E: DEVNAME=/dev/ptys1
+E: DEVPATH=/devices/virtual/tty/ptys1
+E: MAJOR=2
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys2
+N: ptys2
+E: DEVNAME=/dev/ptys2
+E: DEVPATH=/devices/virtual/tty/ptys2
+E: MAJOR=2
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys3
+N: ptys3
+E: DEVNAME=/dev/ptys3
+E: DEVPATH=/devices/virtual/tty/ptys3
+E: MAJOR=2
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys4
+N: ptys4
+E: DEVNAME=/dev/ptys4
+E: DEVPATH=/devices/virtual/tty/ptys4
+E: MAJOR=2
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys5
+N: ptys5
+E: DEVNAME=/dev/ptys5
+E: DEVPATH=/devices/virtual/tty/ptys5
+E: MAJOR=2
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys6
+N: ptys6
+E: DEVNAME=/dev/ptys6
+E: DEVPATH=/devices/virtual/tty/ptys6
+E: MAJOR=2
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys7
+N: ptys7
+E: DEVNAME=/dev/ptys7
+E: DEVPATH=/devices/virtual/tty/ptys7
+E: MAJOR=2
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys8
+N: ptys8
+E: DEVNAME=/dev/ptys8
+E: DEVPATH=/devices/virtual/tty/ptys8
+E: MAJOR=2
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptys9
+N: ptys9
+E: DEVNAME=/dev/ptys9
+E: DEVPATH=/devices/virtual/tty/ptys9
+E: MAJOR=2
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptysa
+N: ptysa
+E: DEVNAME=/dev/ptysa
+E: DEVPATH=/devices/virtual/tty/ptysa
+E: MAJOR=2
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptysb
+N: ptysb
+E: DEVNAME=/dev/ptysb
+E: DEVPATH=/devices/virtual/tty/ptysb
+E: MAJOR=2
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptysc
+N: ptysc
+E: DEVNAME=/dev/ptysc
+E: DEVPATH=/devices/virtual/tty/ptysc
+E: MAJOR=2
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptysd
+N: ptysd
+E: DEVNAME=/dev/ptysd
+E: DEVPATH=/devices/virtual/tty/ptysd
+E: MAJOR=2
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyse
+N: ptyse
+E: DEVNAME=/dev/ptyse
+E: DEVPATH=/devices/virtual/tty/ptyse
+E: MAJOR=2
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptysf
+N: ptysf
+E: DEVNAME=/dev/ptysf
+E: DEVPATH=/devices/virtual/tty/ptysf
+E: MAJOR=2
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt0
+N: ptyt0
+E: DEVNAME=/dev/ptyt0
+E: DEVPATH=/devices/virtual/tty/ptyt0
+E: MAJOR=2
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt1
+N: ptyt1
+E: DEVNAME=/dev/ptyt1
+E: DEVPATH=/devices/virtual/tty/ptyt1
+E: MAJOR=2
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt2
+N: ptyt2
+E: DEVNAME=/dev/ptyt2
+E: DEVPATH=/devices/virtual/tty/ptyt2
+E: MAJOR=2
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt3
+N: ptyt3
+E: DEVNAME=/dev/ptyt3
+E: DEVPATH=/devices/virtual/tty/ptyt3
+E: MAJOR=2
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt4
+N: ptyt4
+E: DEVNAME=/dev/ptyt4
+E: DEVPATH=/devices/virtual/tty/ptyt4
+E: MAJOR=2
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt5
+N: ptyt5
+E: DEVNAME=/dev/ptyt5
+E: DEVPATH=/devices/virtual/tty/ptyt5
+E: MAJOR=2
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt6
+N: ptyt6
+E: DEVNAME=/dev/ptyt6
+E: DEVPATH=/devices/virtual/tty/ptyt6
+E: MAJOR=2
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt7
+N: ptyt7
+E: DEVNAME=/dev/ptyt7
+E: DEVPATH=/devices/virtual/tty/ptyt7
+E: MAJOR=2
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt8
+N: ptyt8
+E: DEVNAME=/dev/ptyt8
+E: DEVPATH=/devices/virtual/tty/ptyt8
+E: MAJOR=2
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyt9
+N: ptyt9
+E: DEVNAME=/dev/ptyt9
+E: DEVPATH=/devices/virtual/tty/ptyt9
+E: MAJOR=2
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyta
+N: ptyta
+E: DEVNAME=/dev/ptyta
+E: DEVPATH=/devices/virtual/tty/ptyta
+E: MAJOR=2
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptytb
+N: ptytb
+E: DEVNAME=/dev/ptytb
+E: DEVPATH=/devices/virtual/tty/ptytb
+E: MAJOR=2
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptytc
+N: ptytc
+E: DEVNAME=/dev/ptytc
+E: DEVPATH=/devices/virtual/tty/ptytc
+E: MAJOR=2
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptytd
+N: ptytd
+E: DEVNAME=/dev/ptytd
+E: DEVPATH=/devices/virtual/tty/ptytd
+E: MAJOR=2
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyte
+N: ptyte
+E: DEVNAME=/dev/ptyte
+E: DEVPATH=/devices/virtual/tty/ptyte
+E: MAJOR=2
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptytf
+N: ptytf
+E: DEVNAME=/dev/ptytf
+E: DEVPATH=/devices/virtual/tty/ptytf
+E: MAJOR=2
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu0
+N: ptyu0
+E: DEVNAME=/dev/ptyu0
+E: DEVPATH=/devices/virtual/tty/ptyu0
+E: MAJOR=2
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu1
+N: ptyu1
+E: DEVNAME=/dev/ptyu1
+E: DEVPATH=/devices/virtual/tty/ptyu1
+E: MAJOR=2
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu2
+N: ptyu2
+E: DEVNAME=/dev/ptyu2
+E: DEVPATH=/devices/virtual/tty/ptyu2
+E: MAJOR=2
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu3
+N: ptyu3
+E: DEVNAME=/dev/ptyu3
+E: DEVPATH=/devices/virtual/tty/ptyu3
+E: MAJOR=2
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu4
+N: ptyu4
+E: DEVNAME=/dev/ptyu4
+E: DEVPATH=/devices/virtual/tty/ptyu4
+E: MAJOR=2
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu5
+N: ptyu5
+E: DEVNAME=/dev/ptyu5
+E: DEVPATH=/devices/virtual/tty/ptyu5
+E: MAJOR=2
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu6
+N: ptyu6
+E: DEVNAME=/dev/ptyu6
+E: DEVPATH=/devices/virtual/tty/ptyu6
+E: MAJOR=2
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu7
+N: ptyu7
+E: DEVNAME=/dev/ptyu7
+E: DEVPATH=/devices/virtual/tty/ptyu7
+E: MAJOR=2
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu8
+N: ptyu8
+E: DEVNAME=/dev/ptyu8
+E: DEVPATH=/devices/virtual/tty/ptyu8
+E: MAJOR=2
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyu9
+N: ptyu9
+E: DEVNAME=/dev/ptyu9
+E: DEVPATH=/devices/virtual/tty/ptyu9
+E: MAJOR=2
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyua
+N: ptyua
+E: DEVNAME=/dev/ptyua
+E: DEVPATH=/devices/virtual/tty/ptyua
+E: MAJOR=2
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyub
+N: ptyub
+E: DEVNAME=/dev/ptyub
+E: DEVPATH=/devices/virtual/tty/ptyub
+E: MAJOR=2
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyuc
+N: ptyuc
+E: DEVNAME=/dev/ptyuc
+E: DEVPATH=/devices/virtual/tty/ptyuc
+E: MAJOR=2
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyud
+N: ptyud
+E: DEVNAME=/dev/ptyud
+E: DEVPATH=/devices/virtual/tty/ptyud
+E: MAJOR=2
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyue
+N: ptyue
+E: DEVNAME=/dev/ptyue
+E: DEVPATH=/devices/virtual/tty/ptyue
+E: MAJOR=2
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyuf
+N: ptyuf
+E: DEVNAME=/dev/ptyuf
+E: DEVPATH=/devices/virtual/tty/ptyuf
+E: MAJOR=2
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv0
+N: ptyv0
+E: DEVNAME=/dev/ptyv0
+E: DEVPATH=/devices/virtual/tty/ptyv0
+E: MAJOR=2
+E: MINOR=96
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv1
+N: ptyv1
+E: DEVNAME=/dev/ptyv1
+E: DEVPATH=/devices/virtual/tty/ptyv1
+E: MAJOR=2
+E: MINOR=97
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv2
+N: ptyv2
+E: DEVNAME=/dev/ptyv2
+E: DEVPATH=/devices/virtual/tty/ptyv2
+E: MAJOR=2
+E: MINOR=98
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv3
+N: ptyv3
+E: DEVNAME=/dev/ptyv3
+E: DEVPATH=/devices/virtual/tty/ptyv3
+E: MAJOR=2
+E: MINOR=99
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv4
+N: ptyv4
+E: DEVNAME=/dev/ptyv4
+E: DEVPATH=/devices/virtual/tty/ptyv4
+E: MAJOR=2
+E: MINOR=100
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv5
+N: ptyv5
+E: DEVNAME=/dev/ptyv5
+E: DEVPATH=/devices/virtual/tty/ptyv5
+E: MAJOR=2
+E: MINOR=101
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv6
+N: ptyv6
+E: DEVNAME=/dev/ptyv6
+E: DEVPATH=/devices/virtual/tty/ptyv6
+E: MAJOR=2
+E: MINOR=102
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv7
+N: ptyv7
+E: DEVNAME=/dev/ptyv7
+E: DEVPATH=/devices/virtual/tty/ptyv7
+E: MAJOR=2
+E: MINOR=103
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv8
+N: ptyv8
+E: DEVNAME=/dev/ptyv8
+E: DEVPATH=/devices/virtual/tty/ptyv8
+E: MAJOR=2
+E: MINOR=104
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyv9
+N: ptyv9
+E: DEVNAME=/dev/ptyv9
+E: DEVPATH=/devices/virtual/tty/ptyv9
+E: MAJOR=2
+E: MINOR=105
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyva
+N: ptyva
+E: DEVNAME=/dev/ptyva
+E: DEVPATH=/devices/virtual/tty/ptyva
+E: MAJOR=2
+E: MINOR=106
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyvb
+N: ptyvb
+E: DEVNAME=/dev/ptyvb
+E: DEVPATH=/devices/virtual/tty/ptyvb
+E: MAJOR=2
+E: MINOR=107
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyvc
+N: ptyvc
+E: DEVNAME=/dev/ptyvc
+E: DEVPATH=/devices/virtual/tty/ptyvc
+E: MAJOR=2
+E: MINOR=108
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyvd
+N: ptyvd
+E: DEVNAME=/dev/ptyvd
+E: DEVPATH=/devices/virtual/tty/ptyvd
+E: MAJOR=2
+E: MINOR=109
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyve
+N: ptyve
+E: DEVNAME=/dev/ptyve
+E: DEVPATH=/devices/virtual/tty/ptyve
+E: MAJOR=2
+E: MINOR=110
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyvf
+N: ptyvf
+E: DEVNAME=/dev/ptyvf
+E: DEVPATH=/devices/virtual/tty/ptyvf
+E: MAJOR=2
+E: MINOR=111
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw0
+N: ptyw0
+E: DEVNAME=/dev/ptyw0
+E: DEVPATH=/devices/virtual/tty/ptyw0
+E: MAJOR=2
+E: MINOR=112
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw1
+N: ptyw1
+E: DEVNAME=/dev/ptyw1
+E: DEVPATH=/devices/virtual/tty/ptyw1
+E: MAJOR=2
+E: MINOR=113
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw2
+N: ptyw2
+E: DEVNAME=/dev/ptyw2
+E: DEVPATH=/devices/virtual/tty/ptyw2
+E: MAJOR=2
+E: MINOR=114
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw3
+N: ptyw3
+E: DEVNAME=/dev/ptyw3
+E: DEVPATH=/devices/virtual/tty/ptyw3
+E: MAJOR=2
+E: MINOR=115
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw4
+N: ptyw4
+E: DEVNAME=/dev/ptyw4
+E: DEVPATH=/devices/virtual/tty/ptyw4
+E: MAJOR=2
+E: MINOR=116
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw5
+N: ptyw5
+E: DEVNAME=/dev/ptyw5
+E: DEVPATH=/devices/virtual/tty/ptyw5
+E: MAJOR=2
+E: MINOR=117
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw6
+N: ptyw6
+E: DEVNAME=/dev/ptyw6
+E: DEVPATH=/devices/virtual/tty/ptyw6
+E: MAJOR=2
+E: MINOR=118
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw7
+N: ptyw7
+E: DEVNAME=/dev/ptyw7
+E: DEVPATH=/devices/virtual/tty/ptyw7
+E: MAJOR=2
+E: MINOR=119
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw8
+N: ptyw8
+E: DEVNAME=/dev/ptyw8
+E: DEVPATH=/devices/virtual/tty/ptyw8
+E: MAJOR=2
+E: MINOR=120
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyw9
+N: ptyw9
+E: DEVNAME=/dev/ptyw9
+E: DEVPATH=/devices/virtual/tty/ptyw9
+E: MAJOR=2
+E: MINOR=121
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptywa
+N: ptywa
+E: DEVNAME=/dev/ptywa
+E: DEVPATH=/devices/virtual/tty/ptywa
+E: MAJOR=2
+E: MINOR=122
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptywb
+N: ptywb
+E: DEVNAME=/dev/ptywb
+E: DEVPATH=/devices/virtual/tty/ptywb
+E: MAJOR=2
+E: MINOR=123
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptywc
+N: ptywc
+E: DEVNAME=/dev/ptywc
+E: DEVPATH=/devices/virtual/tty/ptywc
+E: MAJOR=2
+E: MINOR=124
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptywd
+N: ptywd
+E: DEVNAME=/dev/ptywd
+E: DEVPATH=/devices/virtual/tty/ptywd
+E: MAJOR=2
+E: MINOR=125
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptywe
+N: ptywe
+E: DEVNAME=/dev/ptywe
+E: DEVPATH=/devices/virtual/tty/ptywe
+E: MAJOR=2
+E: MINOR=126
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptywf
+N: ptywf
+E: DEVNAME=/dev/ptywf
+E: DEVPATH=/devices/virtual/tty/ptywf
+E: MAJOR=2
+E: MINOR=127
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx0
+N: ptyx0
+E: DEVNAME=/dev/ptyx0
+E: DEVPATH=/devices/virtual/tty/ptyx0
+E: MAJOR=2
+E: MINOR=128
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx1
+N: ptyx1
+E: DEVNAME=/dev/ptyx1
+E: DEVPATH=/devices/virtual/tty/ptyx1
+E: MAJOR=2
+E: MINOR=129
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx2
+N: ptyx2
+E: DEVNAME=/dev/ptyx2
+E: DEVPATH=/devices/virtual/tty/ptyx2
+E: MAJOR=2
+E: MINOR=130
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx3
+N: ptyx3
+E: DEVNAME=/dev/ptyx3
+E: DEVPATH=/devices/virtual/tty/ptyx3
+E: MAJOR=2
+E: MINOR=131
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx4
+N: ptyx4
+E: DEVNAME=/dev/ptyx4
+E: DEVPATH=/devices/virtual/tty/ptyx4
+E: MAJOR=2
+E: MINOR=132
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx5
+N: ptyx5
+E: DEVNAME=/dev/ptyx5
+E: DEVPATH=/devices/virtual/tty/ptyx5
+E: MAJOR=2
+E: MINOR=133
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx6
+N: ptyx6
+E: DEVNAME=/dev/ptyx6
+E: DEVPATH=/devices/virtual/tty/ptyx6
+E: MAJOR=2
+E: MINOR=134
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx7
+N: ptyx7
+E: DEVNAME=/dev/ptyx7
+E: DEVPATH=/devices/virtual/tty/ptyx7
+E: MAJOR=2
+E: MINOR=135
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx8
+N: ptyx8
+E: DEVNAME=/dev/ptyx8
+E: DEVPATH=/devices/virtual/tty/ptyx8
+E: MAJOR=2
+E: MINOR=136
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyx9
+N: ptyx9
+E: DEVNAME=/dev/ptyx9
+E: DEVPATH=/devices/virtual/tty/ptyx9
+E: MAJOR=2
+E: MINOR=137
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyxa
+N: ptyxa
+E: DEVNAME=/dev/ptyxa
+E: DEVPATH=/devices/virtual/tty/ptyxa
+E: MAJOR=2
+E: MINOR=138
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyxb
+N: ptyxb
+E: DEVNAME=/dev/ptyxb
+E: DEVPATH=/devices/virtual/tty/ptyxb
+E: MAJOR=2
+E: MINOR=139
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyxc
+N: ptyxc
+E: DEVNAME=/dev/ptyxc
+E: DEVPATH=/devices/virtual/tty/ptyxc
+E: MAJOR=2
+E: MINOR=140
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyxd
+N: ptyxd
+E: DEVNAME=/dev/ptyxd
+E: DEVPATH=/devices/virtual/tty/ptyxd
+E: MAJOR=2
+E: MINOR=141
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyxe
+N: ptyxe
+E: DEVNAME=/dev/ptyxe
+E: DEVPATH=/devices/virtual/tty/ptyxe
+E: MAJOR=2
+E: MINOR=142
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyxf
+N: ptyxf
+E: DEVNAME=/dev/ptyxf
+E: DEVPATH=/devices/virtual/tty/ptyxf
+E: MAJOR=2
+E: MINOR=143
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy0
+N: ptyy0
+E: DEVNAME=/dev/ptyy0
+E: DEVPATH=/devices/virtual/tty/ptyy0
+E: MAJOR=2
+E: MINOR=144
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy1
+N: ptyy1
+E: DEVNAME=/dev/ptyy1
+E: DEVPATH=/devices/virtual/tty/ptyy1
+E: MAJOR=2
+E: MINOR=145
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy2
+N: ptyy2
+E: DEVNAME=/dev/ptyy2
+E: DEVPATH=/devices/virtual/tty/ptyy2
+E: MAJOR=2
+E: MINOR=146
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy3
+N: ptyy3
+E: DEVNAME=/dev/ptyy3
+E: DEVPATH=/devices/virtual/tty/ptyy3
+E: MAJOR=2
+E: MINOR=147
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy4
+N: ptyy4
+E: DEVNAME=/dev/ptyy4
+E: DEVPATH=/devices/virtual/tty/ptyy4
+E: MAJOR=2
+E: MINOR=148
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy5
+N: ptyy5
+E: DEVNAME=/dev/ptyy5
+E: DEVPATH=/devices/virtual/tty/ptyy5
+E: MAJOR=2
+E: MINOR=149
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy6
+N: ptyy6
+E: DEVNAME=/dev/ptyy6
+E: DEVPATH=/devices/virtual/tty/ptyy6
+E: MAJOR=2
+E: MINOR=150
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy7
+N: ptyy7
+E: DEVNAME=/dev/ptyy7
+E: DEVPATH=/devices/virtual/tty/ptyy7
+E: MAJOR=2
+E: MINOR=151
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy8
+N: ptyy8
+E: DEVNAME=/dev/ptyy8
+E: DEVPATH=/devices/virtual/tty/ptyy8
+E: MAJOR=2
+E: MINOR=152
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyy9
+N: ptyy9
+E: DEVNAME=/dev/ptyy9
+E: DEVPATH=/devices/virtual/tty/ptyy9
+E: MAJOR=2
+E: MINOR=153
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyya
+N: ptyya
+E: DEVNAME=/dev/ptyya
+E: DEVPATH=/devices/virtual/tty/ptyya
+E: MAJOR=2
+E: MINOR=154
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyyb
+N: ptyyb
+E: DEVNAME=/dev/ptyyb
+E: DEVPATH=/devices/virtual/tty/ptyyb
+E: MAJOR=2
+E: MINOR=155
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyyc
+N: ptyyc
+E: DEVNAME=/dev/ptyyc
+E: DEVPATH=/devices/virtual/tty/ptyyc
+E: MAJOR=2
+E: MINOR=156
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyyd
+N: ptyyd
+E: DEVNAME=/dev/ptyyd
+E: DEVPATH=/devices/virtual/tty/ptyyd
+E: MAJOR=2
+E: MINOR=157
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyye
+N: ptyye
+E: DEVNAME=/dev/ptyye
+E: DEVPATH=/devices/virtual/tty/ptyye
+E: MAJOR=2
+E: MINOR=158
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyyf
+N: ptyyf
+E: DEVNAME=/dev/ptyyf
+E: DEVPATH=/devices/virtual/tty/ptyyf
+E: MAJOR=2
+E: MINOR=159
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz0
+N: ptyz0
+E: DEVNAME=/dev/ptyz0
+E: DEVPATH=/devices/virtual/tty/ptyz0
+E: MAJOR=2
+E: MINOR=160
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz1
+N: ptyz1
+E: DEVNAME=/dev/ptyz1
+E: DEVPATH=/devices/virtual/tty/ptyz1
+E: MAJOR=2
+E: MINOR=161
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz2
+N: ptyz2
+E: DEVNAME=/dev/ptyz2
+E: DEVPATH=/devices/virtual/tty/ptyz2
+E: MAJOR=2
+E: MINOR=162
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz3
+N: ptyz3
+E: DEVNAME=/dev/ptyz3
+E: DEVPATH=/devices/virtual/tty/ptyz3
+E: MAJOR=2
+E: MINOR=163
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz4
+N: ptyz4
+E: DEVNAME=/dev/ptyz4
+E: DEVPATH=/devices/virtual/tty/ptyz4
+E: MAJOR=2
+E: MINOR=164
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz5
+N: ptyz5
+E: DEVNAME=/dev/ptyz5
+E: DEVPATH=/devices/virtual/tty/ptyz5
+E: MAJOR=2
+E: MINOR=165
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz6
+N: ptyz6
+E: DEVNAME=/dev/ptyz6
+E: DEVPATH=/devices/virtual/tty/ptyz6
+E: MAJOR=2
+E: MINOR=166
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz7
+N: ptyz7
+E: DEVNAME=/dev/ptyz7
+E: DEVPATH=/devices/virtual/tty/ptyz7
+E: MAJOR=2
+E: MINOR=167
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz8
+N: ptyz8
+E: DEVNAME=/dev/ptyz8
+E: DEVPATH=/devices/virtual/tty/ptyz8
+E: MAJOR=2
+E: MINOR=168
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyz9
+N: ptyz9
+E: DEVNAME=/dev/ptyz9
+E: DEVPATH=/devices/virtual/tty/ptyz9
+E: MAJOR=2
+E: MINOR=169
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyza
+N: ptyza
+E: DEVNAME=/dev/ptyza
+E: DEVPATH=/devices/virtual/tty/ptyza
+E: MAJOR=2
+E: MINOR=170
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyzb
+N: ptyzb
+E: DEVNAME=/dev/ptyzb
+E: DEVPATH=/devices/virtual/tty/ptyzb
+E: MAJOR=2
+E: MINOR=171
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyzc
+N: ptyzc
+E: DEVNAME=/dev/ptyzc
+E: DEVPATH=/devices/virtual/tty/ptyzc
+E: MAJOR=2
+E: MINOR=172
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyzd
+N: ptyzd
+E: DEVNAME=/dev/ptyzd
+E: DEVPATH=/devices/virtual/tty/ptyzd
+E: MAJOR=2
+E: MINOR=173
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyze
+N: ptyze
+E: DEVNAME=/dev/ptyze
+E: DEVPATH=/devices/virtual/tty/ptyze
+E: MAJOR=2
+E: MINOR=174
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptyzf
+N: ptyzf
+E: DEVNAME=/dev/ptyzf
+E: DEVPATH=/devices/virtual/tty/ptyzf
+E: MAJOR=2
+E: MINOR=175
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya0
+N: ttya0
+E: DEVNAME=/dev/ttya0
+E: DEVPATH=/devices/virtual/tty/ttya0
+E: MAJOR=3
+E: MINOR=176
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya1
+N: ttya1
+E: DEVNAME=/dev/ttya1
+E: DEVPATH=/devices/virtual/tty/ttya1
+E: MAJOR=3
+E: MINOR=177
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya2
+N: ttya2
+E: DEVNAME=/dev/ttya2
+E: DEVPATH=/devices/virtual/tty/ttya2
+E: MAJOR=3
+E: MINOR=178
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya3
+N: ttya3
+E: DEVNAME=/dev/ttya3
+E: DEVPATH=/devices/virtual/tty/ttya3
+E: MAJOR=3
+E: MINOR=179
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya4
+N: ttya4
+E: DEVNAME=/dev/ttya4
+E: DEVPATH=/devices/virtual/tty/ttya4
+E: MAJOR=3
+E: MINOR=180
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya5
+N: ttya5
+E: DEVNAME=/dev/ttya5
+E: DEVPATH=/devices/virtual/tty/ttya5
+E: MAJOR=3
+E: MINOR=181
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya6
+N: ttya6
+E: DEVNAME=/dev/ttya6
+E: DEVPATH=/devices/virtual/tty/ttya6
+E: MAJOR=3
+E: MINOR=182
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya7
+N: ttya7
+E: DEVNAME=/dev/ttya7
+E: DEVPATH=/devices/virtual/tty/ttya7
+E: MAJOR=3
+E: MINOR=183
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya8
+N: ttya8
+E: DEVNAME=/dev/ttya8
+E: DEVPATH=/devices/virtual/tty/ttya8
+E: MAJOR=3
+E: MINOR=184
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttya9
+N: ttya9
+E: DEVNAME=/dev/ttya9
+E: DEVPATH=/devices/virtual/tty/ttya9
+E: MAJOR=3
+E: MINOR=185
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyaa
+N: ttyaa
+E: DEVNAME=/dev/ttyaa
+E: DEVPATH=/devices/virtual/tty/ttyaa
+E: MAJOR=3
+E: MINOR=186
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyab
+N: ttyab
+E: DEVNAME=/dev/ttyab
+E: DEVPATH=/devices/virtual/tty/ttyab
+E: MAJOR=3
+E: MINOR=187
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyac
+N: ttyac
+E: DEVNAME=/dev/ttyac
+E: DEVPATH=/devices/virtual/tty/ttyac
+E: MAJOR=3
+E: MINOR=188
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyad
+N: ttyad
+E: DEVNAME=/dev/ttyad
+E: DEVPATH=/devices/virtual/tty/ttyad
+E: MAJOR=3
+E: MINOR=189
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyae
+N: ttyae
+E: DEVNAME=/dev/ttyae
+E: DEVPATH=/devices/virtual/tty/ttyae
+E: MAJOR=3
+E: MINOR=190
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyaf
+N: ttyaf
+E: DEVNAME=/dev/ttyaf
+E: DEVPATH=/devices/virtual/tty/ttyaf
+E: MAJOR=3
+E: MINOR=191
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb0
+N: ttyb0
+E: DEVNAME=/dev/ttyb0
+E: DEVPATH=/devices/virtual/tty/ttyb0
+E: MAJOR=3
+E: MINOR=192
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb1
+N: ttyb1
+E: DEVNAME=/dev/ttyb1
+E: DEVPATH=/devices/virtual/tty/ttyb1
+E: MAJOR=3
+E: MINOR=193
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb2
+N: ttyb2
+E: DEVNAME=/dev/ttyb2
+E: DEVPATH=/devices/virtual/tty/ttyb2
+E: MAJOR=3
+E: MINOR=194
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb3
+N: ttyb3
+E: DEVNAME=/dev/ttyb3
+E: DEVPATH=/devices/virtual/tty/ttyb3
+E: MAJOR=3
+E: MINOR=195
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb4
+N: ttyb4
+E: DEVNAME=/dev/ttyb4
+E: DEVPATH=/devices/virtual/tty/ttyb4
+E: MAJOR=3
+E: MINOR=196
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb5
+N: ttyb5
+E: DEVNAME=/dev/ttyb5
+E: DEVPATH=/devices/virtual/tty/ttyb5
+E: MAJOR=3
+E: MINOR=197
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb6
+N: ttyb6
+E: DEVNAME=/dev/ttyb6
+E: DEVPATH=/devices/virtual/tty/ttyb6
+E: MAJOR=3
+E: MINOR=198
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb7
+N: ttyb7
+E: DEVNAME=/dev/ttyb7
+E: DEVPATH=/devices/virtual/tty/ttyb7
+E: MAJOR=3
+E: MINOR=199
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb8
+N: ttyb8
+E: DEVNAME=/dev/ttyb8
+E: DEVPATH=/devices/virtual/tty/ttyb8
+E: MAJOR=3
+E: MINOR=200
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyb9
+N: ttyb9
+E: DEVNAME=/dev/ttyb9
+E: DEVPATH=/devices/virtual/tty/ttyb9
+E: MAJOR=3
+E: MINOR=201
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyba
+N: ttyba
+E: DEVNAME=/dev/ttyba
+E: DEVPATH=/devices/virtual/tty/ttyba
+E: MAJOR=3
+E: MINOR=202
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttybb
+N: ttybb
+E: DEVNAME=/dev/ttybb
+E: DEVPATH=/devices/virtual/tty/ttybb
+E: MAJOR=3
+E: MINOR=203
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttybc
+N: ttybc
+E: DEVNAME=/dev/ttybc
+E: DEVPATH=/devices/virtual/tty/ttybc
+E: MAJOR=3
+E: MINOR=204
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttybd
+N: ttybd
+E: DEVNAME=/dev/ttybd
+E: DEVPATH=/devices/virtual/tty/ttybd
+E: MAJOR=3
+E: MINOR=205
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttybe
+N: ttybe
+E: DEVNAME=/dev/ttybe
+E: DEVPATH=/devices/virtual/tty/ttybe
+E: MAJOR=3
+E: MINOR=206
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttybf
+N: ttybf
+E: DEVNAME=/dev/ttybf
+E: DEVPATH=/devices/virtual/tty/ttybf
+E: MAJOR=3
+E: MINOR=207
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc0
+N: ttyc0
+E: DEVNAME=/dev/ttyc0
+E: DEVPATH=/devices/virtual/tty/ttyc0
+E: MAJOR=3
+E: MINOR=208
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc1
+N: ttyc1
+E: DEVNAME=/dev/ttyc1
+E: DEVPATH=/devices/virtual/tty/ttyc1
+E: MAJOR=3
+E: MINOR=209
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc2
+N: ttyc2
+E: DEVNAME=/dev/ttyc2
+E: DEVPATH=/devices/virtual/tty/ttyc2
+E: MAJOR=3
+E: MINOR=210
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc3
+N: ttyc3
+E: DEVNAME=/dev/ttyc3
+E: DEVPATH=/devices/virtual/tty/ttyc3
+E: MAJOR=3
+E: MINOR=211
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc4
+N: ttyc4
+E: DEVNAME=/dev/ttyc4
+E: DEVPATH=/devices/virtual/tty/ttyc4
+E: MAJOR=3
+E: MINOR=212
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc5
+N: ttyc5
+E: DEVNAME=/dev/ttyc5
+E: DEVPATH=/devices/virtual/tty/ttyc5
+E: MAJOR=3
+E: MINOR=213
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc6
+N: ttyc6
+E: DEVNAME=/dev/ttyc6
+E: DEVPATH=/devices/virtual/tty/ttyc6
+E: MAJOR=3
+E: MINOR=214
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc7
+N: ttyc7
+E: DEVNAME=/dev/ttyc7
+E: DEVPATH=/devices/virtual/tty/ttyc7
+E: MAJOR=3
+E: MINOR=215
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc8
+N: ttyc8
+E: DEVNAME=/dev/ttyc8
+E: DEVPATH=/devices/virtual/tty/ttyc8
+E: MAJOR=3
+E: MINOR=216
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyc9
+N: ttyc9
+E: DEVNAME=/dev/ttyc9
+E: DEVPATH=/devices/virtual/tty/ttyc9
+E: MAJOR=3
+E: MINOR=217
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyca
+N: ttyca
+E: DEVNAME=/dev/ttyca
+E: DEVPATH=/devices/virtual/tty/ttyca
+E: MAJOR=3
+E: MINOR=218
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttycb
+N: ttycb
+E: DEVNAME=/dev/ttycb
+E: DEVPATH=/devices/virtual/tty/ttycb
+E: MAJOR=3
+E: MINOR=219
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttycc
+N: ttycc
+E: DEVNAME=/dev/ttycc
+E: DEVPATH=/devices/virtual/tty/ttycc
+E: MAJOR=3
+E: MINOR=220
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttycd
+N: ttycd
+E: DEVNAME=/dev/ttycd
+E: DEVPATH=/devices/virtual/tty/ttycd
+E: MAJOR=3
+E: MINOR=221
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyce
+N: ttyce
+E: DEVNAME=/dev/ttyce
+E: DEVPATH=/devices/virtual/tty/ttyce
+E: MAJOR=3
+E: MINOR=222
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttycf
+N: ttycf
+E: DEVNAME=/dev/ttycf
+E: DEVPATH=/devices/virtual/tty/ttycf
+E: MAJOR=3
+E: MINOR=223
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd0
+N: ttyd0
+E: DEVNAME=/dev/ttyd0
+E: DEVPATH=/devices/virtual/tty/ttyd0
+E: MAJOR=3
+E: MINOR=224
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd1
+N: ttyd1
+E: DEVNAME=/dev/ttyd1
+E: DEVPATH=/devices/virtual/tty/ttyd1
+E: MAJOR=3
+E: MINOR=225
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd2
+N: ttyd2
+E: DEVNAME=/dev/ttyd2
+E: DEVPATH=/devices/virtual/tty/ttyd2
+E: MAJOR=3
+E: MINOR=226
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd3
+N: ttyd3
+E: DEVNAME=/dev/ttyd3
+E: DEVPATH=/devices/virtual/tty/ttyd3
+E: MAJOR=3
+E: MINOR=227
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd4
+N: ttyd4
+E: DEVNAME=/dev/ttyd4
+E: DEVPATH=/devices/virtual/tty/ttyd4
+E: MAJOR=3
+E: MINOR=228
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd5
+N: ttyd5
+E: DEVNAME=/dev/ttyd5
+E: DEVPATH=/devices/virtual/tty/ttyd5
+E: MAJOR=3
+E: MINOR=229
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd6
+N: ttyd6
+E: DEVNAME=/dev/ttyd6
+E: DEVPATH=/devices/virtual/tty/ttyd6
+E: MAJOR=3
+E: MINOR=230
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd7
+N: ttyd7
+E: DEVNAME=/dev/ttyd7
+E: DEVPATH=/devices/virtual/tty/ttyd7
+E: MAJOR=3
+E: MINOR=231
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd8
+N: ttyd8
+E: DEVNAME=/dev/ttyd8
+E: DEVPATH=/devices/virtual/tty/ttyd8
+E: MAJOR=3
+E: MINOR=232
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyd9
+N: ttyd9
+E: DEVNAME=/dev/ttyd9
+E: DEVPATH=/devices/virtual/tty/ttyd9
+E: MAJOR=3
+E: MINOR=233
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyda
+N: ttyda
+E: DEVNAME=/dev/ttyda
+E: DEVPATH=/devices/virtual/tty/ttyda
+E: MAJOR=3
+E: MINOR=234
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttydb
+N: ttydb
+E: DEVNAME=/dev/ttydb
+E: DEVPATH=/devices/virtual/tty/ttydb
+E: MAJOR=3
+E: MINOR=235
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttydc
+N: ttydc
+E: DEVNAME=/dev/ttydc
+E: DEVPATH=/devices/virtual/tty/ttydc
+E: MAJOR=3
+E: MINOR=236
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttydd
+N: ttydd
+E: DEVNAME=/dev/ttydd
+E: DEVPATH=/devices/virtual/tty/ttydd
+E: MAJOR=3
+E: MINOR=237
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyde
+N: ttyde
+E: DEVNAME=/dev/ttyde
+E: DEVPATH=/devices/virtual/tty/ttyde
+E: MAJOR=3
+E: MINOR=238
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttydf
+N: ttydf
+E: DEVNAME=/dev/ttydf
+E: DEVPATH=/devices/virtual/tty/ttydf
+E: MAJOR=3
+E: MINOR=239
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye0
+N: ttye0
+E: DEVNAME=/dev/ttye0
+E: DEVPATH=/devices/virtual/tty/ttye0
+E: MAJOR=3
+E: MINOR=240
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye1
+N: ttye1
+E: DEVNAME=/dev/ttye1
+E: DEVPATH=/devices/virtual/tty/ttye1
+E: MAJOR=3
+E: MINOR=241
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye2
+N: ttye2
+E: DEVNAME=/dev/ttye2
+E: DEVPATH=/devices/virtual/tty/ttye2
+E: MAJOR=3
+E: MINOR=242
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye3
+N: ttye3
+E: DEVNAME=/dev/ttye3
+E: DEVPATH=/devices/virtual/tty/ttye3
+E: MAJOR=3
+E: MINOR=243
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye4
+N: ttye4
+E: DEVNAME=/dev/ttye4
+E: DEVPATH=/devices/virtual/tty/ttye4
+E: MAJOR=3
+E: MINOR=244
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye5
+N: ttye5
+E: DEVNAME=/dev/ttye5
+E: DEVPATH=/devices/virtual/tty/ttye5
+E: MAJOR=3
+E: MINOR=245
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye6
+N: ttye6
+E: DEVNAME=/dev/ttye6
+E: DEVPATH=/devices/virtual/tty/ttye6
+E: MAJOR=3
+E: MINOR=246
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye7
+N: ttye7
+E: DEVNAME=/dev/ttye7
+E: DEVPATH=/devices/virtual/tty/ttye7
+E: MAJOR=3
+E: MINOR=247
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye8
+N: ttye8
+E: DEVNAME=/dev/ttye8
+E: DEVPATH=/devices/virtual/tty/ttye8
+E: MAJOR=3
+E: MINOR=248
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttye9
+N: ttye9
+E: DEVNAME=/dev/ttye9
+E: DEVPATH=/devices/virtual/tty/ttye9
+E: MAJOR=3
+E: MINOR=249
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyea
+N: ttyea
+E: DEVNAME=/dev/ttyea
+E: DEVPATH=/devices/virtual/tty/ttyea
+E: MAJOR=3
+E: MINOR=250
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyeb
+N: ttyeb
+E: DEVNAME=/dev/ttyeb
+E: DEVPATH=/devices/virtual/tty/ttyeb
+E: MAJOR=3
+E: MINOR=251
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyec
+N: ttyec
+E: DEVNAME=/dev/ttyec
+E: DEVPATH=/devices/virtual/tty/ttyec
+E: MAJOR=3
+E: MINOR=252
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyed
+N: ttyed
+E: DEVNAME=/dev/ttyed
+E: DEVPATH=/devices/virtual/tty/ttyed
+E: MAJOR=3
+E: MINOR=253
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyee
+N: ttyee
+E: DEVNAME=/dev/ttyee
+E: DEVPATH=/devices/virtual/tty/ttyee
+E: MAJOR=3
+E: MINOR=254
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyef
+N: ttyef
+E: DEVNAME=/dev/ttyef
+E: DEVPATH=/devices/virtual/tty/ttyef
+E: MAJOR=3
+E: MINOR=255
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp0
+N: ttyp0
+E: DEVNAME=/dev/ttyp0
+E: DEVPATH=/devices/virtual/tty/ttyp0
+E: MAJOR=3
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp1
+N: ttyp1
+E: DEVNAME=/dev/ttyp1
+E: DEVPATH=/devices/virtual/tty/ttyp1
+E: MAJOR=3
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp2
+N: ttyp2
+E: DEVNAME=/dev/ttyp2
+E: DEVPATH=/devices/virtual/tty/ttyp2
+E: MAJOR=3
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp3
+N: ttyp3
+E: DEVNAME=/dev/ttyp3
+E: DEVPATH=/devices/virtual/tty/ttyp3
+E: MAJOR=3
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp4
+N: ttyp4
+E: DEVNAME=/dev/ttyp4
+E: DEVPATH=/devices/virtual/tty/ttyp4
+E: MAJOR=3
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp5
+N: ttyp5
+E: DEVNAME=/dev/ttyp5
+E: DEVPATH=/devices/virtual/tty/ttyp5
+E: MAJOR=3
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp6
+N: ttyp6
+E: DEVNAME=/dev/ttyp6
+E: DEVPATH=/devices/virtual/tty/ttyp6
+E: MAJOR=3
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp7
+N: ttyp7
+E: DEVNAME=/dev/ttyp7
+E: DEVPATH=/devices/virtual/tty/ttyp7
+E: MAJOR=3
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp8
+N: ttyp8
+E: DEVNAME=/dev/ttyp8
+E: DEVPATH=/devices/virtual/tty/ttyp8
+E: MAJOR=3
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyp9
+N: ttyp9
+E: DEVNAME=/dev/ttyp9
+E: DEVPATH=/devices/virtual/tty/ttyp9
+E: MAJOR=3
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttypa
+N: ttypa
+E: DEVNAME=/dev/ttypa
+E: DEVPATH=/devices/virtual/tty/ttypa
+E: MAJOR=3
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttypb
+N: ttypb
+E: DEVNAME=/dev/ttypb
+E: DEVPATH=/devices/virtual/tty/ttypb
+E: MAJOR=3
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttypc
+N: ttypc
+E: DEVNAME=/dev/ttypc
+E: DEVPATH=/devices/virtual/tty/ttypc
+E: MAJOR=3
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttypd
+N: ttypd
+E: DEVNAME=/dev/ttypd
+E: DEVPATH=/devices/virtual/tty/ttypd
+E: MAJOR=3
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttype
+N: ttype
+E: DEVNAME=/dev/ttype
+E: DEVPATH=/devices/virtual/tty/ttype
+E: MAJOR=3
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttypf
+N: ttypf
+E: DEVNAME=/dev/ttypf
+E: DEVPATH=/devices/virtual/tty/ttypf
+E: MAJOR=3
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq0
+N: ttyq0
+E: DEVNAME=/dev/ttyq0
+E: DEVPATH=/devices/virtual/tty/ttyq0
+E: MAJOR=3
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq1
+N: ttyq1
+E: DEVNAME=/dev/ttyq1
+E: DEVPATH=/devices/virtual/tty/ttyq1
+E: MAJOR=3
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq2
+N: ttyq2
+E: DEVNAME=/dev/ttyq2
+E: DEVPATH=/devices/virtual/tty/ttyq2
+E: MAJOR=3
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq3
+N: ttyq3
+E: DEVNAME=/dev/ttyq3
+E: DEVPATH=/devices/virtual/tty/ttyq3
+E: MAJOR=3
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq4
+N: ttyq4
+E: DEVNAME=/dev/ttyq4
+E: DEVPATH=/devices/virtual/tty/ttyq4
+E: MAJOR=3
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq5
+N: ttyq5
+E: DEVNAME=/dev/ttyq5
+E: DEVPATH=/devices/virtual/tty/ttyq5
+E: MAJOR=3
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq6
+N: ttyq6
+E: DEVNAME=/dev/ttyq6
+E: DEVPATH=/devices/virtual/tty/ttyq6
+E: MAJOR=3
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq7
+N: ttyq7
+E: DEVNAME=/dev/ttyq7
+E: DEVPATH=/devices/virtual/tty/ttyq7
+E: MAJOR=3
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq8
+N: ttyq8
+E: DEVNAME=/dev/ttyq8
+E: DEVPATH=/devices/virtual/tty/ttyq8
+E: MAJOR=3
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyq9
+N: ttyq9
+E: DEVNAME=/dev/ttyq9
+E: DEVPATH=/devices/virtual/tty/ttyq9
+E: MAJOR=3
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyqa
+N: ttyqa
+E: DEVNAME=/dev/ttyqa
+E: DEVPATH=/devices/virtual/tty/ttyqa
+E: MAJOR=3
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyqb
+N: ttyqb
+E: DEVNAME=/dev/ttyqb
+E: DEVPATH=/devices/virtual/tty/ttyqb
+E: MAJOR=3
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyqc
+N: ttyqc
+E: DEVNAME=/dev/ttyqc
+E: DEVPATH=/devices/virtual/tty/ttyqc
+E: MAJOR=3
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyqd
+N: ttyqd
+E: DEVNAME=/dev/ttyqd
+E: DEVPATH=/devices/virtual/tty/ttyqd
+E: MAJOR=3
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyqe
+N: ttyqe
+E: DEVNAME=/dev/ttyqe
+E: DEVPATH=/devices/virtual/tty/ttyqe
+E: MAJOR=3
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyqf
+N: ttyqf
+E: DEVNAME=/dev/ttyqf
+E: DEVPATH=/devices/virtual/tty/ttyqf
+E: MAJOR=3
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr0
+N: ttyr0
+E: DEVNAME=/dev/ttyr0
+E: DEVPATH=/devices/virtual/tty/ttyr0
+E: MAJOR=3
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr1
+N: ttyr1
+E: DEVNAME=/dev/ttyr1
+E: DEVPATH=/devices/virtual/tty/ttyr1
+E: MAJOR=3
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr2
+N: ttyr2
+E: DEVNAME=/dev/ttyr2
+E: DEVPATH=/devices/virtual/tty/ttyr2
+E: MAJOR=3
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr3
+N: ttyr3
+E: DEVNAME=/dev/ttyr3
+E: DEVPATH=/devices/virtual/tty/ttyr3
+E: MAJOR=3
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr4
+N: ttyr4
+E: DEVNAME=/dev/ttyr4
+E: DEVPATH=/devices/virtual/tty/ttyr4
+E: MAJOR=3
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr5
+N: ttyr5
+E: DEVNAME=/dev/ttyr5
+E: DEVPATH=/devices/virtual/tty/ttyr5
+E: MAJOR=3
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr6
+N: ttyr6
+E: DEVNAME=/dev/ttyr6
+E: DEVPATH=/devices/virtual/tty/ttyr6
+E: MAJOR=3
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr7
+N: ttyr7
+E: DEVNAME=/dev/ttyr7
+E: DEVPATH=/devices/virtual/tty/ttyr7
+E: MAJOR=3
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr8
+N: ttyr8
+E: DEVNAME=/dev/ttyr8
+E: DEVPATH=/devices/virtual/tty/ttyr8
+E: MAJOR=3
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyr9
+N: ttyr9
+E: DEVNAME=/dev/ttyr9
+E: DEVPATH=/devices/virtual/tty/ttyr9
+E: MAJOR=3
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyra
+N: ttyra
+E: DEVNAME=/dev/ttyra
+E: DEVPATH=/devices/virtual/tty/ttyra
+E: MAJOR=3
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyrb
+N: ttyrb
+E: DEVNAME=/dev/ttyrb
+E: DEVPATH=/devices/virtual/tty/ttyrb
+E: MAJOR=3
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyrc
+N: ttyrc
+E: DEVNAME=/dev/ttyrc
+E: DEVPATH=/devices/virtual/tty/ttyrc
+E: MAJOR=3
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyrd
+N: ttyrd
+E: DEVNAME=/dev/ttyrd
+E: DEVPATH=/devices/virtual/tty/ttyrd
+E: MAJOR=3
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyre
+N: ttyre
+E: DEVNAME=/dev/ttyre
+E: DEVPATH=/devices/virtual/tty/ttyre
+E: MAJOR=3
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyrf
+N: ttyrf
+E: DEVNAME=/dev/ttyrf
+E: DEVPATH=/devices/virtual/tty/ttyrf
+E: MAJOR=3
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys0
+N: ttys0
+E: DEVNAME=/dev/ttys0
+E: DEVPATH=/devices/virtual/tty/ttys0
+E: MAJOR=3
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys1
+N: ttys1
+E: DEVNAME=/dev/ttys1
+E: DEVPATH=/devices/virtual/tty/ttys1
+E: MAJOR=3
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys2
+N: ttys2
+E: DEVNAME=/dev/ttys2
+E: DEVPATH=/devices/virtual/tty/ttys2
+E: MAJOR=3
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys3
+N: ttys3
+E: DEVNAME=/dev/ttys3
+E: DEVPATH=/devices/virtual/tty/ttys3
+E: MAJOR=3
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys4
+N: ttys4
+E: DEVNAME=/dev/ttys4
+E: DEVPATH=/devices/virtual/tty/ttys4
+E: MAJOR=3
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys5
+N: ttys5
+E: DEVNAME=/dev/ttys5
+E: DEVPATH=/devices/virtual/tty/ttys5
+E: MAJOR=3
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys6
+N: ttys6
+E: DEVNAME=/dev/ttys6
+E: DEVPATH=/devices/virtual/tty/ttys6
+E: MAJOR=3
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys7
+N: ttys7
+E: DEVNAME=/dev/ttys7
+E: DEVPATH=/devices/virtual/tty/ttys7
+E: MAJOR=3
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys8
+N: ttys8
+E: DEVNAME=/dev/ttys8
+E: DEVPATH=/devices/virtual/tty/ttys8
+E: MAJOR=3
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttys9
+N: ttys9
+E: DEVNAME=/dev/ttys9
+E: DEVPATH=/devices/virtual/tty/ttys9
+E: MAJOR=3
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttysa
+N: ttysa
+E: DEVNAME=/dev/ttysa
+E: DEVPATH=/devices/virtual/tty/ttysa
+E: MAJOR=3
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttysb
+N: ttysb
+E: DEVNAME=/dev/ttysb
+E: DEVPATH=/devices/virtual/tty/ttysb
+E: MAJOR=3
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttysc
+N: ttysc
+E: DEVNAME=/dev/ttysc
+E: DEVPATH=/devices/virtual/tty/ttysc
+E: MAJOR=3
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttysd
+N: ttysd
+E: DEVNAME=/dev/ttysd
+E: DEVPATH=/devices/virtual/tty/ttysd
+E: MAJOR=3
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyse
+N: ttyse
+E: DEVNAME=/dev/ttyse
+E: DEVPATH=/devices/virtual/tty/ttyse
+E: MAJOR=3
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttysf
+N: ttysf
+E: DEVNAME=/dev/ttysf
+E: DEVPATH=/devices/virtual/tty/ttysf
+E: MAJOR=3
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt0
+N: ttyt0
+E: DEVNAME=/dev/ttyt0
+E: DEVPATH=/devices/virtual/tty/ttyt0
+E: MAJOR=3
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt1
+N: ttyt1
+E: DEVNAME=/dev/ttyt1
+E: DEVPATH=/devices/virtual/tty/ttyt1
+E: MAJOR=3
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt2
+N: ttyt2
+E: DEVNAME=/dev/ttyt2
+E: DEVPATH=/devices/virtual/tty/ttyt2
+E: MAJOR=3
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt3
+N: ttyt3
+E: DEVNAME=/dev/ttyt3
+E: DEVPATH=/devices/virtual/tty/ttyt3
+E: MAJOR=3
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt4
+N: ttyt4
+E: DEVNAME=/dev/ttyt4
+E: DEVPATH=/devices/virtual/tty/ttyt4
+E: MAJOR=3
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt5
+N: ttyt5
+E: DEVNAME=/dev/ttyt5
+E: DEVPATH=/devices/virtual/tty/ttyt5
+E: MAJOR=3
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt6
+N: ttyt6
+E: DEVNAME=/dev/ttyt6
+E: DEVPATH=/devices/virtual/tty/ttyt6
+E: MAJOR=3
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt7
+N: ttyt7
+E: DEVNAME=/dev/ttyt7
+E: DEVPATH=/devices/virtual/tty/ttyt7
+E: MAJOR=3
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt8
+N: ttyt8
+E: DEVNAME=/dev/ttyt8
+E: DEVPATH=/devices/virtual/tty/ttyt8
+E: MAJOR=3
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyt9
+N: ttyt9
+E: DEVNAME=/dev/ttyt9
+E: DEVPATH=/devices/virtual/tty/ttyt9
+E: MAJOR=3
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyta
+N: ttyta
+E: DEVNAME=/dev/ttyta
+E: DEVPATH=/devices/virtual/tty/ttyta
+E: MAJOR=3
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttytb
+N: ttytb
+E: DEVNAME=/dev/ttytb
+E: DEVPATH=/devices/virtual/tty/ttytb
+E: MAJOR=3
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttytc
+N: ttytc
+E: DEVNAME=/dev/ttytc
+E: DEVPATH=/devices/virtual/tty/ttytc
+E: MAJOR=3
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttytd
+N: ttytd
+E: DEVNAME=/dev/ttytd
+E: DEVPATH=/devices/virtual/tty/ttytd
+E: MAJOR=3
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyte
+N: ttyte
+E: DEVNAME=/dev/ttyte
+E: DEVPATH=/devices/virtual/tty/ttyte
+E: MAJOR=3
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttytf
+N: ttytf
+E: DEVNAME=/dev/ttytf
+E: DEVPATH=/devices/virtual/tty/ttytf
+E: MAJOR=3
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu0
+N: ttyu0
+E: DEVNAME=/dev/ttyu0
+E: DEVPATH=/devices/virtual/tty/ttyu0
+E: MAJOR=3
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu1
+N: ttyu1
+E: DEVNAME=/dev/ttyu1
+E: DEVPATH=/devices/virtual/tty/ttyu1
+E: MAJOR=3
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu2
+N: ttyu2
+E: DEVNAME=/dev/ttyu2
+E: DEVPATH=/devices/virtual/tty/ttyu2
+E: MAJOR=3
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu3
+N: ttyu3
+E: DEVNAME=/dev/ttyu3
+E: DEVPATH=/devices/virtual/tty/ttyu3
+E: MAJOR=3
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu4
+N: ttyu4
+E: DEVNAME=/dev/ttyu4
+E: DEVPATH=/devices/virtual/tty/ttyu4
+E: MAJOR=3
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu5
+N: ttyu5
+E: DEVNAME=/dev/ttyu5
+E: DEVPATH=/devices/virtual/tty/ttyu5
+E: MAJOR=3
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu6
+N: ttyu6
+E: DEVNAME=/dev/ttyu6
+E: DEVPATH=/devices/virtual/tty/ttyu6
+E: MAJOR=3
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu7
+N: ttyu7
+E: DEVNAME=/dev/ttyu7
+E: DEVPATH=/devices/virtual/tty/ttyu7
+E: MAJOR=3
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu8
+N: ttyu8
+E: DEVNAME=/dev/ttyu8
+E: DEVPATH=/devices/virtual/tty/ttyu8
+E: MAJOR=3
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyu9
+N: ttyu9
+E: DEVNAME=/dev/ttyu9
+E: DEVPATH=/devices/virtual/tty/ttyu9
+E: MAJOR=3
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyua
+N: ttyua
+E: DEVNAME=/dev/ttyua
+E: DEVPATH=/devices/virtual/tty/ttyua
+E: MAJOR=3
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyub
+N: ttyub
+E: DEVNAME=/dev/ttyub
+E: DEVPATH=/devices/virtual/tty/ttyub
+E: MAJOR=3
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyuc
+N: ttyuc
+E: DEVNAME=/dev/ttyuc
+E: DEVPATH=/devices/virtual/tty/ttyuc
+E: MAJOR=3
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyud
+N: ttyud
+E: DEVNAME=/dev/ttyud
+E: DEVPATH=/devices/virtual/tty/ttyud
+E: MAJOR=3
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyue
+N: ttyue
+E: DEVNAME=/dev/ttyue
+E: DEVPATH=/devices/virtual/tty/ttyue
+E: MAJOR=3
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyuf
+N: ttyuf
+E: DEVNAME=/dev/ttyuf
+E: DEVPATH=/devices/virtual/tty/ttyuf
+E: MAJOR=3
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv0
+N: ttyv0
+E: DEVNAME=/dev/ttyv0
+E: DEVPATH=/devices/virtual/tty/ttyv0
+E: MAJOR=3
+E: MINOR=96
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv1
+N: ttyv1
+E: DEVNAME=/dev/ttyv1
+E: DEVPATH=/devices/virtual/tty/ttyv1
+E: MAJOR=3
+E: MINOR=97
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv2
+N: ttyv2
+E: DEVNAME=/dev/ttyv2
+E: DEVPATH=/devices/virtual/tty/ttyv2
+E: MAJOR=3
+E: MINOR=98
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv3
+N: ttyv3
+E: DEVNAME=/dev/ttyv3
+E: DEVPATH=/devices/virtual/tty/ttyv3
+E: MAJOR=3
+E: MINOR=99
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv4
+N: ttyv4
+E: DEVNAME=/dev/ttyv4
+E: DEVPATH=/devices/virtual/tty/ttyv4
+E: MAJOR=3
+E: MINOR=100
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv5
+N: ttyv5
+E: DEVNAME=/dev/ttyv5
+E: DEVPATH=/devices/virtual/tty/ttyv5
+E: MAJOR=3
+E: MINOR=101
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv6
+N: ttyv6
+E: DEVNAME=/dev/ttyv6
+E: DEVPATH=/devices/virtual/tty/ttyv6
+E: MAJOR=3
+E: MINOR=102
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv7
+N: ttyv7
+E: DEVNAME=/dev/ttyv7
+E: DEVPATH=/devices/virtual/tty/ttyv7
+E: MAJOR=3
+E: MINOR=103
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv8
+N: ttyv8
+E: DEVNAME=/dev/ttyv8
+E: DEVPATH=/devices/virtual/tty/ttyv8
+E: MAJOR=3
+E: MINOR=104
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyv9
+N: ttyv9
+E: DEVNAME=/dev/ttyv9
+E: DEVPATH=/devices/virtual/tty/ttyv9
+E: MAJOR=3
+E: MINOR=105
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyva
+N: ttyva
+E: DEVNAME=/dev/ttyva
+E: DEVPATH=/devices/virtual/tty/ttyva
+E: MAJOR=3
+E: MINOR=106
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyvb
+N: ttyvb
+E: DEVNAME=/dev/ttyvb
+E: DEVPATH=/devices/virtual/tty/ttyvb
+E: MAJOR=3
+E: MINOR=107
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyvc
+N: ttyvc
+E: DEVNAME=/dev/ttyvc
+E: DEVPATH=/devices/virtual/tty/ttyvc
+E: MAJOR=3
+E: MINOR=108
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyvd
+N: ttyvd
+E: DEVNAME=/dev/ttyvd
+E: DEVPATH=/devices/virtual/tty/ttyvd
+E: MAJOR=3
+E: MINOR=109
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyve
+N: ttyve
+E: DEVNAME=/dev/ttyve
+E: DEVPATH=/devices/virtual/tty/ttyve
+E: MAJOR=3
+E: MINOR=110
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyvf
+N: ttyvf
+E: DEVNAME=/dev/ttyvf
+E: DEVPATH=/devices/virtual/tty/ttyvf
+E: MAJOR=3
+E: MINOR=111
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw0
+N: ttyw0
+E: DEVNAME=/dev/ttyw0
+E: DEVPATH=/devices/virtual/tty/ttyw0
+E: MAJOR=3
+E: MINOR=112
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw1
+N: ttyw1
+E: DEVNAME=/dev/ttyw1
+E: DEVPATH=/devices/virtual/tty/ttyw1
+E: MAJOR=3
+E: MINOR=113
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw2
+N: ttyw2
+E: DEVNAME=/dev/ttyw2
+E: DEVPATH=/devices/virtual/tty/ttyw2
+E: MAJOR=3
+E: MINOR=114
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw3
+N: ttyw3
+E: DEVNAME=/dev/ttyw3
+E: DEVPATH=/devices/virtual/tty/ttyw3
+E: MAJOR=3
+E: MINOR=115
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw4
+N: ttyw4
+E: DEVNAME=/dev/ttyw4
+E: DEVPATH=/devices/virtual/tty/ttyw4
+E: MAJOR=3
+E: MINOR=116
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw5
+N: ttyw5
+E: DEVNAME=/dev/ttyw5
+E: DEVPATH=/devices/virtual/tty/ttyw5
+E: MAJOR=3
+E: MINOR=117
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw6
+N: ttyw6
+E: DEVNAME=/dev/ttyw6
+E: DEVPATH=/devices/virtual/tty/ttyw6
+E: MAJOR=3
+E: MINOR=118
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw7
+N: ttyw7
+E: DEVNAME=/dev/ttyw7
+E: DEVPATH=/devices/virtual/tty/ttyw7
+E: MAJOR=3
+E: MINOR=119
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw8
+N: ttyw8
+E: DEVNAME=/dev/ttyw8
+E: DEVPATH=/devices/virtual/tty/ttyw8
+E: MAJOR=3
+E: MINOR=120
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyw9
+N: ttyw9
+E: DEVNAME=/dev/ttyw9
+E: DEVPATH=/devices/virtual/tty/ttyw9
+E: MAJOR=3
+E: MINOR=121
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttywa
+N: ttywa
+E: DEVNAME=/dev/ttywa
+E: DEVPATH=/devices/virtual/tty/ttywa
+E: MAJOR=3
+E: MINOR=122
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttywb
+N: ttywb
+E: DEVNAME=/dev/ttywb
+E: DEVPATH=/devices/virtual/tty/ttywb
+E: MAJOR=3
+E: MINOR=123
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttywc
+N: ttywc
+E: DEVNAME=/dev/ttywc
+E: DEVPATH=/devices/virtual/tty/ttywc
+E: MAJOR=3
+E: MINOR=124
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttywd
+N: ttywd
+E: DEVNAME=/dev/ttywd
+E: DEVPATH=/devices/virtual/tty/ttywd
+E: MAJOR=3
+E: MINOR=125
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttywe
+N: ttywe
+E: DEVNAME=/dev/ttywe
+E: DEVPATH=/devices/virtual/tty/ttywe
+E: MAJOR=3
+E: MINOR=126
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttywf
+N: ttywf
+E: DEVNAME=/dev/ttywf
+E: DEVPATH=/devices/virtual/tty/ttywf
+E: MAJOR=3
+E: MINOR=127
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx0
+N: ttyx0
+E: DEVNAME=/dev/ttyx0
+E: DEVPATH=/devices/virtual/tty/ttyx0
+E: MAJOR=3
+E: MINOR=128
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx1
+N: ttyx1
+E: DEVNAME=/dev/ttyx1
+E: DEVPATH=/devices/virtual/tty/ttyx1
+E: MAJOR=3
+E: MINOR=129
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx2
+N: ttyx2
+E: DEVNAME=/dev/ttyx2
+E: DEVPATH=/devices/virtual/tty/ttyx2
+E: MAJOR=3
+E: MINOR=130
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx3
+N: ttyx3
+E: DEVNAME=/dev/ttyx3
+E: DEVPATH=/devices/virtual/tty/ttyx3
+E: MAJOR=3
+E: MINOR=131
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx4
+N: ttyx4
+E: DEVNAME=/dev/ttyx4
+E: DEVPATH=/devices/virtual/tty/ttyx4
+E: MAJOR=3
+E: MINOR=132
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx5
+N: ttyx5
+E: DEVNAME=/dev/ttyx5
+E: DEVPATH=/devices/virtual/tty/ttyx5
+E: MAJOR=3
+E: MINOR=133
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx6
+N: ttyx6
+E: DEVNAME=/dev/ttyx6
+E: DEVPATH=/devices/virtual/tty/ttyx6
+E: MAJOR=3
+E: MINOR=134
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx7
+N: ttyx7
+E: DEVNAME=/dev/ttyx7
+E: DEVPATH=/devices/virtual/tty/ttyx7
+E: MAJOR=3
+E: MINOR=135
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx8
+N: ttyx8
+E: DEVNAME=/dev/ttyx8
+E: DEVPATH=/devices/virtual/tty/ttyx8
+E: MAJOR=3
+E: MINOR=136
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyx9
+N: ttyx9
+E: DEVNAME=/dev/ttyx9
+E: DEVPATH=/devices/virtual/tty/ttyx9
+E: MAJOR=3
+E: MINOR=137
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyxa
+N: ttyxa
+E: DEVNAME=/dev/ttyxa
+E: DEVPATH=/devices/virtual/tty/ttyxa
+E: MAJOR=3
+E: MINOR=138
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyxb
+N: ttyxb
+E: DEVNAME=/dev/ttyxb
+E: DEVPATH=/devices/virtual/tty/ttyxb
+E: MAJOR=3
+E: MINOR=139
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyxc
+N: ttyxc
+E: DEVNAME=/dev/ttyxc
+E: DEVPATH=/devices/virtual/tty/ttyxc
+E: MAJOR=3
+E: MINOR=140
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyxd
+N: ttyxd
+E: DEVNAME=/dev/ttyxd
+E: DEVPATH=/devices/virtual/tty/ttyxd
+E: MAJOR=3
+E: MINOR=141
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyxe
+N: ttyxe
+E: DEVNAME=/dev/ttyxe
+E: DEVPATH=/devices/virtual/tty/ttyxe
+E: MAJOR=3
+E: MINOR=142
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyxf
+N: ttyxf
+E: DEVNAME=/dev/ttyxf
+E: DEVPATH=/devices/virtual/tty/ttyxf
+E: MAJOR=3
+E: MINOR=143
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy0
+N: ttyy0
+E: DEVNAME=/dev/ttyy0
+E: DEVPATH=/devices/virtual/tty/ttyy0
+E: MAJOR=3
+E: MINOR=144
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy1
+N: ttyy1
+E: DEVNAME=/dev/ttyy1
+E: DEVPATH=/devices/virtual/tty/ttyy1
+E: MAJOR=3
+E: MINOR=145
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy2
+N: ttyy2
+E: DEVNAME=/dev/ttyy2
+E: DEVPATH=/devices/virtual/tty/ttyy2
+E: MAJOR=3
+E: MINOR=146
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy3
+N: ttyy3
+E: DEVNAME=/dev/ttyy3
+E: DEVPATH=/devices/virtual/tty/ttyy3
+E: MAJOR=3
+E: MINOR=147
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy4
+N: ttyy4
+E: DEVNAME=/dev/ttyy4
+E: DEVPATH=/devices/virtual/tty/ttyy4
+E: MAJOR=3
+E: MINOR=148
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy5
+N: ttyy5
+E: DEVNAME=/dev/ttyy5
+E: DEVPATH=/devices/virtual/tty/ttyy5
+E: MAJOR=3
+E: MINOR=149
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy6
+N: ttyy6
+E: DEVNAME=/dev/ttyy6
+E: DEVPATH=/devices/virtual/tty/ttyy6
+E: MAJOR=3
+E: MINOR=150
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy7
+N: ttyy7
+E: DEVNAME=/dev/ttyy7
+E: DEVPATH=/devices/virtual/tty/ttyy7
+E: MAJOR=3
+E: MINOR=151
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy8
+N: ttyy8
+E: DEVNAME=/dev/ttyy8
+E: DEVPATH=/devices/virtual/tty/ttyy8
+E: MAJOR=3
+E: MINOR=152
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyy9
+N: ttyy9
+E: DEVNAME=/dev/ttyy9
+E: DEVPATH=/devices/virtual/tty/ttyy9
+E: MAJOR=3
+E: MINOR=153
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyya
+N: ttyya
+E: DEVNAME=/dev/ttyya
+E: DEVPATH=/devices/virtual/tty/ttyya
+E: MAJOR=3
+E: MINOR=154
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyyb
+N: ttyyb
+E: DEVNAME=/dev/ttyyb
+E: DEVPATH=/devices/virtual/tty/ttyyb
+E: MAJOR=3
+E: MINOR=155
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyyc
+N: ttyyc
+E: DEVNAME=/dev/ttyyc
+E: DEVPATH=/devices/virtual/tty/ttyyc
+E: MAJOR=3
+E: MINOR=156
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyyd
+N: ttyyd
+E: DEVNAME=/dev/ttyyd
+E: DEVPATH=/devices/virtual/tty/ttyyd
+E: MAJOR=3
+E: MINOR=157
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyye
+N: ttyye
+E: DEVNAME=/dev/ttyye
+E: DEVPATH=/devices/virtual/tty/ttyye
+E: MAJOR=3
+E: MINOR=158
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyyf
+N: ttyyf
+E: DEVNAME=/dev/ttyyf
+E: DEVPATH=/devices/virtual/tty/ttyyf
+E: MAJOR=3
+E: MINOR=159
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz0
+N: ttyz0
+E: DEVNAME=/dev/ttyz0
+E: DEVPATH=/devices/virtual/tty/ttyz0
+E: MAJOR=3
+E: MINOR=160
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz1
+N: ttyz1
+E: DEVNAME=/dev/ttyz1
+E: DEVPATH=/devices/virtual/tty/ttyz1
+E: MAJOR=3
+E: MINOR=161
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz2
+N: ttyz2
+E: DEVNAME=/dev/ttyz2
+E: DEVPATH=/devices/virtual/tty/ttyz2
+E: MAJOR=3
+E: MINOR=162
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz3
+N: ttyz3
+E: DEVNAME=/dev/ttyz3
+E: DEVPATH=/devices/virtual/tty/ttyz3
+E: MAJOR=3
+E: MINOR=163
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz4
+N: ttyz4
+E: DEVNAME=/dev/ttyz4
+E: DEVPATH=/devices/virtual/tty/ttyz4
+E: MAJOR=3
+E: MINOR=164
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz5
+N: ttyz5
+E: DEVNAME=/dev/ttyz5
+E: DEVPATH=/devices/virtual/tty/ttyz5
+E: MAJOR=3
+E: MINOR=165
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz6
+N: ttyz6
+E: DEVNAME=/dev/ttyz6
+E: DEVPATH=/devices/virtual/tty/ttyz6
+E: MAJOR=3
+E: MINOR=166
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz7
+N: ttyz7
+E: DEVNAME=/dev/ttyz7
+E: DEVPATH=/devices/virtual/tty/ttyz7
+E: MAJOR=3
+E: MINOR=167
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz8
+N: ttyz8
+E: DEVNAME=/dev/ttyz8
+E: DEVPATH=/devices/virtual/tty/ttyz8
+E: MAJOR=3
+E: MINOR=168
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyz9
+N: ttyz9
+E: DEVNAME=/dev/ttyz9
+E: DEVPATH=/devices/virtual/tty/ttyz9
+E: MAJOR=3
+E: MINOR=169
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyza
+N: ttyza
+E: DEVNAME=/dev/ttyza
+E: DEVPATH=/devices/virtual/tty/ttyza
+E: MAJOR=3
+E: MINOR=170
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyzb
+N: ttyzb
+E: DEVNAME=/dev/ttyzb
+E: DEVPATH=/devices/virtual/tty/ttyzb
+E: MAJOR=3
+E: MINOR=171
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyzc
+N: ttyzc
+E: DEVNAME=/dev/ttyzc
+E: DEVPATH=/devices/virtual/tty/ttyzc
+E: MAJOR=3
+E: MINOR=172
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyzd
+N: ttyzd
+E: DEVNAME=/dev/ttyzd
+E: DEVPATH=/devices/virtual/tty/ttyzd
+E: MAJOR=3
+E: MINOR=173
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyze
+N: ttyze
+E: DEVNAME=/dev/ttyze
+E: DEVPATH=/devices/virtual/tty/ttyze
+E: MAJOR=3
+E: MINOR=174
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyzf
+N: ttyzf
+E: DEVNAME=/dev/ttyzf
+E: DEVPATH=/devices/virtual/tty/ttyzf
+E: MAJOR=3
+E: MINOR=175
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_INSPIRON3521_TOUCHSCREEN.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_INSPIRON3521_TOUCHSCREEN.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_INSPIRON3521_TOUCHSCREEN.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5642 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-LNXPWRBN_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7256552
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7263967
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-LNXVIDEO_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8276482
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4/event4
+N: input/event4
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4/event4
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8278418
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/ACPI0003:00/power_supply/ACAD
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/ACPI0003:00/power_supply/ACAD
+E: POWER_SUPPLY_NAME=ACAD
+E: POWER_SUPPLY_ONLINE=0
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/DLL0597:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/DLL0597:00
+E: MODALIAS=acpi:DLL0597:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/DLLK0597:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/DLLK0597:00
+E: MODALIAS=acpi:DLLK0597:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0A:00/power_supply/BAT1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0A:00/power_supply/BAT1
+E: POWER_SUPPLY_CAPACITY=91
+E: POWER_SUPPLY_CHARGE_FULL=5900000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=5900000
+E: POWER_SUPPLY_CHARGE_NOW=5420000
+E: POWER_SUPPLY_CURRENT_NOW=1177000
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=SDI
+E: POWER_SUPPLY_MODEL_NAME=DELL G019Y2CC
+E: POWER_SUPPLY_NAME=BAT1
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=09D2
+E: POWER_SUPPLY_STATUS=Discharging
+E: POWER_SUPPLY_TECHNOLOGY=Unknown
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=11100000
+E: POWER_SUPPLY_VOLTAGE_NOW=12353000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-PNP0C0C_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7275323
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7281627
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: EV=21
+E: ID_FOR_SEAT=input-acpi-PNP0C0D_00
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7266927
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7230586
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000154sv00001028sd00000597bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0154
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000166sv00001028sd00000597bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0166
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: ID_FOR_SEAT=drm-pci-0000_00_02_0
+E: ID_PATH=pci-0000:00:02.0
+E: ID_PATH_TAG=pci-0000_00_02_0
+E: MAJOR=226
+E: MINOR=0
+E: PRIMARY_DEVICE_FOR_DISPLAY=1
+E: SUBSYSTEM=drm
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22480570
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: ID_FOR_SEAT=graphics-pci-0000_00_02_0
+E: ID_PATH=pci-0000:00:02.0
+E: ID_PATH_TAG=pci-0000_00_02_0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: TAGS=:master-of-seat:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22471586
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv00001028sd00000597bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_14_0
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:14.0
+E: ID_PATH_TAG=pci-0000_00_14_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7232947
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4
+N: bus/usb/003/002
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Mass_Storage
+E: ID_MODEL_ENC=Mass\x20Storage
+E: ID_MODEL_ID=6387
+E: ID_REVISION=0103
+E: ID_SERIAL=Generic_Mass_Storage_EEA1EE5B
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=058f
+E: MAJOR=189
+E: MINOR=257
+E: PRODUCT=58f/6387/103
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8046125
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v058Fp6387d0103dc00dsc00dp00ic08isc06ip50in00
+E: PRODUCT=58f/6387/103
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/scsi_host/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/scsi_host/host6
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0
+S: disk/by-path/pci-0000:00:14.0-usb-0:4:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0 /dev/disk/by-path/pci-0000:00:14.0-usb-0:4:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Flash_Disk
+E: ID_MODEL_ENC=Flash\x20Disk\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=6387
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:14.0-usb-0:4:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_4_1_0-scsi-0_0_0_0
+E: ID_REVISION=8.07
+E: ID_SERIAL=Generic_Flash_Disk_EEA1EE5B-0:0
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=058f
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=9202812
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+N: sdb1
+S: disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0-part1
+S: disk/by-path/pci-0000:00:14.0-usb-0:4:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/613D-C101
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0-part1 /dev/disk/by-path/pci-0000:00:14.0-usb-0:4:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/613D-C101
+E: DEVNAME=/dev/sdb1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=613D-C101
+E: ID_FS_UUID_ENC=613D-C101
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Flash_Disk
+E: ID_MODEL_ENC=Flash\x20Disk\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=6387
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=62
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=4011586
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:14.0-usb-0:4:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_4_1_0-scsi-0_0_0_0
+E: ID_REVISION=8.07
+E: ID_SERIAL=Generic_Flash_Disk_EEA1EE5B-0:0
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=058f
+E: MAJOR=8
+E: MINOR=17
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=31744
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2053932032
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=9283313
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+N: bsg/6:0:0:0
+E: DEVNAME=/dev/bsg/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_14_0
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_PATH=pci-0000:00:14.0
+E: ID_PATH_TAG=pci-0000_00_14_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7233347
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0308dc09dsc00dp03ic09isc00ip00in00
+E: PRODUCT=1d6b/3/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv00001028sd00000597bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001E2Dsv00001028sd00000597bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1a_0
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:1a.0
+E: ID_PATH_TAG=pci-0000_00_1a_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7232500
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1a_0-usb-0_1
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7565163
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+N: bus/usb/001/007
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/007
+E: DEVNUM=007
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Bluetooth_USB_Host_Controller
+E: ID_MODEL_ENC=Bluetooth\x20USB\x20Host\x20Controller
+E: ID_MODEL_ID=e004
+E: ID_REVISION=0002
+E: ID_SERIAL=Atheros_Communications_Bluetooth_USB_Host_Controller_Alaska_Day_2006
+E: ID_SERIAL_SHORT=Alaska_Day_2006
+E: ID_USB_INTERFACES=:e00101:
+E: ID_VENDOR=Atheros_Communications
+E: ID_VENDOR_ENC=Atheros\x20Communications
+E: ID_VENDOR_ID=0cf3
+E: MAJOR=189
+E: MINOR=6
+E: PRODUCT=cf3/e004/2
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=28788952
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0CF3pE004d0002dcE0dsc01dp01icE0isc01ip01in00
+E: PRODUCT=cf3/e004/2
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0/rfkill1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0/rfkill1
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0CF3pE004d0002dcE0dsc01dp01icE0isc01ip01in01
+E: PRODUCT=cf3/e004/2
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Touchscreen
+E: ID_MODEL_ENC=Touchscreen
+E: ID_MODEL_ID=0034
+E: ID_REVISION=0012
+E: ID_SERIAL=ELAN_Touchscreen
+E: ID_USB_INTERFACES=:030000:
+E: ID_VENDOR=ELAN
+E: ID_VENDOR_ENC=ELAN
+E: ID_VENDOR_ID=04f3
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=4f3/34/12
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8375096
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v04F3p0034d0012dc00dsc00dp00ic03isc00ip00in00
+E: PRODUCT=4f3/34/12
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/0003:04F3:0034.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/0003:04F3:0034.0001
+E: DRIVER=hid-multitouch
+E: HID_ID=0003:000004F3:00000034
+E: HID_NAME=ELAN Touchscreen
+E: HID_PHYS=usb-0000:00:1a.0-1.2/input0
+E: MODALIAS=hid:b0003g0002v000004F3p00000034
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/0003:04F3:0034.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/0003:04F3:0034.0001/hidraw/hidraw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input5
+E: ABS=3273800000000003
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input5
+E: EV=10000b
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHSCREEN=1
+E: ID_MODEL=Touchscreen
+E: ID_MODEL_ENC=Touchscreen
+E: ID_MODEL_ID=0034
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_REVISION=0012
+E: ID_SERIAL=ELAN_Touchscreen
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=ELAN
+E: ID_VENDOR_ENC=ELAN
+E: ID_VENDOR_ID=04f3
+E: KEY=400 0 0 0 0 0
+E: MODALIAS=input:b0003v04F3p0034e0110-e0,1,3,14,k14A,ra0,1,2F,30,31,34,35,36,39,3C,3D,mlsfw
+E: NAME="ELAN Touchscreen"
+E: PHYS="usb-0000:00:1a.0-1.2/input0"
+E: PRODUCT=3/4f3/34/110
+E: PROP=2
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=23031781
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-ELAN_Touchscreen-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.2:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-ELAN_Touchscreen-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.2:1.0-event
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHSCREEN=1
+E: ID_MODEL=Touchscreen
+E: ID_MODEL_ENC=Touchscreen
+E: ID_MODEL_ID=0034
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_REVISION=0012
+E: ID_SERIAL=ELAN_Touchscreen
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=ELAN
+E: ID_VENDOR_ENC=ELAN
+E: ID_VENDOR_ID=04f3
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23167936
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input5/mouse0
+N: input/mouse0
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input5/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHSCREEN=1
+E: ID_MODEL=Touchscreen
+E: ID_MODEL_ENC=Touchscreen
+E: ID_MODEL_ID=0034
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_REVISION=0012
+E: ID_SERIAL=ELAN_Touchscreen
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=ELAN
+E: ID_VENDOR_ENC=ELAN
+E: ID_VENDOR_ID=04f3
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23168154
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/usbmisc/hiddev0
+N: usb/hiddev0
+E: DEVNAME=/dev/usb/hiddev0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/usbmisc/hiddev0
+E: MAJOR=180
+E: MINOR=0
+E: SUBSYSTEM=usbmisc
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+N: bus/usb/001/005
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0-CRW
+E: ID_MODEL_ENC=USB2.0-CRW
+E: ID_MODEL_ID=0129
+E: ID_REVISION=3960
+E: ID_SERIAL=Generic_USB2.0-CRW_20100201396000000
+E: ID_SERIAL_SHORT=20100201396000000
+E: ID_USB_INTERFACES=:ff0650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=0bda
+E: MAJOR=189
+E: MINOR=4
+E: PRODUCT=bda/129/3960
+E: SUBSYSTEM=usb
+E: TYPE=255/255/255
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8537603
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=rts5139
+E: INTERFACE=255/6/80
+E: MODALIAS=usb:v0BDAp0129d3960dcFFdscFFdpFFicFFisc06ip50in00
+E: PRODUCT=bda/129/3960
+E: SUBSYSTEM=usb
+E: TYPE=255/255/255
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/scsi_host/host7
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/scsi_host/host7
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/block/sdc
+N: sdc
+S: disk/by-id/usb-Generic_USB2.0-CRW_20100201396000000
+S: disk/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_USB2.0-CRW_20100201396000000 /dev/disk/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdc
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/block/sdc
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0-CRW
+E: ID_MODEL_ENC=USB2.0-CRW
+E: ID_MODEL_ID=0129
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.3:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_3_1_0-scsi-0_0_0_0
+E: ID_REVISION=3960
+E: ID_SERIAL=Generic_USB2.0-CRW_20100201396000000
+E: ID_SERIAL_SHORT=20100201396000000
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=rts5139
+E: ID_USB_INTERFACES=:ff0650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=32
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=23228136
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/bsg/7:0:0:0
+N: bsg/7:0:0:0
+E: DEVNAME=/dev/bsg/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/bsg/7:0:0:0
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/scsi_device/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/scsi_device/7:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/scsi_disk/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/scsi_disk/7:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/scsi_generic/sg3
+N: sg3
+E: DEVNAME=/dev/sg3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host7/target7:0:0/7:0:0:0/scsi_generic/sg3
+E: MAJOR=21
+E: MINOR=3
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/usbmisc/rts51x1
+N: rts51x1
+E: DEVNAME=/dev/rts51x1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/usbmisc/rts51x1
+E: MAJOR=180
+E: MINOR=1
+E: SUBSYSTEM=usbmisc
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+N: bus/usb/001/006
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/006
+E: DEVNUM=006
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=64ad
+E: ID_REVISION=2925
+E: ID_SERIAL=CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ENC=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ID=0c45
+E: MAJOR=189
+E: MINOR=5
+E: PRODUCT=c45/64ad/2925
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8773197
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v0C45p64ADd2925dcEFdsc02dp01ic0Eisc01ip00in00
+E: PRODUCT=c45/64ad/2925
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/input/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/input/input7
+E: EV=3
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_1a_0-usb-0_1_4_1_0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=64ad
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.4:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_4_1_0
+E: ID_REVISION=2925
+E: ID_SERIAL=CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ENC=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ID=0c45
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v0C45p64ADe2925-e0,1,kD4,ramlsfw
+E: NAME="Laptop_Integrated_Webcam_HD"
+E: PHYS="usb-0000:00:1a.0-1.4/button"
+E: PRODUCT=3/c45/64ad/2925
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23475490
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/input/input7/event7
+N: input/event7
+S: input/by-id/usb-CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.4:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.4:1.0-event
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/input/input7/event7
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=64ad
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.4:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_4_1_0
+E: ID_REVISION=2925
+E: ID_SERIAL=CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ENC=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ID=0c45
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23478513
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.4:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.4:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_FOR_SEAT=video4linux-pci-0000_00_1a_0-usb-0_1_4_1_0
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=64ad
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.4:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_4_1_0
+E: ID_REVISION=2925
+E: ID_SERIAL=CN0Y3PX87248731NA8E2A00_Laptop_Integrated_Webcam_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Laptop_Integrated_Webcam_HD
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ENC=CN0Y3PX87248731NA8E2A00
+E: ID_VENDOR_ID=0c45
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23543464
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v0C45p64ADd2925dcEFdsc02dp01ic0Eisc02ip00in01
+E: PRODUCT=c45/64ad/2925
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv00001028sd00000597bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_FOR_SEAT=sound-pci-0000_00_1b_0
+E: ID_MODEL_FROM_DATABASE=7 Series/C210 Series Chipset Family High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24124171
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24129432
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24128899
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24126818
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24202268
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Front Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24127164
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24168832
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24126447
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24203007
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24130406
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24127961
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24127423
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24130093
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv00001028sd00000597bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DRIVER=r8169
+E: MODALIAS=pci:v000010ECd00008136sv00001028sd00000597bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8136
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth0
+E: COMMENT=PCI device 0x10ec:/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0 (r8169)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8101E/RTL8102E PCI Express Fast Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: MATCHADDR=b8:ca:3a:d5:f7:db
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22798982
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E12sv00001028sd00000597bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DRIVER=ath9k
+E: MODALIAS=pci:v0000168Cd00000032sv00001028sd00000209bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=168C:0032
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=1028:0209
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0/rfkill0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0/rfkill0
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/leds/ath9k-phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/leds/ath9k-phy0
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/net/wlan0
+E: COMMENT=PCI device 0x168c:/sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0 (ath9k)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=AR9485 Wireless Network Adapter
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=Atheros Communications Inc.
+E: ID_VENDOR_ID=0x168c
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: MATCHADDR=f4:b7:e2:c9:ff:cb
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24144925
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001E26sv00001028sd00000597bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1d_0
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:1d.0
+E: ID_PATH_TAG=pci-0000_00_1d_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7234109
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1d_0-usb-0_1
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7809300
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: DRIVER=lpc_ich
+E: MODALIAS=pci:v00008086d00001E59sv00001028sd00000597bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E59
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVTYPE=mfd_device
+E: MODALIAS=platform:iTCO_wdt
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=7 Series Chipset Family 6-port SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001E03sv00001028sd00000597bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1E03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22479535
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE
+S: disk/by-id/wwn-0x5000c50060089224
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE /dev/disk/by-id/wwn-0x5000c50060089224 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=6
+E: UDISKS_PARTITION_TABLE_SCHEME=gpt
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8061302
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part1
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part1
+S: disk/by-id/wwn-0x5000c50060089224-part1
+S: disk/by-label/ESP
+S: disk/by-partlabel/EFI\x20system\x20partition
+S: disk/by-partuuid/794a6a73-9dae-4078-aa91-1951340cb86b
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/8667-E38E
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part1 /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part1 /dev/disk/by-id/wwn-0x5000c50060089224-part1 /dev/disk/by-label/ESP /dev/disk/by-partlabel/EFI\x20system\x20partition /dev/disk/by-partuuid/794a6a73-9dae-4078-aa91-1951340cb86b /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/8667-E38E
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=ESP
+E: ID_FS_LABEL_ENC=ESP
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=8667-E38E
+E: ID_FS_UUID_ENC=8667-E38E
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x8000000000000000
+E: ID_PART_ENTRY_NAME=EFI\x20system\x20partition
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=1024000
+E: ID_PART_ENTRY_TYPE=c12a7328-f81f-11d2-ba4b-00a0c93ec93b
+E: ID_PART_ENTRY_UUID=794a6a73-9dae-4078-aa91-1951340cb86b
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_IGNORE=1
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=EFI system partition
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=524288000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=C12A7328-F81F-11D2-BA4B-00A0C93EC93B
+E: UDISKS_PARTITION_UUID=794A6A73-9DAE-4078-AA91-1951340CB86B
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8424075
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part2
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part2
+S: disk/by-id/wwn-0x5000c50060089224-part2
+S: disk/by-label/DIAGS
+S: disk/by-partlabel/Basic\x20data\x20partition
+S: disk/by-partuuid/6b4043e8-06bc-4b7a-97b7-1c4df60e8bdf
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-uuid/A6FF-8A26
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part2 /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part2 /dev/disk/by-id/wwn-0x5000c50060089224-part2 /dev/disk/by-label/DIAGS /dev/disk/by-partlabel/Basic\x20data\x20partition /dev/disk/by-partuuid/6b4043e8-06bc-4b7a-97b7-1c4df60e8bdf /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-uuid/A6FF-8A26
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=DIAGS
+E: ID_FS_LABEL_ENC=DIAGS
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=A6FF-8A26
+E: ID_FS_UUID_ENC=A6FF-8A26
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x8000000000000001
+E: ID_PART_ENTRY_NAME=Basic\x20data\x20partition
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=1026048
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=81920
+E: ID_PART_ENTRY_TYPE=796badd3-6bbf-4d9f-b631-466eb71a4965
+E: ID_PART_ENTRY_UUID=6b4043e8-06bc-4b7a-97b7-1c4df60e8bdf
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=required
+E: UDISKS_PARTITION_LABEL=Basic data partition
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=525336576
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=41943040
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=796BADD3-6BBF-4D9F-B631-466EB71A4965
+E: UDISKS_PARTITION_UUID=6B4043E8-06BC-4B7A-97B7-1C4DF60E8BDF
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8323438
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part3
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part3
+S: disk/by-id/wwn-0x5000c50060089224-part3
+S: disk/by-partlabel/Microsoft\x20reserved\x20partition
+S: disk/by-partuuid/2c9ff6fa-b2cf-4f9c-bf68-5d33d910dfb1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part3 /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part3 /dev/disk/by-id/wwn-0x5000c50060089224-part3 /dev/disk/by-partlabel/Microsoft\x20reserved\x20partition /dev/disk/by-partuuid/2c9ff6fa-b2cf-4f9c-bf68-5d33d910dfb1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x8000000000000000
+E: ID_PART_ENTRY_NAME=Microsoft\x20reserved\x20partition
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=1107968
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=262144
+E: ID_PART_ENTRY_TYPE=e3c9e316-0b5c-4db8-817d-f92df00215ae
+E: ID_PART_ENTRY_UUID=2c9ff6fa-b2cf-4f9c-bf68-5d33d910dfb1
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=Microsoft reserved partition
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=567279616
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=134217728
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=E3C9E316-0B5C-4DB8-817D-F92DF00215AE
+E: UDISKS_PARTITION_UUID=2C9FF6FA-B2CF-4F9C-BF68-5D33D910DFB1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8504981
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+N: sda4
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part4
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part4
+S: disk/by-id/wwn-0x5000c50060089224-part4
+S: disk/by-label/WINRETOOLS
+S: disk/by-partlabel/Basic\x20data\x20partition
+S: disk/by-partuuid/fcb8fcf2-344f-4a9f-85c6-462ef0413cda
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4
+S: disk/by-uuid/A278019B78016F7B
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part4 /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part4 /dev/disk/by-id/wwn-0x5000c50060089224-part4 /dev/disk/by-label/WINRETOOLS /dev/disk/by-partlabel/Basic\x20data\x20partition /dev/disk/by-partuuid/fcb8fcf2-344f-4a9f-85c6-462ef0413cda /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4 /dev/disk/by-uuid/A278019B78016F7B
+E: DEVNAME=/dev/sda4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=WINRETOOLS
+E: ID_FS_LABEL_ENC=WINRETOOLS
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=A278019B78016F7B
+E: ID_FS_UUID_ENC=A278019B78016F7B
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x8000000000000001
+E: ID_PART_ENTRY_NAME=Basic\x20data\x20partition
+E: ID_PART_ENTRY_NUMBER=4
+E: ID_PART_ENTRY_OFFSET=1370112
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=1024000
+E: ID_PART_ENTRY_TYPE=de94bba4-06d1-4d40-a16a-bfd50179d6ac
+E: ID_PART_ENTRY_UUID=fcb8fcf2-344f-4a9f-85c6-462ef0413cda
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=required
+E: UDISKS_PARTITION_LABEL=Basic data partition
+E: UDISKS_PARTITION_NUMBER=4
+E: UDISKS_PARTITION_OFFSET=701497344
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=524288000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=DE94BBA4-06D1-4D40-A16A-BFD50179D6AC
+E: UDISKS_PARTITION_UUID=FCB8FCF2-344F-4A9F-85C6-462EF0413CDA
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8684341
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part5
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part5
+S: disk/by-id/wwn-0x5000c50060089224-part5
+S: disk/by-label/OS
+S: disk/by-partlabel/Basic\x20data\x20partition
+S: disk/by-partuuid/83fcb0fa-c261-463e-8885-374dbf4b5e31
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/18EE06C1EE0696E2
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part5 /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part5 /dev/disk/by-id/wwn-0x5000c50060089224-part5 /dev/disk/by-label/OS /dev/disk/by-partlabel/Basic\x20data\x20partition /dev/disk/by-partuuid/83fcb0fa-c261-463e-8885-374dbf4b5e31 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/18EE06C1EE0696E2
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=OS
+E: ID_FS_LABEL_ENC=OS
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=18EE06C1EE0696E2
+E: ID_FS_UUID_ENC=18EE06C1EE0696E2
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=Basic\x20data\x20partition
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=2394112
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=945317888
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=83fcb0fa-c261-463e-8885-374dbf4b5e31
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=Basic data partition
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=1225785344
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=484002758656
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=83FCB0FA-C261-463E-8885-374DBF4B5E31
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=9136582
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda6
+N: sda6
+S: disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part6
+S: disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part6
+S: disk/by-id/wwn-0x5000c50060089224-part6
+S: disk/by-label/PBR\x20Image
+S: disk/by-partlabel/Microsoft\x20recovery\x20partition
+S: disk/by-partuuid/118b0d56-04af-4cf8-a761-60b3b827e6e0
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part6
+S: disk/by-uuid/C6BC7C9ABC7C8729
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LT012-9WS142_W0V6VGZE-part6 /dev/disk/by-id/scsi-SATA_ST500LT012-9WS1_W0V6VGZE-part6 /dev/disk/by-id/wwn-0x5000c50060089224-part6 /dev/disk/by-label/PBR\x20Image /dev/disk/by-partlabel/Microsoft\x20recovery\x20partition /dev/disk/by-partuuid/118b0d56-04af-4cf8-a761-60b3b827e6e0 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part6 /dev/disk/by-uuid/C6BC7C9ABC7C8729
+E: DEVNAME=/dev/sda6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda6
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=PBR_Image
+E: ID_FS_LABEL_ENC=PBR\x20Image
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=C6BC7C9ABC7C8729
+E: ID_FS_UUID_ENC=C6BC7C9ABC7C8729
+E: ID_MODEL=ST500LT012-9WS142
+E: ID_MODEL_ENC=ST500LT012-9WS142\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x8000000000000001
+E: ID_PART_ENTRY_NAME=Microsoft\x20recovery\x20partition
+E: ID_PART_ENTRY_NUMBER=6
+E: ID_PART_ENTRY_OFFSET=947712000
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=29059120
+E: ID_PART_ENTRY_TYPE=de94bba4-06d1-4d40-a16a-bfd50179d6ac
+E: ID_PART_ENTRY_UUID=118b0d56-04af-4cf8-a761-60b3b827e6e0
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=0001SD1M
+E: ID_SCSI_COMPAT=SATA_ST500LT012-9WS1_W0V6VGZE
+E: ID_SERIAL=ST500LT012-9WS142_W0V6VGZE
+E: ID_SERIAL_SHORT=W0V6VGZE
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50060089224
+E: ID_WWN_WITH_EXTENSION=0x5000c50060089224
+E: MAJOR=8
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=required
+E: UDISKS_PARTITION_LABEL=Microsoft recovery partition
+E: UDISKS_PARTITION_NUMBER=6
+E: UDISKS_PARTITION_OFFSET=485228544000
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=14878269440
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=DE94BBA4-06D1-4D40-A16A-BFD50179D6AC
+E: UDISKS_PARTITION_UUID=118B0D56-04AF-4CF8-A761-60B3B827E6E0
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=9203663
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-TSSTcorp_DVD+_-RW_SU-208BB_R8VQ6GUCC00MBR
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-TSSTcorp_DVD+_-RW_SU-208BB_R8VQ6GUCC00MBR /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_FOR_SEAT=block-pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_MODEL=TSSTcorp_DVD+_-RW_SU-208BB
+E: ID_MODEL_ENC=TSSTcorp\x20DVD+\x2f-RW\x20SU-208BB\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=D300
+E: ID_SERIAL=TSSTcorp_DVD+_-RW_SU-208BB_R8VQ6GUCC00MBR
+E: ID_SERIAL_SHORT=R8VQ6GUCC00MBR
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8056443
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+N: bsg/2:0:0:0
+E: DEVNAME=/dev/bsg/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_generic/sg1
+E: ID_FOR_SEAT=scsi_generic-pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22929422
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv00001028sd00000597bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1028:0597
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon0
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop
+E: DEVPATH=/devices/platform/dell-laptop
+E: DRIVER=dell-laptop
+E: MODALIAS=platform:dell-laptop
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/efifb.0
+E: DEVPATH=/devices/platform/efifb.0
+E: DRIVER=efifb
+E: MODALIAS=platform:efifb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Dell Inc.
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22527086
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_FOR_SEAT=input-platform-i8042-serio-0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=1100f02902002 8380307cf910f001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8D,8E,8F,94,98,9B,9C,9D,9E,9F,A2,A3,A4,A5,A6,AC,AD,B7,B8,B9,BF,C1,CD,D4,D7,D9,E0,E1,E2,E3,EC,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7267657
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7282893
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input8
+E: ABS=660800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input8
+E: EV=b
+E: ID_FOR_SEAT=input-platform-i8042-serio-1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=e520 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,148,14A,14D,14E,14F,ra0,1,18,1C,2F,35,36,39,3A,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=1
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24098241
+
+P: /devices/platform/i8042/serio1/input/input8/event8
+N: input/event8
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/platform/i8042/serio1/input/input8/event8
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24132777
+
+P: /devices/platform/i8042/serio1/input/input8/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/input/input8/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=24131901
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22528224
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22528804
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22529981
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22531614
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22530356
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22531142
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22531932
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22532632
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22532849
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22533360
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22533492
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22534035
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22534178
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22534710
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22534840
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22535403
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22535543
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22536094
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22536339
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22536873
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22537009
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22537541
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22537674
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22538176
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22538307
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22538819
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22538950
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22539455
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22539589
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22540101
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22540292
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22540828
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:05/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7267934
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory40
+E: DEVPATH=/devices/system/memory/memory40
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory41
+E: DEVPATH=/devices/system/memory/memory41
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:25
+E: DEVPATH=/devices/virtual/bdi/0:25
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:32
+E: DEVPATH=/devices/virtual/bdi/8:32
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: ID_FS_TYPE=squashfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_VERSION=1024.0
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7203755
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7203902
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7204066
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7204207
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7204378
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7204532
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7204672
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=7204818
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7204966
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7205104
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7205244
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7205380
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7205556
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7205701
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7205848
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7206010
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7206164
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7206308
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7206923
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7222140
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7209149
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7212081
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7218089
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7237651
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrA05:bd01/03/2013:svnDellInc.:pnInspiron3521:pvrA05:rvnDellInc.:rn033MX4:rvrA00:cvnDellInc.:ct8:cvrA05:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input6
+E: DEVPATH=/devices/virtual/input/input6
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=1500b00000000 200300000 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k94,95,A1,E0,E1,E3,EC,EE,F0,ram4,lsfw
+E: MSC=10
+E: NAME="Dell WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23236639
+
+P: /devices/virtual/input/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/virtual/input/input6/event6
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23248751
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23099370
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22600312
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22601337
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23631912
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23540788
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22607651
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22607656
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22608384
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22608723
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22608657
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22609424
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22609747
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22609716
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22610456
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22610872
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22610782
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22611311
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22611775
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22612203
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22612116
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22612600
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22616909
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22617447
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22617770
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22617755
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22618504
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22618584
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22619189
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22619450
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22620065
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22620663
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22621267
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22621899
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22623172
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22623825
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22624461
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22625062
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22625645
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22626395
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22627009
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22627623
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22628248
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22628875
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22629346
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22629955
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22630559
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22631151
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22631779
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22632359
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22632908
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22636264
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22637059
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22637834
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22639112
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22639574
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22640430
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22641066
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22642672
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22643560
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22644249
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22644965
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22645520
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22646101
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22646891
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22648376
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22648571
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22652524
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22658074
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22658391
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22658650
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22658899
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22659146
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22659396
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:9DBB5994-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: DEVPATH=/devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: MODALIAS=wmi:A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:A80593CE-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_LATITUDEE4310.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_LATITUDEE4310.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_LATITUDEE4310.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5158 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1115668
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+N: input/event3
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1124658
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A03:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A03:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A03:00/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A03:00/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10844937
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8/event8
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10848463
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/SMO8800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/SMO8800:00
+E: MODALIAS=acpi:SMO8800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/DLL0410:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/DLL0410:00
+E: MODALIAS=acpi:DLL0410:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0303:00
+E: MODALIAS=acpi:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0401:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0401:00
+E: MODALIAS=acpi:PNP0401:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0a/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0a/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:10/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:10/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:12/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:12/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:2d/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b/device:2c/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CHARGE_FULL=2089000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=2800000
+E: POWER_SUPPLY_CHARGE_NOW=45000
+E: POWER_SUPPLY_CURRENT_NOW=1692000
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=SMP
+E: POWER_SUPPLY_MODEL_NAME=DELL Y266P01
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=203
+E: POWER_SUPPLY_STATUS=Charging
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=11100000
+E: POWER_SUPPLY_VOLTAGE_NOW=11019000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:01
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1118550
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1131304
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1118684
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1143578
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1119690
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2/event2
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1143580
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: DRIVER=agpgart-intel
+E: MODALIAS=pci:v00008086d00000044sv00001028sd00000410bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0044
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000046sv00001028sd00000410bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0046
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10845343
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00003B64sv00001028sd00000410bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:3B64
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3
+E: DRIVER=serial
+E: MODALIAS=pci:v00008086d00003B67sv00001028sd00000410bc07sc00i02
+E: PCI_CLASS=70002
+E: PCI_ID=8086:3B67
+E: PCI_SLOT_NAME=0000:00:16.3
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3/tty/ttyS4
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=5 Series/3400 Series Chipset KT Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:16.3
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8801344
+
+P: /devices/pci0000:00/0000:00:19.0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0
+E: DRIVER=e1000e
+E: MODALIAS=pci:v00008086d000010EAsv00001028sd00000410bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=8086:10EA
+E: PCI_SLOT_NAME=0000:00:19.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=82577LM Gigabit Network Connection
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:19.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8798442
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00003B3Csv00001028sd00000410bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:3B3C
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-15-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-15-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-15-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1115441
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0020
+E: ID_MODEL_ENC=0020
+E: ID_MODEL_ID=0020
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0020
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1143954
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0020d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00003B57sv00001028sd00000410bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:3B57
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=5 Series/3400 Series Chipset High Definition Audio
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12953481
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12914808
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12914460
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12911443
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12916136
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel Dock Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12911947
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12918325
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12911070
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+N: input/event12
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12913989
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input13
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input13
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12912485
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input13/event13
+N: input/event13
+E: DEVNAME=/dev/input/event13
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input13/event13
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=77
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12917121
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input14
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,
+E: NAME="HDA Intel Dock Line Out"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=40
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12912985
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input14/event14
+N: input/event14
+E: DEVNAME=/dev/input/event14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input14/event14
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=78
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12916134
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel HDMI/DP,pcm=7"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12910902
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12913432
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12914129
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12913783
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12911384
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+N: snd/pcmC0D7p
+E: DEVNAME=/dev/snd/pcmC0D7p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12913413
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12911511
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B42sv00001028sd00000410bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B42
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B44sv00001028sd00000410bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B44
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DRIVER=bcma-pci-bridge
+E: MODALIAS=pci:v000014E4d00004727sv00001028sd00000010bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=14E4:4727
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=1028:0010
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0
+E: DRIVER=brcmsmac
+E: MODALIAS=bcma:m04BFid0812rev18cl00
+E: SUBSYSTEM=bcma
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0/ieee80211/phy0/rfkill0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0/ieee80211/phy0/rfkill0
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=BCM4313 802.11b/g/n Wireless LAN Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/bcma0:0
+E: ID_VENDOR_FROM_DATABASE=Broadcom Corporation
+E: ID_VENDOR_ID=0x14e4
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9084641
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B46sv00001028sd00000410bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B46
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v00001180d0000E822sv00001028sd00000410bc08sc05i00
+E: PCI_CLASS=80500
+E: PCI_ID=1180:E822
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B48sv00001028sd00000410bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B48
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00003B34sv00001028sd00000410bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:3B34
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-15-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-15-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-15-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1117637
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0020
+E: ID_MODEL_ENC=0020
+E: ID_MODEL_ID=0020
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0020
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1288880
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Mass_Storage
+E: ID_MODEL_ENC=Mass\x20Storage
+E: ID_MODEL_ID=6387
+E: ID_REVISION=0103
+E: ID_SERIAL=Generic_Mass_Storage_EEA1EE5B
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=058f
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=58f/6387/103
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1748635
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v058Fp6387d0103dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=58f/6387/103
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/scsi_host/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/scsi_host/host6
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0
+S: disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0 /dev/disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Flash_Disk
+E: ID_MODEL_ENC=Flash\x20Disk\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=6387
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_0-scsi-0_0_0_0
+E: ID_REVISION=8.07
+E: ID_SERIAL=Generic_Flash_Disk_EEA1EE5B-0:0
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=058f
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2913629
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+N: sdb1
+S: disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0-part1
+S: disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/613D-C101
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0-part1 /dev/disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/613D-C101
+E: DEVNAME=/dev/sdb1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=613D-C101
+E: ID_FS_UUID_ENC=613D-C101
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Flash_Disk
+E: ID_MODEL_ENC=Flash\x20Disk\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=6387
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=62
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=4011586
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_0-scsi-0_0_0_0
+E: ID_REVISION=8.07
+E: ID_SERIAL=Generic_Flash_Disk_EEA1EE5B-0:0
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=058f
+E: MAJOR=8
+E: MINOR=17
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=31744
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2053932032
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3001389
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+N: bsg/6:0:0:0
+E: DEVNAME=/dev/bsg/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8
+N: bus/usb/002/004
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=5880
+E: ID_MODEL_ENC=5880
+E: ID_MODEL_ID=5800
+E: ID_REVISION=0101
+E: ID_SERIAL=Broadcom_Corp_5880_0123456789ABCD
+E: ID_SERIAL_SHORT=0123456789ABCD
+E: ID_USB_INTERFACES=:fe0000:0b0000:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=0a5c
+E: MAJOR=189
+E: MINOR=131
+E: PRODUCT=a5c/5800/101
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1935334
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/0/0
+E: MODALIAS=usb:v0A5Cp5800d0101dc00dsc00dp00icFEisc00ip00
+E: PRODUCT=a5c/5800/101
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.1
+E: DEVTYPE=usb_interface
+E: INTERFACE=11/0/0
+E: MODALIAS=usb:v0A5Cp5800d0101dc00dsc00dp00ic0Bisc00ip00
+E: PRODUCT=a5c/5800/101
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0020d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0
+E: MODALIAS=pci:v00008086d00002448sv00001028sd00000410bc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=8086:2448
+E: PCI_SLOT_NAME=0000:00:1e.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0/pci_bus/0000:0a
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/pci_bus/0000:0a
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00003B0Fsv00001028sd00000410bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:3B0F
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=82801 Mobile SATA Controller [RAID mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d0000282Asv00001028sd00000410bc01sc04i00
+E: PCI_CLASS=10400
+E: PCI_ID=8086:282A
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8740431
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT
+S: disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT
+S: disk/by-id/wwn-0x50000392d198058c
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT /dev/disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT /dev/disk/by-id/wwn-0x50000392d198058c /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MK3261GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK3261GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK3261G_X02KT00QT
+E: ID_SERIAL=TOSHIBA_MK3261GSY_X02KT00QT
+E: ID_SERIAL_SHORT=X02KT00QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000392d198058c
+E: ID_WWN_WITH_EXTENSION=0x50000392d198058c
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1097981
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT-part1
+S: disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT-part1
+S: disk/by-id/wwn-0x50000392d198058c-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/a508cd16-1c89-4448-a9d4-9e9917cacac3
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT-part1 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT-part1 /dev/disk/by-id/wwn-0x50000392d198058c-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/a508cd16-1c89-4448-a9d4-9e9917cacac3
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=a508cd16-1c89-4448-a9d4-9e9917cacac3
+E: ID_FS_UUID_ENC=a508cd16-1c89-4448-a9d4-9e9917cacac3
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=TOSHIBA_MK3261GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK3261GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=617164800
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK3261G_X02KT00QT
+E: ID_SERIAL=TOSHIBA_MK3261GSY_X02KT00QT
+E: ID_SERIAL_SHORT=X02KT00QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000392d198058c
+E: ID_WWN_WITH_EXTENSION=0x50000392d198058c
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=315988377600
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1330837
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT-part2
+S: disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT-part2
+S: disk/by-id/wwn-0x50000392d198058c-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT-part2 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT-part2 /dev/disk/by-id/wwn-0x50000392d198058c-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MK3261GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK3261GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=617168894
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=7972866
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK3261G_X02KT00QT
+E: ID_SERIAL=TOSHIBA_MK3261GSY_X02KT00QT
+E: ID_SERIAL_SHORT=X02KT00QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000392d198058c
+E: ID_WWN_WITH_EXTENSION=0x50000392d198058c
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=315990473728
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4082107392
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1295854
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT-part5
+S: disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT-part5
+S: disk/by-id/wwn-0x50000392d198058c-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/618b2220-7623-4778-b8af-bfa0347591d4
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK3261GSY_X02KT00QT-part5 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK3261G_X02KT00QT-part5 /dev/disk/by-id/wwn-0x50000392d198058c-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/618b2220-7623-4778-b8af-bfa0347591d4
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=74
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=618b2220-7623-4778-b8af-bfa0347591d4
+E: ID_FS_UUID_ENC=618b2220-7623-4778-b8af-bfa0347591d4
+E: ID_FS_VERSION=2
+E: ID_MODEL=TOSHIBA_MK3261GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK3261GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=617168896
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=7972864
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK3261G_X02KT00QT
+E: ID_SERIAL=TOSHIBA_MK3261GSY_X02KT00QT
+E: ID_SERIAL_SHORT=X02KT00QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000392d198058c
+E: ID_WWN_WITH_EXTENSION=0x50000392d198058c
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=315990474752
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4082106368
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1381400
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: disk/by-id/ata-TEAC_DVD-ROM_DV18SA_09123021164531
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+E: DEVLINKS=/dev/cdrom /dev/disk/by-id/ata-TEAC_DVD-ROM_DV18SA_09123021164531 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=TEAC_DVD-ROM_DV18SA
+E: ID_MODEL_ENC=TEAC\x20DVD-ROM\x20DV18SA\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=D.0D
+E: ID_SERIAL=TEAC_DVD-ROM_DV18SA_09123021164531
+E: ID_SERIAL_SHORT=09123021164531
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1098194
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8863333
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00003B30sv00001028sd00000410bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:3B30
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.6
+E: DRIVER=intel ips
+E: MODALIAS=pci:v00008086d00003B32sv00001028sd00000410bc11sc80i00
+E: PCI_CLASS=118000
+E: PCI_ID=8086:3B32
+E: PCI_SLOT_NAME=0000:00:1f.6
+E: PCI_SUBSYS_ID=1028:0410
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/0000:3f:00.0
+E: DEVPATH=/devices/pci0000:3f/0000:3f:00.0
+E: MODALIAS=pci:v00008086d00002C62sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2C62
+E: PCI_SLOT_NAME=0000:3f:00.0
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/0000:3f:00.1
+E: DEVPATH=/devices/pci0000:3f/0000:3f:00.1
+E: MODALIAS=pci:v00008086d00002D01sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D01
+E: PCI_SLOT_NAME=0000:3f:00.1
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/0000:3f:02.0
+E: DEVPATH=/devices/pci0000:3f/0000:3f:02.0
+E: MODALIAS=pci:v00008086d00002D10sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D10
+E: PCI_SLOT_NAME=0000:3f:02.0
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/0000:3f:02.1
+E: DEVPATH=/devices/pci0000:3f/0000:3f:02.1
+E: MODALIAS=pci:v00008086d00002D11sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D11
+E: PCI_SLOT_NAME=0000:3f:02.1
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/0000:3f:02.2
+E: DEVPATH=/devices/pci0000:3f/0000:3f:02.2
+E: MODALIAS=pci:v00008086d00002D12sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D12
+E: PCI_SLOT_NAME=0000:3f:02.2
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/0000:3f:02.3
+E: DEVPATH=/devices/pci0000:3f/0000:3f:02.3
+E: MODALIAS=pci:v00008086d00002D13sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D13
+E: PCI_SLOT_NAME=0000:3f:02.3
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:3f/pci_bus/0000:3f
+E: DEVPATH=/devices/pci0000:3f/pci_bus/0000:3f
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon0
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop
+E: DEVPATH=/devices/platform/dell-laptop
+E: DRIVER=dell-laptop
+E: MODALIAS=platform:dell-laptop
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Dell Inc.
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8755852
+
+P: /devices/platform/i8042/serio0/input/input4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=1100f02902002 8380307cf910f001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8D,8E,8F,94,98,9B,9C,9D,9E,9F,A2,A3,A4,A5,A6,AC,AD,B7,B8,B9,BF,C1,CD,D4,D7,D9,E0,E1,E2,E3,EC,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1151868
+
+P: /devices/platform/i8042/serio0/input/input4/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4/event4
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1155845
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input6
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0008e0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="DualPoint Stick"
+E: PHYS="isa0060/serio1/input1"
+E: PRODUCT=11/2/8/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10135584
+
+P: /devices/platform/i8042/serio1/input/input6/event6
+N: input/event6
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6/event6
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10137963
+
+P: /devices/platform/i8042/serio1/input/input6/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10137497
+
+P: /devices/platform/i8042/serio1/input/input7
+E: ABS=260800001000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input7
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=e420 70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0008e7326-e0,1,3,k110,111,112,145,14A,14D,14E,14F,ra0,1,18,2F,35,36,39,mlsfw
+E: NAME="AlpsPS/2 ALPS DualPoint TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/8/7326
+E: PROP=8
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10148889
+
+P: /devices/platform/i8042/serio1/input/input7/event7
+N: input/event7
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/platform/i8042/serio1/input/input7/event7
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10151459
+
+P: /devices/platform/i8042/serio1/input/input7/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/input/input7/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10151484
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8753421
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8755176
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8755384
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756189
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756268
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756340
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756421
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756494
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756571
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756846
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756936
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8757018
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8757103
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8757190
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8757272
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8760588
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8760777
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8760924
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761015
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761104
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761192
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761279
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761365
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761454
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761552
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761647
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761744
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761849
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8761959
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8762059
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8762160
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1156179
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:0025:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0093,0094,0097,0099,00C0,00E0,00E1,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:0025:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0093,0094,0097,0099,00C0,00E0,00E1,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:0025:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0093,0094,0097,0099,00C0,00E0,00E1,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:0025:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0093,0094,0097,0099,00C0,00E0,00E1,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory22
+E: DEVPATH=/devices/system/memory/memory22
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory23
+E: DEVPATH=/devices/system/memory/memory23
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory24
+E: DEVPATH=/devices/system/memory/memory24
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory25
+E: DEVPATH=/devices/system/memory/memory25
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory26
+E: DEVPATH=/devices/system/memory/memory26
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory27
+E: DEVPATH=/devices/system/memory/memory27
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1098306
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1098430
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1098539
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1098656
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1098778
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1098911
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1099030
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1099150
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1099264
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1099383
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1099503
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1099629
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1099759
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1099887
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100041
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100175
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100301
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100430
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100549
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100670
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100794
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1100915
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1101050
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1107028
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrA05:bd11/20/2010:svnDellInc.:pnLatitudeE4310:pvr0001:rvnDellInc.:rn0101BC:rvrX02:cvnDellInc.:ct9:cvr:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input5
+E: DEVPATH=/devices/virtual/input/input5
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=1100b00000400 100000 e000000000000 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k71,72,73,94,CA,E0,E1,E3,EC,F0,ram4,lsfw
+E: MSC=10
+E: NAME="Dell WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8992573
+
+P: /devices/virtual/input/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/virtual/input/input5/event5
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8997236
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/agpgart
+N: agpgart
+E: DEVNAME=/dev/agpgart
+E: DEVPATH=/devices/virtual/misc/agpgart
+E: MAJOR=10
+E: MINOR=175
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9087540
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8937745
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/watchdog
+N: watchdog
+E: DEVNAME=/dev/watchdog
+E: DEVPATH=/devices/virtual/misc/watchdog
+E: MAJOR=10
+E: MINOR=130
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8939217
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8979576
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8976783
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8940777
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8941129
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8941469
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8941807
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8942202
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8942661
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8944334
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8944509
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8944900
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8945422
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8946001
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8946314
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8946582
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8946647
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8947274
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8946978
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8947561
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8947517
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8948310
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8948158
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8948127
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8948457
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8951206
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8951470
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8951268
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8952468
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8953088
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8952908
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8952879
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8953200
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8953524
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8953574
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8953867
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8954359
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8954409
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8956174
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8956606
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8956986
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8957584
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8957617
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8958371
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8958053
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8958387
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8959204
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8958863
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8959198
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8959558
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8960019
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8960388
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8961259
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8961668
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8962103
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8962487
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8963001
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8963117
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8964235
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8963562
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8963904
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8964369
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8964825
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8964894
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8965372
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8966633
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8966496
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8966396
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8966277
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8966702
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8967825
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog0
+N: watchdog0
+E: DEVNAME=/dev/watchdog0
+E: DEVPATH=/devices/virtual/watchdog/watchdog0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:9DBB5994-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: DEVPATH=/devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: MODALIAS=wmi:A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:A80593CE-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_LATITUDEE6430.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_LATITUDEE6430.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_LATITUDEE6430.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5516 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3977957
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+N: input/event3
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3979392
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:50
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:50
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:51
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:51
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:52
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:52
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:53
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:53
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9412781
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input8/event8
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9415239
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/SMO8810:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/SMO8810:00
+E: MODALIAS=acpi:SMO8810:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/DLL0534:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/DLL0534:00
+E: MODALIAS=acpi:DLL0534:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/DLLK0534:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/DLLK0534:00
+E: MODALIAS=acpi:DLLK0534:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0401:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0401:00
+E: MODALIAS=acpi:PNP0401:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:13/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:13/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1e/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1e/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:33/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:33/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2c/device:2d/device:2e/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:36/device:37/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/LNXIOBAY:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/LNXIOBAY:00
+E: MODALIAS=acpi:LNXIOBAY:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:47
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:47
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:48
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:41/device:48
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:49
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:49
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:4a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:4a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:4b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:4b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C01:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C01:01
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:01
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:02
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3987755
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3991467
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3988194
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3990470
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3987836
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2/event2
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3998602
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:54
+E: DEVPATH=/devices/LNXSYSTM:00/device:54
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:54/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:54/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: DRIVER=agpgart-intel
+E: MODALIAS=pci:v00008086d00000154sv00001028sd00000534bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0154
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000166sv00001028sd00000534bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0166
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9415090
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-15
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-15
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-16
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-16
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-10
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-10
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-11
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-11
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-12
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-12
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-13
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-13
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-9
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-9
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv00001028sd00000534bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-29-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-29-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-29-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3989030
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1
+N: bus/usb/003/002
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB_Optical_Mouse
+E: ID_MODEL_ENC=USB\x20Optical\x20Mouse
+E: ID_MODEL_ID=4d80
+E: ID_REVISION=0200
+E: ID_SERIAL=0461_USB_Optical_Mouse
+E: ID_USB_INTERFACES=:030102:
+E: ID_VENDOR=0461
+E: ID_VENDOR_ENC=0461
+E: ID_VENDOR_ID=0461
+E: MAJOR=189
+E: MINOR=257
+E: PRODUCT=461/4d80/200
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3989335
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v0461p4D80d0200dc00dsc00dp00ic03isc01ip02
+E: PRODUCT=461/4d80/200
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:0461:4D80.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:0461:4D80.0001
+E: DRIVER=generic-usb
+E: HID_ID=0003:00000461:00004D80
+E: HID_NAME=USB Optical Mouse
+E: HID_PHYS=usb-0000:00:14.0-1/input0
+E: MODALIAS=hid:b0003v00000461p00004D80
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:0461:4D80.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:0461:4D80.0001/hidraw/hidraw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input5
+E: EV=17
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=USB_Optical_Mouse
+E: ID_MODEL_ENC=USB\x20Optical\x20Mouse
+E: ID_MODEL_ID=4d80
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_0
+E: ID_REVISION=0200
+E: ID_SERIAL=0461_USB_Optical_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=0461
+E: ID_VENDOR_ENC=0461
+E: ID_VENDOR_ID=0461
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0003v0461p4D80e0111-e0,1,2,4,k110,111,112,r0,1,6,8,am4,lsfw
+E: MSC=10
+E: NAME="USB Optical Mouse"
+E: PHYS="usb-0000:00:14.0-1/input0"
+E: PRODUCT=3/461/4d80/111
+E: PROP=0
+E: REL=143
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=4007868
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-0461_USB_Optical_Mouse-event-mouse
+S: input/by-path/pci-0000:00:14.0-usb-0:1:1.0-event-mouse
+E: DEVLINKS=/dev/input/by-id/usb-0461_USB_Optical_Mouse-event-mouse /dev/input/by-path/pci-0000:00:14.0-usb-0:1:1.0-event-mouse
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=USB_Optical_Mouse
+E: ID_MODEL_ENC=USB\x20Optical\x20Mouse
+E: ID_MODEL_ID=4d80
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_0
+E: ID_REVISION=0200
+E: ID_SERIAL=0461_USB_Optical_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=0461
+E: ID_VENDOR_ENC=0461
+E: ID_VENDOR_ID=0461
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=4008910
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input5/mouse0
+N: input/mouse0
+S: input/by-id/usb-0461_USB_Optical_Mouse-mouse
+S: input/by-path/pci-0000:00:14.0-usb-0:1:1.0-mouse
+E: DEVLINKS=/dev/input/by-id/usb-0461_USB_Optical_Mouse-mouse /dev/input/by-path/pci-0000:00:14.0-usb-0:1:1.0-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input5/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=USB_Optical_Mouse
+E: ID_MODEL_ENC=USB\x20Optical\x20Mouse
+E: ID_MODEL_ID=4d80
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_0
+E: ID_REVISION=0200
+E: ID_SERIAL=0461_USB_Optical_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=0461
+E: ID_VENDOR_ENC=0461
+E: ID_VENDOR_ID=0461
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=4008884
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-29-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-29-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-29-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3989032
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0302dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2
+N: bus/usb/004/002
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=ADATA_USB_Flash_Drive
+E: ID_MODEL_ENC=ADATA\x20USB\x20Flash\x20Drive
+E: ID_MODEL_ID=312b
+E: ID_REVISION=0a00
+E: ID_SERIAL=ADATA_ADATA_USB_Flash_Drive_0000000000000505
+E: ID_SERIAL_SHORT=0000000000000505
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=ADATA
+E: ID_VENDOR_ENC=ADATA
+E: ID_VENDOR_ID=125f
+E: MAJOR=189
+E: MINOR=385
+E: PRODUCT=125f/312b/a00
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6428496
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v125Fp312Bd0A00dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=125f/312b/a00
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/scsi_host/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/scsi_host/host6
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-ADATA_USB_Flash_Drive_0000000000000505-0:0
+S: disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-ADATA_USB_Flash_Drive_0000000000000505-0:0 /dev/disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_Flash_Drive
+E: ID_MODEL_ENC=USB\x20Flash\x20Drive\x20
+E: ID_MODEL_ID=312b
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SERIAL=ADATA_USB_Flash_Drive_0000000000000505-0:0
+E: ID_SERIAL_SHORT=0000000000000505
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=ADATA
+E: ID_VENDOR_ENC=ADATA\x20\x20\x20
+E: ID_VENDOR_ID=125f
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7408673
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+N: sdb1
+S: disk/by-id/usb-ADATA_USB_Flash_Drive_0000000000000505-0:0-part1
+S: disk/by-label/PENDRIVE
+S: disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/150C-104B
+E: DEVLINKS=/dev/disk/by-id/usb-ADATA_USB_Flash_Drive_0000000000000505-0:0-part1 /dev/disk/by-label/PENDRIVE /dev/disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/150C-104B
+E: DEVNAME=/dev/sdb1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_LABEL=PENDRIVE
+E: ID_FS_LABEL_ENC=PENDRIVE
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=150C-104B
+E: ID_FS_UUID_ENC=150C-104B
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_Flash_Drive
+E: ID_MODEL_ENC=USB\x20Flash\x20Drive\x20
+E: ID_MODEL_ID=312b
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=128
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=30869376
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SERIAL=ADATA_USB_Flash_Drive_0000000000000505-0:0
+E: ID_SERIAL_SHORT=0000000000000505
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=ADATA
+E: ID_VENDOR_ENC=ADATA\x20\x20\x20
+E: ID_VENDOR_ID=125f
+E: MAJOR=8
+E: MINOR=17
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=65536
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=15805120512
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7872389
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+N: bsg/6:0:0:0
+E: DEVNAME=/dev/bsg/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+E: MAJOR=253
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usbmon/usbmon3
+N: usbmon3
+E: DEVNAME=/dev/usbmon3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usbmon/usbmon3
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usbmon/usbmon4
+N: usbmon4
+E: DEVNAME=/dev/usbmon4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usbmon/usbmon4
+E: MAJOR=252
+E: MINOR=4
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv00001028sd00000534bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3
+E: DRIVER=serial
+E: MODALIAS=pci:v00008086d00001E3Dsv00001028sd00000534bc07sc00i02
+E: PCI_CLASS=70002
+E: PCI_ID=8086:1E3D
+E: PCI_SLOT_NAME=0000:00:16.3
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3/tty/ttyS4
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=Panther Point KT Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:16.3
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6429004
+
+P: /devices/pci0000:00/0000:00:19.0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0
+E: DRIVER=e1000e
+E: MODALIAS=pci:v00008086d00001502sv00001028sd00000534bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=8086:1502
+E: PCI_SLOT_NAME=0000:00:19.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=82579LM Gigabit Network Connection
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:19.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6429165
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E2Dsv00001028sd00000534bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-29-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-29-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-29-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3989943
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3990746
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BCM20702A0
+E: ID_MODEL_ENC=BCM20702A0
+E: ID_MODEL_ID=8197
+E: ID_REVISION=0112
+E: ID_SERIAL=Broadcom_Corp_BCM20702A0_74DE2BD4B470
+E: ID_SERIAL_SHORT=74DE2BD4B470
+E: ID_USB_INTERFACES=:ff0101:ffffff:fe0101:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=413c
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=413c/8197/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6528330
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v413Cp8197d0112dcFFdsc01dp01icFFisc01ip01
+E: PRODUCT=413c/8197/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill0
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v413Cp8197d0112dcFFdsc01dp01icFFisc01ip01
+E: PRODUCT=413c/8197/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v413Cp8197d0112dcFFdsc01dp01icFFiscFFipFF
+E: PRODUCT=413c/8197/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v413Cp8197d0112dcFFdsc01dp01icFEisc01ip01
+E: PRODUCT=413c/8197/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Webcam
+E: ID_MODEL_ENC=Integrated\x20Webcam
+E: ID_MODEL_ID=2895
+E: ID_REVISION=2119
+E: ID_SERIAL=Sunplus_IT_Co_Integrated_Webcam
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=Sunplus_IT_Co
+E: ID_VENDOR_ENC=Sunplus\x20IT\x20Co\x20
+E: ID_VENDOR_ID=1bcf
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=1bcf/2895/2119
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6545311
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v1BCFp2895d2119dcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=1bcf/2895/2119
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input6
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Webcam
+E: ID_MODEL_ENC=Integrated\x20Webcam
+E: ID_MODEL_ID=2895
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=2119
+E: ID_SERIAL=Sunplus_IT_Co_Integrated_Webcam
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Sunplus_IT_Co
+E: ID_VENDOR_ENC=Sunplus\x20IT\x20Co\x20
+E: ID_VENDOR_ID=1bcf
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v1BCFp2895e2119-e0,1,kD4,ramlsfw
+E: NAME="Integrated Webcam"
+E: PHYS="usb-0000:00:1a.0-1.5/button"
+E: PRODUCT=3/1bcf/2895/2119
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6674445
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input6/event6
+N: input/event6
+S: input/by-id/usb-Sunplus_IT_Co_Integrated_Webcam-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-Sunplus_IT_Co_Integrated_Webcam-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-event
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input6/event6
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Webcam
+E: ID_MODEL_ENC=Integrated\x20Webcam
+E: ID_MODEL_ID=2895
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=2119
+E: ID_SERIAL=Sunplus_IT_Co_Integrated_Webcam
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Sunplus_IT_Co
+E: ID_VENDOR_ENC=Sunplus\x20IT\x20Co\x20
+E: ID_VENDOR_ID=1bcf
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6695620
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-Sunplus_IT_Co_Integrated_Webcam-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-Sunplus_IT_Co_Integrated_Webcam-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Webcam
+E: ID_MODEL_ENC=Integrated\x20Webcam
+E: ID_MODEL_ID=2895
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=2119
+E: ID_SERIAL=Sunplus_IT_Co_Integrated_Webcam
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Integrated Webcam
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=Sunplus_IT_Co
+E: ID_VENDOR_ENC=Sunplus\x20IT\x20Co\x20
+E: ID_VENDOR_ID=1bcf
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6687352
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v1BCFp2895d2119dcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=1bcf/2895/2119
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usbmon/usbmon1
+N: usbmon1
+E: DEVNAME=/dev/usbmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv00001028sd00000534bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Panther Point High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9986192
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972542
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D1
+N: snd/hwC0D1
+E: DEVNAME=/dev/snd/hwC0D1
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D1
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972481
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972895
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=7"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972857
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9976350
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9971894
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9974286
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Dock Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9971941
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+N: input/event12
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9977025
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input13
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input13
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9971942
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input13/event13
+N: input/event13
+E: DEVNAME=/dev/input/event13
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input13/event13
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=77
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9977796
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input14
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9973282
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input14/event14
+N: input/event14
+E: DEVNAME=/dev/input/event14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input14/event14
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=78
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9975748
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input15
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input15
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,
+E: NAME="HDA Intel PCH Dock Line-Out"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=40
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972904
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input15/event15
+N: input/event15
+E: DEVNAME=/dev/input/event15
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input15/event15
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=79
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9981132
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=8"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9973867
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9975122
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972260
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9973579
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972584
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+N: snd/pcmC0D7p
+E: DEVNAME=/dev/snd/pcmC0D7p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972198
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D8p
+N: snd/pcmC0D8p
+E: DEVNAME=/dev/snd/pcmC0D8p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D8p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9972305
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=10
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9973249
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv00001028sd00000534bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E12sv00001028sd00000534bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DRIVER=iwlwifi
+E: MODALIAS=pci:v00008086d00000082sv00008086sd00001321bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=8086:0082
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=8086:1321
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0/rfkill3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/ieee80211/phy0/rfkill3
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/leds/phy0-led
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/leds/phy0-led
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=Centrino Advanced-N 6205
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6717415
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E14sv00001028sd00000534bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E14
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E16sv00001028sd00000534bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E16
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:07
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:07
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E1Asv00001028sd00000534bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E1A
+E: PCI_SLOT_NAME=0000:00:1c.5
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/0000:0b:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/0000:0b:00.0
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v00001217d00008221sv00001028sd00000534bc08sc05i01
+E: PCI_CLASS=80501
+E: PCI_ID=1217:8221
+E: PCI_SLOT_NAME=0000:0b:00.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/0000:0b:00.0/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/0000:0b:00.0/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/0000:0b:00.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/0000:0b:00.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/pci_bus/0000:0b
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/pci_bus/0000:0b
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E26sv00001028sd00000534bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-29-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-29-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-29-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3991947
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3992264
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=5880
+E: ID_MODEL_ENC=5880
+E: ID_MODEL_ID=5801
+E: ID_REVISION=0101
+E: ID_SERIAL=Broadcom_Corp_5880_0123456789ABCD
+E: ID_SERIAL_SHORT=0123456789ABCD
+E: ID_USB_INTERFACES=:fe0000:0b0000:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=0a5c
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=a5c/5801/101
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6559023
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/0/0
+E: MODALIAS=usb:v0A5Cp5801d0101dc00dsc00dp00icFEisc00ip00
+E: PRODUCT=a5c/5801/101
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:0.1
+E: DEVTYPE=usb_interface
+E: INTERFACE=11/0/0
+E: MODALIAS=usb:v0A5Cp5801d0101dc00dsc00dp00ic0Bisc00ip00
+E: PRODUCT=a5c/5801/101
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+N: usbmon2
+E: DEVNAME=/dev/usbmon2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00001E55sv00001028sd00000534bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E55
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=82801 Mobile SATA Controller [RAID mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d0000282Asv00001028sd00000534bc01sc04i00
+E: PCI_CLASS=10400
+E: PCI_ID=8086:282A
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6562853
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ
+S: disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ
+S: disk/by-id/wwn-0x5000c50045147983
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ /dev/disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ /dev/disk/by-id/wwn-0x5000c50045147983 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST500LX003-1AC15G
+E: ID_MODEL_ENC=ST500LX003-1AC15G\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=DEM3
+E: ID_SCSI_COMPAT=SATA_ST500LX003-1AC1_W2003CBZ
+E: ID_SERIAL=ST500LX003-1AC15G_W2003CBZ
+E: ID_SERIAL_SHORT=W2003CBZ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50045147983
+E: ID_WWN_WITH_EXTENSION=0x5000c50045147983
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3962984
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ-part1
+S: disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ-part1
+S: disk/by-id/wwn-0x5000c50045147983-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/2bef066c-fb96-4702-b08d-4c7ae7c437fe
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ-part1 /dev/disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ-part1 /dev/disk/by-id/wwn-0x5000c50045147983-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/2bef066c-fb96-4702-b08d-4c7ae7c437fe
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=2bef066c-fb96-4702-b08d-4c7ae7c437fe
+E: ID_FS_UUID_ENC=2bef066c-fb96-4702-b08d-4c7ae7c437fe
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=ST500LX003-1AC15G
+E: ID_MODEL_ENC=ST500LX003-1AC15G\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=968640512
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=DEM3
+E: ID_SCSI_COMPAT=SATA_ST500LX003-1AC1_W2003CBZ
+E: ID_SERIAL=ST500LX003-1AC15G_W2003CBZ
+E: ID_SERIAL_SHORT=W2003CBZ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50045147983
+E: ID_WWN_WITH_EXTENSION=0x5000c50045147983
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=495943942144
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=4072685
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ-part2
+S: disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ-part2
+S: disk/by-id/wwn-0x5000c50045147983-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ-part2 /dev/disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ-part2 /dev/disk/by-id/wwn-0x5000c50045147983-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST500LX003-1AC15G
+E: ID_MODEL_ENC=ST500LX003-1AC15G\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=968644606
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8126466
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=DEM3
+E: ID_SCSI_COMPAT=SATA_ST500LX003-1AC1_W2003CBZ
+E: ID_SERIAL=ST500LX003-1AC15G_W2003CBZ
+E: ID_SERIAL_SHORT=W2003CBZ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50045147983
+E: ID_WWN_WITH_EXTENSION=0x5000c50045147983
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=1024
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=495946038272
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4160750592
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=4038719
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ-part5
+S: disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ-part5
+S: disk/by-id/wwn-0x5000c50045147983-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/a7126f65-e66f-4eb5-9d0f-df7f738cf5f2
+E: DEVLINKS=/dev/disk/by-id/ata-ST500LX003-1AC15G_W2003CBZ-part5 /dev/disk/by-id/scsi-SATA_ST500LX003-1AC1_W2003CBZ-part5 /dev/disk/by-id/wwn-0x5000c50045147983-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/a7126f65-e66f-4eb5-9d0f-df7f738cf5f2
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=106
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=a7126f65-e66f-4eb5-9d0f-df7f738cf5f2
+E: ID_FS_UUID_ENC=a7126f65-e66f-4eb5-9d0f-df7f738cf5f2
+E: ID_FS_VERSION=2
+E: ID_MODEL=ST500LX003-1AC15G
+E: ID_MODEL_ENC=ST500LX003-1AC15G\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=968644608
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8126464
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=DEM3
+E: ID_SCSI_COMPAT=SATA_ST500LX003-1AC1_W2003CBZ
+E: ID_SERIAL=ST500LX003-1AC15G_W2003CBZ
+E: ID_SERIAL_SHORT=W2003CBZ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50045147983
+E: ID_WWN_WITH_EXTENSION=0x5000c50045147983
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=495946039296
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4160749568
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=4056221
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-MATSHITA_DVD+_-RW_UJ8B2_WM94_075000
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-MATSHITA_DVD+_-RW_UJ8B2_WM94_075000 /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=MATSHITA_DVD+_-RW_UJ8B2
+E: ID_MODEL_ENC=MATSHITA\x20DVD+\x2f-RW\x20UJ8B2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=1.01
+E: ID_SERIAL=MATSHITA_DVD+_-RW_UJ8B2_WM94_075000
+E: ID_SERIAL_SHORT=WM94_075000
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3963136
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6576573
+
+P: /devices/pci0000:00/0000:00:1f.2/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv00001028sd00000534bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1028:0534
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop
+E: DEVPATH=/devices/platform/dell-laptop
+E: DRIVER=dell-laptop
+E: MODALIAS=platform:dell-laptop
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop/rfkill/rfkill1
+E: DEVPATH=/devices/platform/dell-laptop/rfkill/rfkill1
+E: RFKILL_NAME=dell-wifi
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop/rfkill/rfkill2
+E: DEVPATH=/devices/platform/dell-laptop/rfkill/rfkill2
+E: RFKILL_NAME=dell-bluetooth
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/dock.0
+E: DEVPATH=/devices/platform/dock.0
+E: MODALIAS=platform:dock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Dell Inc.
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6539052
+
+P: /devices/platform/i8042/serio0/input/input4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=1100f02902002 8380307cf910f001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8D,8E,8F,94,98,9B,9C,9D,9E,9F,A2,A3,A4,A5,A6,AC,AD,B7,B8,B9,BF,C1,CD,D4,D7,D9,E0,E1,E2,E3,EC,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3997397
+
+P: /devices/platform/i8042/serio0/input/input4/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4/event4
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3998839
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input16
+E: DEVPATH=/devices/platform/i8042/serio1/input/input16
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0001e0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="PS/2 Generic Mouse"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/1/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10877240
+
+P: /devices/platform/i8042/serio1/input/input16/event16
+N: input/event16
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event16
+E: DEVPATH=/devices/platform/i8042/serio1/input/input16/event16
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=80
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10892786
+
+P: /devices/platform/i8042/serio1/input/input16/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/input/input16/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10879305
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6540320
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6540612
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6542497
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6543398
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6543825
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6544710
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6548786
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6548840
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6549886
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6550749
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6552810
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6553964
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6553354
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6553961
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6554312
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6554832
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6556464
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6558278
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6559454
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6561177
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6561498
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6562469
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6562778
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6563072
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6572981
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6574562
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6575097
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6575582
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6577201
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6577489
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6577765
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3999512
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0d
+E: DEVPATH=/devices/pnp0/00:0d
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0e
+E: DEVPATH=/devices/pnp0/00:0e
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0f
+E: DEVPATH=/devices/pnp0/00:0f
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:19
+E: DEVPATH=/devices/virtual/bdi/0:19
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963223
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963324
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963400
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963482
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963574
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963666
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963758
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=3963848
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3963938
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964041
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964129
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964236
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964328
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964415
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964505
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964600
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964699
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964790
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964881
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3964974
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3965061
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3965145
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3965238
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3965330
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrA06:bd09/19/2012:svnDellInc.:pnLatitudeE6430:pvr01:rvnDellInc.:rn0CPWYR:rvrX03:cvnDellInc.:ct9:cvr:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input7
+E: DEVPATH=/devices/virtual/input/input7
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=1001b00000400 100000 e000000000000 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k71,72,73,94,CA,E0,E1,E3,E4,F0,ram4,lsfw
+E: MSC=10
+E: NAME="Dell WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7388249
+
+P: /devices/virtual/input/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/virtual/input/input7/event7
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7393435
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mei/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/mei/mei
+E: MAJOR=250
+E: MINOR=1
+E: SUBSYSTEM=mei
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/agpgart
+N: agpgart
+E: DEVNAME=/dev/agpgart
+E: DEVPATH=/devices/virtual/misc/agpgart
+E: MAJOR=10
+E: MINOR=175
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6600267
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/watchdog
+N: watchdog
+E: DEVNAME=/dev/watchdog
+E: DEVPATH=/devices/virtual/misc/watchdog
+E: MAJOR=10
+E: MINOR=130
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6601050
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6668184
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6655252
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6601918
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6602119
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6602319
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6602604
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6602570
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6602899
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6603347
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6602937
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6603141
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6603342
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6603538
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6603787
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604260
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604067
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6603854
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604056
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604717
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604627
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604408
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604611
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6604808
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605004
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605289
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606040
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606235
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605626
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605748
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605435
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605632
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6605835
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606032
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606227
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606420
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606670
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6607384
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6607218
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606876
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6606785
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6607069
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6607277
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6607983
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6608222
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6608060
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6608271
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6626349
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6627823
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6628762
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6629157
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6629884
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6633976
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6634397
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6634908
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6635267
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6635871
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6636880
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6637255
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6637729
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6638129
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6638554
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6641017
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6643065
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6643495
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6643118
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6645992
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6646275
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6646531
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6646776
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6647014
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: DEVNAME=/dev/usbmon0
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:9DBB5994-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: DEVPATH=/devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: MODALIAS=wmi:A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:A80593CE-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_OPTIPLEX9020AIO.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_OPTIPLEX9020AIO.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_OPTIPLEX9020AIO.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5518 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=864299
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input1/event1
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=867239
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:4f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:50
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:50
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:51
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:51
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:52
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:52
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:53
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:53
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:54
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:54
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:55
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:55
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:56
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:56
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:57
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:57
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:58
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:58
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:59
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:59
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9523948
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7/event7
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9525014
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:03
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18/device:19/device:1a/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21/device:22/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:39/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:45/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:45/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:47
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:47
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:48
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:48
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:49
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:49
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=867002
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=862563
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXPOWER:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXPOWER:00
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXPOWER:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXPOWER:01
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXPOWER:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXPOWER:02
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXPOWER:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXPOWER:03
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXPOWER:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXPOWER:04
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/LNXTHERM:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/LNXTHERM:01
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/PNP0C0B:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/PNP0C0B:00
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/PNP0C0B:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/PNP0C0B:01
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/PNP0C0B:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/PNP0C0B:02
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/PNP0C0B:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/PNP0C0B:03
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:5a/PNP0C0B:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:5a/PNP0C0B:04
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000C00sv00001028sd000005A7bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0C00
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000412sv00001028sd000005A7bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0412
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9524647
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-eDP-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.0
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00000C0Csv00001028sd000005A7bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:0C0C
+E: PCI_SLOT_NAME=0000:00:03.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Haswell HD Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:03.0
+E: ID_PATH=pci-0000:00:03.0
+E: ID_PATH_TAG=pci-0000_00_03_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9572166
+
+P: /devices/pci0000:00/0000:00:03.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9566195
+
+P: /devices/pci0000:00/0000:00:03.0/sound/card0/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0/sound/card0/input6
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:03.0
+E: ID_PATH_TAG=pci-0000_00_03_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel MID HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9566184
+
+P: /devices/pci0000:00/0000:00:03.0/sound/card0/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0/sound/card0/input6/event6
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:03.0
+E: ID_PATH_TAG=pci-0000_00_03_0
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9567217
+
+P: /devices/pci0000:00/0000:00:03.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9566169
+
+P: /devices/pci0000:00/0000:00:03.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:03.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:03.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:03.0
+E: ID_PATH_TAG=pci-0000_00_03_0
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9566268
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00008C31sv00001028sd000005A7bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:8C31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-22-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-22-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-22-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=865864
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1
+N: bus/usb/003/002
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: MAJOR=189
+E: MINOR=257
+E: PRODUCT=413c/2506/110
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1347964
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/1
+E: MODALIAS=usb:v413Cp2506d0110dc00dsc00dp00ic03isc01ip01
+E: PRODUCT=413c/2506/110
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:413C:2506.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:413C:2506.0001
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000413C:00002506
+E: HID_NAME=Dell Dell KM713 Wireless Keyboard and Mouse
+E: HID_PHYS=usb-0000:00:14.0-1/input0
+E: MODALIAS=hid:b0003g0001v0000413Cp00002506
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:413C:2506.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/0003:413C:2506.0001/hidraw/hidraw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input2
+E: EV=120013
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_0
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: KEY=1000000000007 ff9f207ac14057ff febeffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0003v413Cp2506e0111-e0,1,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8C,8E,96,98,9E,9F,A1,A3,A4,A5,A6,AD,B0,B1,B2,B3,B4,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="Dell Dell KM713 Wireless Keyboard and Mouse"
+E: PHYS="usb-0000:00:14.0-1/input0"
+E: PRODUCT=3/413c/2506/111
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=8643954
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input2/event2
+N: input/event2
+S: input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-event-kbd
+S: input/by-path/pci-0000:00:14.0-usb-0:1:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-event-kbd /dev/input/by-path/pci-0000:00:14.0-usb-0:1:1.0-event-kbd
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0/input/input2/event2
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_0
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8750478
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v413Cp2506d0110dc00dsc00dp00ic03isc00ip00
+E: PRODUCT=413c/2506/110
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/0003:413C:2506.0002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/0003:413C:2506.0002
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000413C:00002506
+E: HID_NAME=Dell Dell KM713 Wireless Keyboard and Mouse
+E: HID_PHYS=usb-0000:00:14.0-1/input1
+E: MODALIAS=hid:b0003g0001v0000413Cp00002506
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/0003:413C:2506.0002/hidraw/hidraw1
+N: hidraw1
+E: DEVNAME=/dev/hidraw1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/0003:413C:2506.0002/hidraw/hidraw1
+E: MAJOR=251
+E: MINOR=1
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/input/input3
+E: ABS=100000000
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/input/input3
+E: EV=1f
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.1
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_1
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: KEY=4837fff072ff32d bf54444600000000 1 20c100b17c000 267bfad941dfed 9e168000004400 10000002
+E: MODALIAS=input:b0003v413Cp2506e0111-e0,1,2,3,4,k71,72,73,74,77,80,82,83,85,86,87,88,89,8A,8B,8C,8E,8F,90,96,98,9B,9C,9E,9F,A1,A3,A4,A5,A6,A7,A8,A9,AB,AC,AD,AE,B1,B2,B5,CE,CF,D0,D1,D2,D4,D8,D9,DB,E4,EA,EB,F1,100,161,162,166,16A,16E,172,174,176,178,179,17A,17B,17C,17D,17F,180,182,183,185,188,189,18C,18D,18E,18F,190,191,192,193,195,198,199,19A,1A0,1A1,1A2,1A3,1A4,1A5,1A6,1A7,1A8,1A9,1AA,1AB,1AC,1AD,1AE,1B0,1B1,1B7,1BA,r6,a20,m4,lsfw
+E: MSC=10
+E: NAME="Dell Dell KM713 Wireless Keyboard and Mouse"
+E: PHYS="usb-0000:00:14.0-1/input1"
+E: PRODUCT=3/413c/2506/111
+E: PROP=0
+E: REL=40
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=8645070
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/input/input3/event3
+N: input/event3
+S: input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-event-if01
+S: input/by-path/pci-0000:00:14.0-usb-0:1:1.1-event
+E: DEVLINKS=/dev/input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-event-if01 /dev/input/by-path/pci-0000:00:14.0-usb-0:1:1.1-event
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/input/input3/event3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.1
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_1
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8750788
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/usb/hiddev0
+N: usb/hiddev0
+E: DEVNAME=/dev/usb/hiddev0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.1/usb/hiddev0
+E: MAJOR=180
+E: MINOR=0
+E: SUBSYSTEM=usb
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v413Cp2506d0110dc00dsc00dp00ic03isc01ip02
+E: PRODUCT=413c/2506/110
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/0003:413C:2506.0003
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/0003:413C:2506.0003
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000413C:00002506
+E: HID_NAME=Dell Dell KM713 Wireless Keyboard and Mouse
+E: HID_PHYS=usb-0000:00:14.0-1/input2
+E: MODALIAS=hid:b0003g0001v0000413Cp00002506
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/0003:413C:2506.0003/hidraw/hidraw2
+N: hidraw2
+E: DEVNAME=/dev/hidraw2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/0003:413C:2506.0003/hidraw/hidraw2
+E: MAJOR=251
+E: MINOR=2
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/input/input4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/input/input4
+E: EV=17
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.2
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_2
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0003v413Cp2506e0111-e0,1,2,4,k110,111,112,r0,1,8,am4,lsfw
+E: MSC=10
+E: NAME="Dell Dell KM713 Wireless Keyboard and Mouse"
+E: PHYS="usb-0000:00:14.0-1/input2"
+E: PRODUCT=3/413c/2506/111
+E: PROP=0
+E: REL=103
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=8645255
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/input/input4/event4
+N: input/event4
+S: input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-if02-event-mouse
+S: input/by-path/pci-0000:00:14.0-usb-0:1:1.2-event-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-if02-event-mouse /dev/input/by-path/pci-0000:00:14.0-usb-0:1:1.2-event-mouse
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/input/input4/event4
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.2
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_2
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8752995
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/input/input4/mouse0
+N: input/mouse0
+S: input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-if02-mouse
+S: input/by-path/pci-0000:00:14.0-usb-0:1:1.2-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Dell_Dell_KM713_Wireless_Keyboard_and_Mouse-if02-mouse /dev/input/by-path/pci-0000:00:14.0-usb-0:1:1.2-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.2/input/input4/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_MODEL_ENC=Dell\x20KM713\x20Wireless\x20Keyboard\x20and\x20Mouse
+E: ID_MODEL_ID=2506
+E: ID_PATH=pci-0000:00:14.0-usb-0:1:1.2
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_2
+E: ID_REVISION=0110
+E: ID_SERIAL=Dell_Dell_KM713_Wireless_Keyboard_and_Mouse
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030000:030102:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8753301
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-22-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-22-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-22-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=868821
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2
+N: bus/usb/004/003
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=DT_Ultimate_G2
+E: ID_MODEL_ENC=DT\x20Ultimate\x20G2
+E: ID_MODEL_ID=1656
+E: ID_REVISION=0110
+E: ID_SERIAL=Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262
+E: ID_SERIAL_SHORT=0018F3D97D22BBB010000262
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=Kingston
+E: ID_VENDOR_ENC=Kingston
+E: ID_VENDOR_ID=0951
+E: MAJOR=189
+E: MINOR=386
+E: PRODUCT=951/1656/110
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=4065510634
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v0951p1656d0110dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=951/1656/110
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/scsi_host/host7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/scsi_host/host7
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/block/sdc
+N: sdc
+S: disk/by-id/usb-Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262-0:0
+S: disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262-0:0 /dev/disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdc
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/block/sdc
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=DT_Ultimate_G2
+E: ID_MODEL_ENC=DT\x20Ultimate\x20G2\x20\x20
+E: ID_MODEL_ID=1656
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=PMAP
+E: ID_SERIAL=Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262-0:0
+E: ID_SERIAL_SHORT=0018F3D97D22BBB010000262
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Kingston
+E: ID_VENDOR_ENC=Kingston
+E: ID_VENDOR_ID=0951
+E: MAJOR=8
+E: MINOR=32
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=4066780944
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/block/sdc/sdc1
+N: sdc1
+S: disk/by-id/usb-Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262-0:0-part1
+S: disk/by-label/KINGSTON
+S: disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/4E3E-2A55
+E: DEVLINKS=/dev/disk/by-id/usb-Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262-0:0-part1 /dev/disk/by-label/KINGSTON /dev/disk/by-path/pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/4E3E-2A55
+E: DEVNAME=/dev/sdc1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/block/sdc/sdc1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_LABEL=KINGSTON
+E: ID_FS_LABEL_ENC=KINGSTON
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=4E3E-2A55
+E: ID_FS_UUID_ENC=4E3E-2A55
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:0
+E: ID_MODEL=DT_Ultimate_G2
+E: ID_MODEL_ENC=DT\x20Ultimate\x20G2\x20\x20
+E: ID_MODEL_ID=1656
+E: ID_PART_ENTRY_DISK=8:32
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=8064
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=31285376
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=PMAP
+E: ID_SERIAL=Kingston_DT_Ultimate_G2_0018F3D97D22BBB010000262-0:0
+E: ID_SERIAL_SHORT=0018F3D97D22BBB010000262
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Kingston
+E: ID_VENDOR_ENC=Kingston
+E: ID_VENDOR_ID=0951
+E: MAJOR=8
+E: MINOR=33
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=4128768
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=16018112512
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/block/sdc
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=4066824179
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/bsg/7:0:0:0
+N: bsg/7:0:0:0
+E: DEVNAME=/dev/bsg/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/bsg/7:0:0:0
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/scsi_device/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/scsi_device/7:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/scsi_disk/7:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/scsi_disk/7:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/scsi_generic/sg3
+N: sg3
+E: DEVNAME=/dev/sg3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-2/4-2:1.0/host7/target7:0:0/7:0:0:0/scsi_generic/sg3
+E: MAJOR=21
+E: MINOR=3
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: MODALIAS=pci:v00008086d00008C3Asv00001028sd000005A7bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:8C3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3
+E: DRIVER=serial
+E: MODALIAS=pci:v00008086d00008C3Dsv00001028sd000005A7bc07sc00i02
+E: PCI_CLASS=70002
+E: PCI_ID=8086:8C3D
+E: PCI_SLOT_NAME=0000:00:16.3
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3/tty/ttyS4
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=Lynx Point KT Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:16.3
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8616292
+
+P: /devices/pci0000:00/0000:00:19.0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0
+E: DRIVER=e1000e
+E: MODALIAS=pci:v00008086d0000153Asv00001028sd000005A7bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=8086:153A
+E: PCI_SLOT_NAME=0000:00:19.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:19.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8615313
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00008C2Dsv00001028sd000005A7bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:8C2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-22-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-22-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-22-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=871932
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=8008
+E: ID_MODEL_ENC=8008
+E: ID_MODEL_ID=8008
+E: ID_REVISION=0004
+E: ID_SERIAL=8087_8008
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/8008/4
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=916810
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p8008d0004dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/8008/4
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00008C20sv00001028sd000005A7bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:8C20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Lynx Point HD Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9618451
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/hwC1D0
+N: snd/hwC1D0
+E: DEVNAME=/dev/snd/hwC1D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/hwC1D0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611303
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,
+E: NAME="HDA Intel PCH Line Out"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=40
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611468
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9612686
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/input8
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611416
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/input8/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9612730
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Front Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611441
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9612493
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/pcmC1D0c
+N: snd/pcmC1D0c
+E: DEVNAME=/dev/snd/pcmC1D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/pcmC1D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611275
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/pcmC1D0p
+N: snd/pcmC1D0p
+E: DEVNAME=/dev/snd/pcmC1D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/pcmC1D0p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611429
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card1/controlC1
+N: snd/controlC1
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC1
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card1/controlC1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9611475
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00008C10sv00001028sd000005A7bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:8C10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DRIVER=wl
+E: MODALIAS=pci:v000014E4d00004359sv00001028sd00000014bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=14E4:4359
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=1028:0014
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0/rfkill0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0/rfkill0
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth1
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=BCM43228 802.11a/b/g/n
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: ID_VENDOR_FROM_DATABASE=Broadcom Corporation
+E: ID_VENDOR_ID=0x14e4
+E: IFINDEX=3
+E: INTERFACE=eth1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9200619
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth1/rfkill1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth1/rfkill1
+E: RFKILL_NAME=brcmwl-0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00008C1Csv00001028sd000005A7bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:8C1C
+E: PCI_SLOT_NAME=0000:00:1c.6
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0
+E: DRIVER=rts_pstor
+E: MODALIAS=pci:v000010ECd00005209sv00001028sd000005A7bcFFsc00i00
+E: PCI_CLASS=FF0000
+E: PCI_ID=10EC:5209
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/block/sdb
+N: sdb
+S: disk/by-path/pci-0000:02:00.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-path/pci-0000:02:00.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=scsi
+E: ID_DRIVE_FLASH_SD=1
+E: ID_MODEL=xD_SD_M.S.
+E: ID_MODEL_ENC=xD\x2fSD\x2fM.S.\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:02:00.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_02_00_0-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SCSI=1
+E: ID_TYPE=disk
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=9815574
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/bsg/5:0:0:0
+N: bsg/5:0:0:0
+E: DEVNAME=/dev/bsg/5:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/bsg/5:0:0:0
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/scsi_device/5:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/scsi_device/5:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/scsi_disk/5:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/scsi_disk/5:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.0/host5/target5:0:0/5:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.1
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v000010ECd00005209sv00001028sd000005A7bc08sc05i00
+E: PCI_CLASS=80500
+E: PCI_ID=10EC:5209
+E: PCI_SLOT_NAME=0000:02:00.1
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.1/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.1/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/0000:02:00.1/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/0000:02:00.1/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.6/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.6/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00008C26sv00001028sd000005A7bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:8C26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-22-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-22-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-22-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=872391
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=8000
+E: ID_MODEL_ENC=8000
+E: ID_MODEL_ID=8000
+E: ID_REVISION=0004
+E: ID_SERIAL=8087_8000
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/8000/4
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1160664
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p8000d0004dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/8000/4
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00008C4Esv00001028sd000005A7bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:8C4E
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=82801 SATA Controller [RAID mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00002822sv00001028sd000005A7bc01sc04i00
+E: PCI_CLASS=10400
+E: PCI_ID=8086:2822
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8622089
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+S: disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+S: disk/by-id/wwn-0x50014ee2b278d7aa
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029 /dev/disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029 /dev/disk/by-id/wwn-0x50014ee2b278d7aa /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=WDC_WD10EZEX-75ZF5A0
+E: ID_MODEL_ENC=WDC\x20WD10EZEX-75ZF5A0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=80.00A08
+E: ID_SCSI_COMPAT=SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+E: ID_SERIAL=WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+E: ID_SERIAL_SHORT=WD-WCC1S1895029
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2b278d7aa
+E: ID_WWN_WITH_EXTENSION=0x50014ee2b278d7aa
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=5
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=855347
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part1
+S: disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part1
+S: disk/by-id/wwn-0x50014ee2b278d7aa-part1
+S: disk/by-label/DellUtility
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/00B2-DB2B
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part1 /dev/disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part1 /dev/disk/by-id/wwn-0x50014ee2b278d7aa-part1 /dev/disk/by-label/DellUtility /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/00B2-DB2B
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=DellUtility
+E: ID_FS_LABEL_ENC=DellUtility
+E: ID_FS_SEC_TYPE=msdos
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=00B2-DB2B
+E: ID_FS_UUID_ENC=00B2-DB2B
+E: ID_FS_VERSION=FAT16
+E: ID_MODEL=WDC_WD10EZEX-75ZF5A0
+E: ID_MODEL_ENC=WDC\x20WD10EZEX-75ZF5A0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=61440
+E: ID_PART_ENTRY_TYPE=0xde
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=80.00A08
+E: ID_SCSI_COMPAT=SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+E: ID_SERIAL=WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+E: ID_SERIAL_SHORT=WD-WCC1S1895029
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2b278d7aa
+E: ID_WWN_WITH_EXTENSION=0x50014ee2b278d7aa
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=31457280
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0xde
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1205426
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part2
+S: disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part2
+S: disk/by-id/wwn-0x50014ee2b278d7aa-part2
+S: disk/by-label/OS
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-uuid/4D37-9C99
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part2 /dev/disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part2 /dev/disk/by-id/wwn-0x50014ee2b278d7aa-part2 /dev/disk/by-label/OS /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-uuid/4D37-9C99
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=OS
+E: ID_FS_LABEL_ENC=OS
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=4D37-9C99
+E: ID_FS_UUID_ENC=4D37-9C99
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=WDC_WD10EZEX-75ZF5A0
+E: ID_MODEL_ENC=WDC\x20WD10EZEX-75ZF5A0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=63488
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=4329472
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=80.00A08
+E: ID_SCSI_COMPAT=SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+E: ID_SERIAL=WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+E: ID_SERIAL_SHORT=WD-WCC1S1895029
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2b278d7aa
+E: ID_WWN_WITH_EXTENSION=0x50014ee2b278d7aa
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=32505856
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2216689664
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1341218
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part3
+S: disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part3
+S: disk/by-id/wwn-0x50014ee2b278d7aa-part3
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+S: disk/by-uuid/66e653f0-7665-4e30-a876-3564b67bdac0
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part3 /dev/disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part3 /dev/disk/by-id/wwn-0x50014ee2b278d7aa-part3 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3 /dev/disk/by-uuid/66e653f0-7665-4e30-a876-3564b67bdac0
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=66e653f0-7665-4e30-a876-3564b67bdac0
+E: ID_FS_UUID_ENC=66e653f0-7665-4e30-a876-3564b67bdac0
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=WDC_WD10EZEX-75ZF5A0
+E: ID_MODEL_ENC=WDC\x20WD10EZEX-75ZF5A0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=4392960
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=1941248000
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=80.00A08
+E: ID_SCSI_COMPAT=SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+E: ID_SERIAL=WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+E: ID_SERIAL_SHORT=WD-WCC1S1895029
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2b278d7aa
+E: ID_WWN_WITH_EXTENSION=0x50014ee2b278d7aa
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=2249195520
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=993918976000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1353632
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+N: sda4
+S: disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part4
+S: disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part4
+S: disk/by-id/wwn-0x50014ee2b278d7aa-part4
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part4 /dev/disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part4 /dev/disk/by-id/wwn-0x50014ee2b278d7aa-part4 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4
+E: DEVNAME=/dev/sda4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=WDC_WD10EZEX-75ZF5A0
+E: ID_MODEL_ENC=WDC\x20WD10EZEX-75ZF5A0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=4
+E: ID_PART_ENTRY_OFFSET=1945643006
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=7880706
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=80.00A08
+E: ID_SCSI_COMPAT=SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+E: ID_SERIAL=WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+E: ID_SERIAL_SHORT=WD-WCC1S1895029
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2b278d7aa
+E: ID_WWN_WITH_EXTENSION=0x50014ee2b278d7aa
+E: MAJOR=8
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=1024
+E: UDISKS_PARTITION_NUMBER=4
+E: UDISKS_PARTITION_OFFSET=996169219072
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4034921472
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1095234
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part5
+S: disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part5
+S: disk/by-id/wwn-0x50014ee2b278d7aa-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/7cd3fbb2-a998-46d4-97ec-b6f3ddd005df
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029-part5 /dev/disk/by-id/scsi-SATA_WDC_WD10EZEX-75_WD-WCC1S1895029-part5 /dev/disk/by-id/wwn-0x50014ee2b278d7aa-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/7cd3fbb2-a998-46d4-97ec-b6f3ddd005df
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=108
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=7cd3fbb2-a998-46d4-97ec-b6f3ddd005df
+E: ID_FS_UUID_ENC=7cd3fbb2-a998-46d4-97ec-b6f3ddd005df
+E: ID_FS_VERSION=2
+E: ID_MODEL=WDC_WD10EZEX-75ZF5A0
+E: ID_MODEL_ENC=WDC\x20WD10EZEX-75ZF5A0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=1945643008
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=7880704
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=80.00A08
+E: ID_SCSI_COMPAT=SATA_WDC_WD10EZEX-75_WD-WCC1S1895029
+E: ID_SERIAL=WDC_WD10EZEX-75ZF5A0_WD-WCC1S1895029
+E: ID_SERIAL_SHORT=WD-WCC1S1895029
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2b278d7aa
+E: ID_WWN_WITH_EXTENSION=0x50014ee2b278d7aa
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=996169220096
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4034920448
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1314418
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-MATSHITA_BD-RE_UJ260AF_WQ13_001253
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-MATSHITA_BD-RE_UJ260AF_WQ13_001253 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_BD=1
+E: ID_CDROM_BD_R=1
+E: ID_CDROM_BD_RE=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=MATSHITA_BD-RE_UJ260AF
+E: ID_MODEL_ENC=MATSHITA\x20BD-RE\x20UJ260AF\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SERIAL=MATSHITA_BD-RE_UJ260AF_WQ13_001253
+E: ID_SERIAL_SHORT=WQ13_001253
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=855524
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8626501
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00008C22sv00001028sd000005A7bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:8C22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1028:05A7
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon1
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614947
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614996
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614997
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8615530
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8615581
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8615819
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8616053
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8616306
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8616325
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8616539
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8616768
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8617000
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8617191
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8617058
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8617072
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614011
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614032
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614052
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614073
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614093
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614115
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614136
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614158
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614181
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614203
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614226
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614249
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614272
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614311
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614343
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8614367
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=875292
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu4
+E: DEVPATH=/devices/system/cpu/cpu4
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu5
+E: DEVPATH=/devices/system/cpu/cpu5
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu6
+E: DEVPATH=/devices/system/cpu/cpu6
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu7
+E: DEVPATH=/devices/system/cpu/cpu7
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003C:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003A,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008B,008C,008D,008E,008F,0091,0093,0094,0095,0096,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00C5,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0121,0123,0124,0125,0127,0128,0129,012A,012B,012D
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck4
+E: DEVPATH=/devices/system/machinecheck/machinecheck4
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck5
+E: DEVPATH=/devices/system/machinecheck/machinecheck5
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck6
+E: DEVPATH=/devices/system/machinecheck/machinecheck6
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck7
+E: DEVPATH=/devices/system/machinecheck/machinecheck7
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:19
+E: DEVPATH=/devices/virtual/bdi/0:19
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:32
+E: DEVPATH=/devices/virtual/bdi/8:32
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=855591
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=855666
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=855732
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=855797
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=855865
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=855941
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=856028
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=856098
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856170
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856246
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856329
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856398
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856473
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856547
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856618
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856689
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856765
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856842
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856906
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=856979
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=857060
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=857136
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=857206
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=857290
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrA00:bd04/08/2013:svnDellInc.:pnOptiPlex9020AIO:pvr01:rvnDellInc.:rn:rvr:cvnDellInc.:ct13:cvr:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input5
+E: DEVPATH=/devices/virtual/input/input5
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=800000000000 0 0 1000b00000000 0 e000000000000 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k71,72,73,E0,E1,E3,F0,1AF,ram4,lsfw
+E: MSC=10
+E: NAME="Dell AIO WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8785637
+
+P: /devices/virtual/input/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/virtual/input/input5/event5
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8786677
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/btrfs-control
+N: btrfs-control
+E: DEVNAME=/dev/btrfs-control
+E: DEVPATH=/devices/virtual/misc/btrfs-control
+E: MAJOR=10
+E: MINOR=234
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8799231
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8636453
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8636824
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8756657
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8755200
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device10
+E: DEVPATH=/devices/virtual/thermal/cooling_device10
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device11
+E: DEVPATH=/devices/virtual/thermal/cooling_device11
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device12
+E: DEVPATH=/devices/virtual/thermal/cooling_device12
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device13
+E: DEVPATH=/devices/virtual/thermal/cooling_device13
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device5
+E: DEVPATH=/devices/virtual/thermal/cooling_device5
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device6
+E: DEVPATH=/devices/virtual/thermal/cooling_device6
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device7
+E: DEVPATH=/devices/virtual/thermal/cooling_device7
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device8
+E: DEVPATH=/devices/virtual/thermal/cooling_device8
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device9
+E: DEVPATH=/devices/virtual/thermal/cooling_device9
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone1
+E: DEVPATH=/devices/virtual/thermal/thermal_zone1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8637780
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8637967
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638133
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638184
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638337
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638399
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638417
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638458
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638613
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638622
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638675
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638827
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638836
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8638889
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639043
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639053
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639102
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639248
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639279
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639430
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639459
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639609
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639643
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639787
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639822
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639850
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8639993
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640037
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640071
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640230
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640259
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640412
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640467
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640474
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640627
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640673
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640688
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640845
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640886
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8640908
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641098
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641121
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641314
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641325
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641489
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641556
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641558
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641707
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641758
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641783
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641980
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8641992
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642178
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642200
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642251
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642420
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642448
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642586
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642481
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642521
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642766
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642804
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642833
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642873
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642923
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642979
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8642999
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8643028
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/02314822-307C-4F66-BF0E-48AEAEB26CC8
+E: DEVPATH=/devices/virtual/wmi/02314822-307C-4F66-BF0E-48AEAEB26CC8
+E: MODALIAS=wmi:02314822-307C-4F66-BF0E-48AEAEB26CC8
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2D703EE8-36AC-4F88-BDB5-7556CE6B2946
+E: DEVPATH=/devices/virtual/wmi/2D703EE8-36AC-4F88-BDB5-7556CE6B2946
+E: MODALIAS=wmi:2D703EE8-36AC-4F88-BDB5-7556CE6B2946
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/96E2988F-E24D-49AF-84E2-7F3BF72602CD
+E: DEVPATH=/devices/virtual/wmi/96E2988F-E24D-49AF-84E2-7F3BF72602CD
+E: MODALIAS=wmi:96E2988F-E24D-49AF-84E2-7F3BF72602CD
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_VOSTRO3460_FINGERPRINT.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_VOSTRO3460_FINGERPRINT.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_VOSTRO3460_FINGERPRINT.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5373 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=578342
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+N: input/event3
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=579886
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/ADP0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/ADP0
+E: POWER_SUPPLY_NAME=ADP0
+E: POWER_SUPPLY_ONLINE=0
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input7
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input7
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10429533
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input7/event7
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10431390
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/SMO8810:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/SMO8810:00
+E: MODALIAS=acpi:SMO8810:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/DLL0562:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/DLL0562:00
+E: MODALIAS=acpi:DLL0562:PNP0F03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/MSFT0001:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/MSFT0001:00
+E: MODALIAS=acpi:MSFT0001:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C32:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C32:00
+E: MODALIAS=acpi:PNP0C32:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C32:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C32:01
+E: MODALIAS=acpi:PNP0C32:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:14/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:14/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e/device:0f/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:26/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:26/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:28/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CHARGE_FULL=4324000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=4324000
+E: POWER_SUPPLY_CHARGE_NOW=4324000
+E: POWER_SUPPLY_CURRENT_NOW=1000
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=SDI
+E: POWER_SUPPLY_MODEL_NAME=Dell
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=18019
+E: POWER_SUPPLY_STATUS=Full
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=11100000
+E: POWER_SUPPLY_VOLTAGE_NOW=12497000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=777471
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=781874
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=777796
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2/event2
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=781615
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=778003
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1/event1
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=782522
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:01
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000104sv00001028sd00000562bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0104
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000126sv00001028sd00000562bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0126
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10430490
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv00001028sd00000562bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-34-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-34-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-34-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=779326
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-34-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-34-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-34-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=779790
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv00001028sd00000562bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E2Dsv00001028sd00000562bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-34-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-34-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-34-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=780373
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=957012
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0011
+E: ID_MODEL_ENC=0011
+E: ID_MODEL_ID=0011
+E: ID_REVISION=0078
+E: ID_SERIAL=138a_0011_44b47a6651bd
+E: ID_SERIAL_SHORT=44b47a6651bd
+E: ID_USB_INTERFACES=:ff0000:
+E: ID_VENDOR=138a
+E: ID_VENDOR_ENC=138a
+E: ID_VENDOR_ID=138a
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=138a/11/78
+E: SUBSYSTEM=usb
+E: TYPE=255/17/255
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1367543
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/0/0
+E: MODALIAS=usb:v138Ap0011d0078dcFFdsc11dpFFicFFisc00ip00
+E: PRODUCT=138a/11/78
+E: SUBSYSTEM=usb
+E: TYPE=255/17/255
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0-CRW
+E: ID_MODEL_ENC=USB2.0-CRW
+E: ID_MODEL_ID=0129
+E: ID_REVISION=3960
+E: ID_SERIAL=Generic_USB2.0-CRW_20100201396000000
+E: ID_SERIAL_SHORT=20100201396000000
+E: ID_USB_INTERFACES=:ff0650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=0bda
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=bda/129/3960
+E: SUBSYSTEM=usb
+E: TYPE=255/255/255
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1529434
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=rts5139
+E: INTERFACE=255/6/80
+E: MODALIAS=usb:v0BDAp0129d3960dcFFdscFFdpFFicFFisc06ip50
+E: PRODUCT=bda/129/3960
+E: SUBSYSTEM=usb
+E: TYPE=255/255/255
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/scsi_host/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/scsi_host/host6
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-Generic_USB2.0-CRW_20100201396000000
+S: disk/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_USB2.0-CRW_20100201396000000 /dev/disk/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0-CRW
+E: ID_MODEL_ENC=USB2.0-CRW
+E: ID_MODEL_ID=0129
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.3:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_3_1_0-scsi-0_0_0_0
+E: ID_REVISION=3960
+E: ID_SERIAL=Generic_USB2.0-CRW_20100201396000000
+E: ID_SERIAL_SHORT=20100201396000000
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=rts5139
+E: ID_USB_INTERFACES=:ff0650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=9772486
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+N: bsg/6:0:0:0
+E: DEVNAME=/dev/bsg/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/usb/rts51x0
+N: rts51x0
+E: DEVNAME=/dev/rts51x0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/usb/rts51x0
+E: MAJOR=180
+E: MINOR=0
+E: SUBSYSTEM=usb
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5
+N: bus/usb/001/005
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ID=6449
+E: ID_REVISION=1c23
+E: ID_SERIAL=4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ENC=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ID=0c45
+E: MAJOR=189
+E: MINOR=4
+E: PRODUCT=c45/6449/1c23
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9676238
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v0C45p6449d1C23dcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=c45/6449/1c23
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input5
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ID=6449
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=1c23
+E: ID_SERIAL=4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ENC=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ID=0c45
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v0C45p6449e1C23-e0,1,kD4,ramlsfw
+E: NAME="Laptop_Integrated_Webcam_E4HD"
+E: PHYS="usb-0000:00:1a.0-1.5/button"
+E: PRODUCT=3/c45/6449/1c23
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9766187
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-event
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ID=6449
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=1c23
+E: ID_SERIAL=4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ENC=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ID=0c45
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9772287
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_E4HD
+E: ID_MODEL_ID=6449
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=1c23
+E: ID_SERIAL=4437E62E16DE-BC1C-0D3310_Laptop_Integrated_Webcam_E4HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Laptop_Integrated_Webcam_E4HD
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ENC=4437E62E16DE-BC1C-0D3310
+E: ID_VENDOR_ID=0c45
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9779905
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v0C45p6449d1C23dcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=c45/6449/1c23
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv00001028sd00000562bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Panther Point High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11075392
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10976573
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10976186
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10976175
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10977790
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10975839
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10978077
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10975727
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10978937
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10976250
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10975989
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10977091
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10976827
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv00001028sd00000562bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DRIVER=iwlwifi
+E: MODALIAS=pci:v00008086d00000887sv00008086sd00004462bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=8086:0887
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=8086:4462
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0/rfkill1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/ieee80211/phy0/rfkill1
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/leds/phy0-led
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/leds/phy0-led
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=Centrino Wireless-N 2230
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=4
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9837891
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E18sv00001028sd00000562bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E18
+E: PCI_SLOT_NAME=0000:00:1c.4
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:02:00.0
+E: DRIVER=alx
+E: MODALIAS=pci:v00001969d00001091sv00001028sd00000562bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=1969:1091
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:02:00.0/net/eth0
+E: COMMENT=PCI device 0x1969:/sys/devices/pci0000:00/0000:00:1c.4/0000:02:00.0 (alx)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:02:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=AR8161 Gigabit Ethernet
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.4/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=Atheros Communications Inc.
+E: ID_VENDOR_ID=0x1969
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9765488
+
+P: /devices/pci0000:00/0000:00:1c.4/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E26sv00001028sd00000562bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-34-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-34-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-34-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=781377
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1201016
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=07da
+E: ID_MODEL_ENC=07da
+E: ID_MODEL_ID=07da
+E: ID_REVISION=7869
+E: ID_SERIAL=8087_07da
+E: ID_USB_INTERFACES=:e00101:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=8087/7da/7869
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9655594
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v8087p07DAd7869dcE0dsc01dp01icE0isc01ip01
+E: PRODUCT=8087/7da/7869
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/bluetooth/hci0/rfkill0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/bluetooth/hci0/rfkill0
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v8087p07DAd7869dcE0dsc01dp01icE0isc01ip01
+E: PRODUCT=8087/7da/7869
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6
+N: bus/usb/002/004
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MM_ERICSSON_MBM=1
+E: ID_MODEL=DW5560
+E: ID_MODEL_ENC=DW5560
+E: ID_MODEL_ID=818e
+E: ID_REVISION=0000
+E: ID_SERIAL=Dell_DW5560_00E4CD51F65F91F0
+E: ID_SERIAL_SHORT=00E4CD51F65F91F0
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:0a0001:
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_ID=413c
+E: MAJOR=189
+E: MINOR=131
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9660356
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=2/8/0
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc08ip00
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=2/2/1
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc02ip01
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.1/tty/ttyACM0
+N: ttyACM0
+S: serial/by-id/usb-Dell_DW5560_00E4CD51F65F91F0-if01
+S: serial/by-path/pci-0000:00:1d.0-usb-0:1.6:1.1
+E: DEVLINKS=/dev/serial/by-id/usb-Dell_DW5560_00E4CD51F65F91F0-if01 /dev/serial/by-path/pci-0000:00:1d.0-usb-0:1.6:1.1
+E: DEVNAME=/dev/ttyACM0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.1/tty/ttyACM0
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=DW5560
+E: ID_MODEL_ENC=DW5560
+E: ID_MODEL_ID=818e
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.6:1.1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_6_1_1
+E: ID_REVISION=0000
+E: ID_SERIAL=Dell_DW5560_00E4CD51F65F91F0
+E: ID_SERIAL_SHORT=00E4CD51F65F91F0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_acm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:0a0001:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_FROM_DATABASE=Dell Computer Corp.
+E: ID_VENDOR_ID=413c
+E: MAJOR=166
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9785393
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.10
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.10
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=10/0/0
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic0Aisc00ip00
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.2
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=10/0/0
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic0Aisc00ip00
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.3
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=2/2/1
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc02ip01
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.3/tty/ttyACM1
+N: ttyACM1
+S: serial/by-id/usb-Dell_DW5560_00E4CD51F65F91F0-if03
+S: serial/by-path/pci-0000:00:1d.0-usb-0:1.6:1.3
+E: DEVLINKS=/dev/serial/by-id/usb-Dell_DW5560_00E4CD51F65F91F0-if03 /dev/serial/by-path/pci-0000:00:1d.0-usb-0:1.6:1.3
+E: DEVNAME=/dev/ttyACM1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.3/tty/ttyACM1
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=DW5560
+E: ID_MODEL_ENC=DW5560
+E: ID_MODEL_ID=818e
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.6:1.3
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_6_1_3
+E: ID_REVISION=0000
+E: ID_SERIAL=Dell_DW5560_00E4CD51F65F91F0
+E: ID_SERIAL_SHORT=00E4CD51F65F91F0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_acm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:0a0001:
+E: ID_USB_INTERFACE_NUM=03
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_FROM_DATABASE=Dell Computer Corp.
+E: ID_VENDOR_ID=413c
+E: MAJOR=166
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9787769
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.4
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=10/0/0
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic0Aisc00ip00
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.5
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.5
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_wdm
+E: INTERFACE=2/9/1
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc09ip01
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.5/usb/cdc-wdm1
+N: cdc-wdm1
+E: DEVNAME=/dev/cdc-wdm1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.5/usb/cdc-wdm1
+E: MAJOR=180
+E: MINOR=1
+E: SUBSYSTEM=usb
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.6
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_ncm
+E: INTERFACE=2/13/0
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc0Dip00
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.6/net/usb0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.6/net/usb0
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=DW5560
+E: ID_MODEL_ENC=DW5560
+E: ID_MODEL_ID=818e
+E: ID_REVISION=0000
+E: ID_SERIAL=Dell_DW5560_00E4CD51F65F91F0
+E: ID_SERIAL_SHORT=00E4CD51F65F91F0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_ncm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:0a0001:
+E: ID_USB_INTERFACE_NUM=06
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_FROM_DATABASE=Dell Computer Corp.
+E: ID_VENDOR_ID=413c
+E: IFINDEX=3
+E: INTERFACE=usb0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9787556
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.7
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.7
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_ncm
+E: INTERFACE=10/0/1
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic0Aisc00ip01
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.8
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.8
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_wdm
+E: INTERFACE=2/9/1
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc09ip01
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.8/usb/cdc-wdm2
+N: cdc-wdm2
+E: DEVNAME=/dev/cdc-wdm2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.8/usb/cdc-wdm2
+E: MAJOR=180
+E: MINOR=2
+E: SUBSYSTEM=usb
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.9
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.9
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=2/2/1
+E: MODALIAS=usb:v413Cp818Ed0000dc00dsc00dp00ic02isc02ip01
+E: PRODUCT=413c/818e/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.9/tty/ttyACM2
+N: ttyACM2
+S: serial/by-id/usb-Dell_DW5560_00E4CD51F65F91F0-if09
+S: serial/by-path/pci-0000:00:1d.0-usb-0:1.6:1.9
+E: DEVLINKS=/dev/serial/by-id/usb-Dell_DW5560_00E4CD51F65F91F0-if09 /dev/serial/by-path/pci-0000:00:1d.0-usb-0:1.6:1.9
+E: DEVNAME=/dev/ttyACM2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.6/2-1.6:1.9/tty/ttyACM2
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=DW5560
+E: ID_MODEL_ENC=DW5560
+E: ID_MODEL_ID=818e
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.6:1.9
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_6_1_9
+E: ID_REVISION=0000
+E: ID_SERIAL=Dell_DW5560_00E4CD51F65F91F0
+E: ID_SERIAL_SHORT=00E4CD51F65F91F0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_acm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:0a0001:
+E: ID_USB_INTERFACE_NUM=09
+E: ID_VENDOR=Dell
+E: ID_VENDOR_ENC=Dell
+E: ID_VENDOR_FROM_DATABASE=Dell Computer Corp.
+E: ID_VENDOR_ID=413c
+E: MAJOR=166
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9789469
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00001E57sv00001028sd00000562bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E57
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=Panther Point 6 port SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001E03sv00001028sd00000562bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1E03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9681462
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT
+S: disk/by-id/wwn-0x50000393a19032bd
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT /dev/disk/by-id/wwn-0x50000393a19032bd /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MK5061GSYN
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSYN\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MH000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_Y1CJT57QT
+E: ID_SERIAL=TOSHIBA_MK5061GSYN_Y1CJT57QT
+E: ID_SERIAL_SHORT=Y1CJT57QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393a19032bd
+E: ID_WWN_WITH_EXTENSION=0x50000393a19032bd
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1421753
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT-part1
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT-part1
+S: disk/by-id/wwn-0x50000393a19032bd-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/16bb812c-795e-4262-9328-8cfdc79c0cbf
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT-part1 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT-part1 /dev/disk/by-id/wwn-0x50000393a19032bd-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/16bb812c-795e-4262-9328-8cfdc79c0cbf
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=16bb812c-795e-4262-9328-8cfdc79c0cbf
+E: ID_FS_UUID_ENC=16bb812c-795e-4262-9328-8cfdc79c0cbf
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=TOSHIBA_MK5061GSYN
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSYN\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=968673280
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MH000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_Y1CJT57QT
+E: ID_SERIAL=TOSHIBA_MK5061GSYN_Y1CJT57QT
+E: ID_SERIAL_SHORT=Y1CJT57QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393a19032bd
+E: ID_WWN_WITH_EXTENSION=0x50000393a19032bd
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=495960719360
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1540013
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT-part2
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT-part2
+S: disk/by-id/wwn-0x50000393a19032bd-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT-part2 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT-part2 /dev/disk/by-id/wwn-0x50000393a19032bd-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MK5061GSYN
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSYN\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=968677374
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8093698
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MH000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_Y1CJT57QT
+E: ID_SERIAL=TOSHIBA_MK5061GSYN_Y1CJT57QT
+E: ID_SERIAL_SHORT=Y1CJT57QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393a19032bd
+E: ID_WWN_WITH_EXTENSION=0x50000393a19032bd
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=495962815488
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4143973376
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1445857
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT-part5
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT-part5
+S: disk/by-id/wwn-0x50000393a19032bd-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/bd7d419f-6c49-4e85-822e-ece1953b30e4
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSYN_Y1CJT57QT-part5 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_Y1CJT57QT-part5 /dev/disk/by-id/wwn-0x50000393a19032bd-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/bd7d419f-6c49-4e85-822e-ece1953b30e4
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=122
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=bd7d419f-6c49-4e85-822e-ece1953b30e4
+E: ID_FS_UUID_ENC=bd7d419f-6c49-4e85-822e-ece1953b30e4
+E: ID_FS_VERSION=2
+E: ID_MODEL=TOSHIBA_MK5061GSYN
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSYN\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=968677376
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8093696
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MH000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_Y1CJT57QT
+E: ID_SERIAL=TOSHIBA_MK5061GSYN_Y1CJT57QT
+E: ID_SERIAL_SHORT=Y1CJT57QT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393a19032bd
+E: ID_WWN_WITH_EXTENSION=0x50000393a19032bd
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=495962816512
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4143972352
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1567036
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-TSSTcorp_DVD+_-RW_SN-208BB_R8KL6GLB920966
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-TSSTcorp_DVD+_-RW_SN-208BB_R8KL6GLB920966 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=TSSTcorp_DVD+_-RW_SN-208BB
+E: ID_MODEL_ENC=TSSTcorp\x20DVD+\x2f-RW\x20SN-208BB\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=D100
+E: ID_SERIAL=TSSTcorp_DVD+_-RW_SN-208BB_R8KL6GLB920966
+E: ID_SERIAL_SHORT=R8KL6GLB920966
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1302974
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/bsg/3:0:0:0
+N: bsg/3:0:0:0
+E: DEVNAME=/dev/bsg/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/bsg/3:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/scsi_device/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/scsi_device/3:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/target3:0:0/3:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9691131
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv00001028sd00000562bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1028:0562
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon1
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop
+E: DEVPATH=/devices/platform/dell-laptop
+E: DRIVER=dell-laptop
+E: MODALIAS=platform:dell-laptop
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop/leds/dell-laptop::touchpad
+E: DEVPATH=/devices/platform/dell-laptop/leds/dell-laptop::touchpad
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Dell Inc.
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9659395
+
+P: /devices/platform/i8042/serio0/input/input4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=1100f02902002 8380307cf910f001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB83-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8D,8E,8F,94,98,9B,9C,9D,9E,9F,A2,A3,A4,A5,A6,AC,AD,B7,B8,B9,BF,C1,CD,D4,D7,D9,E0,E1,E2,E3,EC,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab83
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=787992
+
+P: /devices/platform/i8042/serio0/input/input4/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4/event4
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=790063
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input8
+E: DEVPATH=/devices/platform/i8042/serio1/input/input8
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0001e0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="PS/2 Generic Mouse"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/1/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10665547
+
+P: /devices/platform/i8042/serio1/input/input8/event8
+N: input/event8
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/platform/i8042/serio1/input/input8/event8
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10695340
+
+P: /devices/platform/i8042/serio1/input/input8/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input8/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10667115
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9668480
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9677026
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9678761
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9679442
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9679496
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9680392
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9681097
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9692511
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9688193
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9689085
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9691456
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9691518
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9691956
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9692301
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9692595
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9692903
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9693189
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9693477
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9693767
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9694046
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9694332
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9694977
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9694984
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9695329
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9695641
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9695976
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9696332
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9696667
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9696991
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9697298
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9698088
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9698596
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:05/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=789089
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory22
+E: DEVPATH=/devices/system/memory/memory22
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory23
+E: DEVPATH=/devices/system/memory/memory23
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:19
+E: DEVPATH=/devices/virtual/bdi/0:19
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=566472
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=566591
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=566684
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=566778
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=566882
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=566977
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=567078
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=567169
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567248
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567334
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567427
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567525
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567620
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567715
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567813
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=567916
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568042
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568143
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568231
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568325
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=577139
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568460
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568552
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568647
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrX58:bd07/24/2012:svnDellInc.:pnVostro3460:pvr:rvnDellInc.:rn:rvr:cvnDellInc.:ct8:cvr0.1:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input6
+E: DEVPATH=/devices/virtual/input/input6
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=1500b00000000 200300000 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k94,95,A1,E0,E1,E3,EC,EE,F0,ram4,lsfw
+E: MSC=10
+E: NAME="Dell WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9856042
+
+P: /devices/virtual/input/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/virtual/input/input6/event6
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9857330
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9825384
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9720346
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9720830
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9757338
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9752624
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone1
+E: DEVPATH=/devices/virtual/thermal/thermal_zone1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9722066
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9722335
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9722966
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9723662
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9724065
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9724649
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9724773
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725040
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725078
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725343
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725386
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725651
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725701
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9725963
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9726015
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9726271
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9726612
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9726901
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9726714
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9726753
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727019
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727067
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727342
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727591
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727439
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727558
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727818
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9727858
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9728148
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9728383
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9728232
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9732263
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9732537
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9732800
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9733067
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9733681
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9733945
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9734213
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9734796
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9735078
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9735341
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9735648
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9735919
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9736596
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9736898
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9737168
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9737476
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9737867
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9738159
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9738475
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9738531
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9738570
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9738782
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9739131
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9743843
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740237
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740279
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740484
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740373
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740671
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740690
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740889
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9740775
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9741086
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9741075
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9741342
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9741377
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9741637
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2FAE25E0-C342-4F49-AD2F-0F06A958721A
+E: DEVPATH=/devices/virtual/wmi/2FAE25E0-C342-4F49-AD2F-0F06A958721A
+E: MODALIAS=wmi:2FAE25E0-C342-4F49-AD2F-0F06A958721A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/72E6BB2F-8380-46B2-9A9F-6D3F513223E7
+E: DEVPATH=/devices/virtual/wmi/72E6BB2F-8380-46B2-9A9F-6D3F513223E7
+E: MODALIAS=wmi:72E6BB2F-8380-46B2-9A9F-6D3F513223E7
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:9DBB5994-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: DEVPATH=/devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: MODALIAS=wmi:A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:A80593CE-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/DD8C7670-1CB5-11DB-A98B-669A0C200008
+E: DEVPATH=/devices/virtual/wmi/DD8C7670-1CB5-11DB-A98B-669A0C200008
+E: MODALIAS=wmi:DD8C7670-1CB5-11DB-A98B-669A0C200008
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_VOSTROV131.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_VOSTROV131.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_VOSTROV131.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5357 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-LNXPWRBN_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5740698
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+N: input/event3
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5751812
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input5
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input5
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-LNXVIDEO_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6957733
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input5/event5
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6959619
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/SMO8800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/SMO8800:00
+E: MODALIAS=acpi:SMO8800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/DLL0510:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/DLL0510:00
+E: MODALIAS=acpi:DLL0510:SYN0600:SYN0002:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0303:00
+E: MODALIAS=acpi:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:25/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:25/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:25/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:25/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2d/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2d/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2d/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2d/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a/device:3b/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:47
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:47
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:48
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:48
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:49
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:49
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:4a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:4a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:4b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:4b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:4c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43/device:44/device:4c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CAPACITY=77
+E: POWER_SUPPLY_CHARGE_FULL=4774000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=5900000
+E: POWER_SUPPLY_CHARGE_NOW=3699000
+E: POWER_SUPPLY_CURRENT_NOW=592000
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=    
+E: POWER_SUPPLY_MODEL_NAME=DELL HK3RG13
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=54085
+E: POWER_SUPPLY_STATUS=Charging
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=11100000
+E: POWER_SUPPLY_VOLTAGE_NOW=13018000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-PNP0C0C_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5716107
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1/event1
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5787764
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_FOR_SEAT=input-acpi-PNP0C0D_00
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5716212
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5786162
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input2
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-PNP0C0E_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5716316
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input2/event2
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5789224
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000104sv00001028sd00000510bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0104
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000116sv00001028sd00000510bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0116
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: ID_FOR_SEAT=drm-pci-0000_00_02_0
+E: ID_PATH=pci-0000:00:02.0
+E: ID_PATH_TAG=pci-0000_00_02_0
+E: MAJOR=226
+E: MINOR=0
+E: PRIMARY_DEVICE_FOR_DISPLAY=1
+E: SUBSYSTEM=drm
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19694155
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: ID_FOR_SEAT=graphics-pci-0000_00_02_0
+E: ID_PATH=pci-0000:00:02.0
+E: ID_PATH_TAG=pci-0000_00_02_0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: TAGS=:master-of-seat:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19686550
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001C3Asv00001028sd00000510bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1C3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001C2Dsv00001028sd00000510bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1C2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1a_0
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:1a.0
+E: ID_PATH_TAG=pci-0000_00_1a_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5726386
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1a_0-usb-0_1
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6114553
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+N: bus/usb/001/005
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=3005
+E: ID_MODEL_ENC=3005
+E: ID_MODEL_ID=3005
+E: ID_REVISION=0001
+E: ID_SERIAL=0cf3_3005
+E: ID_USB_INTERFACES=:e00101:
+E: ID_VENDOR=0cf3
+E: ID_VENDOR_ENC=0cf3
+E: ID_VENDOR_ID=0cf3
+E: MAJOR=189
+E: MINOR=4
+E: PRODUCT=cf3/3005/1
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21554973
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0CF3p3005d0001dcE0dsc01dp01icE0isc01ip01in00
+E: PRODUCT=cf3/3005/1
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill2
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0CF3p3005d0001dcE0dsc01dp01icE0isc01ip01in01
+E: PRODUCT=cf3/3005/1
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=6442
+E: ID_REVISION=1315
+E: ID_SERIAL=001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=001731C3913D-B40D-12131E
+E: ID_VENDOR_ENC=001731C3913D-B40D-12131E
+E: ID_VENDOR_ID=0c45
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=c45/6442/1315
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6739467
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v0C45p6442d1315dcEFdsc02dp01ic0Eisc01ip00in00
+E: PRODUCT=c45/6442/1315
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input9
+E: EV=3
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=6442
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=1315
+E: ID_SERIAL=001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=001731C3913D-B40D-12131E
+E: ID_VENDOR_ENC=001731C3913D-B40D-12131E
+E: ID_VENDOR_ID=0c45
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v0C45p6442e1315-e0,1,kD4,ramlsfw
+E: NAME="Laptop_Integrated_Webcam_HD"
+E: PHYS="usb-0000:00:1a.0-1.5/button"
+E: PRODUCT=3/c45/6442/1315
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21446400
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input9/event9
+N: input/event9
+S: input/by-id/usb-001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-event
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/input/input9/event9
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=6442
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=1315
+E: ID_SERIAL=001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=001731C3913D-B40D-12131E
+E: ID_VENDOR_ENC=001731C3913D-B40D-12131E
+E: ID_VENDOR_ID=0c45
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21504391
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.5:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_FOR_SEAT=video4linux-pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_MODEL=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ENC=Laptop_Integrated_Webcam_HD
+E: ID_MODEL_ID=6442
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.5:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_5_1_0
+E: ID_REVISION=1315
+E: ID_SERIAL=001731C3913D-B40D-12131E_Laptop_Integrated_Webcam_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Laptop_Integrated_Webcam_HD
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=001731C3913D-B40D-12131E
+E: ID_VENDOR_ENC=001731C3913D-B40D-12131E
+E: ID_VENDOR_ID=0c45
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21519447
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.5/1-1.5:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v0C45p6442d1315dcEFdsc02dp01ic0Eisc02ip00in01
+E: PRODUCT=c45/6442/1315
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001C20sv00001028sd00000510bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1C20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_FOR_SEAT=sound-pci-0000_00_1b_0
+E: ID_MODEL_FROM_DATABASE=6 Series/C200 Series Chipset Family High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21432463
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21434753
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21434808
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21441520
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21504341
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21433824
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21434235
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21433697
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21435236
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C10sv00001028sd00000510bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C12sv00001028sd00000510bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:05:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:05:00.0
+E: DRIVER=r8169
+E: MODALIAS=pci:v000010ECd00008168sv00001028sd00000510bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8168
+E: PCI_SLOT_NAME=0000:05:00.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:05:00.0/net/eth0
+E: COMMENT=PCI device 0x10ec:/sys/devices/pci0000:00/0000:00:1c.1/0000:05:00.0 (r8169)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:05:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8111/8168 PCI Express Gigabit Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:05:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: MATCHADDR=78:2b:cb:f7:fb:16
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=20103254
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:05
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:05
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C16sv00001028sd00000510bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C16
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:09:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:09:00.0
+E: DRIVER=ath9k
+E: MODALIAS=pci:v0000168Cd0000002Bsv00001028sd00000205bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=168C:002B
+E: PCI_SLOT_NAME=0000:09:00.0
+E: PCI_SUBSYS_ID=1028:0205
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:09:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:09:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:09:00.0/ieee80211/phy0/rfkill1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:09:00.0/ieee80211/phy0/rfkill1
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:09:00.0/leds/ath9k-phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:09:00.0/leds/ath9k-phy0
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:09:00.0/net/wlan0
+E: COMMENT=PCI device 0x168c:/sys/devices/pci0000:00/0000:00:1c.3/0000:09:00.0 (ath9k)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:09:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=AR9285 Wireless Network Adapter (PCI-Express)
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.3/0000:09:00.0
+E: ID_VENDOR_FROM_DATABASE=Atheros Communications Inc.
+E: ID_VENDOR_ID=0x168c
+E: IFINDEX=4
+E: INTERFACE=wlan0
+E: MATCHADDR=c0:f8:da:5d:0b:9b
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21585634
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:09
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:09
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C18sv00001028sd00000510bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C18
+E: PCI_SLOT_NAME=0000:00:1c.4
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0b:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0b:00.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v0000104Cd00008241sv00001028sd00000510bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=104C:8241
+E: PCI_SLOT_NAME=0000:0b:00.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_0b_00_0
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:0b:00.0
+E: ID_PATH_TAG=pci-0000_0b_00_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_xhci_hcd_xHCI_Host_Controller_0000:0b:00.0
+E: ID_SERIAL_SHORT=0000:0b:00.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5786584
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_0b_00_0
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_PATH=pci-0000:0b:00.0
+E: ID_PATH_TAG=pci-0000_0b_00_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_xhci_hcd_xHCI_Host_Controller_0000:0b:00.0
+E: ID_SERIAL_SHORT=0000:0b:00.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5786970
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0b:00.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0308dc09dsc00dp03ic09isc00ip00in00
+E: PRODUCT=1d6b/3/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/pci_bus/0000:0b
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/pci_bus/0000:0b
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.7
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.7
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C1Esv00001028sd00000510bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C1E
+E: PCI_SLOT_NAME=0000:00:1c.7
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.7/0000:00:1c.7:pcie04
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.7/0000:00:1c.7:pcie04
+E: DRIVER=pciehp
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.7/pci_bus/0000:11
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.7/pci_bus/0000:11
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001C26sv00001028sd00000510bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1C26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1d_0
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:1d.0
+E: ID_PATH_TAG=pci-0000_00_1d_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5741448
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1d_0-usb-0_1
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6357116
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Mass_Storage
+E: ID_MODEL_ENC=Mass\x20Storage
+E: ID_MODEL_ID=6387
+E: ID_REVISION=0103
+E: ID_SERIAL=Generic_Mass_Storage_EEA1EE5B
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=058f
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=58f/6387/103
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6997417
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v058Fp6387d0103dc00dsc00dp00ic08isc06ip50in00
+E: PRODUCT=58f/6387/103
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/scsi_host/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/scsi_host/host6
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0
+S: disk/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0 /dev/disk/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Flash_Disk
+E: ID_MODEL_ENC=Flash\x20Disk\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=6387
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8.07
+E: ID_SERIAL=Generic_Flash_Disk_EEA1EE5B-0:0
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=058f
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8174123
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+N: sdb1
+S: disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0-part1
+S: disk/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/613D-C101
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Flash_Disk_EEA1EE5B-0:0-part1 /dev/disk/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/613D-C101
+E: DEVNAME=/dev/sdb1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=613D-C101
+E: ID_FS_UUID_ENC=613D-C101
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Flash_Disk
+E: ID_MODEL_ENC=Flash\x20Disk\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=6387
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=62
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=4011586
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8.07
+E: ID_SERIAL=Generic_Flash_Disk_EEA1EE5B-0:0
+E: ID_SERIAL_SHORT=EEA1EE5B
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=058f
+E: MAJOR=8
+E: MINOR=17
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=31744
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2053932032
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=8260671
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+N: bsg/6:0:0:0
+E: DEVNAME=/dev/bsg/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.2/2-1.2:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.3
+N: bus/usb/002/004
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0011
+E: ID_MODEL_ENC=0011
+E: ID_MODEL_ID=0011
+E: ID_REVISION=0078
+E: ID_SERIAL=138a_0011_6730c2f90f1b
+E: ID_SERIAL_SHORT=6730c2f90f1b
+E: ID_USB_INTERFACES=:ff0000:
+E: ID_VENDOR=138a
+E: ID_VENDOR_ENC=138a
+E: ID_VENDOR_ID=138a
+E: MAJOR=189
+E: MINOR=131
+E: PRODUCT=138a/11/78
+E: SUBSYSTEM=usb
+E: TYPE=255/17/255
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7162269
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.3/2-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.3/2-1.3:1.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/0/0
+E: MODALIAS=usb:v138Ap0011d0078dcFFdsc11dpFFicFFisc00ip00in00
+E: PRODUCT=138a/11/78
+E: SUBSYSTEM=usb
+E: TYPE=255/17/255
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5
+N: bus/usb/002/005
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Intel_R__Centrino_R__Wireless-N_+_WiMAX_6150
+E: ID_MODEL_ENC=Intel\x28R\x29\x20Centrino\x28R\x29\x20Wireless-N\x20+\x20WiMAX\x206150
+E: ID_MODEL_ID=07d9
+E: ID_REVISION=0000
+E: ID_SERIAL=Intel_Corporation_Intel_R__Centrino_R__Wireless-N_+_WiMAX_6150
+E: ID_USB_INTERFACES=:ff0000:
+E: ID_VENDOR=Intel_Corporation
+E: ID_VENDOR_ENC=Intel\x20Corporation
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=132
+E: PRODUCT=8087/7d9/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7325337
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=i2400m_usb
+E: INTERFACE=255/0/0
+E: MODALIAS=usb:v8087p07D9d0000dc00dsc00dp00icFFisc00ip00in00
+E: PRODUCT=8087/7d9/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/net/wmx0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/net/wmx0
+E: DEVTYPE=wimax
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=Intel_R__Centrino_R__Wireless-N_+_WiMAX_6150
+E: ID_MODEL_ENC=Intel\x28R\x29\x20Centrino\x28R\x29\x20Wireless-N\x20+\x20WiMAX\x206150
+E: ID_MODEL_ID=07d9
+E: ID_REVISION=0000
+E: ID_SERIAL=Intel_Corporation_Intel_R__Centrino_R__Wireless-N_+_WiMAX_6150
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=i2400m_usb
+E: ID_USB_INTERFACES=:ff0000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Intel_Corporation
+E: ID_VENDOR_ENC=Intel\x20Corporation
+E: ID_VENDOR_FROM_DATABASE=Intel Corp.
+E: ID_VENDOR_ID=8087
+E: IFINDEX=3
+E: INTERFACE=wmx0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=25003906
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/rfkill/rfkill0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.5/2-1.5:1.0/rfkill/rfkill0
+E: RFKILL_NAME=i2400m-usb:2-1.5:1.0
+E: RFKILL_STATE=0
+E: RFKILL_TYPE=wimax
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: DRIVER=lpc_ich
+E: MODALIAS=pci:v00008086d00001C4Bsv00001028sd00000510bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1C4B
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVTYPE=mfd_device
+E: MODALIAS=platform:iTCO_wdt
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=6 Series/C200 Series Chipset Family 6 port SATA AHCI Controller
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001C03sv00001028sd00000510bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1C03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19699985
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT
+S: disk/by-id/wwn-0x5000039331685398
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT /dev/disk/by-id/wwn-0x5000039331685398 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MK5061GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_41GET3OLT
+E: ID_SERIAL=TOSHIBA_MK5061GSY_41GET3OLT
+E: ID_SERIAL_SHORT=41GET3OLT
+E: ID_TYPE=disk
+E: ID_WWN=0x5000039331685398
+E: ID_WWN_WITH_EXTENSION=0x5000039331685398
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=4
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7182294
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part1
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part1
+S: disk/by-id/wwn-0x5000039331685398-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/be88c3db-0a6b-4c94-b6c3-0b14a051b8aa
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part1 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part1 /dev/disk/by-id/wwn-0x5000039331685398-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/be88c3db-0a6b-4c94-b6c3-0b14a051b8aa
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=be88c3db-0a6b-4c94-b6c3-0b14a051b8aa
+E: ID_FS_UUID_ENC=be88c3db-0a6b-4c94-b6c3-0b14a051b8aa
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=TOSHIBA_MK5061GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=491147085
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_41GET3OLT
+E: ID_SERIAL=TOSHIBA_MK5061GSY_41GET3OLT
+E: ID_SERIAL_SHORT=41GET3OLT
+E: ID_TYPE=disk
+E: ID_WWN=0x5000039331685398
+E: ID_WWN_WITH_EXTENSION=0x5000039331685398
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=251467307520
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7367727
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part2
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part2
+S: disk/by-id/wwn-0x5000039331685398-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part2 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part2 /dev/disk/by-id/wwn-0x5000039331685398-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MK5061GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=491149310
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=485621762
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_41GET3OLT
+E: ID_SERIAL=TOSHIBA_MK5061GSY_41GET3OLT
+E: ID_SERIAL_SHORT=41GET3OLT
+E: ID_TYPE=disk
+E: ID_WWN=0x5000039331685398
+E: ID_WWN_WITH_EXTENSION=0x5000039331685398
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=251468446720
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=248638342144
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7250155
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part5
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part5
+S: disk/by-id/wwn-0x5000039331685398-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/a556471f-ff00-4d0d-ad6a-8b94032f1f0b
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part5 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part5 /dev/disk/by-id/wwn-0x5000039331685398-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/a556471f-ff00-4d0d-ad6a-8b94032f1f0b
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=a556471f-ff00-4d0d-ad6a-8b94032f1f0b
+E: ID_FS_UUID_ENC=a556471f-ff00-4d0d-ad6a-8b94032f1f0b
+E: ID_FS_VERSION=2
+E: ID_MODEL=TOSHIBA_MK5061GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=968579072
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8192000
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_41GET3OLT
+E: ID_SERIAL=TOSHIBA_MK5061GSY_41GET3OLT
+E: ID_SERIAL_SHORT=41GET3OLT
+E: ID_TYPE=disk
+E: ID_WWN=0x5000039331685398
+E: ID_WWN_WITH_EXTENSION=0x5000039331685398
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=495912484864
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4194304000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7332111
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda6
+N: sda6
+S: disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part6
+S: disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part6
+S: disk/by-id/wwn-0x5000039331685398-part6
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part6
+S: disk/by-uuid/656cc45d-2f4e-4b5f-b3cd-e97e575417b9
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MK5061GSY_41GET3OLT-part6 /dev/disk/by-id/scsi-SATA_TOSHIBA_MK5061G_41GET3OLT-part6 /dev/disk/by-id/wwn-0x5000039331685398-part6 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part6 /dev/disk/by-uuid/656cc45d-2f4e-4b5f-b3cd-e97e575417b9
+E: DEVNAME=/dev/sda6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda6
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=128
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=656cc45d-2f4e-4b5f-b3cd-e97e575417b9
+E: ID_FS_UUID_ENC=656cc45d-2f4e-4b5f-b3cd-e97e575417b9
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=TOSHIBA_MK5061GSY
+E: ID_MODEL_ENC=TOSHIBA\x20MK5061GSY\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=6
+E: ID_PART_ENTRY_OFFSET=491149312
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=477429760
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=MC000D
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MK5061G_41GET3OLT
+E: ID_SERIAL=TOSHIBA_MK5061GSY_41GET3OLT
+E: ID_SERIAL_SHORT=41GET3OLT
+E: ID_TYPE=disk
+E: ID_WWN=0x5000039331685398
+E: ID_WWN_WITH_EXTENSION=0x5000039331685398
+E: MAJOR=8
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=6
+E: UDISKS_PARTITION_OFFSET=251468447744
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=244444037120
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=7399010
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001C22sv00001028sd00000510bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1C22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1028:0510
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon1
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop
+E: DEVPATH=/devices/platform/dell-laptop
+E: DRIVER=dell-laptop
+E: MODALIAS=platform:dell-laptop
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop/leds/dell-laptop::touchpad
+E: DEVPATH=/devices/platform/dell-laptop/leds/dell-laptop::touchpad
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Dell Inc.
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19740528
+
+P: /devices/platform/i8042/serio0/input/input4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4
+E: EV=120013
+E: ID_FOR_SEAT=input-platform-i8042-serio-0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=1100f02902002 8380307cf910f001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8D,8E,8F,94,98,9B,9C,9D,9E,9F,A2,A3,A4,A5,A6,AC,AD,B7,B8,B9,BF,C1,CD,D4,D7,D9,E0,E1,E2,E3,EC,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5742217
+
+P: /devices/platform/i8042/serio0/input/input4/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4/event4
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5788459
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input7
+E: ABS=260800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input7
+E: EV=b
+E: ID_FOR_SEAT=input-platform-i8042-serio-1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=6420 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=9
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21190308
+
+P: /devices/platform/i8042/serio1/input/input7/event7
+N: input/event7
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/platform/i8042/serio1/input/input7/event7
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21326811
+
+P: /devices/platform/i8042/serio1/input/input7/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input7/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21327531
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19739046
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19739581
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19739746
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19741004
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19741511
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19742070
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19742687
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19742814
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19743284
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19743526
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19743983
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19744228
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19744810
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19745312
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19745896
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19746395
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19746521
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19747045
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19747450
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19747325
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19748110
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19748651
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19748399
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19749476
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19749550
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19749737
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19751033
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19750426
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19751005
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19753400
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19751664
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19752175
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:04/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5767824
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory22
+E: DEVPATH=/devices/system/memory/memory22
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory23
+E: DEVPATH=/devices/system/memory/memory23
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory24
+E: DEVPATH=/devices/system/memory/memory24
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory25
+E: DEVPATH=/devices/system/memory/memory25
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory26
+E: DEVPATH=/devices/system/memory/memory26
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory27
+E: DEVPATH=/devices/system/memory/memory27
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/uncore_cbox_0
+E: DEVPATH=/devices/uncore_cbox_0
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/uncore_cbox_1
+E: DEVPATH=/devices/uncore_cbox_1
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:24
+E: DEVPATH=/devices/virtual/bdi/0:24
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: ID_FS_TYPE=squashfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_VERSION=1024.0
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5703869
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5703985
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5704134
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5704273
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5704399
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5704536
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5704670
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=5704803
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5704930
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705061
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705187
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705312
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705443
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705601
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705737
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5705877
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706014
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706149
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706277
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706410
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706541
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706678
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706808
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5706955
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrA04:bd12/12/2011:svnDellInc.:pnVostroV131:pvrNotSpecified:rvnDellInc.:rn4ND010:rvrA04:cvnDellInc.:ct8:cvrNotSpecified:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input6
+E: DEVPATH=/devices/virtual/input/input6
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=1500b00000000 200300000 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k94,95,A1,E0,E1,E3,EC,EE,F0,ram4,lsfw
+E: MSC=10
+E: NAME="Dell WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=20210725
+
+P: /devices/virtual/input/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/virtual/input/input6/event6
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=20259551
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=20796798
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19809701
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19811117
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=20789531
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=20715804
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19813810
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19812893
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19814559
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19813892
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19812975
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19814305
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19814697
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19814458
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19815078
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19815553
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19815857
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19816201
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19816564
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19839540
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19817324
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19817852
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19820297
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19819746
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19826481
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19828492
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19841737
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19841219
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19865041
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19847218
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19846896
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19849548
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19849290
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19850861
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19850566
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19850259
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19855544
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19855241
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19854917
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19856193
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19857690
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19858194
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19857245
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19859921
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19859516
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19859109
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19865619
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19866387
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19871136
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19871703
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19872209
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19872711
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19873404
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19873901
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19874390
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19874863
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19875598
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19876087
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19876913
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19876743
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19876886
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19877371
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19877824
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19878001
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19878575
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19878697
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19879137
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19879451
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19879416
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19879860
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19880722
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19880252
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19881099
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=19881580
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/77BD0728-2E34-478C-B625-67F02A7E4897
+E: DEVPATH=/devices/virtual/wmi/77BD0728-2E34-478C-B625-67F02A7E4897
+E: MODALIAS=wmi:77BD0728-2E34-478C-B625-67F02A7E4897
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:9DBB5994-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: DEVPATH=/devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: MODALIAS=wmi:A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:A80593CE-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_XPS1340.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_XPS1340.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/DELL_XPS1340.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5621 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1324774
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+N: input/event3
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1377393
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/ITE8708:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/ITE8708:00
+E: MODALIAS=acpi:ITE8708:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:08
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:09
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0a
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0b
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0c
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0d
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0e
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:0f
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:10
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:11
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:12
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:13
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:14
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:15
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:16
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:17
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:18
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:19
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1a
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1b
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1c
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1d
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1e
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:1f
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:20
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:21
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:22
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:23
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:24
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:25
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:26
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:27
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:28
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:29
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:2a
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C0F:2b
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C14:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C14:01
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C14:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C14:02
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/device:06/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/device:06/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/input/input8
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/input/input8
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21950231
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/input/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LNXVIDEO:00/input/input8/event8
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22148310
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/input/input9
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/input/input9
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:01
+E: ID_PATH_TAG=acpi-LNXVIDEO_01
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21948859
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/input/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:11/LNXVIDEO:01/input/input9/event9
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:01
+E: ID_PATH_TAG=acpi-LNXVIDEO_01
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22148037
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:26/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:26/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:26/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:26/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0303:00
+E: MODALIAS=acpi:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/ACPI0003:00/power_supply/ADP0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/ACPI0003:00/power_supply/ADP0
+E: POWER_SUPPLY_NAME=ADP0
+E: POWER_SUPPLY_ONLINE=0
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CHARGE_FULL=4353000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=5661000
+E: POWER_SUPPLY_CHARGE_NOW=4198000
+E: POWER_SUPPLY_CURRENT_NOW=1813000
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=PANASONIC
+E: POWER_SUPPLY_MODEL_NAME=Dell
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=28703
+E: POWER_SUPPLY_STATUS=Discharging
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=11100000
+E: POWER_SUPPLY_VOLTAGE_NOW=11902000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C0E:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C0E:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1383732
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C0E:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0C0E:00/input/input1/event1
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1405910
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0F13:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/PNP0F13:00
+E: MODALIAS=acpi:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1321333
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1404820
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1321391
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input2/event2
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1406309
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v000010DEd00000A82sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=10DE:0A82
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.1
+E: DEVPATH=/devices/pci0000:00/0000:00:00.1
+E: MODALIAS=pci:v000010DEd00000A88sv00000000sd00000000bc05sc00i00
+E: PCI_CLASS=50000
+E: PCI_ID=10DE:0A88
+E: PCI_SLOT_NAME=0000:00:00.1
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.0
+E: DEVPATH=/devices/pci0000:00/0000:00:03.0
+E: MODALIAS=pci:v000010DEd00000AAEsv00001028sd00000271bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=10DE:0AAE
+E: PCI_SLOT_NAME=0000:00:03.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.1
+E: DEVPATH=/devices/pci0000:00/0000:00:03.1
+E: MODALIAS=pci:v000010DEd00000AA4sv00001028sd00000271bc05sc00i00
+E: PCI_CLASS=50000
+E: PCI_ID=10DE:0AA4
+E: PCI_SLOT_NAME=0000:00:03.1
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.2
+E: DEVPATH=/devices/pci0000:00/0000:00:03.2
+E: DRIVER=nForce2_smbus
+E: MODALIAS=pci:v000010DEd00000AA2sv00001028sd00000271bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=10DE:0AA2
+E: PCI_SLOT_NAME=0000:00:03.2
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.2/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:03.2/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.2/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:03.2/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.3
+E: DEVPATH=/devices/pci0000:00/0000:00:03.3
+E: MODALIAS=pci:v000010DEd00000A89sv00001028sd00000271bc05sc00i00
+E: PCI_CLASS=50000
+E: PCI_ID=10DE:0A89
+E: PCI_SLOT_NAME=0000:00:03.3
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:03.5
+E: DEVPATH=/devices/pci0000:00/0000:00:03.5
+E: DRIVER=nvidia
+E: MODALIAS=pci:v000010DEd00000AA3sv00001028sd00000271bc0Bsc40i00
+E: PCI_CLASS=B4000
+E: PCI_ID=10DE:0AA3
+E: PCI_SLOT_NAME=0000:00:03.5
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0
+E: DRIVER=ohci_hcd
+E: MODALIAS=pci:v000010DEd00000AA5sv00001028sd00000271bc0Csc03i10
+E: PCI_CLASS=C0310
+E: PCI_ID=10DE:0AA5
+E: PCI_SLOT_NAME=0000:00:04.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OHCI_Host_Controller
+E: ID_MODEL_ENC=OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-40-generic_ohci_hcd_OHCI_Host_Controller_0000:00:04.0
+E: ID_SERIAL_SHORT=0000:00:04.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-40-generic_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-40-generic\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1406365
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4
+N: bus/usb/003/002
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BCM2046B1
+E: ID_MODEL_ENC=BCM2046B1
+E: ID_MODEL_ID=4500
+E: ID_REVISION=0100
+E: ID_SERIAL=Broadcom_BCM2046B1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Broadcom
+E: ID_VENDOR_ENC=Broadcom
+E: ID_VENDOR_ID=0a5c
+E: MAJOR=189
+E: MINOR=257
+E: PRODUCT=a5c/4500/100
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1588594
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1
+N: bus/usb/003/003
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=8157
+E: ID_MODEL_ENC=8157
+E: ID_MODEL_ID=8157
+E: ID_REVISION=0100
+E: ID_SERIAL=413c_8157
+E: ID_USB_INTERFACES=:030101:
+E: ID_VENDOR=413c
+E: ID_VENDOR_ENC=413c
+E: ID_VENDOR_ID=413c
+E: MAJOR=189
+E: MINOR=258
+E: PRODUCT=413c/8157/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2009459
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/1
+E: MODALIAS=usb:v413Cp8157d0100dc00dsc00dp00ic03isc01ip01
+E: PRODUCT=413c/8157/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/0003:413C:8157.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/0003:413C:8157.0001
+E: DRIVER=generic-usb
+E: HID_ID=0003:0000413C:00008157
+E: HID_NAME=HID 413c:8157
+E: HID_PHYS=usb-0000:00:04.0-4.1/input0
+E: MODALIAS=hid:b0003v0000413Cp00008157
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/0003:413C:8157.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/0003:413C:8157.0001/hidraw/hidraw0
+E: MAJOR=250
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/input/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/input/input5
+E: EV=120013
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=8157
+E: ID_MODEL_ENC=8157
+E: ID_MODEL_ID=8157
+E: ID_PATH=pci-0000:00:04.0-usb-0:4.1:1.0
+E: ID_PATH_TAG=pci-0000_00_04_0-usb-0_4_1_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=413c_8157
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=413c
+E: ID_VENDOR_ENC=413c
+E: ID_VENDOR_ID=413c
+E: KEY=1000000000007 ff800000000007ff febeffdff3cfffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0003v413Cp8157e0111-e0,1,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="HID 413c:8157"
+E: PHYS="usb-0000:00:04.0-4.1/input0"
+E: PRODUCT=3/413c/8157/111
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=2020067
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-413c_8157-event-kbd
+S: input/by-path/pci-0000:00:04.0-usb-0:4.1:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-413c_8157-event-kbd /dev/input/by-path/pci-0000:00:04.0-usb-0:4.1:1.0-event-kbd
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.1/3-4.1:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=8157
+E: ID_MODEL_ENC=8157
+E: ID_MODEL_ID=8157
+E: ID_PATH=pci-0000:00:04.0-usb-0:4.1:1.0
+E: ID_PATH_TAG=pci-0000_00_04_0-usb-0_4_1_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=413c_8157
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=413c
+E: ID_VENDOR_ENC=413c
+E: ID_VENDOR_ID=413c
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2021969
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.2
+N: bus/usb/003/004
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=8158
+E: ID_MODEL_ENC=8158
+E: ID_MODEL_ID=8158
+E: ID_REVISION=0100
+E: ID_SERIAL=413c_8158
+E: ID_USB_INTERFACES=:030102:
+E: ID_VENDOR=413c
+E: ID_VENDOR_ENC=413c
+E: ID_VENDOR_ID=413c
+E: MAJOR=189
+E: MINOR=259
+E: PRODUCT=413c/8158/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2214606
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.2/3-4.2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.2/3-4.2:1.0
+E: DEVTYPE=usb_interface
+E: HID2HCI_SWITCH=1
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v413Cp8158d0100dc00dsc00dp00ic03isc01ip02
+E: PRODUCT=413c/8158/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23167659
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3
+N: bus/usb/003/005
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Dell_Wireless_370_Bluetooth_Mini-card
+E: ID_MODEL_ENC=Dell\x20Wireless\x20370\x20Bluetooth\x20Mini-card
+E: ID_MODEL_ID=8156
+E: ID_REVISION=0456
+E: ID_SERIAL=Dell_Computer_Corp_Dell_Wireless_370_Bluetooth_Mini-card
+E: ID_USB_INTERFACES=:e00101:ffffff:fe0100:
+E: ID_VENDOR=Dell_Computer_Corp
+E: ID_VENDOR_ENC=Dell\x20Computer\x20Corp
+E: ID_VENDOR_ID=413c
+E: MAJOR=189
+E: MINOR=260
+E: PRODUCT=413c/8156/456
+E: REMOVE_CMD=/sbin/udevadm trigger --action=change --subsystem-match=usb --property-match=HID2HCI_SWITCH=1
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23959833
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v413Cp8156d0456dcE0dsc01dp01icE0isc01ip01
+E: PRODUCT=413c/8156/456
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.0/bluetooth/hci0/rfkill3
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.0/bluetooth/hci0/rfkill3
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v413Cp8156d0456dcE0dsc01dp01icE0isc01ip01
+E: PRODUCT=413c/8156/456
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v413Cp8156d0456dcE0dsc01dp01icFFiscFFipFF
+E: PRODUCT=413c/8156/456
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4.3/3-4.3:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/0
+E: MODALIAS=usb:v413Cp8156d0456dcE0dsc01dp01icFEisc01ip00
+E: PRODUCT=413c/8156/456
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usb3/3-4/3-4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v0A5Cp4500d0100dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=a5c/4500/100
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/usbmon/usbmon3
+N: usbmon3
+E: DEVNAME=/dev/usbmon3
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/usbmon/usbmon3
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.1
+E: DEVPATH=/devices/pci0000:00/0000:00:04.1
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v000010DEd00000AA6sv00001028sd00000271bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=10DE:0AA6
+E: PCI_SLOT_NAME=0000:00:04.1
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.1/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:04.1/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-40-generic_ehci_hcd_EHCI_Host_Controller_0000:00:04.1
+E: ID_SERIAL_SHORT=0000:00:04.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-40-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-40-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1407446
+
+P: /devices/pci0000:00/0000:00:04.1/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.1/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.1/usbmon/usbmon1
+N: usbmon1
+E: DEVNAME=/dev/usbmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:04.1/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:06.0
+E: DEVPATH=/devices/pci0000:00/0000:00:06.0
+E: DRIVER=ohci_hcd
+E: MODALIAS=pci:v000010DEd00000AA7sv00001028sd00000271bc0Csc03i10
+E: PCI_CLASS=C0310
+E: PCI_ID=10DE:0AA7
+E: PCI_SLOT_NAME=0000:00:06.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:06.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:06.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OHCI_Host_Controller
+E: ID_MODEL_ENC=OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-40-generic_ohci_hcd_OHCI_Host_Controller_0000:00:06.0
+E: ID_SERIAL_SHORT=0000:00:06.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-40-generic_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-40-generic\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1407783
+
+P: /devices/pci0000:00/0000:00:06.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:06.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:06.0/usbmon/usbmon4
+N: usbmon4
+E: DEVNAME=/dev/usbmon4
+E: DEVPATH=/devices/pci0000:00/0000:00:06.0/usbmon/usbmon4
+E: MAJOR=252
+E: MINOR=4
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:06.1
+E: DEVPATH=/devices/pci0000:00/0000:00:06.1
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v000010DEd00000AA9sv00001028sd00000271bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=10DE:0AA9
+E: PCI_SLOT_NAME=0000:00:06.1
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:06.1/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:06.1/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-40-generic_ehci_hcd_EHCI_Host_Controller_0000:00:06.1
+E: ID_SERIAL_SHORT=0000:00:06.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-40-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-40-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1408310
+
+P: /devices/pci0000:00/0000:00:06.1/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:06.1/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:06.1/usbmon/usbmon2
+N: usbmon2
+E: DEVNAME=/dev/usbmon2
+E: DEVPATH=/devices/pci0000:00/0000:00:06.1/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:08.0
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v000010DEd00000AC0sv00001028sd00000271bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=10DE:0AC0
+E: PCI_SLOT_NAME=0000:00:08.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=MCP79 High Definition Audio
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:08.0
+E: ID_PATH=pci-0000:00:08.0
+E: ID_PATH_TAG=pci-0000_00_08_0
+E: ID_VENDOR_FROM_DATABASE=NVIDIA Corporation
+E: ID_VENDOR_ID=0x10de
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29674581
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29522831
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29522529
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/input13
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/input13
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:08.0
+E: ID_PATH_TAG=pci-0000_00_08_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA NVidia Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29521488
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/input13/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/input13/event6
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:08.0
+E: ID_PATH_TAG=pci-0000_00_08_0
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29530596
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29522243
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29521942
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29523521
+
+P: /devices/pci0000:00/0000:00:08.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:08.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:08.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:08.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:08.0
+E: ID_PATH_TAG=pci-0000_00_08_0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29525214
+
+P: /devices/pci0000:00/0000:00:09.0
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0
+E: MODALIAS=pci:v000010DEd00000AABsv000010DEsd0000CB79bc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=10DE:0AAB
+E: PCI_SLOT_NAME=0000:00:09.0
+E: PCI_SUBSYS_ID=10DE:CB79
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.0
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.0
+E: DRIVER=firewire_ohci
+E: MODALIAS=pci:v00001180d00000832sv00001028sd00000271bc0Csc00i10
+E: PCI_CLASS=C0010
+E: PCI_ID=1180:0832
+E: PCI_SLOT_NAME=0000:01:07.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.0/fw0
+N: fw0
+E: DEVNAME=/dev/fw0
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.0/fw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=firewire
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.1
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.1
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v00001180d00000822sv00001028sd00000271bc08sc05i00
+E: PCI_CLASS=80500
+E: PCI_ID=1180:0822
+E: PCI_SLOT_NAME=0000:01:07.1
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.1/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.1/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.1/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.1/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.2
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.2
+E: DRIVER=r592
+E: MODALIAS=pci:v00001180d00000592sv00001028sd00000271bc08sc80i00
+E: PCI_CLASS=88000
+E: PCI_ID=1180:0592
+E: PCI_SLOT_NAME=0000:01:07.2
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.2/memstick_host/memstick0
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.2/memstick_host/memstick0
+E: SUBSYSTEM=memstick_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/0000:01:07.3
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/0000:01:07.3
+E: DRIVER=r852
+E: MODALIAS=pci:v00001180d00000852sv00001028sd00000271bc08sc80i00
+E: PCI_CLASS=88000
+E: PCI_ID=1180:0852
+E: PCI_SLOT_NAME=0000:01:07.3
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:09.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:09.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0a.0
+E: DRIVER=forcedeth
+E: MODALIAS=pci:v000010DEd00000AB0sv00001028sd00000271bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10DE:0AB0
+E: PCI_SLOT_NAME=0000:00:0a.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0a.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:0a.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=MCP79 Ethernet
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:0a.0
+E: ID_VENDOR_FROM_DATABASE=NVIDIA Corporation
+E: ID_VENDOR_ID=0x10de
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21582344
+
+P: /devices/pci0000:00/0000:00:0b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=MCP79 AHCI Controller
+E: ID_VENDOR_FROM_DATABASE=NVIDIA Corporation
+E: MODALIAS=pci:v000010DEd00000AB9sv00001028sd00000271bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=10DE:0AB9
+E: PCI_SLOT_NAME=0000:00:0b.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21581839
+
+P: /devices/pci0000:00/0000:00:0b.0/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST
+S: disk/by-id/wwn-0x5000c5001eb4921a
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST /dev/disk/by-id/wwn-0x5000c5001eb4921a /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=8
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1276924
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part1
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part1
+S: disk/by-id/wwn-0x5000c5001eb4921a-part1
+S: disk/by-label/DellUtility
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/3030-3030
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part1 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part1 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part1 /dev/disk/by-label/DellUtility /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/3030-3030
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=DellUtility
+E: ID_FS_LABEL_ENC=DellUtility
+E: ID_FS_SEC_TYPE=msdos
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=3030-3030
+E: ID_FS_UUID_ENC=3030-3030
+E: ID_FS_VERSION=FAT16
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=63
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=80262
+E: ID_PART_ENTRY_TYPE=0xde
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=32256
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=41094144
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0xde
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1730720
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part2
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part2
+S: disk/by-id/wwn-0x5000c5001eb4921a-part2
+S: disk/by-label/RECOVERY
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part2
+S: disk/by-uuid/1C70DFD670DFB4AC
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part2 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part2 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part2 /dev/disk/by-label/RECOVERY /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part2 /dev/disk/by-uuid/1C70DFD670DFB4AC
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=RECOVERY
+E: ID_FS_LABEL_ENC=RECOVERY
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=1C70DFD670DFB4AC
+E: ID_FS_UUID_ENC=1C70DFD670DFB4AC
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=80325
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=30720000
+E: ID_PART_ENTRY_TYPE=0x7
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=41126400
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=15728640000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x07
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2060296
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part3
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part3
+S: disk/by-id/wwn-0x5000c5001eb4921a-part3
+S: disk/by-label/OS
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part3
+S: disk/by-uuid/D6B4E1E7B4E1C9D7
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part3 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part3 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part3 /dev/disk/by-label/OS /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part3 /dev/disk/by-uuid/D6B4E1E7B4E1C9D7
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=OS
+E: ID_FS_LABEL_ENC=OS
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=D6B4E1E7B4E1C9D7
+E: ID_FS_UUID_ENC=D6B4E1E7B4E1C9D7
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=30800325
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=280394790
+E: ID_PART_ENTRY_TYPE=0x7
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=15769766400
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=143562132480
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x07
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2138553
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda4
+N: sda4
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part4
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part4
+S: disk/by-id/wwn-0x5000c5001eb4921a-part4
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part4
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part4 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part4 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part4 /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part4
+E: DEVNAME=/dev/sda4
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda4
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=4
+E: ID_PART_ENTRY_OFFSET=311195646
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=665572419
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=4
+E: UDISKS_PARTITION_OFFSET=159332170752
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=340773078528
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1730194
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part5
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part5
+S: disk/by-id/wwn-0x5000c5001eb4921a-part5
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part5
+S: disk/by-uuid/e0c6ad1b-c066-4e5d-acad-8f4c49a22f22
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part5 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part5 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part5 /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part5 /dev/disk/by-uuid/e0c6ad1b-c066-4e5d-acad-8f4c49a22f22
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=e0c6ad1b-c066-4e5d-acad-8f4c49a22f22
+E: ID_FS_UUID_ENC=e0c6ad1b-c066-4e5d-acad-8f4c49a22f22
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=520907688
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=308738282
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=266704736256
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=158074000384
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2082323
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda6
+N: sda6
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part6
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part6
+S: disk/by-id/wwn-0x5000c5001eb4921a-part6
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part6
+S: disk/by-uuid/4c85d0f2-b754-4147-91b8-bfd6ae0eb485
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part6 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part6 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part6 /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part6 /dev/disk/by-uuid/4c85d0f2-b754-4147-91b8-bfd6ae0eb485
+E: DEVNAME=/dev/sda6
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda6
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=4c85d0f2-b754-4147-91b8-bfd6ae0eb485
+E: ID_FS_UUID_ENC=4c85d0f2-b754-4147-91b8-bfd6ae0eb485
+E: ID_FS_VERSION=2
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=6
+E: ID_PART_ENTRY_OFFSET=958213053
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=18555012
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=6
+E: UDISKS_PARTITION_OFFSET=490605083136
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=9500166144
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1971848
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda7
+N: sda7
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part7
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part7
+S: disk/by-id/wwn-0x5000c5001eb4921a-part7
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part7
+S: disk/by-uuid/d7b1dbe7-ea88-4b91-b43d-86926f6e742f
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part7 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part7 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part7 /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part7 /dev/disk/by-uuid/d7b1dbe7-ea88-4b91-b43d-86926f6e742f
+E: DEVNAME=/dev/sda7
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda7
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=d7b1dbe7-ea88-4b91-b43d-86926f6e742f
+E: ID_FS_UUID_ENC=d7b1dbe7-ea88-4b91-b43d-86926f6e742f
+E: ID_FS_VERSION=2
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=7
+E: ID_PART_ENTRY_OFFSET=502353920
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=18552832
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=7
+E: UDISKS_PARTITION_OFFSET=257205207040
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=9499049984
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2392165
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda8
+N: sda8
+S: disk/by-id/ata-ST9500420ASG_5VJ364ST-part8
+S: disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part8
+S: disk/by-id/wwn-0x5000c5001eb4921a-part8
+S: disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part8
+S: disk/by-uuid/5af11115-1870-4ea4-b67b-cfaefe755319
+E: DEVLINKS=/dev/disk/by-id/ata-ST9500420ASG_5VJ364ST-part8 /dev/disk/by-id/scsi-SATA_ST9500420ASG_5VJ364ST-part8 /dev/disk/by-id/wwn-0x5000c5001eb4921a-part8 /dev/disk/by-path/pci-0000:00:0b.0-scsi-0:0:0:0-part8 /dev/disk/by-uuid/5af11115-1870-4ea4-b67b-cfaefe755319
+E: DEVNAME=/dev/sda8
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda/sda8
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=208
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=5af11115-1870-4ea4-b67b-cfaefe755319
+E: ID_FS_UUID_ENC=5af11115-1870-4ea4-b67b-cfaefe755319
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=ST9500420ASG
+E: ID_MODEL_ENC=ST9500420ASG\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=8
+E: ID_PART_ENTRY_OFFSET=311195648
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=191156224
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:0b.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-0_0_0_0
+E: ID_REVISION=0004SD1M
+E: ID_SCSI_COMPAT=SATA_ST9500420ASG_5VJ364ST
+E: ID_SERIAL=ST9500420ASG_5VJ364ST
+E: ID_SERIAL_SHORT=5VJ364ST
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c5001eb4921a
+E: ID_WWN_WITH_EXTENSION=0x5000c5001eb4921a
+E: MAJOR=8
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=8
+E: UDISKS_PARTITION_OFFSET=159332171776
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=97871986688
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2104538
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-HL-DT-ST_DVD+_-RW_GS20N_KZ5A1S70602
+S: disk/by-path/pci-0000:00:0b.0-scsi-1:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-HL-DT-ST_DVD+_-RW_GS20N_KZ5A1S70602 /dev/disk/by-path/pci-0000:00:0b.0-scsi-1:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=HL-DT-ST_DVD+_-RW_GS20N
+E: ID_MODEL_ENC=HL-DT-ST\x20DVD+\x2f-RW\x20GS20N\x20\x20\x20
+E: ID_PATH=pci-0000:00:0b.0-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_0b_0-scsi-1_0_0_0
+E: ID_REVISION=A110
+E: ID_SERIAL=HL-DT-ST_DVD+_-RW_GS20N_KZ5A1S70602
+E: ID_SERIAL_SHORT=KZ5A1S70602
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1277251
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21609074
+
+P: /devices/pci0000:00/0000:00:0b.0/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0b.0/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:0b.0/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v000010DEd00000AC4sv000010DEsd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=10DE:0AC4
+E: PCI_SLOT_NAME=0000:00:0c.0
+E: PCI_SUBSYS_ID=10DE:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/0000:02:00.0
+E: DRIVER=nvidia
+E: MODALIAS=pci:v000010DEd00000A74sv00001028sd00000271bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=10DE:0A74
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/0000:02:00.0/backlight/acpi_video1
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/0000:02:00.0/backlight/acpi_video1
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-9
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/0000:02:00.0/i2c-9
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:0c.0/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:0c.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0
+E: MODALIAS=pci:v000010DEd00000AA0sv000010DEsd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=10DE:0AA0
+E: PCI_SLOT_NAME=0000:00:10.0
+E: PCI_SUBSYS_ID=10DE:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/0000:03:00.0
+E: DRIVER=nvidia
+E: MODALIAS=pci:v000010DEd00000866sv00001028sd00000271bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=10DE:0866
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=1028:0271
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/0000:03:00.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/0000:03:00.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/0000:03:00.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v000010DEd00000AC6sv000010DEsd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=10DE:0AC6
+E: PCI_SLOT_NAME=0000:00:15.0
+E: PCI_SUBSYS_ID=10DE:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v000010DEd00000AC7sv000010DEsd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=10DE:0AC7
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=10DE:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0/0000:06:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0/0000:06:00.0
+E: DRIVER=ath9k
+E: MODALIAS=pci:v0000168Cd0000002Asv0000168Csd00000200bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=168C:002A
+E: PCI_SLOT_NAME=0000:06:00.0
+E: PCI_SUBSYS_ID=168C:0200
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0/0000:06:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0/0000:06:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0/0000:06:00.0/ieee80211/phy0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0/0000:06:00.0/ieee80211/phy0/rfkill2
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0/0000:06:00.0/leds/ath9k-phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0/0000:06:00.0/leds/ath9k-phy0
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0/0000:06:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0/0000:06:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=AR928X Wireless Network Adapter (PCI-Express)
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:16.0/0000:06:00.0
+E: ID_VENDOR_FROM_DATABASE=Atheros Communications Inc.
+E: ID_VENDOR_ID=0x168c
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23098582
+
+P: /devices/pci0000:00/0000:00:16.0/pci_bus/0000:06
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0/pci_bus/0000:06
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:17.0
+E: DEVPATH=/devices/pci0000:00/0000:00:17.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v000010DEd00000AC7sv000010DEsd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=10DE:0AC7
+E: PCI_SLOT_NAME=0000:00:17.0
+E: PCI_SUBSYS_ID=10DE:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:17.0/pci_bus/0000:07
+E: DEVPATH=/devices/pci0000:00/0000:00:17.0/pci_bus/0000:07
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.0
+E: DEVPATH=/devices/pci0000:00/0000:00:18.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v000010DEd00000AC7sv000010DEsd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=10DE:0AC7
+E: PCI_SLOT_NAME=0000:00:18.0
+E: PCI_SUBSYS_ID=10DE:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.0/pci_bus/0000:08
+E: DEVPATH=/devices/pci0000:00/0000:00:18.0/pci_bus/0000:08
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dcdbas
+E: DEVPATH=/devices/platform/dcdbas
+E: DRIVER=dcdbas
+E: MODALIAS=platform:dcdbas
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop
+E: DEVPATH=/devices/platform/dell-laptop
+E: DRIVER=dell-laptop
+E: MODALIAS=platform:dell-laptop
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop/rfkill/rfkill0
+E: DEVPATH=/devices/platform/dell-laptop/rfkill/rfkill0
+E: RFKILL_NAME=dell-wifi
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/dell-laptop/rfkill/rfkill1
+E: DEVPATH=/devices/platform/dell-laptop/rfkill/rfkill1
+E: RFKILL_NAME=dell-bluetooth
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Dell Inc.
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21473640
+
+P: /devices/platform/i8042/serio0/input/input4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=1100f02902002 8380307cf910f001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8D,8E,8F,94,98,9B,9C,9D,9E,9F,A2,A3,A4,A5,A6,AC,AD,B7,B8,B9,BF,C1,CD,D4,D7,D9,E0,E1,E2,E3,EC,F0,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1435227
+
+P: /devices/platform/i8042/serio0/input/input4/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4/event4
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1444522
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input12
+E: ABS=260800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input12
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=6420 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=9
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23144158
+
+P: /devices/platform/i8042/serio1/input/input12/event12
+N: input/event12
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/platform/i8042/serio1/input/input12/event12
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23395727
+
+P: /devices/platform/i8042/serio1/input/input12/mouse2
+N: input/mouse2
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse2
+E: DEVPATH=/devices/platform/i8042/serio1/input/input12/mouse2
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=34
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=23395223
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21475778
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21488052
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21568416
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21571741
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21573048
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21573611
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21574138
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21574648
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21575149
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21575661
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21576229
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21576732
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21577246
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21578818
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21579291
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21579754
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21580236
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21580699
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21594165
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21603391
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21605532
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21606308
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21609372
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21613074
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21614885
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21659922
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21658355
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21658102
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21657858
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21657619
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21657384
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21657136
+
+P: /devices/platform/vboxdrv.0
+E: DEVPATH=/devices/platform/vboxdrv.0
+E: DRIVER=vboxdrv
+E: MODALIAS=platform:vboxdrv
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:0a/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1426665
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: DRIVER=ite-cir
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:28
+E: DEVPATH=/devices/virtual/bdi/0:28
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/mtd-romap
+E: DEVPATH=/devices/virtual/bdi/mtd-romap
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/mtd-rwmap
+E: DEVPATH=/devices/virtual/bdi/mtd-rwmap
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/mtd-unmap
+E: DEVPATH=/devices/virtual/bdi/mtd-unmap
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1278278
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1278427
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1278582
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1278739
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1278898
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1279068
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1279226
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1279396
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1279552
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1279720
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1279880
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1280918
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1281086
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1281249
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1281405
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1281561
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1281722
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1281884
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1282042
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1282201
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1282363
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1282522
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1282675
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1282842
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnDellInc.:bvrA11:bd09/08/2009:svnDellInc.:pnStudioXPS1340:pvrA11:rvnDellInc.:rn0Y525R:rvrA11:cvnDellInc.:ct8:cvrA11:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input10
+E: DEVPATH=/devices/virtual/input/input10
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=1500b00000000 200300000 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,k94,95,A1,E0,E1,E3,EC,EE,F0,ram4,lsfw
+E: MSC=10
+E: NAME="Dell WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22240899
+
+P: /devices/virtual/input/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/virtual/input/input10/event10
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22244458
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/virtual/input/input11
+E: DEVPATH=/devices/virtual/input/input11
+E: EV=100017
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_SERIAL=noserial
+E: KEY=30000 7 ff87207ac14057ff febeffdfffefffff fffffffffffffffe
+E: MODALIAS=input:b0000v0000p0000e0000-e0,1,2,4,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8C,8E,96,98,9E,9F,A1,A3,A4,A5,A6,AD,B0,B1,B2,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,110,111,r0,1,am4,lsfw
+E: MSC=10
+E: NAME="MCE IR Keyboard/Mouse (ite-cir)"
+E: PHYS="/input0"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22427364
+
+P: /devices/virtual/input/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/virtual/input/input11/event11
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22429973
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/virtual/input/input11/mouse1
+N: input/mouse1
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/virtual/input/input11/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22429937
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=26815306
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21693323
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vboxdrv
+N: vboxdrv
+E: DEVNAME=/dev/vboxdrv
+E: DEVPATH=/devices/virtual/misc/vboxdrv
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vboxnetctl
+N: vboxnetctl
+E: DEVNAME=/dev/vboxnetctl
+E: DEVPATH=/devices/virtual/misc/vboxnetctl
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21694475
+
+P: /devices/virtual/net/virbr0
+E: DEVPATH=/devices/virtual/net/virbr0
+E: DEVTYPE=bridge
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=4
+E: INTERFACE=virbr0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=26761355
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/rc/rc0
+E: DEVPATH=/devices/virtual/rc/rc0
+E: DRV_NAME=ite-cir
+E: NAME=rc-rc6-mce
+E: SUBSYSTEM=rc
+E: UDEV_LOG=3
+
+P: /devices/virtual/rc/rc0/input7
+E: DEVPATH=/devices/virtual/rc/rc0/input7
+E: EV=100013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=fff 0 200108fc32e 237605100000000 0 700158000 419200004001 8e968000000000 10000000
+E: MODALIAS=input:b0019v1283p0000e0000-e0,1,4,14,k71,72,73,77,80,8E,A1,A4,A7,A8,AE,CF,D0,D2,D4,E0,E1,E2,160,164,166,16D,16E,170,171,172,174,175,179,181,182,183,185,188,189,18E,18F,190,191,192,193,197,19C,1A9,200,201,202,203,204,205,206,207,208,209,20A,20B,ram4,lsfw
+E: MSC=10
+E: NAME="ITE8708 CIR transceiver"
+E: PRODUCT=19/1283/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21750715
+
+P: /devices/virtual/rc/rc0/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/virtual/rc/rc0/input7/event7
+E: DMI_VENDOR=Dell Inc.
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22147890
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/virtual/rc/rc0/lirc0
+N: lirc0
+E: DEVNAME=/dev/lirc0
+E: DEVPATH=/devices/virtual/rc/rc0/lirc0
+E: MAJOR=249
+E: MINOR=0
+E: SUBSYSTEM=lirc
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22417947
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=22277704
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21695755
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21696027
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21696284
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21696534
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21696793
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21697183
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21697206
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21697495
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21697747
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21698004
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21698261
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21698534
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21698790
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21699040
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21699290
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21699540
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21699917
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21699946
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21700240
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21700490
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21700739
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21700992
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21701246
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21701502
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21701757
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21702037
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21702341
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21703231
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21703496
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21703753
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21704083
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21704343
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21704595
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21704845
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21705095
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21705344
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21705595
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21705845
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21706202
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21706463
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21706723
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21707006
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21707259
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21707508
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21707761
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21708052
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21708315
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21708569
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21708821
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21709194
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21709462
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21709716
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21709968
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21710225
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21710475
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21710752
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21711004
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21711256
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21711512
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21711766
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21712187
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21712446
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21712713
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21734292
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21734340
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21735098
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21735562
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=21736169
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: DEVNAME=/dev/usbmon0
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:8D9DDCBC-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/9DBB5994-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:9DBB5994-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799A85-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799A85-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799A85-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799A86-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799A86-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799A86-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799A87-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799A87-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799A87-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799A88-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799A88-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799A88-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799AC3-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799AC3-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799AC3-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799AC5-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799AC5-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799AC5-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799ACA-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799ACA-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799ACA-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799ACB-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799ACB-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799ACB-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A1799AF2-9429-4529-927E-DFE13736EEBA
+E: DEVPATH=/devices/virtual/wmi/A1799AF2-9429-4529-927E-DFE13736EEBA
+E: MODALIAS=wmi:A1799AF2-9429-4529-927E-DFE13736EEBA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: DEVPATH=/devices/virtual/wmi/A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: MODALIAS=wmi:A3776CE0-1E88-11DB-A98B-0800200C9A66
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: DEVPATH=/devices/virtual/wmi/A80593CE-A997-11DA-B012-B622A1EF5492
+E: MODALIAS=wmi:A80593CE-A997-11DA-B012-B622A1EF5492
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/ABBC0F6C-8EA1-11D1-00A0-C90629100000
+E: DEVPATH=/devices/virtual/wmi/ABBC0F6C-8EA1-11D1-00A0-C90629100000
+E: MODALIAS=wmi:ABBC0F6C-8EA1-11D1-00A0-C90629100000
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/ABBC0F6D-8EA1-11D1-00A0-C90629100000
+E: DEVPATH=/devices/virtual/wmi/ABBC0F6D-8EA1-11D1-00A0-C90629100000
+E: MODALIAS=wmi:ABBC0F6D-8EA1-11D1-00A0-C90629100000
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/F28A9357-CF4B-4A1A-8893-BB1F58EEA1AF
+E: DEVPATH=/devices/virtual/wmi/F28A9357-CF4B-4A1A-8893-BB1F58EEA1AF
+E: MODALIAS=wmi:F28A9357-CF4B-4A1A-8893-BB1F58EEA1AF
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/F6CB5C3C-9CAE-4EBD-B577-931EA32A2CC0
+E: DEVPATH=/devices/virtual/wmi/F6CB5C3C-9CAE-4EBD-B577-931EA32A2CC0
+E: MODALIAS=wmi:F6CB5C3C-9CAE-4EBD-B577-931EA32A2CC0
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/HOME_MADE.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/HOME_MADE.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/HOME_MADE.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5383 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1451734
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input1/event1
+E: DMI_VENDOR=System manufacturer
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1471048
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:04
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/ATK0110:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/ATK0110:00
+E: DRIVER=ATK0110
+E: MODALIAS=acpi:ATK0110:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/ATK0110:00/hwmon/hwmon0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/ATK0110:00/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0501:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0501:00
+E: MODALIAS=acpi:PNP0501:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0700:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0700:00
+E: MODALIAS=acpi:PNP0700:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C02:03
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:04/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:06/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:06/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:06/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:06/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:09/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:09/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:09/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:05/device:09/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:0d/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:10/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:10/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:10/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0c/device:10/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C01:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C01:01
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1455958
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=System manufacturer
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1471898
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00002E20sv00001043sd000082D3bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2E20
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=1043:82D3
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00002E21sv00001043sd000082D3bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:2E21
+E: PCI_SLOT_NAME=0000:00:01.0
+E: PCI_SUBSYS_ID=1043:82D3
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:00:01.0:pcie08
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:00:01.0:pcie08
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.0
+E: DRIVER=fglrx_pci
+E: MODALIAS=pci:v00001002d00009442sv000010B0sd00000801bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=1002:9442
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=10B0:0801
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00001002d0000AA30sv000010B0sd0000AA30bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=1002:AA30
+E: PCI_SLOT_NAME=0000:01:00.1
+E: PCI_SUBSYS_ID=10B0:AA30
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=RV770 HDMI Audio [Radeon HD 4850/4870]
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:01.0/0000:01:00.1
+E: ID_PATH=pci-0000:01:00.1
+E: ID_PATH_TAG=pci-0000_01_00_1
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD] nee ATI
+E: ID_VENDOR_ID=0x1002
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11494260
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/hwC1D0
+N: snd/hwC1D0
+E: DEVNAME=/dev/snd/hwC1D0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/hwC1D0
+E: MAJOR=116
+E: MINOR=10
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11341193
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/input6
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:01:00.1
+E: ID_PATH_TAG=pci-0000_01_00_1
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA ATI HDMI HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11341808
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/input6/event6
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:01:00.1
+E: ID_PATH_TAG=pci-0000_01_00_1
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11344335
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/pcmC1D3p
+N: snd/pcmC1D3p
+E: DEVNAME=/dev/snd/pcmC1D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/pcmC1D3p
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11341157
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/controlC1
+N: snd/controlC1
+S: snd/by-path/pci-0000:01:00.1
+E: DEVLINKS=/dev/snd/by-path/pci-0000:01:00.1
+E: DEVNAME=/dev/snd/controlC1
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.1/sound/card1/controlC1
+E: ID_PATH=pci-0000:01:00.1
+E: ID_PATH_TAG=pci-0000_01_00_1
+E: MAJOR=116
+E: MINOR=11
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11341462
+
+P: /devices/pci0000:00/0000:00:01.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d00003A37sv00001043sd000082D4bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:3A37
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1426414
+
+P: /devices/pci0000:00/0000:00:1a.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usbmon/usbmon3
+N: usbmon3
+E: DEVNAME=/dev/usbmon3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usbmon/usbmon3
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.1
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d00003A38sv00001043sd000082D4bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:3A38
+E: PCI_SLOT_NAME=0000:00:1a.1
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.1/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.1/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1a.1
+E: ID_SERIAL_SHORT=0000:00:1a.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1427073
+
+P: /devices/pci0000:00/0000:00:1a.1/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.1/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.1/usbmon/usbmon4
+N: usbmon4
+E: DEVNAME=/dev/usbmon4
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.1/usbmon/usbmon4
+E: MAJOR=252
+E: MINOR=4
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.2
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d00003A39sv00001043sd000082D4bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:3A39
+E: PCI_SLOT_NAME=0000:00:1a.2
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.2/usb5
+N: bus/usb/005/001
+E: BUSNUM=005
+E: DEVNAME=/dev/bus/usb/005/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.2/usb5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1a.2
+E: ID_SERIAL_SHORT=0000:00:1a.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=512
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1432205
+
+P: /devices/pci0000:00/0000:00:1a.2/usb5/5-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.2/usb5/5-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.2/usbmon/usbmon5
+N: usbmon5
+E: DEVNAME=/dev/usbmon5
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.2/usbmon/usbmon5
+E: MAJOR=252
+E: MINOR=5
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.7
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.7
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00003A3Csv00001043sd000082D4bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:3A3C
+E: PCI_SLOT_NAME=0000:00:1a.7
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.7/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.7/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.7
+E: ID_SERIAL_SHORT=0000:00:1a.7
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1429576
+
+P: /devices/pci0000:00/0000:00:1a.7/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.7/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.7/usbmon/usbmon1
+N: usbmon1
+E: DEVNAME=/dev/usbmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.7/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00003A3Esv00001043sd000082FEbc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:3A3E
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=1043:82FE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=82801JI (ICH10 Family) HD Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11503880
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11296014
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11295807
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11295605
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D1c
+N: snd/pcmC0D1c
+E: DEVNAME=/dev/snd/pcmC0D1c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D1c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11295406
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D1p
+N: snd/pcmC0D1p
+E: DEVNAME=/dev/snd/pcmC0D1p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D1p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11295168
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D2c
+N: snd/pcmC0D2c
+E: DEVNAME=/dev/snd/pcmC0D2c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D2c
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11296285
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11295244
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003A40sv00001043sd000082D4bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3A40
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie08
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie08
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003A4Asv00001043sd000082D4bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3A4A
+E: PCI_SLOT_NAME=0000:00:1c.5
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/0000:00:1c.5:pcie08
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/0000:00:1c.5:pcie08
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/0000:02:00.0
+E: DRIVER=ATL1E
+E: MODALIAS=pci:v00001969d00001026sv00001043sd00008226bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=1969:1026
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=1043:8226
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.5/0000:02:00.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/0000:02:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=AR8121/AR8113/AR8114 Gigabit or Fast Ethernet
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.5/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=Atheros Communications Inc.
+E: ID_VENDOR_ID=0x1969
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11177200
+
+P: /devices/pci0000:00/0000:00:1c.5/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.5/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d00003A34sv00001043sd000082D4bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:3A34
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6
+N: bus/usb/006/001
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=640
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1427747
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1
+N: bus/usb/006/002
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Generic_USB_Hub
+E: ID_MODEL_ENC=Generic\x20USB\x20Hub
+E: ID_MODEL_ID=9254
+E: ID_REVISION=0312
+E: ID_SERIAL=ALCOR_Generic_USB_Hub
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=ALCOR
+E: ID_VENDOR_ENC=ALCOR
+E: ID_VENDOR_ID=058f
+E: MAJOR=189
+E: MINOR=641
+E: PRODUCT=58f/9254/312
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1485470
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1
+N: bus/usb/006/003
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=189
+E: MINOR=642
+E: PRODUCT=46d/c318/5501
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: UPOWER_VENDOR=Logitech, Inc.
+E: USEC_INITIALIZED=1911218
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/1
+E: MODALIAS=usb:v046DpC318d5501dc00dsc00dp00ic03isc01ip01
+E: PRODUCT=46d/c318/5501
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/0003:046D:C318.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/0003:046D:C318.0001
+E: DRIVER=generic-usb
+E: HID_ID=0003:0000046D:0000C318
+E: HID_NAME=Logitech Logitech Illuminated Keyboard
+E: HID_PHYS=usb-0000:00:1d.0-1.1/input0
+E: MODALIAS=hid:b0003v0000046Dp0000C318
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/0003:046D:C318.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/0003:046D:C318.0001/hidraw/hidraw0
+E: MAJOR=250
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/input/input2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/input/input2
+E: EV=120013
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_0
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: KEY=1000000000007 ff9f207ac14057ff febeffdfffefffff fffffffffffffffe
+E: LED=1f
+E: MODALIAS=input:b0003v046DpC318e0111-e0,1,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8C,8E,96,98,9E,9F,A1,A3,A4,A5,A6,AD,B0,B1,B2,B3,B4,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,3,4,sfw
+E: MSC=10
+E: NAME="Logitech Logitech Illuminated Keyboard"
+E: PHYS="usb-0000:00:1d.0-1.1/input0"
+E: PRODUCT=3/46d/c318/111
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=1924582
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/input/input2/event2
+N: input/event2
+S: input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-kbd
+S: input/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-kbd /dev/input/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-event-kbd
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.0/input/input2/event2
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_0
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1925507
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/2
+E: MODALIAS=usb:v046DpC318d5501dc00dsc00dp00ic03isc00ip02
+E: PRODUCT=46d/c318/5501
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/0003:046D:C318.0002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/0003:046D:C318.0002
+E: DRIVER=generic-usb
+E: HID_ID=0003:0000046D:0000C318
+E: HID_NAME=Logitech Logitech Illuminated Keyboard
+E: HID_PHYS=usb-0000:00:1d.0-1.1/input1
+E: MODALIAS=hid:b0003v0000046Dp0000C318
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/0003:046D:C318.0002/hidraw/hidraw1
+N: hidraw1
+E: DEVNAME=/dev/hidraw1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/0003:046D:C318.0002/hidraw/hidraw1
+E: MAJOR=250
+E: MINOR=1
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/input/input3
+E: ABS=100000000
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/input/input3
+E: EV=1f
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_1
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: KEY=4837fff072ff32d bf54444600000000 1 20f908b17c000 677bfad9415fed 9ed68000004400 10000002
+E: MODALIAS=input:b0003v046DpC318e0111-e0,1,2,3,4,k71,72,73,74,77,80,82,83,85,86,87,88,89,8A,8B,8C,8E,90,96,98,9B,9C,9E,9F,A1,A3,A4,A5,A6,A7,A8,A9,AB,AC,AD,AE,B0,B1,B2,B5,B6,CE,CF,D0,D1,D2,D4,D8,D9,DB,DF,E4,E7,E8,E9,EA,EB,F1,100,161,162,166,16A,16E,172,174,176,178,179,17A,17B,17C,17D,17F,180,182,183,185,188,189,18C,18D,18E,18F,190,191,192,193,195,198,199,19A,1A0,1A1,1A2,1A3,1A4,1A5,1A6,1A7,1A8,1A9,1AA,1AB,1AC,1AD,1AE,1B0,1B1,1B7,1BA,r6,a20,m4,lsfw
+E: MSC=10
+E: NAME="Logitech Logitech Illuminated Keyboard"
+E: PHYS="usb-0000:00:1d.0-1.1/input1"
+E: PRODUCT=3/46d/c318/111
+E: PROP=0
+E: REL=40
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=11118222
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/input/input3/event3
+N: input/event3
+S: input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-if01
+S: input/by-path/pci-0000:00:1d.0-usb-0:1.1:1.1-event
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-if01 /dev/input/by-path/pci-0000:00:1d.0-usb-0:1.1:1.1-event
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/input/input3/event3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_1
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11154675
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/usb/hiddev0
+N: usb/hiddev0
+E: DEVNAME=/dev/usb/hiddev0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.1/6-1.1:1.1/usb/hiddev0
+E: MAJOR=180
+E: MINOR=96
+E: SUBSYSTEM=usb
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2
+N: bus/usb/006/004
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_USB_INTERFACES=:030102:
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: MAJOR=189
+E: MINOR=643
+E: PRODUCT=45e/47/300
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11097678
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v045Ep0047d0300dc00dsc00dp00ic03isc01ip02
+E: PRODUCT=45e/47/300
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/0003:045E:0047.0003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/0003:045E:0047.0003
+E: DRIVER=generic-usb
+E: HID_ID=0003:0000045E:00000047
+E: HID_NAME=Microsoft Microsoft 5-Button Mouse with IntelliEye(TM)
+E: HID_PHYS=usb-0000:00:1d.0-1.2/input0
+E: MODALIAS=hid:b0003v0000045Ep00000047
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/0003:045E:0047.0003/hidraw/hidraw2
+N: hidraw2
+E: DEVNAME=/dev/hidraw2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/0003:045E:0047.0003/hidraw/hidraw2
+E: MAJOR=250
+E: MINOR=2
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/input/input4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/input/input4
+E: EV=17
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_2_1_0
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: KEY=1f0000 0 0 0 0
+E: MODALIAS=input:b0003v045Ep0047e0110-e0,1,2,4,k110,111,112,113,114,r0,1,8,am4,lsfw
+E: MSC=10
+E: NAME="Microsoft Microsoft 5-Button Mouse with IntelliEye(TM)"
+E: PHYS="usb-0000:00:1d.0-1.2/input0"
+E: PRODUCT=3/45e/47/110
+E: PROP=0
+E: REL=103
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=11119735
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/input/input4/event4
+N: input/event4
+S: input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-event-mouse
+S: input/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-event-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-event-mouse /dev/input/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-event-mouse
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/input/input4/event4
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_2_1_0
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11149152
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/input/input4/mouse0
+N: input/mouse0
+S: input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-mouse
+S: input/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-mouse /dev/input/by-path/pci-0000:00:1d.0-usb-0:1.2:1.0-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.2/6-1.2:1.0/input/input4/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_2_1_0
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11152122
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3
+N: bus/usb/006/005
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=2Port_KVMSwicther
+E: ID_MODEL_ENC=2Port\x20KVMSwicther
+E: ID_MODEL_ID=55a2
+E: ID_REVISION=0100
+E: ID_SERIAL=No_brand_2Port_KVMSwicther_02
+E: ID_SERIAL_SHORT=02
+E: ID_USB_INTERFACES=:030000:
+E: ID_VENDOR=No_brand
+E: ID_VENDOR_ENC=No\x20brand
+E: ID_VENDOR_ID=10d5
+E: MAJOR=189
+E: MINOR=644
+E: PRODUCT=10d5/55a2/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11099472
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v10D5p55A2d0100dc00dsc00dp00ic03isc00ip00
+E: PRODUCT=10d5/55a2/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/0003:10D5:55A2.0004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/0003:10D5:55A2.0004
+E: DRIVER=generic-usb
+E: HID_ID=0003:000010D5:000055A2
+E: HID_NAME=No brand 2Port KVMSwicther
+E: HID_PHYS=usb-0000:00:1d.0-1.3/input0
+E: HID_UNIQ=02
+E: MODALIAS=hid:b0003v000010D5p000055A2
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/0003:10D5:55A2.0004/hidraw/hidraw3
+N: hidraw3
+E: DEVNAME=/dev/hidraw3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/0003:10D5:55A2.0004/hidraw/hidraw3
+E: MAJOR=250
+E: MINOR=3
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/input/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/input/input5
+E: EV=120013
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=2Port_KVMSwicther
+E: ID_MODEL_ENC=2Port\x20KVMSwicther
+E: ID_MODEL_ID=55a2
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_3_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=No_brand_2Port_KVMSwicther_02
+E: ID_SERIAL_SHORT=02
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=No_brand
+E: ID_VENDOR_ENC=No\x20brand
+E: ID_VENDOR_ID=10d5
+E: KEY=1000000000007 ff9f207ac14057ff febeffdfffefffff fffffffffffffffe
+E: LED=1f
+E: MODALIAS=input:b0003v10D5p55A2e0110-e0,1,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8C,8E,96,98,9E,9F,A1,A3,A4,A5,A6,AD,B0,B1,B2,B3,B4,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,3,4,sfw
+E: MSC=10
+E: NAME="No brand 2Port KVMSwicther"
+E: PHYS="usb-0000:00:1d.0-1.3/input0"
+E: PRODUCT=3/10d5/55a2/110
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ="02"
+E: USEC_INITIALIZED=11120754
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-No_brand_2Port_KVMSwicther_02-event-kbd
+S: input/by-path/pci-0000:00:1d.0-usb-0:1.3:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-No_brand_2Port_KVMSwicther_02-event-kbd /dev/input/by-path/pci-0000:00:1d.0-usb-0:1.3:1.0-event-kbd
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=2Port_KVMSwicther
+E: ID_MODEL_ENC=2Port\x20KVMSwicther
+E: ID_MODEL_ID=55a2
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_3_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=No_brand_2Port_KVMSwicther_02
+E: ID_SERIAL_SHORT=02
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=No_brand
+E: ID_VENDOR_ENC=No\x20brand
+E: ID_VENDOR_ID=10d5
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11153143
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1.3/6-1.3:1.1
+E: DEVTYPE=usb_interface
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v10D5p55A2d0100dc00dsc00dp00ic03isc00ip00
+E: PRODUCT=10d5/55a2/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb6/6-1/6-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v058Fp9254d0312dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=58f/9254/312
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usbmon/usbmon6
+N: usbmon6
+E: DEVNAME=/dev/usbmon6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usbmon/usbmon6
+E: MAJOR=252
+E: MINOR=6
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d00003A35sv00001043sd000082D4bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:3A35
+E: PCI_SLOT_NAME=0000:00:1d.1
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.1/usb7
+N: bus/usb/007/001
+E: BUSNUM=007
+E: DEVNAME=/dev/bus/usb/007/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usb7
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.1
+E: ID_SERIAL_SHORT=0000:00:1d.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=768
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1428172
+
+P: /devices/pci0000:00/0000:00:1d.1/usb7/7-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usb7/7-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.1/usbmon/usbmon7
+N: usbmon7
+E: DEVNAME=/dev/usbmon7
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usbmon/usbmon7
+E: MAJOR=252
+E: MINOR=7
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d00003A36sv00001043sd000082D4bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:3A36
+E: PCI_SLOT_NAME=0000:00:1d.2
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.2/usb8
+N: bus/usb/008/001
+E: BUSNUM=008
+E: DEVNAME=/dev/bus/usb/008/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb8
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.2
+E: ID_SERIAL_SHORT=0000:00:1d.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=896
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1428436
+
+P: /devices/pci0000:00/0000:00:1d.2/usb8/8-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb8/8-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.2/usbmon/usbmon8
+N: usbmon8
+E: DEVNAME=/dev/usbmon8
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usbmon/usbmon8
+E: MAJOR=252
+E: MINOR=8
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00003A3Asv00001043sd000082D4bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:3A3A
+E: PCI_SLOT_NAME=0000:00:1d.7
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-32-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.7
+E: ID_SERIAL_SHORT=0000:00:1d.7
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-32-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-32-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1450979
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=2514
+E: ID_MODEL_ENC=2514
+E: ID_MODEL_ID=2514
+E: ID_REVISION=0000
+E: ID_SERIAL=0424_2514
+E: ID_USB_INTERFACES=:090001:090002:
+E: ID_VENDOR=0424
+E: ID_VENDOR_ENC=0424
+E: ID_VENDOR_ID=0424
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=424/2514/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/2
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1452976
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1
+N: bus/usb/002/004
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=2640
+E: ID_MODEL_ENC=2640
+E: ID_MODEL_ID=2640
+E: ID_REVISION=0000
+E: ID_SERIAL=0424_2640
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=0424
+E: ID_VENDOR_ENC=0424
+E: ID_VENDOR_ID=0424
+E: MAJOR=189
+E: MINOR=131
+E: PRODUCT=424/2640/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1664648
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1
+N: bus/usb/002/005
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Ultra_Fast_Media_Reader
+E: ID_MODEL_ENC=Ultra\x20Fast\x20Media\x20Reader
+E: ID_MODEL_ID=4060
+E: ID_REVISION=0182
+E: ID_SERIAL=Generic_Ultra_Fast_Media_Reader_000000264001
+E: ID_SERIAL_SHORT=000000264001
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=0424
+E: MAJOR=189
+E: MINOR=132
+E: PRODUCT=424/4060/182
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11066735
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v0424p4060d0182dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=424/4060/182
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/block/sdc
+N: sdc
+S: disk/by-id/usb-Generic_Ultra_HS-SD_MMC_000000264001-0:0
+S: disk/by-path/pci-0000:00:1d.7-usb-0:2.1.1:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic_Ultra_HS-SD_MMC_000000264001-0:0 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:2.1.1:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdc
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/block/sdc
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Ultra_HS-SD_MMC
+E: ID_MODEL_ENC=Ultra\x20HS-SD\x2fMMC\x20
+E: ID_MODEL_ID=4060
+E: ID_PATH=pci-0000:00:1d.7-usb-0:2.1.1:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_2_1_1_1_0-scsi-0_0_0_0
+E: ID_REVISION=1.82
+E: ID_SERIAL=Generic_Ultra_HS-SD_MMC_000000264001-0:0
+E: ID_SERIAL_SHORT=000000264001
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic\x20
+E: ID_VENDOR_ID=0424
+E: MAJOR=8
+E: MINOR=32
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=11953756
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/bsg/4:0:0:0
+N: bsg/4:0:0:0
+E: DEVNAME=/dev/bsg/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/bsg/4:0:0:0
+E: MAJOR=253
+E: MINOR=4
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/scsi_device/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/scsi_device/4:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/scsi_disk/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/scsi_disk/4:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/scsi_generic/sg4
+N: sg4
+E: DEVNAME=/dev/sg4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1.1/2-2.1.1:1.0/host4/target4:0:0/4:0:0:0/scsi_generic/sg4
+E: MAJOR=21
+E: MINOR=4
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2.1/2-2.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v0424p2640d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=424/2640/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb2/2-2/2-2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/2
+E: MODALIAS=usb:v0424p2514d0000dc09dsc00dp02ic09isc00ip02
+E: PRODUCT=424/2514/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/2
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usbmon/usbmon2
+N: usbmon2
+E: DEVNAME=/dev/usbmon2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0
+E: MODALIAS=pci:v00008086d0000244Esv00001043sd000082D4bc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=8086:244E
+E: PCI_SLOT_NAME=0000:00:1e.0
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0/0000:04:03.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/0000:04:03.0
+E: DRIVER=firewire_ohci
+E: MODALIAS=pci:v000011C1d00005811sv00001043sd00008294bc0Csc00i10
+E: PCI_CLASS=C0010
+E: PCI_ID=11C1:5811
+E: PCI_SLOT_NAME=0000:04:03.0
+E: PCI_SUBSYS_ID=1043:8294
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0/0000:04:03.0/fw0
+N: fw0
+E: DEVNAME=/dev/fw0
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/0000:04:03.0/fw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=firewire
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00003A16sv00001043sd000082D4bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:3A16
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ata_piix
+E: ID_MODEL_FROM_DATABASE=82801JI (ICH10 Family) 4 port SATA IDE Controller #1
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00003A20sv00001043sd000082D4bc01sc01i8f
+E: PCI_CLASS=1018F
+E: PCI_ID=8086:3A20
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11159618
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.1/ata_device/dev1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.1/ata_device/dev1.1
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.1/ata_device/dev2.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.1/ata_device/dev2.1
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357
+S: disk/by-id/wwn-0x50000f000b393075
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357 /dev/disk/by-id/wwn-0x50000f000b393075 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930357
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930357
+E: ID_SERIAL_SHORT=S13TJ90Q930357
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393075
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393075
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=4
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1406196
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part1
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part1
+S: disk/by-id/wwn-0x50000f000b393075-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/b1dd88a3-3f5f-403d-a2fc-8db8efbc31c7
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part1 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part1 /dev/disk/by-id/wwn-0x50000f000b393075-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/b1dd88a3-3f5f-403d-a2fc-8db8efbc31c7
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=b1dd88a3-3f5f-403d-a2fc-8db8efbc31c7
+E: ID_FS_UUID_ENC=b1dd88a3-3f5f-403d-a2fc-8db8efbc31c7
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=63
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=140841792
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930357
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930357
+E: ID_SERIAL_SHORT=S13TJ90Q930357
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393075
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393075
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=32256
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=72110997504
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1869612
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part2
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part2
+S: disk/by-id/wwn-0x50000f000b393075-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part2 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part2 /dev/disk/by-id/wwn-0x50000f000b393075-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=943656958
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=21045250
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930357
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930357
+E: ID_SERIAL_SHORT=S13TJ90Q930357
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393075
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393075
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=483152362496
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=10775168000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1740483
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part3
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part3
+S: disk/by-id/wwn-0x50000f000b393075-part3
+S: disk/by-label/Data2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+S: disk/by-uuid/02D4E26262F1C4A6
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part3 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part3 /dev/disk/by-id/wwn-0x50000f000b393075-part3 /dev/disk/by-label/Data2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3 /dev/disk/by-uuid/02D4E26262F1C4A6
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Data2
+E: ID_FS_LABEL_ENC=Data2
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=02D4E26262F1C4A6
+E: ID_FS_UUID_ENC=02D4E26262F1C4A6
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=140841855
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=306472005
+E: ID_PART_ENTRY_TYPE=0x7
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930357
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930357
+E: ID_SERIAL_SHORT=S13TJ90Q930357
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393075
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393075
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=72111029760
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=156913666560
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x07
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1851931
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part5
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part5
+S: disk/by-id/wwn-0x50000f000b393075-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/14822152-5725-4b3f-864b-4e5e7eccf8a6
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930357-part5 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930357-part5 /dev/disk/by-id/wwn-0x50000f000b393075-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/14822152-5725-4b3f-864b-4e5e7eccf8a6
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=90
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=14822152-5725-4b3f-864b-4e5e7eccf8a6
+E: ID_FS_UUID_ENC=14822152-5725-4b3f-864b-4e5e7eccf8a6
+E: ID_FS_VERSION=2
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=943656960
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=21045248
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930357
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930357
+E: ID_SERIAL_SHORT=S13TJ90Q930357
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393075
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393075
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=483152363520
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=10775166976
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1740147
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-TSSTcorp_CDDVDW_SH-S223F
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:1:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-TSSTcorp_CDDVDW_SH-S223F /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:1:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=TSSTcorp_CDDVDW_SH-S223F
+E: ID_MODEL_ENC=TSSTcorp\x20CDDVDW\x20SH-S223F\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:1:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_1_0
+E: ID_REVISION=SB00
+E: ID_SERIAL=TSSTcorp_CDDVDW_SH-S223F
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1406316
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/bsg/0:0:1:0
+N: bsg/0:0:1:0
+E: DEVNAME=/dev/bsg/0:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/bsg/0:0:1:0
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_device/0:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_device/0:0:1:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11171021
+
+P: /devices/pci0000:00/0000:00:1f.2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358
+S: disk/by-id/wwn-0x50000f000b393085
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358 /dev/disk/by-id/wwn-0x50000f000b393085 /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930358
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930358
+E: ID_SERIAL_SHORT=S13TJ90Q930358
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393085
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393085
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=4
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1406387
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb1
+N: sdb1
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part1
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part1
+S: disk/by-id/wwn-0x50000f000b393085-part1
+S: disk/by-label/System
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part1
+S: disk/by-uuid/F464EBC464EB87A6
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part1 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part1 /dev/disk/by-id/wwn-0x50000f000b393085-part1 /dev/disk/by-label/System /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part1 /dev/disk/by-uuid/F464EBC464EB87A6
+E: DEVNAME=/dev/sdb1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=System
+E: ID_FS_LABEL_ENC=System
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=F464EBC464EB87A6
+E: ID_FS_UUID_ENC=F464EBC464EB87A6
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=63
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=204796557
+E: ID_PART_ENTRY_TYPE=0x7
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930358
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930358
+E: ID_SERIAL_SHORT=S13TJ90Q930358
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393085
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393085
+E: MAJOR=8
+E: MINOR=17
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=32256
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=104855837184
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x07
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1800420
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb2
+N: sdb2
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part2
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part2
+S: disk/by-id/wwn-0x50000f000b393085-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part2 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part2 /dev/disk/by-id/wwn-0x50000f000b393085-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part2
+E: DEVNAME=/dev/sdb2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=204796620
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=771955380
+E: ID_PART_ENTRY_TYPE=0xf
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930358
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930358
+E: ID_SERIAL_SHORT=S13TJ90Q930358
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393085
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393085
+E: MAJOR=8
+E: MINOR=18
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=104855869440
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=395241154560
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x0f
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1565685
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb5
+N: sdb5
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part5
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part5
+S: disk/by-id/wwn-0x50000f000b393085-part5
+S: disk/by-label/Games
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part5
+S: disk/by-uuid/406ABC8A6ABC7E6A
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part5 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part5 /dev/disk/by-id/wwn-0x50000f000b393085-part5 /dev/disk/by-label/Games /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part5 /dev/disk/by-uuid/406ABC8A6ABC7E6A
+E: DEVNAME=/dev/sdb5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Games
+E: ID_FS_LABEL_ENC=Games
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=406ABC8A6ABC7E6A
+E: ID_FS_UUID_ENC=406ABC8A6ABC7E6A
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=204796683
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=362362077
+E: ID_PART_ENTRY_TYPE=0x7
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930358
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930358
+E: ID_SERIAL_SHORT=S13TJ90Q930358
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393085
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393085
+E: MAJOR=8
+E: MINOR=21
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=104855901696
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=185529383424
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x07
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1767165
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb6
+N: sdb6
+S: disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part6
+S: disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part6
+S: disk/by-id/wwn-0x50000f000b393085-part6
+S: disk/by-label/Data
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part6
+S: disk/by-uuid/349413659413293E
+E: DEVLINKS=/dev/disk/by-id/ata-SAMSUNG_HD502IJ_S13TJ90Q930358-part6 /dev/disk/by-id/scsi-SATA_SAMSUNG_HD502IJS13TJ90Q930358-part6 /dev/disk/by-id/wwn-0x50000f000b393085-part6 /dev/disk/by-label/Data /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0-part6 /dev/disk/by-uuid/349413659413293E
+E: DEVNAME=/dev/sdb6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb/sdb6
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=0
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=86
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Data
+E: ID_FS_LABEL_ENC=Data
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=349413659413293E
+E: ID_FS_UUID_ENC=349413659413293E
+E: ID_MODEL=SAMSUNG_HD502IJ
+E: ID_MODEL_ENC=SAMSUNG\x20HD502IJ\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_NUMBER=6
+E: ID_PART_ENTRY_OFFSET=567158823
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=409593177
+E: ID_PART_ENTRY_TYPE=0x7
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=1AA01131
+E: ID_SCSI_COMPAT=SATA_SAMSUNG_HD502IJS13TJ90Q930358
+E: ID_SERIAL=SAMSUNG_HD502IJ_S13TJ90Q930358
+E: ID_SERIAL_SHORT=S13TJ90Q930358
+E: ID_TYPE=disk
+E: ID_WWN=0x50000f000b393085
+E: ID_WWN_WITH_EXTENSION=0x50000f000b393085
+E: MAJOR=8
+E: MINOR=22
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=6
+E: UDISKS_PARTITION_OFFSET=290385317376
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=209711706624
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x07
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1697821
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=253
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_disk/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_disk/1:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:1
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/block/sr1
+N: sr1
+S: cdrom1
+S: cdrw1
+S: disk/by-id/ata-TSSTcorp_CDDVDW_SH-S223F
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:1:0
+S: dvd1
+S: dvdrw1
+E: DEVLINKS=/dev/cdrom1 /dev/cdrw1 /dev/disk/by-id/ata-TSSTcorp_CDDVDW_SH-S223F /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:1:0 /dev/dvd1 /dev/dvdrw1
+E: DEVNAME=/dev/sr1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/block/sr1
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=TSSTcorp_CDDVDW_SH-S223F
+E: ID_MODEL_ENC=TSSTcorp\x20CDDVDW\x20SH-S223F\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:1:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_1_0
+E: ID_REVISION=SB00
+E: ID_SERIAL=TSSTcorp_CDDVDW_SH-S223F
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=1
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1407789
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/bsg/1:0:1:0
+N: bsg/1:0:1:0
+E: DEVNAME=/dev/bsg/1:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/bsg/1:0:1:0
+E: MAJOR=253
+E: MINOR=3
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/scsi_device/1:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/scsi_device/1:0:1:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/scsi_generic/sg3
+N: sg3
+E: DEVNAME=/dev/sg3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:1/1:0:1:0/scsi_generic/sg3
+E: MAJOR=21
+E: MINOR=3
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11173231
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00003A30sv00001043sd000082D4bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:3A30
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5
+E: DRIVER=ata_piix
+E: ID_MODEL_FROM_DATABASE=82801JI (ICH10 Family) 2 port SATA IDE Controller #2
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00003A26sv00001043sd000082D4bc01sc01i85
+E: PCI_CLASS=10185
+E: PCI_ID=8086:3A26
+E: PCI_SLOT_NAME=0000:00:1f.5
+E: PCI_SUBSYS_ID=1043:82D4
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11158845
+
+P: /devices/pci0000:00/0000:00:1f.5/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.5/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.5/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/floppy.0
+E: DEVPATH=/devices/platform/floppy.0
+E: DRIVER=floppy
+E: MODALIAS=platform:floppy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/floppy.0/block/fd0
+N: fd0
+E: DEVNAME=/dev/fd0
+E: DEVPATH=/devices/platform/floppy.0/block/fd0
+E: DEVTYPE=disk
+E: ID_DRIVE_FLOPPY=1
+E: MAJOR=2
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=11074338
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11076282
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11076652
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11077022
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11077389
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11077756
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11078123
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11078501
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11078869
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11079239
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11079606
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11079971
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11080343
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11080574
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11081102
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11081313
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11081680
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11082194
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11082405
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11082771
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11083284
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11083495
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11083862
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11084232
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11084746
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11084956
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11085326
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11085842
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11086053
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11086421
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11086924
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11087297
+
+P: /devices/platform/vesafb.0
+E: DEVPATH=/devices/platform/vesafb.0
+E: DRIVER=vesafb
+E: MODALIAS=platform:vesafb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/vesafb.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/platform/vesafb.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: PRIMARY_DEVICE_FOR_DISPLAY=1
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12128933
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:03/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1472485
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: DRIVER=serial
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/pnp0/00:0c/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11123432
+
+P: /devices/pnp0/00:0d
+E: DEVPATH=/devices/pnp0/00:0d
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0e
+E: DEVPATH=/devices/pnp0/00:0e
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0f
+E: DEVPATH=/devices/pnp0/00:0f
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:1
+E: DEVPATH=/devices/virtual/bdi/11:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/2:0
+E: DEVPATH=/devices/virtual/bdi/2:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:32
+E: DEVPATH=/devices/virtual/bdi/8:32
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1407929
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412043
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412140
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412229
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412318
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412406
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412486
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1412573
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1412665
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1412753
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1412837
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1412935
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413018
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413103
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413205
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413293
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413385
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413485
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413583
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413670
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413770
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413870
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1413961
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1414060
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnAmericanMegatrendsInc.:bvr2102:bd02/23/2009:svnSystemmanufacturer:pnSystemProductName:pvrSystemVersion:rvnASUSTeKComputerINC.:rnP5Q-PRO:rvrRev1.xx:cvnChassisManufacture:ct3:cvrChassisVersion:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11175753
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11176649
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11219174
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11218594
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11198214
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11198407
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11198600
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11198795
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11199000
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11199262
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11199290
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11199629
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11199822
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11200017
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11200206
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11200393
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11200579
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11200766
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11200953
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11201140
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11201368
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11201556
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11201745
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11201932
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11202118
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11202306
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11202516
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11202722
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11202908
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11203095
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11203283
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11203532
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11203724
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11203912
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11204795
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11204988
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11205176
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11205364
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11205552
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11205739
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11206321
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11206708
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11206978
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11207717
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11209222
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11209592
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11209930
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11210287
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11210607
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11210926
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11211245
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11211552
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11212195
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11211761
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11211930
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11212262
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11212431
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11212597
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11212765
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11212932
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11213099
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11213266
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11213433
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11213600
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11214095
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11214267
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11214435
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11214602
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11214769
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11214936
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11215102
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11215268
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: DEVNAME=/dev/usbmon0
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_ENVY_15_MEDIATEK_BT.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_ENVY_15_MEDIATEK_BT.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_ENVY_15_MEDIATEK_BT.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5163 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME=&quot;Power Button&quot;
+E: PHYS=&quot;LNXPWRBN/button/input0&quot;
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2858394
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2861085
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/INT33A0:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/INT33A0:00
+E: MODALIAS=acpi:INT33A0:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/HPQ6007:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/HPQ6007:00
+E: MODALIAS=acpi:HPQ6007:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:47
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:47
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:48
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:48
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:49
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:49
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:4e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input8
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input8
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:01
+E: ID_PATH_TAG=acpi-LNXVIDEO_01
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME=&quot;Video Bus&quot;
+E: PHYS=&quot;LNXVIDEO/video/input0&quot;
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12686207
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input8/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input8/event7
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:01
+E: ID_PATH_TAG=acpi-LNXVIDEO_01
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12690778
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0303:00
+E: MODALIAS=acpi:PNP0303:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/SYN1E89:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/SYN1E89:00
+E: MODALIAS=acpi:SYN1E89:SYN1E00:SYN0002:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0b/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/device:03/device:04/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:14/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:14/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0f/device:10/device:11/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:29/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:32/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:32/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/input/input7
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/input/input7
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME=&quot;Video Bus&quot;
+E: PHYS=&quot;LNXVIDEO/video/input0&quot;
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12681910
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/input/input7/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3a/LNXVIDEO:00/input/input7/event6
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12684765
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CHARGE_FULL=5145000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=5145000
+E: POWER_SUPPLY_CHARGE_NOW=5145000
+E: POWER_SUPPLY_CURRENT_NOW=0
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=Hewlett-Packard
+E: POWER_SUPPLY_MODEL_NAME=Primary
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=00390 2012/11/20
+E: POWER_SUPPLY_STATUS=Full
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=10800000
+E: POWER_SUPPLY_VOLTAGE_NOW=10975000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME=&quot;Power Button&quot;
+E: PHYS=&quot;PNP0C0C/button/input0&quot;
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2982660
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input1/event1
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2988280
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME=&quot;Lid Switch&quot;
+E: PHYS=&quot;PNP0C0D/button/input0&quot;
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2983324
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3002711
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:01
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXPOWER:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXPOWER:00
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:01
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:02
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/PNP0C0B:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/PNP0C0B:00
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000154sv0000103Csd00001961bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0154
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00000151sv0000103Csd00001961bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:0151
+E: PCI_SLOT_NAME=0000:00:01.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:00:01.0:pcie08
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:00:01.0:pcie08
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.0
+E: MODALIAS=pci:v000010DEd00001292sv0000103Csd00001961bc03sc02i00
+E: PCI_CLASS=30200
+E: PCI_ID=10DE:1292
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/0000:01:00.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/0000:01:00.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000166sv0000103Csd00001961bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0166
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video1
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12686607
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv0000103Csd00001961bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2984182
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2984509
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv0000103Csd00001961bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E2Dsv0000103Csd00001961bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2984547
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3036851
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+N: bus/usb/001/012
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/012
+E: DEVNUM=012
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BT
+E: ID_MODEL_ENC=BT
+E: ID_MODEL_ID=763f
+E: ID_REVISION=0100
+E: ID_SERIAL=MediaTek_BT_1.0
+E: ID_SERIAL_SHORT=1.0
+E: ID_USB_INTERFACES=:ffffff:
+E: ID_VENDOR=MediaTek
+E: ID_VENDOR_ENC=MediaTek
+E: ID_VENDOR_ID=0e8d
+E: MAJOR=189
+E: MINOR=11
+E: PRODUCT=e8d/763f/100
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2973746857
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0E8Dp763Fd0100dcEFdsc02dp01icFFiscFFipFF
+E: PRODUCT=e8d/763f/100
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0/rfkill6
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0/rfkill6
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0E8Dp763Fd0100dcEFdsc02dp01icFFiscFFipFF
+E: PRODUCT=e8d/763f/100
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=0360
+E: ID_REVISION=0103
+E: ID_SERIAL=SunplusIT_INC._HP_Truevision_HD
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=SunplusIT_INC.
+E: ID_VENDOR_ENC=SunplusIT\x20INC.
+E: ID_VENDOR_ID=05c8
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=5c8/360/103
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3656645
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v05C8p0360d0103dcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=5c8/360/103
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/input/input4
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/input/input4
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=0360
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_3_1_0
+E: ID_REVISION=0103
+E: ID_SERIAL=SunplusIT_INC._HP_Truevision_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=SunplusIT_INC.
+E: ID_VENDOR_ENC=SunplusIT\x20INC.
+E: ID_VENDOR_ID=05c8
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v05C8p0360e0103-e0,1,kD4,ramlsfw
+E: NAME=&quot;HP Truevision HD&quot;
+E: PHYS=&quot;usb-0000:00:1a.0-1.3/button&quot;
+E: PRODUCT=3/5c8/360/103
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12049728
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/input/input4/event4
+N: input/event4
+S: input/by-id/usb-SunplusIT_INC._HP_Truevision_HD-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-SunplusIT_INC._HP_Truevision_HD-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-event
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/input/input4/event4
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=0360
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_3_1_0
+E: ID_REVISION=0103
+E: ID_SERIAL=SunplusIT_INC._HP_Truevision_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=SunplusIT_INC.
+E: ID_VENDOR_ENC=SunplusIT\x20INC.
+E: ID_VENDOR_ID=05c8
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12054111
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-SunplusIT_INC._HP_Truevision_HD-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-SunplusIT_INC._HP_Truevision_HD-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.3:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=0360
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_3_1_0
+E: ID_REVISION=0103
+E: ID_SERIAL=SunplusIT_INC._HP_Truevision_HD
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=HP Truevision HD
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=SunplusIT_INC.
+E: ID_VENDOR_ENC=SunplusIT\x20INC.
+E: ID_VENDOR_ID=05c8
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12172072
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v05C8p0360d0103dcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=5c8/360/103
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv0000103Csd00001961bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Panther Point High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13070892
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12781130
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12782103
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME=&quot;HDA Intel PCH Headphone&quot;
+E: PHYS=&quot;ALSA&quot;
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12781360
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12784929
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME=&quot;HDA Intel PCH Mic&quot;
+E: PHYS=&quot;ALSA&quot;
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12781752
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12787292
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME=&quot;HDA Intel PCH HDMI/DP,pcm=3&quot;
+E: PHYS=&quot;ALSA&quot;
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12780932
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12784532
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12781039
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12781023
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12781316
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12782493
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv0000103Csd00001961bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0
+E: DRIVER=rt2800pci
+E: MODALIAS=pci:v000014C3d00007630sv0000103Csd0000197Cbc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=14C3:7630
+E: PCI_SLOT_NAME=0000:07:00.0
+E: PCI_SUBSYS_ID=103C:197C
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0/ieee80211/phy0/rfkill1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0/ieee80211/phy0/rfkill1
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0/leds/rt2800pci-phy0::assoc
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0/leds/rt2800pci-phy0::assoc
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0/leds/rt2800pci-phy0::quality
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0/leds/rt2800pci-phy0::quality
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0/leds/rt2800pci-phy0::radio
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0/leds/rt2800pci-phy0::radio
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:07:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:07:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.0/0000:07:00.0
+E: ID_VENDOR_FROM_DATABASE=MEDIATEK Corp.
+E: ID_VENDOR_ID=0x14c3
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12053156
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:07
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:07
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E14sv0000103Csd00001961bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E14
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:08:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:08:00.0
+E: DRIVER=rtsx_pci
+E: MODALIAS=pci:v000010ECd00005229sv0000103Csd00001961bcFFsc00i00
+E: PCI_CLASS=FF0000
+E: PCI_ID=10EC:5229
+E: PCI_SLOT_NAME=0000:08:00.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_ms.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_ms.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_ms
+E: MODALIAS=platform:rtsx_pci_ms
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: SUBSYSTEM=memstick_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_sdmmc.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_sdmmc.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_sdmmc
+E: MODALIAS=platform:rtsx_pci_sdmmc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:08:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:08
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:08
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E16sv0000103Csd00001961bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E16
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:0e:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:0e:00.0
+E: DRIVER=r8168
+E: MODALIAS=pci:v000010ECd00008168sv0000103Csd00001961bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8168
+E: PCI_SLOT_NAME=0000:0e:00.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:0e:00.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:0e:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8111/8168B PCI Express Gigabit Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.3/0000:0e:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12046980
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:0e
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:0e
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E26sv0000103Csd00001961bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2989134
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3280897
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0050
+E: ID_MODEL_ENC=0050
+E: ID_MODEL_ID=0050
+E: ID_REVISION=0060
+E: ID_SERIAL=138a_0050_990e00207093
+E: ID_SERIAL_SHORT=990e00207093
+E: ID_USB_INTERFACES=:ff0000:
+E: ID_VENDOR=138a
+E: ID_VENDOR_ENC=138a
+E: ID_VENDOR_ID=138a
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=138a/50/60
+E: SUBSYSTEM=usb
+E: TYPE=255/16/255
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3889705
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.8/2-1.8:1.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/0/0
+E: MODALIAS=usb:v138Ap0050d0060dcFFdsc10dpFFicFFisc00ip00
+E: PRODUCT=138a/50/60
+E: SUBSYSTEM=usb
+E: TYPE=255/16/255
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00001E57sv0000103Csd00001961bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E57
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=Panther Point 6 port SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001E03sv0000103Csd00001961bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1E03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12005512
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR
+S: disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR
+S: disk/by-id/wwn-0x5000cca6f7de4b0a
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR /dev/disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR /dev/disk/by-id/wwn-0x5000cca6f7de4b0a /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=112
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=110
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=HGST_HTS545050A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545050A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GG2OAC0A
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545050A_TE85113RJ4MVMR
+E: ID_SERIAL=HGST_HTS545050A7E380_TE85113RJ4MVMR
+E: ID_SERIAL_SHORT=TE85113RJ4MVMR
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f7de4b0a
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f7de4b0a
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3494523
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR-part1
+S: disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR-part1
+S: disk/by-id/wwn-0x5000cca6f7de4b0a-part1
+S: disk/by-label/HP_TOOLS
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/3226-B630
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR-part1 /dev/disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR-part1 /dev/disk/by-id/wwn-0x5000cca6f7de4b0a-part1 /dev/disk/by-label/HP_TOOLS /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/3226-B630
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=112
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=110
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=HP_TOOLS
+E: ID_FS_LABEL_ENC=HP_TOOLS
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=3226-B630
+E: ID_FS_UUID_ENC=3226-B630
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=HGST_HTS545050A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545050A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=4734280
+E: ID_PART_ENTRY_TYPE=0x1c
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GG2OAC0A
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545050A_TE85113RJ4MVMR
+E: ID_SERIAL=HGST_HTS545050A7E380_TE85113RJ4MVMR
+E: ID_SERIAL_SHORT=TE85113RJ4MVMR
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f7de4b0a
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f7de4b0a
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2423951360
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x1c
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3865386
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR-part2
+S: disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR-part2
+S: disk/by-id/wwn-0x5000cca6f7de4b0a-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-uuid/9ddba1e2-4702-4770-98a5-e2866236822d
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR-part2 /dev/disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR-part2 /dev/disk/by-id/wwn-0x5000cca6f7de4b0a-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-uuid/9ddba1e2-4702-4770-98a5-e2866236822d
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=112
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=110
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=9ddba1e2-4702-4770-98a5-e2866236822d
+E: ID_FS_UUID_ENC=9ddba1e2-4702-4770-98a5-e2866236822d
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=HGST_HTS545050A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545050A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=4737024
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=963860480
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GG2OAC0A
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545050A_TE85113RJ4MVMR
+E: ID_SERIAL=HGST_HTS545050A7E380_TE85113RJ4MVMR
+E: ID_SERIAL_SHORT=TE85113RJ4MVMR
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f7de4b0a
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f7de4b0a
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=2425356288
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=493496565760
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3873407
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR-part3
+S: disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR-part3
+S: disk/by-id/wwn-0x5000cca6f7de4b0a-part3
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+S: disk/by-uuid/1b421640-0aa7-4187-9f70-df6800b3dce1
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545050A7E380_TE85113RJ4MVMR-part3 /dev/disk/by-id/scsi-SATA_HGST_HTS545050A_TE85113RJ4MVMR-part3 /dev/disk/by-id/wwn-0x5000cca6f7de4b0a-part3 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3 /dev/disk/by-uuid/1b421640-0aa7-4187-9f70-df6800b3dce1
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=112
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=110
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=1b421640-0aa7-4187-9f70-df6800b3dce1
+E: ID_FS_UUID_ENC=1b421640-0aa7-4187-9f70-df6800b3dce1
+E: ID_FS_VERSION=2
+E: ID_MODEL=HGST_HTS545050A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545050A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=968597504
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8173568
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GG2OAC0A
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545050A_TE85113RJ4MVMR
+E: ID_SERIAL=HGST_HTS545050A7E380_TE85113RJ4MVMR
+E: ID_SERIAL_SHORT=TE85113RJ4MVMR
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f7de4b0a
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f7de4b0a
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=495921922048
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4184866816
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3865349
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv0000103Csd00001961bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=103C:1961
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon1
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi
+E: DEVPATH=/devices/platform/hp-wmi
+E: DRIVER=hp-wmi
+E: MODALIAS=platform:hp-wmi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill2
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill2
+E: RFKILL_NAME=hp-wifi
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Hewlett-Packard
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11810151
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=20 0 0 500f02100402 3803078f900d401 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8A,8C,8E,8F,98,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,C1,CA,D4,D9,E0,E1,E2,E3,EC,EE,185,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME=&quot;AT Translated Set 2 keyboard&quot;
+E: PHYS=&quot;isa0060/serio0/input0&quot;
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3002783
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=3006100
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=serio_raw
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/misc/serio_raw0
+N: serio_raw0
+E: DEVNAME=/dev/serio_raw0
+E: DEVPATH=/devices/platform/i8042/serio1/misc/serio_raw0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12524357
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11810537
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11810804
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11811064
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11811317
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11811570
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11811821
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11812081
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11812332
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11812581
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11812831
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11813077
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11813325
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11813577
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11813827
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11814076
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11814325
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11814574
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11814823
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11815123
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11815137
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11815417
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11815445
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11815730
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11815762
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816098
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816079
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816332
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816614
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816639
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816919
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11816953
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11817226
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2990107
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory40
+E: DEVPATH=/devices/system/memory/memory40
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory41
+E: DEVPATH=/devices/system/memory/memory41
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory42
+E: DEVPATH=/devices/system/memory/memory42
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory43
+E: DEVPATH=/devices/system/memory/memory43
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837114
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837227
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837325
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837434
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837541
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837646
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837752
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2837839
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2837934
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838031
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838133
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838246
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838345
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838443
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838548
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838651
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838749
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838845
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2838943
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2839045
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2839152
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2839254
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2839356
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2839451
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnInsyde:bvrF.22:bd08/02/2013:svnHewlett-Packard:pnHPENVY15NotebookPC:pvr08A1100000000000000320100:rvnHewlett-Packard:rn1961:rvr93.46:cvnHewlett-Packard:ct10:cvrChassisVersion:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input6
+E: DEVPATH=/devices/virtual/input/input6
+E: EV=33
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=4000000000 0 1000700000000 2100400 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,5,k8A,94,99,E0,E1,E2,F0,166,ram4,lsfw1,5,
+E: MSC=10
+E: NAME=&quot;HP WMI hotkeys&quot;
+E: PHYS=&quot;wmi/input0&quot;
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=22
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12552872
+
+P: /devices/virtual/input/input6/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/virtual/input/input6/event5
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12556473
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/btrfs-control
+N: btrfs-control
+E: DEVNAME=/dev/btrfs-control
+E: DEVPATH=/devices/virtual/misc/btrfs-control
+E: MAJOR=10
+E: MINOR=234
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=53
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11843653
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr0
+N: cpu/0/msr
+E: DEVNAME=/dev/cpu/0/msr
+E: DEVPATH=/devices/virtual/msr/msr0
+E: MAJOR=202
+E: MINOR=0
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr1
+N: cpu/1/msr
+E: DEVNAME=/dev/cpu/1/msr
+E: DEVPATH=/devices/virtual/msr/msr1
+E: MAJOR=202
+E: MINOR=1
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr2
+N: cpu/2/msr
+E: DEVNAME=/dev/cpu/2/msr
+E: DEVPATH=/devices/virtual/msr/msr2
+E: MAJOR=202
+E: MINOR=2
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr3
+N: cpu/3/msr
+E: DEVNAME=/dev/cpu/3/msr
+E: DEVPATH=/devices/virtual/msr/msr3
+E: MAJOR=202
+E: MINOR=3
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11844674
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12043861
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12042115
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device5
+E: DEVPATH=/devices/virtual/thermal/cooling_device5
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device6
+E: DEVPATH=/devices/virtual/thermal/cooling_device6
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone1
+E: DEVPATH=/devices/virtual/thermal/thermal_zone1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone2
+E: DEVPATH=/devices/virtual/thermal/thermal_zone2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11846163
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11846389
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11846614
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11846839
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847052
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847182
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847309
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847410
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847515
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847614
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847715
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847817
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11847915
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848027
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848124
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848227
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848329
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848431
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848532
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848639
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848742
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848841
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11848942
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849040
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849142
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849239
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849339
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849444
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849546
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849650
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849757
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849861
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11849964
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850067
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850169
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850272
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850373
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850476
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850577
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850678
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850784
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850880
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11850984
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851087
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851189
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851288
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851392
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851499
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851602
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851705
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851807
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11851910
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12012673
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12015136
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12015771
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12018090
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12018431
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12018850
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12019200
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12019596
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12019947
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12020277
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12020644
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12020969
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12021634
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12021945
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12022222
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12023072
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs63
+N: vcs63
+E: DEVNAME=/dev/vcs63
+E: DEVPATH=/devices/virtual/vc/vcs63
+E: MAJOR=7
+E: MINOR=63
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa63
+N: vcsa63
+E: DEVNAME=/dev/vcsa63
+E: DEVPATH=/devices/virtual/vc/vcsa63
+E: MAJOR=7
+E: MINOR=191
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/00000000-0000-0000-0000-000000000000
+E: DEVPATH=/devices/virtual/wmi/00000000-0000-0000-0000-000000000000
+E: MODALIAS=wmi:00000000-0000-0000-0000-000000000000
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: DEVPATH=/devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: MODALIAS=wmi:14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/1E519311-3E75-4208-B05E-EBE17E3FF41F
+E: DEVPATH=/devices/virtual/wmi/1E519311-3E75-4208-B05E-EBE17E3FF41F
+E: MODALIAS=wmi:1E519311-3E75-4208-B05E-EBE17E3FF41F
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: DEVPATH=/devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: MODALIAS=wmi:1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2B814318-4BE8-4707-9D84-A190A859B5D0
+E: DEVPATH=/devices/virtual/wmi/2B814318-4BE8-4707-9D84-A190A859B5D0
+E: MODALIAS=wmi:2B814318-4BE8-4707-9D84-A190A859B5D0
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: DEVPATH=/devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: MODALIAS=wmi:2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: DEVPATH=/devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: MODALIAS=wmi:322F2028-0F84-4901-988E-015176049E2D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/37F85341-4418-4F24-8533-38FFC7295542
+E: DEVPATH=/devices/virtual/wmi/37F85341-4418-4F24-8533-38FFC7295542
+E: MODALIAS=wmi:37F85341-4418-4F24-8533-38FFC7295542
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/3ADEBD0F-0C5F-46ED-AB2E-04962B4FDCBC
+E: DEVPATH=/devices/virtual/wmi/3ADEBD0F-0C5F-46ED-AB2E-04962B4FDCBC
+E: MODALIAS=wmi:3ADEBD0F-0C5F-46ED-AB2E-04962B4FDCBC
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/42848006-8886-490E-8C72-2BDCA93A8A09
+E: DEVPATH=/devices/virtual/wmi/42848006-8886-490E-8C72-2BDCA93A8A09
+E: MODALIAS=wmi:42848006-8886-490E-8C72-2BDCA93A8A09
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: DEVPATH=/devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: MODALIAS=wmi:5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: DEVPATH=/devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: MODALIAS=wmi:8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: DEVPATH=/devices/virtual/wmi/8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: MODALIAS=wmi:8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: DEVPATH=/devices/virtual/wmi/8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: MODALIAS=wmi:8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: DEVPATH=/devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: MODALIAS=wmi:95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: DEVPATH=/devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: MODALIAS=wmi:988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: DEVPATH=/devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: MODALIAS=wmi:DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/E06BDE62-EE75-48F4-A583-B23E69ABF891
+E: DEVPATH=/devices/virtual/wmi/E06BDE62-EE75-48F4-A583-B23E69ABF891
+E: MODALIAS=wmi:E06BDE62-EE75-48F4-A583-B23E69ABF891
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PAVILION14_NOTEBOOK_MEDIATEK_BT.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PAVILION14_NOTEBOOK_MEDIATEK_BT.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PAVILION14_NOTEBOOK_MEDIATEK_BT.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,4947 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1992756
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2014048
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/ACAD
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/ACAD
+E: POWER_SUPPLY_NAME=ACAD
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/HPQ6007:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/HPQ6007:00
+E: MODALIAS=acpi:HPQ6007:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8244145
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4/event4
+N: input/event4
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input4/event4
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8919814
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/LNXVIDEO:01/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:05/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:10/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:10/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:19/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18/device:19/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/AUI1710:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/AUI1710:00
+E: MODALIAS=acpi:AUI1710:SYN1E00:SYN0002:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0303:00
+E: MODALIAS=acpi:PNP0303:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:24/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:29/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25/device:29/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2f/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2f/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2f/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2f/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CHARGE_FULL=2720000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=2720000
+E: POWER_SUPPLY_CHARGE_NOW=2720000
+E: POWER_SUPPLY_CURRENT_NOW=0
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=Hewlett-Packard
+E: POWER_SUPPLY_MODEL_NAME=Primary
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER= 
+E: POWER_SUPPLY_STATUS=Full
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=14800000
+E: POWER_SUPPLY_VOLTAGE_NOW=17021000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2079230
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2120993
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2079761
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2120967
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/ibs_fetch
+E: DEVPATH=/devices/ibs_fetch
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/ibs_op
+E: DEVPATH=/devices/ibs_op
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00001022d00001410sv0000103Csd00002169bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1410
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0
+E: DRIVER=fglrx_pci
+E: MODALIAS=pci:v00001002d0000990Asv0000103Csd00002169bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=1002:990A
+E: PCI_SLOT_NAME=0000:00:01.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.1
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00001002d00009902sv0000103Csd00002169bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=1002:9902
+E: PCI_SLOT_NAME=0000:00:01.1
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:01.1
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD] nee ATI
+E: ID_VENDOR_ID=0x1002
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13419544
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9381539
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/input6
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA ATI HDMI HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9382428
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/input6/event6
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9393981
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9380555
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:01.1
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:01.1
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9381786
+
+P: /devices/pci0000:00/0000:00:04.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d00001414sv00001022sd00001234bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:1414
+E: PCI_SLOT_NAME=0000:00:04.0
+E: PCI_SUBSYS_ID=1022:1234
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0
+E: DRIVER=rt2800pci
+E: MODALIAS=pci:v000014C3d00007630sv0000103Csd0000197Cbc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=14C3:7630
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=103C:197C
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/ieee80211/phy0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/ieee80211/phy0/rfkill2
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/leds/rt2800pci-phy0::assoc
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/leds/rt2800pci-phy0::assoc
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/leds/rt2800pci-phy0::quality
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/leds/rt2800pci-phy0::quality
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/leds/rt2800pci-phy0::radio
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/leds/rt2800pci-phy0::radio
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:04.0/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=MEDIATEK Corp.
+E: ID_VENDOR_ID=0x14c3
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12509151
+
+P: /devices/pci0000:00/0000:00:04.0/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d00001415sv00001022sd00001234bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:1415
+E: PCI_SLOT_NAME=0000:00:05.0
+E: PCI_SUBSYS_ID=1022:1234
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0
+E: DRIVER=r8169
+E: MODALIAS=pci:v000010ECd00008136sv0000103Csd00002169bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8136
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8101E/RTL8102E PCI Express Fast Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:05.0/0000:03:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8708360
+
+P: /devices/pci0000:00/0000:00:05.0/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00001022d00007814sv0000103Csd00002169bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=1022:7814
+E: PCI_SLOT_NAME=0000:00:10.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/usb5
+N: bus/usb/005/001
+E: BUSNUM=005
+E: DEVNAME=/dev/bus/usb/005/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_xhci_hcd_xHCI_Host_Controller_0000:00:10.0
+E: ID_SERIAL_SHORT=0000:00:10.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=512
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2009679
+
+P: /devices/pci0000:00/0000:00:10.0/usb5/5-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb5/5-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/usb6
+N: bus/usb/006/001
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_xhci_hcd_xHCI_Host_Controller_0000:00:10.0
+E: ID_SERIAL_SHORT=0000:00:10.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=640
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2010144
+
+P: /devices/pci0000:00/0000:00:10.0/usb6/6-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb6/6-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=Hudson SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD]
+E: MODALIAS=pci:v00001022d00007804sv0000103Csd00002169bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=1022:7804
+E: PCI_SLOT_NAME=0000:00:11.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7918276
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT
+S: disk/by-id/wwn-0x50000394a4980fcf
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT /dev/disk/by-id/wwn-0x50000394a4980fcf /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MQ01ABD075
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD075\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_337BW0PBT
+E: ID_SERIAL=TOSHIBA_MQ01ABD075_337BW0PBT
+E: ID_SERIAL_SHORT=337BW0PBT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000394a4980fcf
+E: ID_WWN_WITH_EXTENSION=0x50000394a4980fcf
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2763046
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT-part1
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT-part1
+S: disk/by-id/wwn-0x50000394a4980fcf-part1
+S: disk/by-label/HP_TOOLS
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/62BE-A702
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT-part1 /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT-part1 /dev/disk/by-id/wwn-0x50000394a4980fcf-part1 /dev/disk/by-label/HP_TOOLS /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/62BE-A702
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=HP_TOOLS
+E: ID_FS_LABEL_ENC=HP_TOOLS
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=62BE-A702
+E: ID_FS_UUID_ENC=62BE-A702
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=TOSHIBA_MQ01ABD075
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD075\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=4734280
+E: ID_PART_ENTRY_TYPE=0x1c
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_337BW0PBT
+E: ID_SERIAL=TOSHIBA_MQ01ABD075_337BW0PBT
+E: ID_SERIAL_SHORT=337BW0PBT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000394a4980fcf
+E: ID_WWN_WITH_EXTENSION=0x50000394a4980fcf
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2423951360
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x1c
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2954186
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT-part2
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT-part2
+S: disk/by-id/wwn-0x50000394a4980fcf-part2
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part2
+S: disk/by-uuid/0053c60c-f815-4a3b-a8c1-1573556f1eb3
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT-part2 /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT-part2 /dev/disk/by-id/wwn-0x50000394a4980fcf-part2 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part2 /dev/disk/by-uuid/0053c60c-f815-4a3b-a8c1-1573556f1eb3
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=0053c60c-f815-4a3b-a8c1-1573556f1eb3
+E: ID_FS_UUID_ENC=0053c60c-f815-4a3b-a8c1-1573556f1eb3
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=TOSHIBA_MQ01ABD075
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD075\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=4737024
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=1445318656
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_337BW0PBT
+E: ID_SERIAL=TOSHIBA_MQ01ABD075_337BW0PBT
+E: ID_SERIAL_SHORT=337BW0PBT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000394a4980fcf
+E: ID_WWN_WITH_EXTENSION=0x50000394a4980fcf
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=2425356288
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=740003151872
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3083573
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT-part3
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT-part3
+S: disk/by-id/wwn-0x50000394a4980fcf-part3
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part3
+S: disk/by-uuid/ae8bf947-fb71-4cac-9785-79d3ebe575d6
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD075_337BW0PBT-part3 /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_337BW0PBT-part3 /dev/disk/by-id/wwn-0x50000394a4980fcf-part3 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part3 /dev/disk/by-uuid/ae8bf947-fb71-4cac-9785-79d3ebe575d6
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=158
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=ae8bf947-fb71-4cac-9785-79d3ebe575d6
+E: ID_FS_UUID_ENC=ae8bf947-fb71-4cac-9785-79d3ebe575d6
+E: ID_FS_VERSION=2
+E: ID_MODEL=TOSHIBA_MQ01ABD075
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD075\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=1450055680
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=15091712
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_337BW0PBT
+E: ID_SERIAL=TOSHIBA_MQ01ABD075_337BW0PBT
+E: ID_SERIAL_SHORT=337BW0PBT
+E: ID_TYPE=disk
+E: ID_WWN=0x50000394a4980fcf
+E: ID_WWN_WITH_EXTENSION=0x50000394a4980fcf
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=742428508160
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=7726956544
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3122593
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-hp_CDDVDW_SU-208CB_R9366YGD40002T
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-hp_CDDVDW_SU-208CB_R9366YGD40002T /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=hp_CDDVDW_SU-208CB
+E: ID_MODEL_ENC=hp\x20\x20\x20\x20\x20\x20\x20CDDVDW\x20SU-208CB\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=HH00
+E: ID_SERIAL=hp_CDDVDW_SU-208CB_R9366YGD40002T
+E: ID_SERIAL_SHORT=R9366YGD40002T
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2673768
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8692470
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.0
+E: DRIVER=ohci_hcd
+E: MODALIAS=pci:v00001022d00007807sv0000103Csd00002169bc0Csc03i10
+E: PCI_CLASS=C0310
+E: PCI_ID=1022:7807
+E: PCI_SLOT_NAME=0000:00:12.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:12.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OHCI_Host_Controller
+E: ID_MODEL_ENC=OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_ohci_hcd_OHCI_Host_Controller_0000:00:12.0
+E: ID_SERIAL_SHORT=0000:00:12.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2010678
+
+P: /devices/pci0000:00/0000:00:12.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00001022d00007808sv0000103Csd00002169bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=1022:7808
+E: PCI_SLOT_NAME=0000:00:12.2
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_ehci_hcd_EHCI_Host_Controller_0000:00:12.2
+E: ID_SERIAL_SHORT=0000:00:12.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2015651
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-3
+N: bus/usb/001/005
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BT
+E: ID_MODEL_ENC=BT
+E: ID_MODEL_ID=763f
+E: ID_REVISION=0100
+E: ID_SERIAL=MediaTek_BT_1.0
+E: ID_SERIAL_SHORT=1.0
+E: ID_USB_INTERFACES=:ffffff:
+E: ID_VENDOR=MediaTek
+E: ID_VENDOR_ENC=MediaTek
+E: ID_VENDOR_ID=0e8d
+E: MAJOR=189
+E: MINOR=4
+E: PRODUCT=e8d/763f/100
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=749099904
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0E8Dp763Fd0100dcEFdsc02dp01icFFiscFFipFF
+E: PRODUCT=e8d/763f/100
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.0/bluetooth/hci0/rfkill4
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.0/bluetooth/hci0/rfkill4
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-3/1-3:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0E8Dp763Fd0100dcEFdsc02dp01icFFiscFFipFF
+E: PRODUCT=e8d/763f/100
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0
+E: DRIVER=ohci_hcd
+E: MODALIAS=pci:v00001022d00007807sv0000103Csd00002169bc0Csc03i10
+E: PCI_CLASS=C0310
+E: PCI_ID=1022:7807
+E: PCI_SLOT_NAME=0000:00:13.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OHCI_Host_Controller
+E: ID_MODEL_ENC=OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_ohci_hcd_OHCI_Host_Controller_0000:00:13.0
+E: ID_SERIAL_SHORT=0000:00:13.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2025978
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00001022d00007808sv0000103Csd00002169bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=1022:7808
+E: PCI_SLOT_NAME=0000:00:13.2
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-32-generic_ehci_hcd_EHCI_Host_Controller_0000:00:13.2
+E: ID_SERIAL_SHORT=0000:00:13.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-32-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-32-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2121408
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-4
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=e264
+E: ID_REVISION=0103
+E: ID_SERIAL=SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103
+E: ID_SERIAL_SHORT=HF1016-T821-HN03-REV0103
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=SuYin
+E: ID_VENDOR_ENC=SuYin
+E: ID_VENDOR_ID=064e
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=64e/e264/103
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2378407
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v064EpE264d0103dcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=64e/e264/103
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0/input/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0/input/input10
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=e264
+E: ID_PATH=pci-0000:00:13.2-usb-0:4:1.0
+E: ID_PATH_TAG=pci-0000_00_13_2-usb-0_4_1_0
+E: ID_REVISION=0103
+E: ID_SERIAL=SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103
+E: ID_SERIAL_SHORT=HF1016-T821-HN03-REV0103
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=SuYin
+E: ID_VENDOR_ENC=SuYin
+E: ID_VENDOR_ID=064e
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v064EpE264e0103-e0,1,kD4,ramlsfw
+E: NAME="HP Truevision HD"
+E: PHYS="usb-0000:00:13.2-4/button"
+E: PRODUCT=3/64e/e264/103
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9659797
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0/input/input10/event10
+N: input/event10
+S: input/by-id/usb-SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103-event-if00
+S: input/by-path/pci-0000:00:13.2-usb-0:4:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103-event-if00 /dev/input/by-path/pci-0000:00:13.2-usb-0:4:1.0-event
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0/input/input10/event10
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=e264
+E: ID_PATH=pci-0000:00:13.2-usb-0:4:1.0
+E: ID_PATH_TAG=pci-0000_00_13_2-usb-0_4_1_0
+E: ID_REVISION=0103
+E: ID_SERIAL=SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103
+E: ID_SERIAL_SHORT=HF1016-T821-HN03-REV0103
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=SuYin
+E: ID_VENDOR_ENC=SuYin
+E: ID_VENDOR_ID=064e
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9668977
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103-video-index0
+S: v4l/by-path/pci-0000:00:13.2-usb-0:4:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103-video-index0 /dev/v4l/by-path/pci-0000:00:13.2-usb-0:4:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=HP_Truevision_HD
+E: ID_MODEL_ENC=HP\x20Truevision\x20HD
+E: ID_MODEL_ID=e264
+E: ID_PATH=pci-0000:00:13.2-usb-0:4:1.0
+E: ID_PATH_TAG=pci-0000_00_13_2-usb-0_4_1_0
+E: ID_REVISION=0103
+E: ID_SERIAL=SuYin_HP_Truevision_HD_HF1016-T821-HN03-REV0103
+E: ID_SERIAL_SHORT=HF1016-T821-HN03-REV0103
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=HP Truevision HD
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=SuYin
+E: ID_VENDOR_ENC=SuYin
+E: ID_VENDOR_ID=064e
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9698662
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-4/2-4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v064EpE264d0103dcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=64e/e264/103
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: MODALIAS=pci:v00001022d0000780Bsv0000103Csd00002169bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=1022:780B
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00001022d0000780Dsv0000103Csd00002169bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=1022:780D
+E: PCI_SLOT_NAME=0000:00:14.2
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Hudson Azalia Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:14.2
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD]
+E: ID_VENDOR_ID=0x1022
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13418462
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/hwC1D0
+N: snd/hwC1D0
+E: DEVNAME=/dev/snd/hwC1D0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/hwC1D0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9443014
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input7
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HD-Audio Generic Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9441388
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input7/event7
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9503602
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input8
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HD-Audio Generic Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9401704
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input8/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9509597
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0c
+N: snd/pcmC1D0c
+E: DEVNAME=/dev/snd/pcmC1D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9439237
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0p
+N: snd/pcmC1D0p
+E: DEVNAME=/dev/snd/pcmC1D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9402206
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/controlC1
+N: snd/controlC1
+S: snd/by-path/pci-0000:00:14.2
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:14.2
+E: DEVNAME=/dev/snd/controlC1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/controlC1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9441502
+
+P: /devices/pci0000:00/0000:00:14.3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.3
+E: MODALIAS=pci:v00001022d0000780Esv0000103Csd00002169bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=1022:780E
+E: PCI_SLOT_NAME=0000:00:14.3
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.4
+E: MODALIAS=pci:v00001022d0000780Fsv00000000sd00000000bc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=1022:780F
+E: PCI_SLOT_NAME=0000:00:14.4
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.4/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:14.4/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d000043A0sv00001022sd00000000bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:43A0
+E: PCI_SLOT_NAME=0000:00:15.0
+E: PCI_SUBSYS_ID=1022:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/0000:05:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/0000:05:00.0
+E: DRIVER=rtsx_pci
+E: MODALIAS=pci:v000010ECd00005229sv0000103Csd00002169bcFFsc00i00
+E: PCI_CLASS=FF0000
+E: PCI_ID=10EC:5229
+E: PCI_SLOT_NAME=0000:05:00.0
+E: PCI_SUBSYS_ID=103C:2169
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_ms.0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_ms.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_ms
+E: MODALIAS=platform:rtsx_pci_ms
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: SUBSYSTEM=memstick_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_sdmmc.0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_sdmmc.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_sdmmc
+E: MODALIAS=platform:rtsx_pci_sdmmc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/0000:05:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:15.0/pci_bus/0000:05
+E: DEVPATH=/devices/pci0000:00/0000:00:15.0/pci_bus/0000:05
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.0
+E: DEVPATH=/devices/pci0000:00/0000:00:18.0
+E: MODALIAS=pci:v00001022d00001400sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1400
+E: PCI_SLOT_NAME=0000:00:18.0
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.1
+E: DEVPATH=/devices/pci0000:00/0000:00:18.1
+E: MODALIAS=pci:v00001022d00001401sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1401
+E: PCI_SLOT_NAME=0000:00:18.1
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.2
+E: DEVPATH=/devices/pci0000:00/0000:00:18.2
+E: MODALIAS=pci:v00001022d00001402sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1402
+E: PCI_SLOT_NAME=0000:00:18.2
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.3
+E: DEVPATH=/devices/pci0000:00/0000:00:18.3
+E: DRIVER=k10temp
+E: MODALIAS=pci:v00001022d00001403sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1403
+E: PCI_SLOT_NAME=0000:00:18.3
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.3/hwmon/hwmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:18.3/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.4
+E: DEVPATH=/devices/pci0000:00/0000:00:18.4
+E: MODALIAS=pci:v00001022d00001404sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1404
+E: PCI_SLOT_NAME=0000:00:18.4
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.5
+E: DEVPATH=/devices/pci0000:00/0000:00:18.5
+E: MODALIAS=pci:v00001022d00001405sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1405
+E: PCI_SLOT_NAME=0000:00:18.5
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi
+E: DEVPATH=/devices/platform/hp-wmi
+E: DRIVER=hp-wmi
+E: MODALIAS=platform:hp-wmi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill0
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill0
+E: RFKILL_NAME=hp-wifi
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill1
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill1
+E: RFKILL_NAME=hp-bluetooth
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Hewlett-Packard
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7978821
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=20 0 0 500f02100403 3803078f900d401 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB83-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8A,8C,8E,8F,98,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,C0,C1,CA,D4,D9,E0,E1,E2,E3,EC,EE,185,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab83
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2136324
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2142211
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=serio_raw
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/misc/serio_raw0
+N: serio_raw0
+E: DEVNAME=/dev/serio_raw0
+E: DEVPATH=/devices/platform/i8042/serio1/misc/serio_raw0
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7974031
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7977629
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7980552
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981271
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981372
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981432
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981492
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981557
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981620
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981685
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981758
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981832
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981906
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7981986
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982067
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982143
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982225
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982309
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982397
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982482
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982568
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982668
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982769
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982876
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7982984
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983097
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983214
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983325
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983451
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983564
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983686
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7983806
+
+P: /devices/platform/vesafb.0
+E: DEVPATH=/devices/platform/vesafb.0
+E: DRIVER=vesafb
+E: MODALIAS=platform:vesafb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/vesafb.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/platform/vesafb.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: PRIMARY_DEVICE_FOR_DISPLAY=1
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=17778091
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:05/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2118337
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0002:family:0015:model:0010:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0017,0018,0019,001A,001C,0020,0021,0022,0023,0024,0025,0026,0027,0028,0029,002B,002C,002D,002E,002F,0030,0031,0034,0036,0037,0038,0039,003A,003B,003D,0064,0068,006A,006E,0070,0071,0074,0078,007A,007C,0080,0081,0083,0089,008C,008D,0093,0094,0097,0099,009A,009B,009C,009D,00C0,00C1,00C2,00C3,00C4,00C5,00C6,00C7,00C8,00C9,00CA,00CB,00CC,00CD,00CF,00D0,00D1,00D3,00D5,00D6,00D7,00D8,00E1,00E2,00E8,0105,0106,0107,0108,0109,010A,010B,010C,010D,010E,0123
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0002:family:0015:model:0010:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0017,0018,0019,001A,001C,0020,0021,0022,0023,0024,0025,0026,0027,0028,0029,002B,002C,002D,002E,002F,0030,0031,0034,0036,0037,0038,0039,003A,003B,003D,0064,0068,006A,006E,0070,0071,0074,0078,007A,007C,0080,0081,0083,0089,008C,008D,0093,0094,0097,0099,009A,009B,009C,009D,00C0,00C1,00C2,00C3,00C4,00C5,00C6,00C7,00C8,00C9,00CA,00CB,00CC,00CD,00CF,00D0,00D1,00D3,00D5,00D6,00D7,00D8,00E1,00E2,00E8,0105,0106,0107,0108,0109,010A,010B,010C,010D,010E,0123
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory40
+E: DEVPATH=/devices/system/memory/memory40
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory41
+E: DEVPATH=/devices/system/memory/memory41
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory42
+E: DEVPATH=/devices/system/memory/memory42
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory43
+E: DEVPATH=/devices/system/memory/memory43
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory44
+E: DEVPATH=/devices/system/memory/memory44
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory45
+E: DEVPATH=/devices/system/memory/memory45
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory46
+E: DEVPATH=/devices/system/memory/memory46
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory47
+E: DEVPATH=/devices/system/memory/memory47
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory48
+E: DEVPATH=/devices/system/memory/memory48
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory49
+E: DEVPATH=/devices/system/memory/memory49
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory50
+E: DEVPATH=/devices/system/memory/memory50
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory51
+E: DEVPATH=/devices/system/memory/memory51
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory52
+E: DEVPATH=/devices/system/memory/memory52
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory53
+E: DEVPATH=/devices/system/memory/memory53
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory54
+E: DEVPATH=/devices/system/memory/memory54
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory55
+E: DEVPATH=/devices/system/memory/memory55
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory56
+E: DEVPATH=/devices/system/memory/memory56
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory57
+E: DEVPATH=/devices/system/memory/memory57
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory58
+E: DEVPATH=/devices/system/memory/memory58
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory59
+E: DEVPATH=/devices/system/memory/memory59
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory60
+E: DEVPATH=/devices/system/memory/memory60
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory61
+E: DEVPATH=/devices/system/memory/memory61
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory62
+E: DEVPATH=/devices/system/memory/memory62
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory63
+E: DEVPATH=/devices/system/memory/memory63
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory64
+E: DEVPATH=/devices/system/memory/memory64
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory65
+E: DEVPATH=/devices/system/memory/memory65
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory66
+E: DEVPATH=/devices/system/memory/memory66
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory67
+E: DEVPATH=/devices/system/memory/memory67
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1905419
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1905748
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1905981
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1906264
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1911665
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1911887
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1912160
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1912364
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1912573
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1912779
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1912982
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1913146
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1913341
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1913548
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1913753
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1913953
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1914132
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1914327
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1914530
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1914727
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1914931
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1915128
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1915328
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1915530
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnInsyde:bvrB.0C:bd07/12/2013:svnHewlett-Packard:pnHPPavilion14NotebookPC:pvr088E100000005910000630100:rvnHewlett-Packard:rn2169:rvr30.0F:cvnHewlett-Packard:ct10:cvrChassisVersion:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input11
+E: DEVPATH=/devices/virtual/input/input11
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_SERIAL=noserial
+E: KEY=30000 ff0000 ffffffffffffffff ffffffffffffffff ffffffffffffffff fffffffffffffffe
+E: MODALIAS=input:b0000v0000p0000e0000-e0,1,2,k71,72,73,74,75,76,77,78,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8B,8C,8D,8E,8F,90,91,92,93,94,95,96,97,98,99,9A,9B,9C,9D,9E,9F,A0,A1,A2,A3,A4,A5,A6,A7,A8,A9,AA,AB,AC,AD,AE,AF,B0,B1,B2,B3,B4,B5,B6,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,C3,C4,C5,C6,C7,C8,C9,CA,CB,CC,CD,CE,CF,D0,D1,D2,D3,D4,D5,D6,D7,D8,D9,DA,DB,DC,DD,DE,DF,E0,E1,E2,E3,E4,E5,E6,E7,E8,E9,EA,EB,EC,ED,EE,EF,F0,F1,F2,F3,F4,F5,F6,F7,F8,F9,FA,FB,FC,FD,FE,FF,110,111,112,113,114,115,116,117,150,151,r0,1,6,8,amlsfw
+E: NAME="GlidePoint Virtual Touchpad"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: REL=143
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29763347
+
+P: /devices/virtual/input/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/virtual/input/input11/event11
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29769422
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/input11/mouse1
+N: input/mouse1
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/virtual/input/input11/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=29768726
+
+P: /devices/virtual/input/input5
+E: DEVPATH=/devices/virtual/input/input5
+E: EV=33
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=4000000000 0 1000700000000 2100400 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,5,k8A,94,99,E0,E1,E2,F0,166,ram4,lsfw1,5,
+E: MSC=10
+E: NAME="HP WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=22
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8437642
+
+P: /devices/virtual/input/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/virtual/input/input5/event5
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8906125
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/btrfs-control
+N: btrfs-control
+E: DEVNAME=/dev/btrfs-control
+E: DEVPATH=/devices/virtual/misc/btrfs-control
+E: MAJOR=10
+E: MINOR=234
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8207238
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8209146
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8504189
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8411035
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8211713
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8211298
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8211344
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8212683
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8212286
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8212347
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8213405
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8213155
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8214371
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8213811
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8214432
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8214301
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8214010
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8216140
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8215154
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8215735
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8215612
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8215338
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8215774
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8216673
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8217548
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8216977
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8219988
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8220733
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8221228
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8221524
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8220995
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8221808
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8222158
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8222450
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8222719
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8221795
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8222414
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8222874
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8224127
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8224127
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8225276
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8225328
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8225862
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8225927
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8226359
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8226779
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8227155
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8227465
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8227767
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8228838
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8228898
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8229242
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8229558
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8230031
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8230560
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8231002
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8231069
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8231579
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8231633
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8232163
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8232255
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8232777
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8232829
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8233337
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8233390
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8233877
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8234588
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8235059
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8235090
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8235733
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8235782
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8236138
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: DEVPATH=/devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: MODALIAS=wmi:14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: DEVPATH=/devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: MODALIAS=wmi:1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: DEVPATH=/devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: MODALIAS=wmi:2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: DEVPATH=/devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: MODALIAS=wmi:322F2028-0F84-4901-988E-015176049E2D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: DEVPATH=/devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: MODALIAS=wmi:5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: DEVPATH=/devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: MODALIAS=wmi:8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: DEVPATH=/devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: MODALIAS=wmi:95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: DEVPATH=/devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: MODALIAS=wmi:988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/D0992BD4-A47C-4EFE-B072-324AEC92296C
+E: DEVPATH=/devices/virtual/wmi/D0992BD4-A47C-4EFE-B072-324AEC92296C
+E: MODALIAS=wmi:D0992BD4-A47C-4EFE-B072-324AEC92296C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: DEVPATH=/devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: MODALIAS=wmi:DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PAVILIONSLEEKBOOK14_ACCELEROMETER.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PAVILIONSLEEKBOOK14_ACCELEROMETER.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PAVILIONSLEEKBOOK14_ACCELEROMETER.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,4447 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1753008
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1806304
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/ACAD
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/ACAD
+E: POWER_SUPPLY_NAME=ACAD
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/HPQ0004:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/HPQ0004:00
+E: DRIVER=hp_accel
+E: MODALIAS=acpi:HPQ0004:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14466255
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input7/event7
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14477791
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/HPQ8001:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/HPQ8001:00
+E: MODALIAS=acpi:HPQ8001:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/SYN1E82:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:02/SYN1E82:00
+E: MODALIAS=acpi:SYN1E82:SYN1E00:SYN0002:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:03/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d/device:0e/device:0f/device:12/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15/device:16/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:14/device:15/device:16/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:19/device:1a/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:25/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:25/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:27/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:27/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:27/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:27/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CHARGE_FULL=2528000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=2528000
+E: POWER_SUPPLY_CHARGE_NOW=2528000
+E: POWER_SUPPLY_CURRENT_NOW=0
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_MANUFACTURER=Hewlett-Packard
+E: POWER_SUPPLY_MODEL_NAME=Primary
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER= 
+E: POWER_SUPPLY_STATUS=Full
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=14400000
+E: POWER_SUPPLY_VOLTAGE_NOW=16679000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1732981
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1810298
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1733076
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1816210
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/device:2c/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/device:2c/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: DRIVER=agpgart-intel
+E: MODALIAS=pci:v00008086d00000104sv0000103Csd000018FCbc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0104
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000106sv0000103Csd000018FCbc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0106
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14472455
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-10
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-10
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-11
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-11
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-12
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-12
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-13
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-13
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-9
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-9
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv0000103Csd000018FCbc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-27-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-27-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-27-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1810674
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-27-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-27-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-27-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1810269
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0302dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usbmon/usbmon3
+N: usbmon3
+E: DEVNAME=/dev/usbmon3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usbmon/usbmon3
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usbmon/usbmon4
+N: usbmon4
+E: DEVNAME=/dev/usbmon4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usbmon/usbmon4
+E: MAJOR=252
+E: MINOR=4
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv0000103Csd000018FCbc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E2Dsv0000103Csd000018FCbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-27-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-27-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-27-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1811850
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1817081
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usbmon/usbmon1
+N: usbmon1
+E: DEVNAME=/dev/usbmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv0000103Csd000018FCbc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Panther Point High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16369675
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15927639
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15927262
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15925695
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15946856
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15928382
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15962767
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15925175
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15944787
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15926898
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15926526
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15926131
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15929363
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv0000103Csd000018FCbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DRIVER=rt2860
+E: MODALIAS=pci:v00001814d00003290sv0000103Csd000018ECbc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=1814:3290
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=103C:18EC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/ra0
+E: COMMENT=PCI device 0x1814:/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0 (rt2860)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/ra0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: ID_VENDOR_FROM_DATABASE=Ralink corp.
+E: ID_VENDOR_ID=0x1814
+E: IFINDEX=3
+E: INTERFACE=ra0
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13258923
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.1
+E: DRIVER=rtbt
+E: MODALIAS=pci:v00001814d00003298sv0000103Csd000018ECbc0Dsc11i00
+E: PCI_CLASS=D1100
+E: PCI_ID=1814:3298
+E: PCI_SLOT_NAME=0000:01:00.1
+E: PCI_SUBSYS_ID=103C:18EC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.1/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.1/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.1/bluetooth/hci0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.1/bluetooth/hci0/rfkill2
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E12sv0000103Csd000018FCbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: DRIVER=r8169
+E: MODALIAS=pci:v000010ECd00008136sv0000103Csd000018FCbc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8136
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:02:00.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:02:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8101E/RTL8102E PCI Express Fast Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13223526
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E14sv0000103Csd000018FCbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E14
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0
+E: DRIVER=rts5229
+E: MODALIAS=pci:v000010ECd00005229sv0000103Csd000018FCbcFFsc00i00
+E: PCI_CLASS=FF0000
+E: PCI_ID=10EC:5229
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/block/sdb
+N: sdb
+S: disk/by-path/pci-0000:03:00.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-path/pci-0000:03:00.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=scsi
+E: ID_DRIVE_FLASH_SD=1
+E: ID_MODEL=SD_M.S.
+E: ID_MODEL_ENC=SD\x2fM.S.\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:03:00.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_03_00_0-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SCSI=1
+E: ID_TYPE=disk
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=13734173
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/bsg/4:0:0:0
+N: bsg/4:0:0:0
+E: DEVNAME=/dev/bsg/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/bsg/4:0:0:0
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/scsi_device/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/scsi_device/4:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/scsi_disk/4:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/scsi_disk/4:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/host4/target4:0:0/4:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E26sv0000103Csd000018FCbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-27-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-27-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-27-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1818034
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1921138
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+N: usbmon2
+E: DEVNAME=/dev/usbmon2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00001E5Esv0000103Csd000018FCbc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E5E
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=Panther Point 6 port SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001E03sv0000103Csd000018FCbc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1E03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11750620
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S
+S: disk/by-id/wwn-0x50000393e6e80391
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S /dev/disk/by-id/wwn-0x50000393e6e80391 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=TOSHIBA_MQ01ABD050
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD050\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_32HFF056S
+E: ID_SERIAL=TOSHIBA_MQ01ABD050_32HFF056S
+E: ID_SERIAL_SHORT=32HFF056S
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393e6e80391
+E: ID_WWN_WITH_EXTENSION=0x50000393e6e80391
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1697645
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S-part1
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S-part1
+S: disk/by-id/wwn-0x50000393e6e80391-part1
+S: disk/by-label/PQSERVICE
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/5024-B97F
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S-part1 /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S-part1 /dev/disk/by-id/wwn-0x50000393e6e80391-part1 /dev/disk/by-label/PQSERVICE /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/5024-B97F
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=PQSERVICE
+E: ID_FS_LABEL_ENC=PQSERVICE
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=5024-B97F
+E: ID_FS_UUID_ENC=5024-B97F
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=TOSHIBA_MQ01ABD050
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD050\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=20969473
+E: ID_PART_ENTRY_TYPE=0x1c
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_32HFF056S
+E: ID_SERIAL=TOSHIBA_MQ01ABD050_32HFF056S
+E: ID_SERIAL_SHORT=32HFF056S
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393e6e80391
+E: ID_WWN_WITH_EXTENSION=0x50000393e6e80391
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=10736370176
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x1c
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2475380
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S-part2
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S-part2
+S: disk/by-id/wwn-0x50000393e6e80391-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-uuid/ff04617f-489b-4ef4-b320-dbed3ff82818
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S-part2 /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S-part2 /dev/disk/by-id/wwn-0x50000393e6e80391-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-uuid/ff04617f-489b-4ef4-b320-dbed3ff82818
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=ff04617f-489b-4ef4-b320-dbed3ff82818
+E: ID_FS_UUID_ENC=ff04617f-489b-4ef4-b320-dbed3ff82818
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=TOSHIBA_MQ01ABD050
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD050\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=20973568
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=943435776
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_32HFF056S
+E: ID_SERIAL=TOSHIBA_MQ01ABD050_32HFF056S
+E: ID_SERIAL_SHORT=32HFF056S
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393e6e80391
+E: ID_WWN_WITH_EXTENSION=0x50000393e6e80391
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=10738466816
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=483039117312
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2254235
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S-part3
+S: disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S-part3
+S: disk/by-id/wwn-0x50000393e6e80391-part3
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+S: disk/by-uuid/06c75bce-addb-4138-89a5-98e5585999a1
+E: DEVLINKS=/dev/disk/by-id/ata-TOSHIBA_MQ01ABD050_32HFF056S-part3 /dev/disk/by-id/scsi-SATA_TOSHIBA_MQ01ABD_32HFF056S-part3 /dev/disk/by-id/wwn-0x50000393e6e80391-part3 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3 /dev/disk/by-uuid/06c75bce-addb-4138-89a5-98e5585999a1
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=104
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=06c75bce-addb-4138-89a5-98e5585999a1
+E: ID_FS_UUID_ENC=06c75bce-addb-4138-89a5-98e5585999a1
+E: ID_FS_VERSION=2
+E: ID_MODEL=TOSHIBA_MQ01ABD050
+E: ID_MODEL_ENC=TOSHIBA\x20MQ01ABD050\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=964409344
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=12361728
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=AX001C
+E: ID_SCSI_COMPAT=SATA_TOSHIBA_MQ01ABD_32HFF056S
+E: ID_SERIAL=TOSHIBA_MQ01ABD050_32HFF056S
+E: ID_SERIAL_SHORT=32HFF056S
+E: ID_TYPE=disk
+E: ID_WWN=0x50000393e6e80391
+E: ID_WWN_WITH_EXTENSION=0x50000393e6e80391
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=493777584128
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=6329204736
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2379614
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv0000103Csd000018FCbc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=103C:18FC
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi
+E: DEVPATH=/devices/platform/hp-wmi
+E: DRIVER=hp-wmi
+E: MODALIAS=platform:hp-wmi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill0
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill0
+E: RFKILL_NAME=hp-wifi
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill1
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill1
+E: RFKILL_NAME=hp-bluetooth
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Hewlett-Packard
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11764840
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=20 0 0 500f02100403 3803078f900d401 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8A,8C,8E,8F,98,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,C0,C1,CA,D4,D9,E0,E1,E2,E3,EC,EE,185,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1821740
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1827244
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input6
+E: ABS=260800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=6420 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=9
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13745342
+
+P: /devices/platform/i8042/serio1/input/input6/event6
+N: input/event6
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6/event6
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13753606
+
+P: /devices/platform/i8042/serio1/input/input6/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13754742
+
+P: /devices/platform/lis3lv02d
+E: DEVPATH=/devices/platform/lis3lv02d
+E: MODALIAS=platform:lis3lv02d
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/lis3lv02d/input/input5
+E: ABS=7
+E: DEVPATH=/devices/platform/lis3lv02d/input/input5
+E: EV=9
+E: ID_INPUT=1
+E: ID_INPUT_ACCELEROMETER=1
+E: ID_PATH=platform-lis3lv02d
+E: ID_PATH_TAG=platform-lis3lv02d
+E: MODALIAS=input:b0019v0000p0000e0000-e0,3,kra0,1,2,mlsfw
+E: NAME="ST LIS3LV02DL Accelerometer"
+E: PHYS="lis3lv02d/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13280010
+
+P: /devices/platform/lis3lv02d/input/input5/event5
+N: input/event5
+S: input/by-path/platform-lis3lv02d-event
+E: DEVLINKS=/dev/input/by-path/platform-lis3lv02d-event
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/platform/lis3lv02d/input/input5/event5
+E: ID_INPUT=1
+E: ID_INPUT_ACCELEROMETER=1
+E: ID_PATH=platform-lis3lv02d
+E: ID_PATH_TAG=platform-lis3lv02d
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13490256
+
+P: /devices/platform/lis3lv02d/input/input5/js0
+N: input/js0
+E: DEVNAME=/dev/input/js0
+E: DEVPATH=/devices/platform/lis3lv02d/input/input5/js0
+E: ID_INPUT=1
+E: ID_INPUT_ACCELEROMETER=1
+E: ID_PATH=platform-lis3lv02d
+E: ID_PATH_TAG=platform-lis3lv02d
+E: MAJOR=13
+E: MINOR=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13490873
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11831691
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11832603
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11832613
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11833884
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11834893
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11836820
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11836822
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11837755
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11838534
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11838544
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11839393
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11839822
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11840320
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11840721
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11841097
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785039
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785081
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785127
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785171
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785219
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785269
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785314
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785362
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785410
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785464
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785515
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785564
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785616
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785665
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785718
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785772
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11785824
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1830993
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1697890
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698008
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698146
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698273
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698392
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698518
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698648
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1698769
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1698890
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699018
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699155
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699280
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699398
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699527
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699654
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699779
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1699900
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1718080
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1731413
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1710187
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1710319
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1710444
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1710568
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1710690
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnInsyde:bvrB.0C:bd08/03/2012:svnHewlett-Packard:pnPavilionSleekbook14:pvr088F1000000B0000000320100:rvnHewlett-Packard:rn18FC:rvr82.0F:cvnHewlett-Packard:ct10:cvrChassisVersion:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input4
+E: DEVPATH=/devices/virtual/input/input4
+E: EV=33
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=4000000000 0 1000700000000 2100400 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,5,k8A,94,99,E0,E1,E2,F0,166,ram4,lsfw1,5,
+E: MSC=10
+E: NAME="HP WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=22
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12180044
+
+P: /devices/virtual/input/input4/event4
+N: input/event4
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/virtual/input/input4/event4
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12449278
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/leds/hp::hddprotect
+E: DEVPATH=/devices/virtual/leds/hp::hddprotect
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/virtual/mei/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/mei/mei
+E: MAJOR=251
+E: MINOR=1
+E: SUBSYSTEM=mei
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/agpgart
+N: agpgart
+E: DEVNAME=/dev/agpgart
+E: DEVPATH=/devices/virtual/misc/agpgart
+E: MAJOR=10
+E: MINOR=175
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/btrfs-control
+N: btrfs-control
+E: DEVNAME=/dev/btrfs-control
+E: DEVPATH=/devices/virtual/misc/btrfs-control
+E: MAJOR=10
+E: MINOR=234
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/freefall
+N: freefall
+E: DEVNAME=/dev/freefall
+E: DEVPATH=/devices/virtual/misc/freefall
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11885238
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11886794
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13519247
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13513982
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11888731
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11889456
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11889189
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11889206
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11890092
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11889850
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11890554
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11890578
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11891185
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11891237
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11891558
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11891883
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11892207
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11892519
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11892826
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11893140
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11893586
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11894380
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11894547
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11893755
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11894085
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11894407
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11895178
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11896078
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11895733
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11895464
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11895479
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11895913
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11896840
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11897117
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11897356
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11897628
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11897082
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11897548
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11898375
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11898910
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11898642
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11898609
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11899174
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11899112
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11899947
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11900177
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11900464
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11900727
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11900208
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11900666
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11901474
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11901737
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11902004
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11902345
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11904558
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11904877
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11905803
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11905612
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11904861
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11905212
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11905543
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11905869
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11906188
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11907594
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11908150
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11907865
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11907580
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11908107
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11908888
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11909344
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11909491
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11909079
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: DEVNAME=/dev/usbmon0
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs63
+N: vcs63
+E: DEVNAME=/dev/vcs63
+E: DEVPATH=/devices/virtual/vc/vcs63
+E: MAJOR=7
+E: MINOR=63
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa63
+N: vcsa63
+E: DEVNAME=/dev/vcsa63
+E: DEVPATH=/devices/virtual/vc/vcsa63
+E: MAJOR=7
+E: MINOR=191
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: DEVPATH=/devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: MODALIAS=wmi:14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: DEVPATH=/devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: MODALIAS=wmi:1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: DEVPATH=/devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: MODALIAS=wmi:2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: DEVPATH=/devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: MODALIAS=wmi:322F2028-0F84-4901-988E-015176049E2D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: DEVPATH=/devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: MODALIAS=wmi:5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: DEVPATH=/devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: MODALIAS=wmi:8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: DEVPATH=/devices/virtual/wmi/8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: MODALIAS=wmi:8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: DEVPATH=/devices/virtual/wmi/8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: MODALIAS=wmi:8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: DEVPATH=/devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: MODALIAS=wmi:95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: DEVPATH=/devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: MODALIAS=wmi:988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/D0992BD4-A47C-4EFE-B072-324AEC92296C
+E: DEVPATH=/devices/virtual/wmi/D0992BD4-A47C-4EFE-B072-324AEC92296C
+E: MODALIAS=wmi:D0992BD4-A47C-4EFE-B072-324AEC92296C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: DEVPATH=/devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: MODALIAS=wmi:DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PRO2110.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PRO2110.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PRO2110.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,4642 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=949018
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input1/event1
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=958792
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:04
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0501:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0501:00
+E: MODALIAS=acpi:PNP0501:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C02:03
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:05/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:05/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:05/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:05/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:08/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:08/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:08/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:04/device:08/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0f/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0f/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:01
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=962879
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=970523
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: DRIVER=agpgart-intel
+E: MODALIAS=pci:v00008086d00002E30sv0000103Csd00003666bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2E30
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00002E32sv0000103Csd00003666bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:2E32
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12317380
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-10
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-10
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-11
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-11
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-12
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-12
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-13
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-13
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-9
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-9
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.1
+E: MODALIAS=pci:v00008086d00002E33sv0000103Csd00003666bc03sc80i00
+E: PCI_CLASS=38000
+E: PCI_ID=8086:2E33
+E: PCI_SLOT_NAME=0000:00:02.1
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d000027D8sv0000103Csd00003666bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:27D8
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=N10/ICH 7 Family High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15871609
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13396928
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input4
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input4
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfwD,
+E: NAME="HDA Intel Line"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=2000
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13396104
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input4/event4
+N: input/event4
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input4/event4
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13399843
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input5
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13396302
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input5/event5
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13398628
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input6
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel Front Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13396456
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input6/event6
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13400175
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input7
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,
+E: NAME="HDA Intel Line-Out"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=40
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13397638
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input7/event7
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13401012
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13396709
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13397325
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D2c
+N: snd/pcmC0D2c
+E: DEVNAME=/dev/snd/pcmC0D2c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D2c
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13397532
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13397201
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d000027D0sv0000103Csd00003666bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:27D0
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie08
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie08
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: DRIVER=r8169
+E: MODALIAS=pci:v000010ECd00008168sv0000103Csd00003666bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8168
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:01:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8111/8168B PCI Express Gigabit Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.0/0000:01:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9311821
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d000027C8sv0000103Csd00003666bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27C8
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-49-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-49-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-49-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=943039
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=IBM_73P5832
+E: ID_MODEL_ENC=IBM\x2073P5832
+E: ID_MODEL_ID=0296
+E: ID_REVISION=0100
+E: ID_SERIAL=Avocent_IBM_73P5832
+E: ID_USB_INTERFACES=:030101:030102:
+E: ID_VENDOR=Avocent
+E: ID_VENDOR_ENC=Avocent
+E: ID_VENDOR_ID=0624
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=624/296/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8652540
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/1
+E: MODALIAS=usb:v0624p0296d0100dc00dsc00dp00ic03isc01ip01
+E: PRODUCT=624/296/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/0003:0624:0296.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/0003:0624:0296.0001
+E: DRIVER=generic-usb
+E: HID_ID=0003:00000624:00000296
+E: HID_NAME=Avocent IBM 73P5832
+E: HID_PHYS=usb-0000:00:1d.0-1/input0
+E: MODALIAS=hid:b0003v00000624p00000296
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/0003:0624:0296.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/0003:0624:0296.0001/hidraw/hidraw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/input/input2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/input/input2
+E: EV=120013
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=IBM_73P5832
+E: ID_MODEL_ENC=IBM\x2073P5832
+E: ID_MODEL_ID=0296
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=Avocent_IBM_73P5832
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Avocent
+E: ID_VENDOR_ENC=Avocent
+E: ID_VENDOR_ID=0624
+E: KEY=1000000000007 ff800000000007ff f2beffdf73cfffff fffffffffffffffe
+E: LED=1f
+E: MODALIAS=input:b0003v0624p0296e0110-e0,1,4,11,14,k71,72,73,74,75,77,79,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,3,4,sfw
+E: MSC=10
+E: NAME="Avocent IBM 73P5832"
+E: PHYS="usb-0000:00:1d.0-1/input0"
+E: PRODUCT=3/624/296/110
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=11487621
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/input/input2/event2
+N: input/event2
+S: input/by-id/usb-Avocent_IBM_73P5832-event-kbd
+S: input/by-path/pci-0000:00:1d.0-usb-0:1:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-Avocent_IBM_73P5832-event-kbd /dev/input/by-path/pci-0000:00:1d.0-usb-0:1:1.0-event-kbd
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0/input/input2/event2
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=IBM_73P5832
+E: ID_MODEL_ENC=IBM\x2073P5832
+E: ID_MODEL_ID=0296
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=Avocent_IBM_73P5832
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Avocent
+E: ID_VENDOR_ENC=Avocent
+E: ID_VENDOR_ID=0624
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11525043
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v0624p0296d0100dc00dsc00dp00ic03isc01ip02
+E: PRODUCT=624/296/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/0003:0624:0296.0002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/0003:0624:0296.0002
+E: DRIVER=generic-usb
+E: HID_ID=0003:00000624:00000296
+E: HID_NAME=Avocent IBM 73P5832
+E: HID_PHYS=usb-0000:00:1d.0-1/input1
+E: MODALIAS=hid:b0003v00000624p00000296
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/0003:0624:0296.0002/hidraw/hidraw1
+N: hidraw1
+E: DEVNAME=/dev/hidraw1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/0003:0624:0296.0002/hidraw/hidraw1
+E: MAJOR=251
+E: MINOR=1
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/input/input3
+E: ABS=100000000
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/input/input3
+E: EV=1f
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=IBM_73P5832
+E: ID_MODEL_ENC=IBM\x2073P5832
+E: ID_MODEL_ID=0296
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1:1.1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1
+E: ID_REVISION=0100
+E: ID_SERIAL=Avocent_IBM_73P5832
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Avocent
+E: ID_VENDOR_ENC=Avocent
+E: ID_VENDOR_ID=0624
+E: KEY=4837fff072ff32d bf54444600000000 1f0001 20c100b17c000 267bfad941dfed 9e168000004400 10000002
+E: MODALIAS=input:b0003v0624p0296e0110-e0,1,2,3,4,k71,72,73,74,77,80,82,83,85,86,87,88,89,8A,8B,8C,8E,8F,90,96,98,9B,9C,9E,9F,A1,A3,A4,A5,A6,A7,A8,A9,AB,AC,AD,AE,B1,B2,B5,CE,CF,D0,D1,D2,D4,D8,D9,DB,E4,EA,EB,F1,100,110,111,112,113,114,161,162,166,16A,16E,172,174,176,178,179,17A,17B,17C,17D,17F,180,182,183,185,188,189,18C,18D,18E,18F,190,191,192,193,195,198,199,19A,1A0,1A1,1A2,1A3,1A4,1A5,1A6,1A7,1A8,1A9,1AA,1AB,1AC,1AD,1AE,1B0,1B1,1B7,1BA,r0,1,6,8,a20,m4,lsfw
+E: MSC=10
+E: NAME="Avocent IBM 73P5832"
+E: PHYS="usb-0000:00:1d.0-1/input1"
+E: PRODUCT=3/624/296/110
+E: PROP=0
+E: REL=143
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=11521318
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/input/input3/event3
+N: input/event3
+S: input/by-id/usb-Avocent_IBM_73P5832-if01-event-mouse
+S: input/by-path/pci-0000:00:1d.0-usb-0:1:1.1-event-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Avocent_IBM_73P5832-if01-event-mouse /dev/input/by-path/pci-0000:00:1d.0-usb-0:1:1.1-event-mouse
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/input/input3/event3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=IBM_73P5832
+E: ID_MODEL_ENC=IBM\x2073P5832
+E: ID_MODEL_ID=0296
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1:1.1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1
+E: ID_REVISION=0100
+E: ID_SERIAL=Avocent_IBM_73P5832
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Avocent
+E: ID_VENDOR_ENC=Avocent
+E: ID_VENDOR_ID=0624
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11564416
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/input/input3/mouse0
+N: input/mouse0
+S: input/by-id/usb-Avocent_IBM_73P5832-if01-mouse
+S: input/by-path/pci-0000:00:1d.0-usb-0:1:1.1-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Avocent_IBM_73P5832-if01-mouse /dev/input/by-path/pci-0000:00:1d.0-usb-0:1:1.1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.1/input/input3/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=IBM_73P5832
+E: ID_MODEL_ENC=IBM\x2073P5832
+E: ID_MODEL_ID=0296
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1:1.1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1
+E: ID_REVISION=0100
+E: ID_SERIAL=Avocent_IBM_73P5832
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Avocent
+E: ID_VENDOR_ENC=Avocent
+E: ID_VENDOR_ID=0624
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11564369
+
+P: /devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+N: usbmon2
+E: DEVNAME=/dev/usbmon2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d000027C9sv0000103Csd00003666bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27C9
+E: PCI_SLOT_NAME=0000:00:1d.1
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.1/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-49-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.1
+E: ID_SERIAL_SHORT=0000:00:1d.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-49-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-49-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=943670
+
+P: /devices/pci0000:00/0000:00:1d.1/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.1/usbmon/usbmon3
+N: usbmon3
+E: DEVNAME=/dev/usbmon3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usbmon/usbmon3
+E: MAJOR=252
+E: MINOR=3
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d000027CAsv0000103Csd00003666bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27CA
+E: PCI_SLOT_NAME=0000:00:1d.2
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-49-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.2
+E: ID_SERIAL_SHORT=0000:00:1d.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-49-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-49-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=943457
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.2/usbmon/usbmon4
+N: usbmon4
+E: DEVNAME=/dev/usbmon4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usbmon/usbmon4
+E: MAJOR=252
+E: MINOR=4
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3
+E: DRIVER=uhci_hcd
+E: MODALIAS=pci:v00008086d000027CBsv0000103Csd00003666bc0Csc03i00
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27CB
+E: PCI_SLOT_NAME=0000:00:1d.3
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.3/usb5
+N: bus/usb/005/001
+E: BUSNUM=005
+E: DEVNAME=/dev/bus/usb/005/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3/usb5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-49-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.3
+E: ID_SERIAL_SHORT=0000:00:1d.3
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-49-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-49-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=512
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=945778
+
+P: /devices/pci0000:00/0000:00:1d.3/usb5/5-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3/usb5/5-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.3/usbmon/usbmon5
+N: usbmon5
+E: DEVNAME=/dev/usbmon5
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3/usbmon/usbmon5
+E: MAJOR=252
+E: MINOR=5
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d000027CCsv0000103Csd00003666bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:27CC
+E: PCI_SLOT_NAME=0000:00:1d.7
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-49-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.7
+E: ID_SERIAL_SHORT=0000:00:1d.7
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-49-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-49-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=944635
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0-CRW
+E: ID_MODEL_ENC=USB2.0-CRW
+E: ID_MODEL_ID=0151
+E: ID_REVISION=5195
+E: ID_SERIAL=Generic_USB2.0-CRW_20060413092100000
+E: ID_SERIAL_SHORT=20060413092100000
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=Generic
+E: ID_VENDOR_ENC=Generic
+E: ID_VENDOR_ID=0bda
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=bda/151/5195
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1171696
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v0BDAp0151d5195dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=bda/151/5195
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-Generic-_Compact_Flash_20060413092100000-0:0
+S: disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-Generic-_Compact_Flash_20060413092100000-0:0 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=Compact_Flash
+E: ID_MODEL_ENC=Compact\x20Flash\x20\x20\x20
+E: ID_MODEL_ID=0151
+E: ID_PATH=pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_5_1_0-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SERIAL=Generic-_Compact_Flash_20060413092100000-0:0
+E: ID_SERIAL_SHORT=20060413092100000
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=12659524
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+N: bsg/2:0:0:0
+E: DEVNAME=/dev/bsg/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+E: MAJOR=253
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/scsi_disk/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/scsi_disk/2:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/block/sdc
+N: sdc
+S: disk/by-id/usb-Generic-_SM_xD-Picture_20060413092100000-0:1
+S: disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:1
+E: DEVLINKS=/dev/disk/by-id/usb-Generic-_SM_xD-Picture_20060413092100000-0:1 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:1
+E: DEVNAME=/dev/sdc
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/block/sdc
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:1
+E: ID_MODEL=SM_xD-Picture
+E: ID_MODEL_ENC=SM\x2fxD-Picture\x20\x20\x20
+E: ID_MODEL_ID=0151
+E: ID_PATH=pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:1
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_5_1_0-scsi-0_0_0_1
+E: ID_REVISION=1.00
+E: ID_SERIAL=Generic-_SM_xD-Picture_20060413092100000-0:1
+E: ID_SERIAL_SHORT=20060413092100000
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=32
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=12659124
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/bsg/2:0:0:1
+N: bsg/2:0:0:1
+E: DEVNAME=/dev/bsg/2:0:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/bsg/2:0:0:1
+E: MAJOR=253
+E: MINOR=3
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/scsi_device/2:0:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/scsi_device/2:0:0:1
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/scsi_disk/2:0:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/scsi_disk/2:0:0:1
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/scsi_generic/sg3
+N: sg3
+E: DEVNAME=/dev/sg3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:1/scsi_generic/sg3
+E: MAJOR=21
+E: MINOR=3
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/block/sdd
+N: sdd
+S: disk/by-id/usb-Generic-_SD_MMC_20060413092100000-0:2
+S: disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:2
+E: DEVLINKS=/dev/disk/by-id/usb-Generic-_SD_MMC_20060413092100000-0:2 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:2
+E: DEVNAME=/dev/sdd
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/block/sdd
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:2
+E: ID_MODEL=SD_MMC
+E: ID_MODEL_ENC=SD\x2fMMC\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0151
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:2
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_5_1_0-scsi-0_0_0_2
+E: ID_REVISION=1.00
+E: ID_SERIAL=Generic-_SD_MMC_20060413092100000-0:2
+E: ID_SERIAL_SHORT=20060413092100000
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=48
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=12664274
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/block/sdd/sdd1
+N: sdd1
+S: disk/by-id/usb-Generic-_SD_MMC_20060413092100000-0:2-part1
+S: disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:2-part1
+S: disk/by-uuid/6767-714A
+E: DEVLINKS=/dev/disk/by-id/usb-Generic-_SD_MMC_20060413092100000-0:2-part1 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:2-part1 /dev/disk/by-uuid/6767-714A
+E: DEVNAME=/dev/sdd1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/block/sdd/sdd1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=6767-714A
+E: ID_FS_UUID_ENC=6767-714A
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:2
+E: ID_MODEL=SD_MMC
+E: ID_MODEL_ENC=SD\x2fMMC\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0151
+E: ID_PART_ENTRY_DISK=8:48
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=8192
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=7766016
+E: ID_PART_ENTRY_TYPE=0xb
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:2
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_5_1_0-scsi-0_0_0_2
+E: ID_REVISION=1.00
+E: ID_SERIAL=Generic-_SD_MMC_20060413092100000-0:2
+E: ID_SERIAL_SHORT=20060413092100000
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=49
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=4194304
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=3976200192
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/block/sdd
+E: UDISKS_PARTITION_TYPE=0x0b
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=14113093
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/bsg/2:0:0:2
+N: bsg/2:0:0:2
+E: DEVNAME=/dev/bsg/2:0:0:2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/bsg/2:0:0:2
+E: MAJOR=253
+E: MINOR=4
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/scsi_device/2:0:0:2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/scsi_device/2:0:0:2
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/scsi_disk/2:0:0:2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/scsi_disk/2:0:0:2
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/scsi_generic/sg4
+N: sg4
+E: DEVNAME=/dev/sg4
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:2/scsi_generic/sg4
+E: MAJOR=21
+E: MINOR=4
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/block/sde
+N: sde
+S: disk/by-id/usb-Generic-_MS_MS-Pro_20060413092100000-0:3
+S: disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:3
+E: DEVLINKS=/dev/disk/by-id/usb-Generic-_MS_MS-Pro_20060413092100000-0:3 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:3
+E: DEVNAME=/dev/sde
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/block/sde
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:3
+E: ID_MODEL=MS_MS-Pro
+E: ID_MODEL_ENC=MS\x2fMS-Pro\x20\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0151
+E: ID_PATH=pci-0000:00:1d.7-usb-0:5:1.0-scsi-0:0:0:3
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_5_1_0-scsi-0_0_0_3
+E: ID_REVISION=1.00
+E: ID_SERIAL=Generic-_MS_MS-Pro_20060413092100000-0:3
+E: ID_SERIAL_SHORT=20060413092100000
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Generic-
+E: ID_VENDOR_ENC=Generic-
+E: ID_VENDOR_ID=0bda
+E: MAJOR=8
+E: MINOR=64
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=12657822
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/bsg/2:0:0:3
+N: bsg/2:0:0:3
+E: DEVNAME=/dev/bsg/2:0:0:3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/bsg/2:0:0:3
+E: MAJOR=253
+E: MINOR=5
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/scsi_device/2:0:0:3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/scsi_device/2:0:0:3
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/scsi_disk/2:0:0:3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/scsi_disk/2:0:0:3
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/scsi_generic/sg5
+N: sg5
+E: DEVNAME=/dev/sg5
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-5/1-5:1.0/host2/target2:0:0/2:0:0:3/scsi_generic/sg5
+E: MAJOR=21
+E: MINOR=5
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=MKNUFDPR2GB
+E: ID_MODEL_ENC=MKNUFDPR2GB
+E: ID_MODEL_ID=3600
+E: ID_REVISION=0100
+E: ID_SERIAL=MUSHKIN_MKNUFDPR2GB_07C10403C8956552
+E: ID_SERIAL_SHORT=07C10403C8956552
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=MUSHKIN
+E: ID_VENDOR_ENC=MUSHKIN
+E: ID_VENDOR_ID=13fe
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=13fe/3600/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9522863
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v13FEp3600d0100dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=13fe/3600/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/block/sdf
+N: sdf
+S: disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C8956552-0:0
+S: disk/by-path/pci-0000:00:1d.7-usb-0:7:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C8956552-0:0 /dev/disk/by-path/pci-0000:00:1d.7-usb-0:7:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdf
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/block/sdf
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=MKNUFDPR2GB
+E: ID_MODEL_ENC=MKNUFDPR2GB\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=3600
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.7-usb-0:7:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_7_1_0-scsi-0_0_0_0
+E: ID_REVISION=PMAP
+E: ID_SERIAL=MUSHKIN_MKNUFDPR2GB_07C10403C8956552-0:0
+E: ID_SERIAL_SHORT=07C10403C8956552
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=MUSHKIN
+E: ID_VENDOR_ENC=MUSHKIN\x20
+E: ID_VENDOR_ID=13fe
+E: MAJOR=8
+E: MINOR=80
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=12663985
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/block/sdf/sdf1
+N: sdf1
+S: disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C8956552-0:0-part1
+S: disk/by-label/MUSHKIN
+S: disk/by-path/pci-0000:00:1d.7-usb-0:7:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/7E58-61F8
+E: DEVLINKS=/dev/disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C8956552-0:0-part1 /dev/disk/by-label/MUSHKIN /dev/disk/by-path/pci-0000:00:1d.7-usb-0:7:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/7E58-61F8
+E: DEVNAME=/dev/sdf1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/block/sdf/sdf1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_LABEL=MUSHKIN
+E: ID_FS_LABEL_ENC=MUSHKIN
+E: ID_FS_SEC_TYPE=msdos
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=7E58-61F8
+E: ID_FS_UUID_ENC=7E58-61F8
+E: ID_FS_VERSION=FAT16
+E: ID_INSTANCE=0:0
+E: ID_MODEL=MKNUFDPR2GB
+E: ID_MODEL_ENC=MKNUFDPR2GB\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=3600
+E: ID_PART_ENTRY_DISK=8:80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=8064
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=3903616
+E: ID_PART_ENTRY_TYPE=0x6
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.7-usb-0:7:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_7_1_0-scsi-0_0_0_0
+E: ID_REVISION=PMAP
+E: ID_SERIAL=MUSHKIN_MKNUFDPR2GB_07C10403C8956552-0:0
+E: ID_SERIAL_SHORT=07C10403C8956552
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=MUSHKIN
+E: ID_VENDOR_ENC=MUSHKIN\x20
+E: ID_VENDOR_ID=13fe
+E: MAJOR=8
+E: MINOR=81
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=4128768
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=1998651392
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/block/sdf
+E: UDISKS_PARTITION_TYPE=0x06
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=14088728
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/bsg/3:0:0:0
+N: bsg/3:0:0:0
+E: DEVNAME=/dev/bsg/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/bsg/3:0:0:0
+E: MAJOR=253
+E: MINOR=6
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/scsi_device/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/scsi_device/3:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/scsi_disk/3:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/scsi_disk/3:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/scsi_generic/sg6
+N: sg6
+E: DEVNAME=/dev/sg6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-7/1-7:1.0/host3/target3:0:0/3:0:0:0/scsi_generic/sg6
+E: MAJOR=21
+E: MINOR=6
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.7/usbmon/usbmon1
+N: usbmon1
+E: DEVNAME=/dev/usbmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0
+E: MODALIAS=pci:v00008086d0000244Esv0000103Csd00003666bc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=8086:244E
+E: PCI_SLOT_NAME=0000:00:1e.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d000027B8sv0000103Csd00003666bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:27B8
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ata_piix
+E: ID_MODEL_FROM_DATABASE=N10/ICH7 Family SATA Controller [IDE mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d000027C0sv0000103Csd00003666bc01sc01i8a
+E: PCI_CLASS=1018A
+E: PCI_ID=8086:27C0
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8656237
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.1/ata_device/dev1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.1/ata_device/dev1.1
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.1/ata_device/dev2.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.1/ata_device/dev2.1
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-ST3160318AS_6VY0FDCY
+S: disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY
+S: disk/by-id/wwn-0x5000c50016149491
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-ST3160318AS_6VY0FDCY /dev/disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY /dev/disk/by-id/wwn-0x5000c50016149491 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST3160318AS
+E: ID_MODEL_ENC=ST3160318AS\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=HP11
+E: ID_SCSI_COMPAT=SATA_ST3160318AS_6VY0FDCY
+E: ID_SERIAL=ST3160318AS_6VY0FDCY
+E: ID_SERIAL_SHORT=6VY0FDCY
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50016149491
+E: ID_WWN_WITH_EXTENSION=0x5000c50016149491
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=922644
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-ST3160318AS_6VY0FDCY-part1
+S: disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY-part1
+S: disk/by-id/wwn-0x5000c50016149491-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/62203983-2293-477c-9367-c15347395705
+E: DEVLINKS=/dev/disk/by-id/ata-ST3160318AS_6VY0FDCY-part1 /dev/disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY-part1 /dev/disk/by-id/wwn-0x5000c50016149491-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/62203983-2293-477c-9367-c15347395705
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=62203983-2293-477c-9367-c15347395705
+E: ID_FS_UUID_ENC=62203983-2293-477c-9367-c15347395705
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=ST3160318AS
+E: ID_MODEL_ENC=ST3160318AS\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=308652032
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=HP11
+E: ID_SCSI_COMPAT=SATA_ST3160318AS_6VY0FDCY
+E: ID_SERIAL=ST3160318AS_6VY0FDCY
+E: ID_SERIAL_SHORT=6VY0FDCY
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50016149491
+E: ID_WWN_WITH_EXTENSION=0x5000c50016149491
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=158029840384
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1143582
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-ST3160318AS_6VY0FDCY-part2
+S: disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY-part2
+S: disk/by-id/wwn-0x5000c50016149491-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-ST3160318AS_6VY0FDCY-part2 /dev/disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY-part2 /dev/disk/by-id/wwn-0x5000c50016149491-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=ST3160318AS
+E: ID_MODEL_ENC=ST3160318AS\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=308656126
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=3923970
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=HP11
+E: ID_SCSI_COMPAT=SATA_ST3160318AS_6VY0FDCY
+E: ID_SERIAL=ST3160318AS_6VY0FDCY
+E: ID_SERIAL_SHORT=6VY0FDCY
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50016149491
+E: ID_WWN_WITH_EXTENSION=0x5000c50016149491
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=158031936512
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2009072640
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1059293
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-ST3160318AS_6VY0FDCY-part5
+S: disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY-part5
+S: disk/by-id/wwn-0x5000c50016149491-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/bcceaa7d-75e0-4896-9f9e-1bd24591207c
+E: DEVLINKS=/dev/disk/by-id/ata-ST3160318AS_6VY0FDCY-part5 /dev/disk/by-id/scsi-SATA_ST3160318AS_6VY0FDCY-part5 /dev/disk/by-id/wwn-0x5000c50016149491-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/bcceaa7d-75e0-4896-9f9e-1bd24591207c
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=32
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=bcceaa7d-75e0-4896-9f9e-1bd24591207c
+E: ID_FS_UUID_ENC=bcceaa7d-75e0-4896-9f9e-1bd24591207c
+E: ID_FS_VERSION=2
+E: ID_MODEL=ST3160318AS
+E: ID_MODEL_ENC=ST3160318AS\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=308656128
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=3923968
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=HP11
+E: ID_SCSI_COMPAT=SATA_ST3160318AS_6VY0FDCY
+E: ID_SERIAL=ST3160318AS_6VY0FDCY
+E: ID_SERIAL_SHORT=6VY0FDCY
+E: ID_TYPE=disk
+E: ID_WWN=0x5000c50016149491
+E: ID_WWN_WITH_EXTENSION=0x5000c50016149491
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=158031937536
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2009071616
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1105603
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/block/sr0
+N: sr0
+S: cdrom
+S: disk/by-id/ata-TSSTcorpDVD-ROM_TS-H353B_4R9486SB094843T_
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:1:0
+S: dvd
+E: DEVLINKS=/dev/cdrom /dev/disk/by-id/ata-TSSTcorpDVD-ROM_TS-H353B_4R9486SB094843T_ /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:1:0 /dev/dvd
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/block/sr0
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=TSSTcorpDVD-ROM_TS-H353B
+E: ID_MODEL_ENC=TSSTcorpDVD-ROM\x20TS-H353B\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:1:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_1_0
+E: ID_REVISION=DW10
+E: ID_SERIAL=TSSTcorpDVD-ROM_TS-H353B_4R9486SB094843T_
+E: ID_SERIAL_SHORT=4R9486SB094843T_
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=922760
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/bsg/0:0:1:0
+N: bsg/0:0:1:0
+E: DEVNAME=/dev/bsg/0:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/bsg/0:0:1:0
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_device/0:0:1:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_device/0:0:1:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:1/0:0:1:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=9594710
+
+P: /devices/pci0000:00/0000:00:1f.2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d000027DAsv0000103Csd00003666bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:27DA
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=103C:3666
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8699902
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8700378
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8700767
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8701314
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8701707
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8702420
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8704835
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8706020
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8706241
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8706454
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8706663
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8707210
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8707246
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8707478
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8707714
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8707925
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8708181
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8708391
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8708600
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8708810
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8709018
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8709227
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8709436
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8709646
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8709854
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8710064
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8710273
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8710693
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8710529
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8711111
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8710949
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:03/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=954518
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: DRIVER=serial
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/pnp0/00:0c/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8713898
+
+P: /devices/pnp0/00:0d
+E: DEVPATH=/devices/pnp0/00:0d
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0e
+E: DEVPATH=/devices/pnp0/00:0e
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:19
+E: DEVPATH=/devices/virtual/bdi/0:19
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:32
+E: DEVPATH=/devices/virtual/bdi/8:32
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:48
+E: DEVPATH=/devices/virtual/bdi/8:48
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:64
+E: DEVPATH=/devices/virtual/bdi/8:64
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:80
+E: DEVPATH=/devices/virtual/bdi/8:80
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=922827
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=922901
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=922976
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=923061
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=923145
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=923233
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=923318
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=923406
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=923499
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=923584
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=923677
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=923772
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=923865
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=923960
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=942269
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=939459
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=939777
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=940984
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=929142
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=929229
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=929316
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=929412
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=929497
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=929586
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnAmericanMegatrendsInc.:bvrv6.07:bd07/02/2010:svnHewlett-Packard:pnHPPro2110:pvr:rvnMICRO-STARINTERNATIONALCO.,LTD:rn3666:rvr:cvnHewlett-Packard:ct3:cvr:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/agpgart
+N: agpgart
+E: DEVNAME=/dev/agpgart
+E: DEVPATH=/devices/virtual/misc/agpgart
+E: MAJOR=10
+E: MINOR=175
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8726379
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8727244
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11741349
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11294416
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8728147
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8728334
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8728518
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8728701
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8728883
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8729186
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8729369
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8729549
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8729778
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8729960
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8730140
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8730322
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8730503
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8730683
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8730862
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8731046
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8731415
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8731445
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8731627
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8731812
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8731998
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8732219
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8732398
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8732577
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8732813
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8732849
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8733032
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8733280
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8733350
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8733537
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8733723
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8733903
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8734083
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8734262
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8734441
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8734621
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8734800
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8734980
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8735274
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8735343
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8735530
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8735715
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8735895
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8736080
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8736260
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8736441
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8736620
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8736800
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8736980
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8737232
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8737298
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8737482
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8737668
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8737849
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8738029
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8738208
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8738387
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8738566
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8738747
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8738928
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8739167
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8739350
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8739532
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8739712
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8739894
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8740189
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8740491
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8740673
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: DEVNAME=/dev/usbmon0
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs63
+N: vcs63
+E: DEVNAME=/dev/vcs63
+E: DEVPATH=/devices/virtual/vc/vcs63
+E: MAJOR=7
+E: MINOR=63
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa63
+N: vcsa63
+E: DEVNAME=/dev/vcsa63
+E: DEVPATH=/devices/virtual/vc/vcsa63
+E: MAJOR=7
+E: MINOR=191
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: DEVPATH=/devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: MODALIAS=wmi:5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PROBOOK6550B_ACCELEROMETER.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PROBOOK6550B_ACCELEROMETER.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/HP_PROBOOK6550B_ACCELEROMETER.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5636 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2705796
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2709378
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A03:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A03:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A03:00/device:4d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A03:00/device:4d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/HPQ0004:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/HPQ0004:00
+E: DRIVER=hp_accel
+E: MODALIAS=acpi:HPQ0004:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXPOWER:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXPOWER:00
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input16
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:01
+E: ID_PATH_TAG=acpi-LNXVIDEO_01
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14994028
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input16/event16
+N: input/event16
+E: DEVNAME=/dev/input/event16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:01/input/input16/event16
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:01
+E: ID_PATH_TAG=acpi-LNXVIDEO_01
+E: MAJOR=13
+E: MINOR=80
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15016777
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:02/LNXVIDEO:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:24/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:22/device:23/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/IFX0102:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/IFX0102:00
+E: MODALIAS=acpi:IFX0102:PNP0C31:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0303:00
+E: MODALIAS=acpi:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00
+E: DRIVER=container
+E: MODALIAS=acpi:PNP0A06:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/LNXPOWER:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/LNXPOWER:01
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/LNXPOWER:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/LNXPOWER:02
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/PNP0401:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/PNP0401:00
+E: MODALIAS=acpi:PNP0401:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/PNP0501:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0A06:00/PNP0501:00
+E: MODALIAS=acpi:PNP0501:PNP0500:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/SYN0179:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/SYN0179:00
+E: MODALIAS=acpi:SYN0179:SYN0100:SYN0002:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2e/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:47
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:47
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:48
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:48
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:49
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:49
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0A:01
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2669033
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2745726
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2669114
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input0/event0
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2745701
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C32:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C32:00
+E: MODALIAS=acpi:PNP0C32:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:01
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:02
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:03
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:04
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:05
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:06
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:07
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:08
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:09
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: DRIVER=agpgart-intel
+E: MODALIAS=pci:v00008086d00000044sv0000103Csd0000146Dbc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0044
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000046sv0000103Csd0000146Dbc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0046
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15000665
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-14
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-15
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-15
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-16
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-16
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-10
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-10
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-11
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-11
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-12
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-12
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-13
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-13
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-9
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-9
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00003B64sv0000103Csd0000146Dbc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:3B64
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0
+E: DRIVER=e1000e
+E: MODALIAS=pci:v00008086d000010EBsv0000103Csd00001471bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=8086:10EB
+E: PCI_SLOT_NAME=0000:00:19.0
+E: PCI_SUBSYS_ID=103C:1471
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=82577LC Gigabit Network Connection
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:19.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10825367
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00003B3Csv0000103Csd0000146Dbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:3B3C
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-48-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-48-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-48-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2708801
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0020
+E: ID_MODEL_ENC=0020
+E: ID_MODEL_ID=0020
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0020
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2672797
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=HP_Integrated_Module
+E: ID_MODEL_ENC=HP\x20Integrated\x20Module
+E: ID_MODEL_ID=231d
+E: ID_REVISION=0306
+E: ID_SERIAL=Broadcom_Corp_HP_Integrated_Module
+E: ID_USB_INTERFACES=:e00101:ffffff:fe0101:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=03f0
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=3f0/231d/306
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2746080
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v03F0p231Dd0306dcE0dsc01dp01icE0isc01ip01
+E: PRODUCT=3f0/231d/306
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0/rfkill4
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.0/bluetooth/hci0/rfkill4
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v03F0p231Dd0306dcE0dsc01dp01icE0isc01ip01
+E: PRODUCT=3f0/231d/306
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v03F0p231Dd0306dcE0dsc01dp01icFFiscFFipFF
+E: PRODUCT=3f0/231d/306
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.1/1-1.1:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v03F0p231Dd0306dcE0dsc01dp01icFEisc01ip01
+E: PRODUCT=3f0/231d/306
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0020d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usbmon/usbmon1
+N: usbmon1
+E: DEVNAME=/dev/usbmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00003B56sv0000103Csd0000146Dbc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:3B56
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=5 Series/3400 Series Chipset High Definition Audio
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16237764
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246315
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D1
+N: snd/hwC0D1
+E: DEVNAME=/dev/snd/hwC0D1
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D1
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246266
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246201
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel HDMI/DP,pcm=7"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14290185
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14304235
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14284081
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14289368
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfwD,
+E: NAME="HDA Intel Line"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=2000
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14283576
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+N: input/event12
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14286761
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input13
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input13
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14253679
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input13/event13
+N: input/event13
+E: DEVNAME=/dev/input/event13
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input13/event13
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=77
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14259841
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input14
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel Dock Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14245655
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input14/event14
+N: input/event14
+E: DEVNAME=/dev/input/event14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input14/event14
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=78
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14282635
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input15
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input15
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14245765
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input15/event15
+N: input/event15
+E: DEVNAME=/dev/input/event15
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input15/event15
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=79
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14279611
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel HDMI/DP,pcm=8"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14254165
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14262531
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246148
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246078
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246009
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+N: snd/pcmC0D7p
+E: DEVNAME=/dev/snd/pcmC0D7p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14245960
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D8p
+N: snd/pcmC0D8p
+E: DEVNAME=/dev/snd/pcmC0D8p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D8p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14245892
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=10
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14246411
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B42sv0000103Csd0000146Dbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B42
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie01
+E: DRIVER=pcie_pme
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B44sv0000103Csd0000146Dbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B44
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:00:1c.1:pcie01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:00:1c.1:pcie01
+E: DRIVER=pcie_pme
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:00:1c.1:pcie04
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:00:1c.1:pcie04
+E: DRIVER=pciehp
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B46sv0000103Csd0000146Dbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B46
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:00:1c.2:pcie01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:00:1c.2:pcie01
+E: DRIVER=pcie_pme
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:43:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:43:00.0
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v00001180d0000E822sv0000103Csd0000146Dbc08sc05i00
+E: PCI_CLASS=80500
+E: PCI_ID=1180:E822
+E: PCI_SLOT_NAME=0000:43:00.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:43:00.0/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:43:00.0/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:43:00.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:43:00.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:43:00.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:43:00.1
+E: MODALIAS=pci:v00001180d0000E230sv0000103Csd0000146Dbc08sc80i00
+E: PCI_CLASS=88000
+E: PCI_ID=1180:E230
+E: PCI_SLOT_NAME=0000:43:00.1
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:43:00.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:43:00.3
+E: DRIVER=firewire_ohci
+E: MODALIAS=pci:v00001180d0000E832sv0000103Csd0000146Dbc0Csc00i10
+E: PCI_CLASS=C0010
+E: PCI_ID=1180:E832
+E: PCI_SLOT_NAME=0000:43:00.3
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:43:00.3/fw0
+N: fw0
+E: DEVNAME=/dev/fw0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:43:00.3/fw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=firewire
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:43
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:43
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00003B48sv0000103Csd0000146Dbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:3B48
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:00:1c.3:pcie01
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:00:1c.3:pcie01
+E: DRIVER=pcie_pme
+E: SUBSYSTEM=pci_express
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:44:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:44:00.0
+E: DRIVER=iwlwifi
+E: MODALIAS=pci:v00008086d00004239sv00008086sd00001311bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=8086:4239
+E: PCI_SLOT_NAME=0000:44:00.0
+E: PCI_SUBSYS_ID=8086:1311
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:44:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:44:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:44:00.0/ieee80211/phy0/rfkill3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:44:00.0/ieee80211/phy0/rfkill3
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:44:00.0/leds/phy0-led
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:44:00.0/leds/phy0-led
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:44:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:44:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=Centrino Advanced-N 6200
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.3/0000:44:00.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14682626
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:44
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:44
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00003B34sv0000103Csd0000146Dbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:3B34
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0302
+E: ID_SERIAL=Linux_3.2.0-48-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.2.0-48-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.2.0-48-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2681973
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0302dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/302
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0020
+E: ID_MODEL_ENC=0020
+E: ID_MODEL_ID=0020
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0020
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2682708
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=MKNUFDPR2GB
+E: ID_MODEL_ENC=MKNUFDPR2GB
+E: ID_MODEL_ID=3600
+E: ID_REVISION=0100
+E: ID_SERIAL=MUSHKIN_MKNUFDPR2GB_07C10403C895655E
+E: ID_SERIAL_SHORT=07C10403C895655E
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=MUSHKIN
+E: ID_VENDOR_ENC=MUSHKIN
+E: ID_VENDOR_ID=13fe
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=13fe/3600/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2683046
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v13FEp3600d0100dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=13fe/3600/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/scsi_host/host6
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/scsi_host/host6
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+N: sdb
+S: disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C895655E-0:0
+S: disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C895655E-0:0 /dev/disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sdb
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=MKNUFDPR2GB
+E: ID_MODEL_ENC=MKNUFDPR2GB\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=3600
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_0-scsi-0_0_0_0
+E: ID_REVISION=PMAP
+E: ID_SERIAL=MUSHKIN_MKNUFDPR2GB_07C10403C895655E-0:0
+E: ID_SERIAL_SHORT=07C10403C895655E
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=MUSHKIN
+E: ID_VENDOR_ENC=MUSHKIN\x20
+E: ID_VENDOR_ID=13fe
+E: MAJOR=8
+E: MINOR=16
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=15194803
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+N: sdb1
+S: disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C895655E-0:0-part1
+S: disk/by-label/New\x20Volume
+S: disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/5109-812D
+E: DEVLINKS=/dev/disk/by-id/usb-MUSHKIN_MKNUFDPR2GB_07C10403C895655E-0:0-part1 /dev/disk/by-label/New\x20Volume /dev/disk/by-path/pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/5109-812D
+E: DEVNAME=/dev/sdb1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb/sdb1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_LABEL=New_Volume
+E: ID_FS_LABEL_ENC=New\x20Volume
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=5109-812D
+E: ID_FS_UUID_ENC=5109-812D
+E: ID_FS_VERSION=FAT32
+E: ID_INSTANCE=0:0
+E: ID_MODEL=MKNUFDPR2GB
+E: ID_MODEL_ENC=MKNUFDPR2GB\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=3600
+E: ID_PART_ENTRY_DISK=8:16
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=62
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=3909286
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.1:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_1_1_0-scsi-0_0_0_0
+E: ID_REVISION=PMAP
+E: ID_SERIAL=MUSHKIN_MKNUFDPR2GB_07C10403C895655E-0:0
+E: ID_SERIAL_SHORT=07C10403C895655E
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=MUSHKIN
+E: ID_VENDOR_ENC=MUSHKIN\x20
+E: ID_VENDOR_ID=13fe
+E: MAJOR=8
+E: MINOR=17
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=31744
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=2001554432
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/block/sdb
+E: UDISKS_PARTITION_TYPE=0x0c
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=16742905
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+N: bsg/6:0:0:0
+E: DEVNAME=/dev/bsg/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/bsg/6:0:0:0
+E: MAJOR=253
+E: MINOR=2
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_device/6:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_disk/6:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+N: sg2
+E: DEVNAME=/dev/sg2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.1/2-1.1:1.0/host6/target6:0:0/6:0:0:0/scsi_generic/sg2
+E: MAJOR=21
+E: MINOR=2
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4
+N: bus/usb/002/004
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0_Camera
+E: ID_MODEL_ENC=USB2.0\x20Camera
+E: ID_MODEL_ID=0101
+E: ID_REVISION=000c
+E: ID_SERIAL=AVEO_Technology_Corp._USB2.0_Camera
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=AVEO_Technology_Corp.
+E: ID_VENDOR_ENC=AVEO\x20Technology\x20Corp.
+E: ID_VENDOR_ID=1871
+E: MAJOR=189
+E: MINOR=131
+E: PRODUCT=1871/101/c
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2683901
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v1871p0101d000CdcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=1871/101/c
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0/input/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0/input/input8
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=USB2.0_Camera
+E: ID_MODEL_ENC=USB2.0\x20Camera
+E: ID_MODEL_ID=0101
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.4:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_4_1_0
+E: ID_REVISION=000c
+E: ID_SERIAL=AVEO_Technology_Corp._USB2.0_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=AVEO_Technology_Corp.
+E: ID_VENDOR_ENC=AVEO\x20Technology\x20Corp.
+E: ID_VENDOR_ID=1871
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v1871p0101e000C-e0,1,kD4,ramlsfw
+E: NAME="USB2.0 Camera"
+E: PHYS="usb-0000:00:1d.0-1.4/button"
+E: PRODUCT=3/1871/101/c
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13600519
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0/input/input8/event8
+N: input/event8
+S: input/by-id/usb-AVEO_Technology_Corp._USB2.0_Camera-event-if00
+S: input/by-path/pci-0000:00:1d.0-usb-0:1.4:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-AVEO_Technology_Corp._USB2.0_Camera-event-if00 /dev/input/by-path/pci-0000:00:1d.0-usb-0:1.4:1.0-event
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0/input/input8/event8
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=USB2.0_Camera
+E: ID_MODEL_ENC=USB2.0\x20Camera
+E: ID_MODEL_ID=0101
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.4:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_4_1_0
+E: ID_REVISION=000c
+E: ID_SERIAL=AVEO_Technology_Corp._USB2.0_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=AVEO_Technology_Corp.
+E: ID_VENDOR_ENC=AVEO\x20Technology\x20Corp.
+E: ID_VENDOR_ID=1871
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13606045
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0/video4linux/video0
+N: video0
+S: external_webcam
+S: v4l/by-id/usb-AVEO_Technology_Corp._USB2.0_Camera-video-index0
+S: v4l/by-path/pci-0000:00:1d.0-usb-0:1.4:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/external_webcam /dev/v4l/by-id/usb-AVEO_Technology_Corp._USB2.0_Camera-video-index0 /dev/v4l/by-path/pci-0000:00:1d.0-usb-0:1.4:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.0/video4linux/video0
+E: GENERATED=1
+E: ID_BUS=usb
+E: ID_MODEL=USB2.0_Camera
+E: ID_MODEL_ENC=USB2.0\x20Camera
+E: ID_MODEL_ID=0101
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1.4:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1_4_1_0
+E: ID_REVISION=000c
+E: ID_SERIAL=AVEO_Technology_Corp._USB2.0_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=USB2.0 Camera
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=AVEO_Technology_Corp.
+E: ID_VENDOR_ENC=AVEO\x20Technology\x20Corp.
+E: ID_VENDOR_ID=1871
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13993892
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1.4/2-1.4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v1871p0101d000CdcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=1871/101/c
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0020d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/20/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+N: usbmon2
+E: DEVNAME=/dev/usbmon2
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0
+E: MODALIAS=pci:v00008086d00002448sv0000103Csd0000146Dbc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=8086:2448
+E: PCI_SLOT_NAME=0000:00:1e.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1e.0/pci_bus/0000:45
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/pci_bus/0000:45
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00003B0Bsv0000103Csd0000146Dbc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:3B0B
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=5 Series/3400 Series Chipset 6 port SATA AHCI Controller
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00003B2Fsv0000103Csd0000146Dbc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:3B2F
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12276338
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242
+S: disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242
+S: disk/by-id/wwn-0x50014ee2ae99101f
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242 /dev/disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242 /dev/disk/by-id/wwn-0x50014ee2ae99101f /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=128
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=WDC_WD1600BEVT-75A23T0
+E: ID_MODEL_ENC=WDC\x20WD1600BEVT-75A23T0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=01.01A10
+E: ID_SCSI_COMPAT=SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242
+E: ID_SERIAL=WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242
+E: ID_SERIAL_SHORT=WD-WX60AC9A4242
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2ae99101f
+E: ID_WWN_WITH_EXTENSION=0x50014ee2ae99101f
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2646556
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242-part1
+S: disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242-part1
+S: disk/by-id/wwn-0x50014ee2ae99101f-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/f5a83d85-20ca-41f6-bc7e-2d26e1b2b8a7
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242-part1 /dev/disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242-part1 /dev/disk/by-id/wwn-0x50014ee2ae99101f-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/f5a83d85-20ca-41f6-bc7e-2d26e1b2b8a7
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=128
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=f5a83d85-20ca-41f6-bc7e-2d26e1b2b8a7
+E: ID_FS_UUID_ENC=f5a83d85-20ca-41f6-bc7e-2d26e1b2b8a7
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=WDC_WD1600BEVT-75A23T0
+E: ID_MODEL_ENC=WDC\x20WD1600BEVT-75A23T0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=308680704
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=01.01A10
+E: ID_SCSI_COMPAT=SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242
+E: ID_SERIAL=WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242
+E: ID_SERIAL_SHORT=WD-WX60AC9A4242
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2ae99101f
+E: ID_WWN_WITH_EXTENSION=0x50014ee2ae99101f
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=158044520448
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3015877
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242-part2
+S: disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242-part2
+S: disk/by-id/wwn-0x50014ee2ae99101f-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242-part2 /dev/disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242-part2 /dev/disk/by-id/wwn-0x50014ee2ae99101f-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=128
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=WDC_WD1600BEVT-75A23T0
+E: ID_MODEL_ENC=WDC\x20WD1600BEVT-75A23T0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=308684798
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=3895298
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=01.01A10
+E: ID_SCSI_COMPAT=SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242
+E: ID_SERIAL=WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242
+E: ID_SERIAL_SHORT=WD-WX60AC9A4242
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2ae99101f
+E: ID_WWN_WITH_EXTENSION=0x50014ee2ae99101f
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=158046616576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=1994392576
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2893070
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242-part5
+S: disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242-part5
+S: disk/by-id/wwn-0x50014ee2ae99101f-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/cfd0ed14-0c9f-4ecf-b772-d5242c2d8d91
+E: DEVLINKS=/dev/disk/by-id/ata-WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242-part5 /dev/disk/by-id/scsi-SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242-part5 /dev/disk/by-id/wwn-0x50014ee2ae99101f-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/cfd0ed14-0c9f-4ecf-b772-d5242c2d8d91
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=128
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=70
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=cfd0ed14-0c9f-4ecf-b772-d5242c2d8d91
+E: ID_FS_UUID_ENC=cfd0ed14-0c9f-4ecf-b772-d5242c2d8d91
+E: ID_FS_VERSION=2
+E: ID_MODEL=WDC_WD1600BEVT-75A23T0
+E: ID_MODEL_ENC=WDC\x20WD1600BEVT-75A23T0\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=308684800
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=3895296
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=01.01A10
+E: ID_SCSI_COMPAT=SATA_WDC_WD1600BEVT-_WD-WX60AC9A4242
+E: ID_SERIAL=WDC_WD1600BEVT-75A23T0_WD-WX60AC9A4242
+E: ID_SERIAL_SHORT=WD-WX60AC9A4242
+E: ID_TYPE=disk
+E: ID_WWN=0x50014ee2ae99101f
+E: ID_WWN_WITH_EXTENSION=0x50014ee2ae99101f
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=158046617600
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=1994391552
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2893467
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-hp_DVDRAM_GT30L_M57A5AI4234
+S: disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-hp_DVDRAM_GT30L_M57A5AI4234 /dev/disk/by-path/pci-0000:00:1f.2-scsi-1:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=hp_DVDRAM_GT30L
+E: ID_MODEL_ENC=hp\x20\x20\x20\x20\x20\x20DVDRAM\x20GT30L\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-1:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-1_0_0_0
+E: ID_REVISION=mP04
+E: ID_SERIAL=hp_DVDRAM_GT30L_M57A5AI4234
+E: ID_SERIAL_SHORT=M57A5AI4234
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2646885
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12285217
+
+P: /devices/pci0000:00/0000:00:1f.2/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.6
+E: MODALIAS=pci:v00008086d00003B32sv0000103Csd0000146Dbc11sc80i00
+E: PCI_CLASS=118000
+E: PCI_ID=8086:3B32
+E: PCI_SLOT_NAME=0000:00:1f.6
+E: PCI_SUBSYS_ID=103C:146D
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/0000:ff:00.0
+E: DEVPATH=/devices/pci0000:ff/0000:ff:00.0
+E: MODALIAS=pci:v00008086d00002C62sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2C62
+E: PCI_SLOT_NAME=0000:ff:00.0
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/0000:ff:00.1
+E: DEVPATH=/devices/pci0000:ff/0000:ff:00.1
+E: MODALIAS=pci:v00008086d00002D01sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D01
+E: PCI_SLOT_NAME=0000:ff:00.1
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/0000:ff:02.0
+E: DEVPATH=/devices/pci0000:ff/0000:ff:02.0
+E: MODALIAS=pci:v00008086d00002D10sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D10
+E: PCI_SLOT_NAME=0000:ff:02.0
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/0000:ff:02.1
+E: DEVPATH=/devices/pci0000:ff/0000:ff:02.1
+E: MODALIAS=pci:v00008086d00002D11sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D11
+E: PCI_SLOT_NAME=0000:ff:02.1
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/0000:ff:02.2
+E: DEVPATH=/devices/pci0000:ff/0000:ff:02.2
+E: MODALIAS=pci:v00008086d00002D12sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D12
+E: PCI_SLOT_NAME=0000:ff:02.2
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/0000:ff:02.3
+E: DEVPATH=/devices/pci0000:ff/0000:ff:02.3
+E: MODALIAS=pci:v00008086d00002D13sv00008086sd00008086bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:2D13
+E: PCI_SLOT_NAME=0000:ff:02.3
+E: PCI_SUBSYS_ID=8086:8086
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:ff/pci_bus/0000:ff
+E: DEVPATH=/devices/pci0000:ff/pci_bus/0000:ff
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi
+E: DEVPATH=/devices/platform/hp-wmi
+E: DRIVER=hp-wmi
+E: MODALIAS=platform:hp-wmi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill0
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill0
+E: RFKILL_NAME=hp-wifi
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/hp-wmi/rfkill/rfkill1
+E: DEVPATH=/devices/platform/hp-wmi/rfkill/rfkill1
+E: RFKILL_NAME=hp-bluetooth
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=Hewlett-Packard
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10924682
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=20000 20 0 0 80500f02100002 3803078f900d401 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8A,8C,8E,8F,98,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,C1,D4,D9,E0,E1,E2,E3,EC,EE,F7,185,1D1,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2780648
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2782762
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input6
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0001e0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="PS/2 Generic Mouse"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/1/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12589565
+
+P: /devices/platform/i8042/serio1/input/input6/event6
+N: input/event6
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6/event6
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12591688
+
+P: /devices/platform/i8042/serio1/input/input6/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input6/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12592165
+
+P: /devices/platform/i8042/serio2
+E: DEVPATH=/devices/platform/i8042/serio2
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio3
+E: DEVPATH=/devices/platform/i8042/serio3
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio4
+E: DEVPATH=/devices/platform/i8042/serio4
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio4/input/input7
+E: ABS=260800011000003
+E: DEVPATH=/devices/platform/i8042/serio4/input/input7
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-4
+E: ID_PATH_TAG=platform-i8042-serio-4
+E: ID_SERIAL=noserial
+E: KEY=6420 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio4/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=9
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13422319
+
+P: /devices/platform/i8042/serio4/input/input7/event7
+N: input/event7
+S: input/by-path/platform-i8042-serio-4-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-4-event-mouse
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/platform/i8042/serio4/input/input7/event7
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-4
+E: ID_PATH_TAG=platform-i8042-serio-4
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13422102
+
+P: /devices/platform/i8042/serio4/input/input7/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-4-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-4-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio4/input/input7/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-4
+E: ID_PATH_TAG=platform-i8042-serio-4
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13424689
+
+P: /devices/platform/lis3lv02d
+E: DEVPATH=/devices/platform/lis3lv02d
+E: MODALIAS=platform:lis3lv02d
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/lis3lv02d/input/input4
+E: ABS=7
+E: DEVPATH=/devices/platform/lis3lv02d/input/input4
+E: EV=9
+E: ID_INPUT=1
+E: ID_INPUT_ACCELEROMETER=1
+E: ID_PATH=platform-lis3lv02d
+E: ID_PATH_TAG=platform-lis3lv02d
+E: MODALIAS=input:b0019v0000p0000e0000-e0,3,kra0,1,2,mlsfw
+E: NAME="ST LIS3LV02DL Accelerometer"
+E: PHYS="lis3lv02d/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12721149
+
+P: /devices/platform/lis3lv02d/input/input4/event4
+N: input/event4
+S: input/by-path/platform-lis3lv02d-event
+E: DEVLINKS=/dev/input/by-path/platform-lis3lv02d-event
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/lis3lv02d/input/input4/event4
+E: ID_INPUT=1
+E: ID_INPUT_ACCELEROMETER=1
+E: ID_PATH=platform-lis3lv02d
+E: ID_PATH_TAG=platform-lis3lv02d
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12960199
+
+P: /devices/platform/lis3lv02d/input/input4/js0
+N: input/js0
+E: DEVNAME=/dev/input/js0
+E: DEVPATH=/devices/platform/lis3lv02d/input/input4/js0
+E: ID_INPUT=1
+E: ID_INPUT_ACCELEROMETER=1
+E: ID_PATH=platform-lis3lv02d
+E: ID_PATH_TAG=platform-lis3lv02d
+E: MAJOR=13
+E: MINOR=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12960123
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930795
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10931635
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10931367
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930952
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10932283
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10933016
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10934045
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10933456
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10933782
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10933134
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10933795
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10929876
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10929911
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10929945
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10929982
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930019
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930054
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930091
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930128
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930172
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930211
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930286
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930331
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930371
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930413
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930455
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10930512
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10937321
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10937983
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10937783
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10937495
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=tpm_tis
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04/misc/tpm0
+N: tpm0
+E: DEVNAME=/dev/tpm0
+E: DEVPATH=/devices/pnp0/00:04/misc/tpm0
+E: MAJOR=10
+E: MINOR=224
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:08/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2785056
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=serial
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/pnp0/00:09/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10959596
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=parport_pc
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a/ppdev/parport0
+N: parport0
+E: DEVNAME=/dev/parport0
+E: DEVPATH=/devices/pnp0/00:0a/ppdev/parport0
+E: MAJOR=99
+E: MINOR=0
+E: SUBSYSTEM=ppdev
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a/printer/lp0
+N: lp0
+E: DEVNAME=/dev/lp0
+E: DEVPATH=/devices/pnp0/00:0a/printer/lp0
+E: MAJOR=6
+E: MINOR=0
+E: SUBSYSTEM=printer
+E: TAGS=:udev-configure-printer:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12037647
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0c
+E: DEVPATH=/devices/pnp0/00:0c
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0d
+E: DEVPATH=/devices/pnp0/00:0d
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0e
+E: DEVPATH=/devices/pnp0/00:0e
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:19
+E: DEVPATH=/devices/virtual/bdi/0:19
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:16
+E: DEVPATH=/devices/virtual/bdi/8:16
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647023
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647175
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647312
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647452
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647597
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647749
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2647894
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=2670809
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2679165
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2672215
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2675174
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656224
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656363
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656477
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656590
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656703
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656814
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2656930
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2657038
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2657152
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2657263
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2673803
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2657428
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2657538
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnHewlett-Packard:bvr68CDEVer.F.00:bd04/21/2010:svnHewlett-Packard:pnHPProBook6550b:pvr:rvnHewlett-Packard:rn146D:rvrKBCVersion73.11:cvnHewlett-Packard:ct10:cvr:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/input5
+E: DEVPATH=/devices/virtual/input/input5
+E: EV=33
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: KEY=4000000000 0 1000700000000 2100400 0 0
+E: MODALIAS=input:b0019v0000p0000e0000-e0,1,4,5,k8A,94,99,E0,E1,E2,F0,166,ram4,lsfw1,5,
+E: MSC=10
+E: NAME="HP WMI hotkeys"
+E: PHYS="wmi/input0"
+E: PRODUCT=19/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=22
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12000772
+
+P: /devices/virtual/input/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/virtual/input/input5/event5
+E: DMI_VENDOR=Hewlett-Packard
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12005997
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/leds/hp::hddprotect
+E: DEVPATH=/devices/virtual/leds/hp::hddprotect
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/virtual/mei/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/mei/mei
+E: MAJOR=250
+E: MINOR=1
+E: SUBSYSTEM=mei
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/agpgart
+N: agpgart
+E: DEVNAME=/dev/agpgart
+E: DEVPATH=/devices/virtual/misc/agpgart
+E: MAJOR=10
+E: MINOR=175
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/freefall
+N: freefall
+E: DEVNAME=/dev/freefall
+E: DEVPATH=/devices/virtual/misc/freefall
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10982943
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10985088
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/regulator/regulator.0
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12409445
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12287986
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone1
+E: DEVPATH=/devices/virtual/thermal/thermal_zone1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone2
+E: DEVPATH=/devices/virtual/thermal/thermal_zone2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone3
+E: DEVPATH=/devices/virtual/thermal/thermal_zone3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone4
+E: DEVPATH=/devices/virtual/thermal/thermal_zone4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone5
+E: DEVPATH=/devices/virtual/thermal/thermal_zone5
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone6
+E: DEVPATH=/devices/virtual/thermal/thermal_zone6
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone7
+E: DEVPATH=/devices/virtual/thermal/thermal_zone7
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone8
+E: DEVPATH=/devices/virtual/thermal/thermal_zone8
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone9
+E: DEVPATH=/devices/virtual/thermal/thermal_zone9
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10988677
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10988757
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10989066
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10989375
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10989674
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10990099
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10990166
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10990470
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10990778
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10991076
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10991372
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10991669
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10991966
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10992337
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10992634
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10992933
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10993339
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10993201
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10993385
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10993585
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994045
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10993882
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994045
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994201
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994656
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994499
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994662
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10994820
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995297
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995137
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995299
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995457
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995939
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995776
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10995937
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10996124
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10996570
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10996427
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10996578
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10996732
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997151
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997020
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997173
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997333
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997785
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997632
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997790
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10997960
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10998408
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11001915
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10998755
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10998956
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10999129
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10999299
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10999460
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10999613
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10999791
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10999957
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11018509
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11021465
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11020027
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11020580
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11018812
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11020309
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11019420
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11019092
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11019716
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=11021125
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: DEVNAME=/dev/usbmon0
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=usbmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs63
+N: vcs63
+E: DEVNAME=/dev/vcs63
+E: DEVPATH=/devices/virtual/vc/vcs63
+E: MAJOR=7
+E: MINOR=63
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa63
+N: vcsa63
+E: DEVNAME=/dev/vcsa63
+E: DEVPATH=/devices/virtual/vc/vcsa63
+E: MAJOR=7
+E: MINOR=191
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: DEVPATH=/devices/virtual/wmi/14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: MODALIAS=wmi:14EA9746-CE1F-4098-A0E0-7045CB4DA745
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: DEVPATH=/devices/virtual/wmi/1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: MODALIAS=wmi:1F4C91EB-DC5C-460B-951D-C7CB9B4B8D5E
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2B814318-4BE8-4707-9D84-A190A859B5D0
+E: DEVPATH=/devices/virtual/wmi/2B814318-4BE8-4707-9D84-A190A859B5D0
+E: MODALIAS=wmi:2B814318-4BE8-4707-9D84-A190A859B5D0
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: DEVPATH=/devices/virtual/wmi/2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: MODALIAS=wmi:2D114B49-2DFB-4130-B8FE-4A3C09E75133
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: DEVPATH=/devices/virtual/wmi/322F2028-0F84-4901-988E-015176049E2D
+E: MODALIAS=wmi:322F2028-0F84-4901-988E-015176049E2D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: DEVPATH=/devices/virtual/wmi/5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: MODALIAS=wmi:5FB7F034-2C63-45E9-BE91-3D44E2C707E4
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/7391A661-223A-47DB-A77A-7BE84C60822D
+E: DEVPATH=/devices/virtual/wmi/7391A661-223A-47DB-A77A-7BE84C60822D
+E: MODALIAS=wmi:7391A661-223A-47DB-A77A-7BE84C60822D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: DEVPATH=/devices/virtual/wmi/8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: MODALIAS=wmi:8232DE3D-663D-4327-A8F4-E293ADB9BF05
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: DEVPATH=/devices/virtual/wmi/8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: MODALIAS=wmi:8F1F6435-9F42-42C8-BADC-0E9424F20C9A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: DEVPATH=/devices/virtual/wmi/8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: MODALIAS=wmi:8F1F6436-9F42-42C8-BADC-0E9424F20C9A
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: DEVPATH=/devices/virtual/wmi/95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: MODALIAS=wmi:95F24279-4D7B-4334-9387-ACCDC67EF61C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: DEVPATH=/devices/virtual/wmi/988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: MODALIAS=wmi:988D08E3-68F4-4C35-AF3E-6A1B8106F83C
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: DEVPATH=/devices/virtual/wmi/DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: MODALIAS=wmi:DF4E63B6-3BBC-4858-9737-C74F82F821F3
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_E431.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_E431.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_E431.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5716 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1994102
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2000289
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+E: XKBOPTIONS=''
+E: XKBVARIANT='intl'
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/INT340E:00
+E: MODALIAS=acpi:INT340E:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input6
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input6
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13286295
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input6/event6
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13288502
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+E: XKBOPTIONS=''
+E: XKBVARIANT='intl'
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/INT3F0D:00
+E: MODALIAS=acpi:INT3F0D:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/LEN0068:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/LEN0068:00
+E: DRIVER=thinkpad_hotkey
+E: MODALIAS=acpi:LEN0068:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_ENERGY_FULL=47510000
+E: POWER_SUPPLY_ENERGY_FULL_DESIGN=47520000
+E: POWER_SUPPLY_ENERGY_NOW=47390000
+E: POWER_SUPPLY_MANUFACTURER=LGC
+E: POWER_SUPPLY_MODEL_NAME=45N1049
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_POWER_NOW=0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER=11692
+E: POWER_SUPPLY_STATUS=Unknown
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=10800000
+E: POWER_SUPPLY_VOLTAGE_NOW=12503000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PNP0C09:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PTL0001:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:01/PTL0001:00
+E: MODALIAS=acpi:PTL0001:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LEN2001:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/LEN2001:00
+E: MODALIAS=acpi:LEN2001:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0b/device:0c/device:0d/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1e/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18/device:1e/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2d/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:33/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:33/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:39/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/LNXIOBAY:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/LNXIOBAY:00
+E: MODALIAS=acpi:LNXIOBAY:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3b/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1999470
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2012553
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+E: XKBOPTIONS=''
+E: XKBVARIANT='intl'
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1999489
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2012852
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000154sv000017AAsd00005018bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0154
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000166sv000017AAsd00005018bc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0166
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13287716
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv000017AAsd00005018bc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-27-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-27-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-27-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1972932
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-27-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-27-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-27-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1973219
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv000017AAsd00005018bc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E2Dsv000017AAsd00005018bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-27-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-27-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-27-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1971814
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1972479
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+N: bus/usb/001/051
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/051
+E: DEVNUM=051
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BCM43142A0
+E: ID_MODEL_ENC=BCM43142A0
+E: ID_MODEL_ID=e065
+E: ID_REVISION=0112
+E: ID_SERIAL=Broadcom_Corp_BCM43142A0_0090A2CAB3AE
+E: ID_SERIAL_SHORT=0090A2CAB3AE
+E: ID_USB_INTERFACES=:ff0101:ffffff:fe0101:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=105b
+E: MAJOR=189
+E: MINOR=50
+E: PRODUCT=105b/e065/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5276211005
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v105BpE065d0112dcFFdsc01dp01icFFisc01ip01
+E: PRODUCT=105b/e065/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/bluetooth/hci0/rfkill50
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0/bluetooth/hci0/rfkill50
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v105BpE065d0112dcFFdsc01dp01icFFisc01ip01
+E: PRODUCT=105b/e065/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v105BpE065d0112dcFFdsc01dp01icFFiscFFipFF
+E: PRODUCT=105b/e065/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v105BpE065d0112dcFFdsc01dp01icFEisc01ip01
+E: PRODUCT=105b/e065/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=0397
+E: ID_REVISION=1457
+E: ID_SERIAL=Vimicro_corp._Integrated_Camera
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=Vimicro_corp.
+E: ID_VENDOR_ENC=Vimicro\x20corp.
+E: ID_VENDOR_ID=5986
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=5986/397/1457
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2436140
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v5986p0397d1457dcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=5986/397/1457
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=0397
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=1457
+E: ID_SERIAL=Vimicro_corp._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Vimicro_corp.
+E: ID_VENDOR_ENC=Vimicro\x20corp.
+E: ID_VENDOR_ID=5986
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v5986p0397e1457-e0,1,kD4,ramlsfw
+E: NAME="Integrated Camera"
+E: PHYS="usb-0000:00:1a.0-1.6/button"
+E: PRODUCT=3/5986/397/1457
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13678004
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11/event11
+N: input/event11
+S: input/by-id/usb-Vimicro_corp._Integrated_Camera-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-Vimicro_corp._Integrated_Camera-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-event
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11/event11
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=0397
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=1457
+E: ID_SERIAL=Vimicro_corp._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Vimicro_corp.
+E: ID_VENDOR_ENC=Vimicro\x20corp.
+E: ID_VENDOR_ID=5986
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13680559
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+E: XKBOPTIONS=''
+E: XKBVARIANT='intl'
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-Vimicro_corp._Integrated_Camera-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-Vimicro_corp._Integrated_Camera-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=0397
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=1457
+E: ID_SERIAL=Vimicro_corp._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Integrated Camera
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=Vimicro_corp.
+E: ID_VENDOR_ENC=Vimicro\x20corp.
+E: ID_VENDOR_ID=5986
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13678520
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v5986p0397d1457dcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=5986/397/1457
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv000017AAsd00005018bc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Panther Point High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13435042
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13424843
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13424385
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13422291
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13425823
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input7
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=7"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13421612
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input7/event7
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13426049
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13421738
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13425854
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13421737
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13426327
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13424378
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13424039
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13422247
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+N: snd/pcmC0D7p
+E: DEVNAME=/dev/snd/pcmC0D7p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13422242
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13425187
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv000017AAsd00005018bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:03:00.0
+E: DRIVER=rtsx_pci
+E: MODALIAS=pci:v000010ECd00005229sv000017AAsd00005018bcFFsc00i00
+E: PCI_CLASS=FF0000
+E: PCI_ID=10EC:5229
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_ms.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_ms.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_ms
+E: MODALIAS=platform:rtsx_pci_ms
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: SUBSYSTEM=memstick_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_sdmmc.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_sdmmc.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_sdmmc
+E: MODALIAS=platform:rtsx_pci_sdmmc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:03:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E12sv000017AAsd00005018bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:04:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:04:00.0
+E: DRIVER=wl
+E: MODALIAS=pci:v000014E4d00004365sv000017AAsd00000611bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=14E4:4365
+E: PCI_SLOT_NAME=0000:04:00.0
+E: PCI_SUBSYS_ID=17AA:0611
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:04:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:04:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:04:00.0/ieee80211/phy0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:04:00.0/ieee80211/phy0/rfkill2
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:04:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:04:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:04:00.0
+E: ID_VENDOR_FROM_DATABASE=Broadcom Corporation
+E: ID_VENDOR_ID=0x14e4
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13668643
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:04:00.0/net/wlan0/rfkill3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:04:00.0/net/wlan0/rfkill3
+E: RFKILL_NAME=brcmwl-0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E16sv000017AAsd00005018bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E16
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:05:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:05:00.0
+E: DRIVER=r8168
+E: MODALIAS=pci:v000010ECd00008168sv000017AAsd00005018bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8168
+E: PCI_SLOT_NAME=0000:05:00.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/0000:05:00.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/0000:05:00.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8111/8168B PCI Express Gigabit Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.3/0000:05:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12916562
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:05
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:05
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00008086d00001E26sv000017AAsd00005018bc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-27-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-27-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-27-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1979151
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1989223
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: MODALIAS=pci:v00008086d00001E57sv000017AAsd00005018bc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E57
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=Panther Point 6 port SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001E03sv000017AAsd00005018bc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1E03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12294223
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+S: disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+S: disk/by-id/wwn-0x5000cca6f8cc70db
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ /dev/disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ /dev/disk/by-id/wwn-0x5000cca6f8cc70db /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=100
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=HGST_HTS545032A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545032A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GGBZBF04
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+E: ID_SERIAL=HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+E: ID_SERIAL_SHORT=TEAB5A3R0WBDSJ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f8cc70db
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f8cc70db
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=5
+E: UDISKS_PARTITION_TABLE_SCHEME=gpt
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3316645
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part1
+S: disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part1
+S: disk/by-id/wwn-0x5000cca6f8cc70db-part1
+S: disk/by-partlabel/EFI\x20System\x20Partition
+S: disk/by-partuuid/5ca831b7-c1ff-470a-afab-98a1da6076a1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/87C9-B356
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part1 /dev/disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part1 /dev/disk/by-id/wwn-0x5000cca6f8cc70db-part1 /dev/disk/by-partlabel/EFI\x20System\x20Partition /dev/disk/by-partuuid/5ca831b7-c1ff-470a-afab-98a1da6076a1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/87C9-B356
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=100
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=87C9-B356
+E: ID_FS_UUID_ENC=87C9-B356
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=HGST_HTS545032A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545032A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=EFI\x20System\x20Partition
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=40
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=97616
+E: ID_PART_ENTRY_TYPE=c12a7328-f81f-11d2-ba4b-00a0c93ec93b
+E: ID_PART_ENTRY_UUID=5ca831b7-c1ff-470a-afab-98a1da6076a1
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GGBZBF04
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+E: ID_SERIAL=HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+E: ID_SERIAL_SHORT=TEAB5A3R0WBDSJ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f8cc70db
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f8cc70db
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=EFI System Partition
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=20480
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=49979392
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=C12A7328-F81F-11D2-BA4B-00A0C93EC93B
+E: UDISKS_PARTITION_UUID=5CA831B7-C1FF-470A-AFAB-98A1DA6076A1
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3440341
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part2
+S: disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part2
+S: disk/by-id/wwn-0x5000cca6f8cc70db-part2
+S: disk/by-label/PQSERVICE
+S: disk/by-partlabel/Recovery\x20Partition
+S: disk/by-partuuid/39914e84-f5d8-41ed-bbd4-57f1e44b52cc
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-uuid/10AF-3D7E
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part2 /dev/disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part2 /dev/disk/by-id/wwn-0x5000cca6f8cc70db-part2 /dev/disk/by-label/PQSERVICE /dev/disk/by-partlabel/Recovery\x20Partition /dev/disk/by-partuuid/39914e84-f5d8-41ed-bbd4-57f1e44b52cc /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-uuid/10AF-3D7E
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=100
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=PQSERVICE
+E: ID_FS_LABEL_ENC=PQSERVICE
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=10AF-3D7E
+E: ID_FS_UUID_ENC=10AF-3D7E
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=HGST_HTS545032A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545032A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=Recovery\x20Partition
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=97656
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=2994144
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=39914e84-f5d8-41ed-bbd4-57f1e44b52cc
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GGBZBF04
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+E: ID_SERIAL=HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+E: ID_SERIAL_SHORT=TEAB5A3R0WBDSJ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f8cc70db
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f8cc70db
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=Recovery Partition
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=49999872
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=1533001728
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=39914E84-F5D8-41ED-BBD4-57F1E44B52CC
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3685605
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part3
+S: disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part3
+S: disk/by-id/wwn-0x5000cca6f8cc70db-part3
+S: disk/by-label/Ubuntu
+S: disk/by-partuuid/55067743-f4b0-40a1-965d-c29bc1772b84
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+S: disk/by-uuid/9f5642a1-4712-4564-9865-e76670e1bcd8
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part3 /dev/disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part3 /dev/disk/by-id/wwn-0x5000cca6f8cc70db-part3 /dev/disk/by-label/Ubuntu /dev/disk/by-partuuid/55067743-f4b0-40a1-965d-c29bc1772b84 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3 /dev/disk/by-uuid/9f5642a1-4712-4564-9865-e76670e1bcd8
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=100
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Ubuntu
+E: ID_FS_LABEL_ENC=Ubuntu
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=9f5642a1-4712-4564-9865-e76670e1bcd8
+E: ID_FS_UUID_ENC=9f5642a1-4712-4564-9865-e76670e1bcd8
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=HGST_HTS545032A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545032A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=3092480
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=39061504
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=55067743-f4b0-40a1-965d-c29bc1772b84
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GGBZBF04
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+E: ID_SERIAL=HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+E: ID_SERIAL_SHORT=TEAB5A3R0WBDSJ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f8cc70db
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f8cc70db
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=1583349760
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=19999490048
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=55067743-F4B0-40A1-965D-C29BC1772B84
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3736818
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+N: sda4
+S: disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part4
+S: disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part4
+S: disk/by-id/wwn-0x5000cca6f8cc70db-part4
+S: disk/by-label/Swap
+S: disk/by-partlabel/primary
+S: disk/by-partuuid/0feb80e7-f26f-4122-8151-addc26e21299
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4
+S: disk/by-uuid/6d82776d-0789-4a76-8819-7facf37d0ddb
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part4 /dev/disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part4 /dev/disk/by-id/wwn-0x5000cca6f8cc70db-part4 /dev/disk/by-label/Swap /dev/disk/by-partlabel/primary /dev/disk/by-partuuid/0feb80e7-f26f-4122-8151-addc26e21299 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4 /dev/disk/by-uuid/6d82776d-0789-4a76-8819-7facf37d0ddb
+E: DEVNAME=/dev/sda4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=100
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Swap
+E: ID_FS_LABEL_ENC=Swap
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=6d82776d-0789-4a76-8819-7facf37d0ddb
+E: ID_FS_UUID_ENC=6d82776d-0789-4a76-8819-7facf37d0ddb
+E: ID_FS_VERSION=2
+E: ID_MODEL=HGST_HTS545032A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545032A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=primary
+E: ID_PART_ENTRY_NUMBER=4
+E: ID_PART_ENTRY_OFFSET=42153984
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=10342400
+E: ID_PART_ENTRY_TYPE=0657fd6d-a4ab-43c4-84e5-0933c84b4f4f
+E: ID_PART_ENTRY_UUID=0feb80e7-f26f-4122-8151-addc26e21299
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GGBZBF04
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+E: ID_SERIAL=HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+E: ID_SERIAL_SHORT=TEAB5A3R0WBDSJ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f8cc70db
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f8cc70db
+E: MAJOR=8
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=primary
+E: UDISKS_PARTITION_NUMBER=4
+E: UDISKS_PARTITION_OFFSET=21582839808
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=5295308800
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0657FD6D-A4AB-43C4-84E5-0933C84B4F4F
+E: UDISKS_PARTITION_UUID=0FEB80E7-F26F-4122-8151-ADDC26E21299
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3708640
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part5
+S: disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part5
+S: disk/by-id/wwn-0x5000cca6f8cc70db-part5
+S: disk/by-label/User_Data
+S: disk/by-partlabel/primary
+S: disk/by-partuuid/53196356-c69e-43e8-ab7c-5099f3b1fb4c
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/daea450f-c3a4-4994-9822-8d7d9c952df6
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS545032A7E380_TEAB5A3R0WBDSJ-part5 /dev/disk/by-id/scsi-SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ-part5 /dev/disk/by-id/wwn-0x5000cca6f8cc70db-part5 /dev/disk/by-label/User_Data /dev/disk/by-partlabel/primary /dev/disk/by-partuuid/53196356-c69e-43e8-ab7c-5099f3b1fb4c /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/daea450f-c3a4-4994-9822-8d7d9c952df6
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=100
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=98
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=User_Data
+E: ID_FS_LABEL_ENC=User_Data
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=daea450f-c3a4-4994-9822-8d7d9c952df6
+E: ID_FS_UUID_ENC=daea450f-c3a4-4994-9822-8d7d9c952df6
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=HGST_HTS545032A7E380
+E: ID_MODEL_ENC=HGST\x20HTS545032A7E380\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=primary
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=52496384
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=572645376
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=53196356-c69e-43e8-ab7c-5099f3b1fb4c
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GGBZBF04
+E: ID_SCSI_COMPAT=SATA_HGST_HTS545032A_TEAB5A3R0WBDSJ
+E: ID_SERIAL=HGST_HTS545032A7E380_TEAB5A3R0WBDSJ
+E: ID_SERIAL_SHORT=TEAB5A3R0WBDSJ
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6f8cc70db
+E: ID_WWN_WITH_EXTENSION=0x5000cca6f8cc70db
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=primary
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=26878148608
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=293194432512
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=53196356-C69E-43E8-AB7C-5099F3B1FB4C
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=3760238
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-MATSHITADVD-RAM_UJ8C2_HP39_539700
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-MATSHITADVD-RAM_UJ8C2_HP39_539700 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=MATSHITADVD-RAM_UJ8C2
+E: ID_MODEL_ENC=MATSHITADVD-RAM\x20UJ8C2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=1.00
+E: ID_SERIAL=MATSHITADVD-RAM_UJ8C2_HP39_539700
+E: ID_SERIAL_SHORT=HP39_539700
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2983761
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+N: bsg/2:0:0:0
+E: DEVNAME=/dev/bsg/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/bsg/2:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_device/2:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/target2:0:0/2:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12353151
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv000017AAsd00005018bc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=17AA:5018
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon2
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon2
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dock.0
+E: DEVPATH=/devices/platform/dock.0
+E: MODALIAS=platform:dock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/efifb.0
+E: DEVPATH=/devices/platform/efifb.0
+E: DRIVER=efifb
+E: MODALIAS=platform:efifb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=LENOVO
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12357088
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=402000000 3803078f800d001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8E,8F,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,D9,E2,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1989555
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1995865
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+E: XKBOPTIONS=''
+E: XKBVARIANT='intl'
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input107
+E: ABS=660800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input107
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=e520 10000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,145,148,14A,14D,14E,14F,ra0,1,18,1C,2F,35,36,39,3A,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=5
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5276693875
+
+P: /devices/platform/i8042/serio1/input/input107/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/i8042/serio1/input/input107/event4
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5276755052
+
+P: /devices/platform/i8042/serio1/input/input107/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input107/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5276754695
+
+P: /devices/platform/i8042/serio1/serio49
+E: DEVPATH=/devices/platform/i8042/serio1/serio49
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty05pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=05
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/serio49/input/input108
+E: DEVPATH=/devices/platform/i8042/serio1/serio49/input/input108
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-49
+E: ID_PATH_TAG=platform-i8042-serio-49
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p000Ae0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="TPPS/2 IBM TrackPoint"
+E: PHYS="synaptics-pt/serio0/input0"
+E: PRODUCT=11/2/a/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5285602764
+
+P: /devices/platform/i8042/serio1/serio49/input/input108/event12
+N: input/event12
+S: input/by-path/platform-i8042-serio-49-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-49-event-mouse
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/platform/i8042/serio1/serio49/input/input108/event12
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-49
+E: ID_PATH_TAG=platform-i8042-serio-49
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5285716568
+
+P: /devices/platform/i8042/serio1/serio49/input/input108/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-49-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-49-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/serio49/input/input108/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-49
+E: ID_PATH_TAG=platform-i8042-serio-49
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=5285690887
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12357560
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12358371
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12358745
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12359123
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12359231
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12359495
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12359546
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12359921
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360759
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360347
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360147
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360418
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360522
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360782
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12360888
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12361148
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12361229
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12361499
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12362321
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12361916
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12361704
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12361960
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12362071
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12362335
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12362447
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12362707
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12362805
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12363059
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12363272
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12363214
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12363480
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12363587
+
+P: /devices/platform/thinkpad_acpi
+E: DEVPATH=/devices/platform/thinkpad_acpi
+E: DRIVER=thinkpad_acpi
+E: MODALIAS=platform:thinkpad_acpi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/input/input5
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input5
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: KEY=18040000 0 10000000000000 0 101501b00102004 8000000001104000 e000000000000 0
+E: MODALIAS=input:b0019v17AAp5054e4101-e0,1,4,k71,72,73,8E,94,98,BF,C2,CD,D4,E0,E1,E3,E4,EC,EE,F0,F8,174,1D2,1DB,1DC,ram4,lsfw
+E: MSC=10
+E: NAME="ThinkPad Extra Buttons"
+E: PHYS="thinkpad_acpi/input0"
+E: PRODUCT=19/17aa/5054/4101
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13057783
+
+P: /devices/platform/thinkpad_acpi/input/input5/event5
+N: input/event5
+S: input/by-path/platform-thinkpad_acpi-event
+E: DEVLINKS=/dev/input/by-path/platform-thinkpad_acpi-event
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input5/event5
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13059739
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+E: XKBOPTIONS=''
+E: XKBVARIANT='intl'
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/rfkill/rfkill0
+E: DEVPATH=/devices/platform/thinkpad_acpi/rfkill/rfkill0
+E: RFKILL_NAME=tpacpi_bluetooth_sw
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/sound/card29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: PULSE_IGNORE=1
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13147420
+
+P: /devices/platform/thinkpad_acpi/sound/card29/controlC29
+N: snd/controlC29
+S: snd/by-path/platform-thinkpad_acpi
+E: DEVLINKS=/dev/snd/by-path/platform-thinkpad_acpi
+E: DEVNAME=/dev/snd/controlC29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29/controlC29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=13056901
+
+P: /devices/platform/thinkpad_hwmon
+E: DEVPATH=/devices/platform/thinkpad_hwmon
+E: DRIVER=thinkpad_hwmon
+E: MODALIAS=platform:thinkpad_hwmon
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_hwmon/hwmon/hwmon1
+E: DEVPATH=/devices/platform/thinkpad_hwmon/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1976497
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0b
+E: DEVPATH=/devices/pnp0/00:0b
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,0080,0081,0082,0083,0084,0085,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,009A,009B,009C,009D,00C0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory22
+E: DEVPATH=/devices/system/memory/memory22
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory23
+E: DEVPATH=/devices/system/memory/memory23
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory24
+E: DEVPATH=/devices/system/memory/memory24
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory25
+E: DEVPATH=/devices/system/memory/memory25
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory26
+E: DEVPATH=/devices/system/memory/memory26
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory27
+E: DEVPATH=/devices/system/memory/memory27
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:21
+E: DEVPATH=/devices/virtual/bdi/0:21
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1953646
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1953766
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1953873
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1953988
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1954099
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1954202
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1954321
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=1954420
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1954525
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1954622
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1954720
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1954822
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1954919
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955026
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955126
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955229
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955326
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955419
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955514
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955609
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955711
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955807
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1955910
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1956034
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnLENOVO:bvrHEET27WW(1.08):bd03/29/2013:svnLENOVO:pn627725U:pvrThinkPadEdgeE431:rvnLENOVO:rn627725U:rvrWIN8PROTPG:cvnLENOVO:ct10:cvrNotAvailable:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/autofs
+N: autofs
+E: DEVNAME=/dev/autofs
+E: DEVPATH=/devices/virtual/misc/autofs
+E: MAJOR=10
+E: MINOR=235
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/btrfs-control
+N: btrfs-control
+E: DEVNAME=/dev/btrfs-control
+E: DEVPATH=/devices/virtual/misc/btrfs-control
+E: MAJOR=10
+E: MINOR=234
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/nvram
+N: nvram
+E: DEVNAME=/dev/nvram
+E: DEVPATH=/devices/virtual/misc/nvram
+E: MAJOR=10
+E: MINOR=144
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12382732
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/watchdog
+N: watchdog
+E: DEVNAME=/dev/watchdog
+E: DEVPATH=/devices/virtual/misc/watchdog
+E: MAJOR=10
+E: MINOR=130
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr0
+N: cpu/0/msr
+E: DEVNAME=/dev/cpu/0/msr
+E: DEVPATH=/devices/virtual/msr/msr0
+E: MAJOR=202
+E: MINOR=0
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr1
+N: cpu/1/msr
+E: DEVNAME=/dev/cpu/1/msr
+E: DEVPATH=/devices/virtual/msr/msr1
+E: MAJOR=202
+E: MINOR=1
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr2
+N: cpu/2/msr
+E: DEVNAME=/dev/cpu/2/msr
+E: DEVPATH=/devices/virtual/msr/msr2
+E: MAJOR=202
+E: MINOR=2
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr3
+N: cpu/3/msr
+E: DEVNAME=/dev/cpu/3/msr
+E: DEVPATH=/devices/virtual/msr/msr3
+E: MAJOR=202
+E: MINOR=3
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12384015
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12890809
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12717017
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12385386
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12385665
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12385944
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12386217
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12386491
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12386865
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12386904
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12387171
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12387449
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12387726
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12388008
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12388284
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12388606
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12388618
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12388882
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12389167
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12389499
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12389767
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12390032
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12390294
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12390562
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12390828
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12391093
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12391368
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12391650
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12391917
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12392205
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12392566
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12392837
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12393107
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12393376
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12393639
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12393893
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12394186
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12394453
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12394718
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12394982
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12395258
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12395611
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12395890
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12400159
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12400487
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12400785
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12401070
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12401350
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12401637
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12401912
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12402189
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12402453
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12402778
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12402831
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403860
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12402935
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403182
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403045
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403371
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403386
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403583
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403508
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12403796
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12404144
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12404371
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12404584
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12404794
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12405012
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12405200
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12405141
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=12405485
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs63
+N: vcs63
+E: DEVNAME=/dev/vcs63
+E: DEVPATH=/devices/virtual/vc/vcs63
+E: MAJOR=7
+E: MINOR=63
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa63
+N: vcsa63
+E: DEVNAME=/dev/vcsa63
+E: DEVPATH=/devices/virtual/vc/vcsa63
+E: MAJOR=7
+E: MINOR=191
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog0
+N: watchdog0
+E: DEVNAME=/dev/watchdog0
+E: DEVPATH=/devices/virtual/watchdog/watchdog0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog1
+N: watchdog1
+E: DEVNAME=/dev/watchdog1
+E: DEVPATH=/devices/virtual/watchdog/watchdog1
+E: MAJOR=253
+E: MINOR=1
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog10
+N: watchdog10
+E: DEVNAME=/dev/watchdog10
+E: DEVPATH=/devices/virtual/watchdog/watchdog10
+E: MAJOR=253
+E: MINOR=10
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog11
+N: watchdog11
+E: DEVNAME=/dev/watchdog11
+E: DEVPATH=/devices/virtual/watchdog/watchdog11
+E: MAJOR=253
+E: MINOR=11
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog12
+N: watchdog12
+E: DEVNAME=/dev/watchdog12
+E: DEVPATH=/devices/virtual/watchdog/watchdog12
+E: MAJOR=253
+E: MINOR=12
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog13
+N: watchdog13
+E: DEVNAME=/dev/watchdog13
+E: DEVPATH=/devices/virtual/watchdog/watchdog13
+E: MAJOR=253
+E: MINOR=13
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog14
+N: watchdog14
+E: DEVNAME=/dev/watchdog14
+E: DEVPATH=/devices/virtual/watchdog/watchdog14
+E: MAJOR=253
+E: MINOR=14
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog15
+N: watchdog15
+E: DEVNAME=/dev/watchdog15
+E: DEVPATH=/devices/virtual/watchdog/watchdog15
+E: MAJOR=253
+E: MINOR=15
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog16
+N: watchdog16
+E: DEVNAME=/dev/watchdog16
+E: DEVPATH=/devices/virtual/watchdog/watchdog16
+E: MAJOR=253
+E: MINOR=16
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog17
+N: watchdog17
+E: DEVNAME=/dev/watchdog17
+E: DEVPATH=/devices/virtual/watchdog/watchdog17
+E: MAJOR=253
+E: MINOR=17
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog18
+N: watchdog18
+E: DEVNAME=/dev/watchdog18
+E: DEVPATH=/devices/virtual/watchdog/watchdog18
+E: MAJOR=253
+E: MINOR=18
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog19
+N: watchdog19
+E: DEVNAME=/dev/watchdog19
+E: DEVPATH=/devices/virtual/watchdog/watchdog19
+E: MAJOR=253
+E: MINOR=19
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog2
+N: watchdog2
+E: DEVNAME=/dev/watchdog2
+E: DEVPATH=/devices/virtual/watchdog/watchdog2
+E: MAJOR=253
+E: MINOR=2
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog20
+N: watchdog20
+E: DEVNAME=/dev/watchdog20
+E: DEVPATH=/devices/virtual/watchdog/watchdog20
+E: MAJOR=253
+E: MINOR=20
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog21
+N: watchdog21
+E: DEVNAME=/dev/watchdog21
+E: DEVPATH=/devices/virtual/watchdog/watchdog21
+E: MAJOR=253
+E: MINOR=21
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog22
+N: watchdog22
+E: DEVNAME=/dev/watchdog22
+E: DEVPATH=/devices/virtual/watchdog/watchdog22
+E: MAJOR=253
+E: MINOR=22
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog23
+N: watchdog23
+E: DEVNAME=/dev/watchdog23
+E: DEVPATH=/devices/virtual/watchdog/watchdog23
+E: MAJOR=253
+E: MINOR=23
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog24
+N: watchdog24
+E: DEVNAME=/dev/watchdog24
+E: DEVPATH=/devices/virtual/watchdog/watchdog24
+E: MAJOR=253
+E: MINOR=24
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog25
+N: watchdog25
+E: DEVNAME=/dev/watchdog25
+E: DEVPATH=/devices/virtual/watchdog/watchdog25
+E: MAJOR=253
+E: MINOR=25
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog26
+N: watchdog26
+E: DEVNAME=/dev/watchdog26
+E: DEVPATH=/devices/virtual/watchdog/watchdog26
+E: MAJOR=253
+E: MINOR=26
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog27
+N: watchdog27
+E: DEVNAME=/dev/watchdog27
+E: DEVPATH=/devices/virtual/watchdog/watchdog27
+E: MAJOR=253
+E: MINOR=27
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog28
+N: watchdog28
+E: DEVNAME=/dev/watchdog28
+E: DEVPATH=/devices/virtual/watchdog/watchdog28
+E: MAJOR=253
+E: MINOR=28
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog29
+N: watchdog29
+E: DEVNAME=/dev/watchdog29
+E: DEVPATH=/devices/virtual/watchdog/watchdog29
+E: MAJOR=253
+E: MINOR=29
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog3
+N: watchdog3
+E: DEVNAME=/dev/watchdog3
+E: DEVPATH=/devices/virtual/watchdog/watchdog3
+E: MAJOR=253
+E: MINOR=3
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog30
+N: watchdog30
+E: DEVNAME=/dev/watchdog30
+E: DEVPATH=/devices/virtual/watchdog/watchdog30
+E: MAJOR=253
+E: MINOR=30
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog31
+N: watchdog31
+E: DEVNAME=/dev/watchdog31
+E: DEVPATH=/devices/virtual/watchdog/watchdog31
+E: MAJOR=253
+E: MINOR=31
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog4
+N: watchdog4
+E: DEVNAME=/dev/watchdog4
+E: DEVPATH=/devices/virtual/watchdog/watchdog4
+E: MAJOR=253
+E: MINOR=4
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog5
+N: watchdog5
+E: DEVNAME=/dev/watchdog5
+E: DEVPATH=/devices/virtual/watchdog/watchdog5
+E: MAJOR=253
+E: MINOR=5
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog6
+N: watchdog6
+E: DEVNAME=/dev/watchdog6
+E: DEVPATH=/devices/virtual/watchdog/watchdog6
+E: MAJOR=253
+E: MINOR=6
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog7
+N: watchdog7
+E: DEVNAME=/dev/watchdog7
+E: DEVPATH=/devices/virtual/watchdog/watchdog7
+E: MAJOR=253
+E: MINOR=7
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog8
+N: watchdog8
+E: DEVNAME=/dev/watchdog8
+E: DEVPATH=/devices/virtual/watchdog/watchdog8
+E: MAJOR=253
+E: MINOR=8
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog9
+N: watchdog9
+E: DEVNAME=/dev/watchdog9
+E: DEVPATH=/devices/virtual/watchdog/watchdog9
+E: MAJOR=253
+E: MINOR=9
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: DEVPATH=/devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: MODALIAS=wmi:E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: DEVPATH=/devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: MODALIAS=wmi:FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_E445.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_E445.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_E445.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5546 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1014749
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1017199
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02/input/input5
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02/input/input5
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:02
+E: ID_PATH_TAG=acpi-LNXVIDEO_02
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10485881
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02/input/input5/event5
+N: input/event5
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:02/input/input5/event5
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:02
+E: ID_PATH_TAG=acpi-LNXVIDEO_02
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10491225
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/SMB0001:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/SMB0001:00
+E: MODALIAS=acpi:SMB0001:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00/input/input4
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00/input/input4
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10483994
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00/input/input4/event4
+N: input/event4
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/LNXVIDEO:00/input/input4/event4
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10489758
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/LNXVIDEO:01
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/LNXVIDEO:01/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/LNXVIDEO:01/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:03/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:06/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:06/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0a/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0c/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:0e/device:0f/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12/device:13/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12/device:13/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12/device:13/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12/device:13/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1b/device:1c/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2a/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2a/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:38/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3a/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3a/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3c/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3c/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3e/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:3e/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:40/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:37/device:40/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/LEN0022:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/LEN0022:00
+E: MODALIAS=acpi:LEN0022:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0303:00
+E: MODALIAS=acpi:PNP0303:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C02:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/LEN0068:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/LEN0068:00
+E: DRIVER=thinkpad_hotkey
+E: MODALIAS=acpi:LEN0068:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_ENERGY_FULL=48680000
+E: POWER_SUPPLY_ENERGY_FULL_DESIGN=47520000
+E: POWER_SUPPLY_ENERGY_NOW=48680000
+E: POWER_SUPPLY_MANUFACTURER=SANYO
+E: POWER_SUPPLY_MODEL_NAME=45N1043
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_POWER_NOW=0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER= 6849
+E: POWER_SUPPLY_STATUS=Full
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=10800000
+E: POWER_SUPPLY_VOLTAGE_NOW=12506000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C09:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:44/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46/device:47
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:46/device:47
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:48
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:48
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:48/device:49
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:48/device:49
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4a/device:4b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4a/device:4b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4c/device:4d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:4c/device:4d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1018040
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0C:00/input/input0/event0
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1023706
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1018051
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input1/event1
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1023708
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/ibs_fetch
+E: DEVPATH=/devices/ibs_fetch
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/ibs_op
+E: DEVPATH=/devices/ibs_op
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00001022d00001410sv000017AAsd0000510Abc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1410
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0
+E: DRIVER=fglrx_pci
+E: MODALIAS=pci:v00001002d0000990Bsv000017AAsd0000510Bbc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=1002:990B
+E: PCI_SLOT_NAME=0000:00:01.0
+E: PCI_SUBSYS_ID=17AA:510B
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.0/backlight/acpi_video1
+E: DEVPATH=/devices/pci0000:00/0000:00:01.0/backlight/acpi_video1
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.1
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00001002d00009902sv000017AAsd0000510Abc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=1002:9902
+E: PCI_SLOT_NAME=0000:00:01.1
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:01.1
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD] nee ATI
+E: ID_VENDOR_ID=0x1002
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10631726
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10618376
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/input7
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA ATI HDMI HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10618179
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/input7/event7
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10622184
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10618087
+
+P: /devices/pci0000:00/0000:00:01.1/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:01.1
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:01.1
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:01.1/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:01.1
+E: ID_PATH_TAG=pci-0000_00_01_1
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10618702
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d00001412sv00001022sd00001234bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:1412
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=1022:1234
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/0000:01:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/0000:01:00.0
+E: DRIVER=fglrx_pci
+E: MODALIAS=pci:v00001002d00006663sv000017AAsd0000510Bbc03sc80i00
+E: PCI_CLASS=38000
+E: PCI_ID=1002:6663
+E: PCI_SLOT_NAME=0000:01:00.0
+E: PCI_SUBSYS_ID=17AA:510B
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/0000:01:00.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/0000:01:00.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/pci_bus/0000:01
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/pci_bus/0000:01
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d00001414sv00001022sd00001234bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:1414
+E: PCI_SLOT_NAME=0000:00:04.0
+E: PCI_SUBSYS_ID=1022:1234
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0
+E: DRIVER=r8169
+E: MODALIAS=pci:v000010ECd00008168sv000017AAsd00005100bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=10EC:8168
+E: PCI_SLOT_NAME=0000:02:00.0
+E: PCI_SUBSYS_ID=17AA:5100
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:04.0/0000:02:00.0/net/eth1
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/0000:02:00.0/net/eth1
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=RTL8111/8168B PCI Express Gigabit Ethernet controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:04.0/0000:02:00.0
+E: ID_VENDOR_FROM_DATABASE=Realtek Semiconductor Co., Ltd.
+E: ID_VENDOR_ID=0x10ec
+E: IFINDEX=2
+E: INTERFACE=eth1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10296914
+
+P: /devices/pci0000:00/0000:00:04.0/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:04.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d00001415sv00001022sd00001234bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:1415
+E: PCI_SLOT_NAME=0000:00:05.0
+E: PCI_SUBSYS_ID=1022:1234
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0
+E: DRIVER=wl
+E: MODALIAS=pci:v000014E4d00004365sv000017AAsd00000611bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=14E4:4365
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=17AA:0611
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0/ieee80211/phy0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0/ieee80211/phy0/rfkill2
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:05.0/0000:03:00.0
+E: ID_VENDOR_FROM_DATABASE=Broadcom Corporation
+E: ID_VENDOR_ID=0x14e4
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10833090
+
+P: /devices/pci0000:00/0000:00:05.0/0000:03:00.0/net/wlan0/rfkill3
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/0000:03:00.0/net/wlan0/rfkill3
+E: RFKILL_NAME=brcmwl-0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:05.0/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:05.0/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00001022d00001417sv00001022sd00001234bc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=1022:1417
+E: PCI_SLOT_NAME=0000:00:07.0
+E: PCI_SUBSYS_ID=1022:1234
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0/0000:04:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0/0000:04:00.0
+E: DRIVER=rtsx_pci
+E: MODALIAS=pci:v000010ECd00005229sv000017AAsd00005100bcFFsc00i00
+E: PCI_CLASS=FF0000
+E: PCI_ID=10EC:5229
+E: PCI_SLOT_NAME=0000:04:00.0
+E: PCI_SUBSYS_ID=17AA:5100
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_ms.0
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_ms.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_ms
+E: MODALIAS=platform:rtsx_pci_ms
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_ms.0/memstick_host/memstick0
+E: SUBSYSTEM=memstick_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_sdmmc.0
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_sdmmc.0
+E: DEVTYPE=mfd_device
+E: DRIVER=rtsx_pci_sdmmc
+E: MODALIAS=platform:rtsx_pci_sdmmc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0/0000:04:00.0/rtsx_pci_sdmmc.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:07.0/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:07.0/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00001022d00007814sv000017AAsd0000510Abc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=1022:7814
+E: PCI_SLOT_NAME=0000:00:10.0
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/usb5
+N: bus/usb/005/001
+E: BUSNUM=005
+E: DEVNAME=/dev/bus/usb/005/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb5
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_xhci_hcd_xHCI_Host_Controller_0000:00:10.0
+E: ID_SERIAL_SHORT=0000:00:10.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=512
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=994007
+
+P: /devices/pci0000:00/0000:00:10.0/usb5/5-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb5/5-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.0/usb6
+N: bus/usb/006/001
+E: BUSNUM=006
+E: DEVNAME=/dev/bus/usb/006/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_xhci_hcd_xHCI_Host_Controller_0000:00:10.0
+E: ID_SERIAL_SHORT=0000:00:10.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=640
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=994025
+
+P: /devices/pci0000:00/0000:00:10.0/usb6/6-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.0/usb6/6-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.1
+E: DEVPATH=/devices/pci0000:00/0000:00:10.1
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00001022d00007814sv000017AAsd0000510Abc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=1022:7814
+E: PCI_SLOT_NAME=0000:00:10.1
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.1/usb7
+N: bus/usb/007/001
+E: BUSNUM=007
+E: DEVNAME=/dev/bus/usb/007/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:10.1/usb7
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_xhci_hcd_xHCI_Host_Controller_0000:00:10.1
+E: ID_SERIAL_SHORT=0000:00:10.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=768
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=994625
+
+P: /devices/pci0000:00/0000:00:10.1/usb7/7-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.1/usb7/7-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp01ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:10.1/usb8
+N: bus/usb/008/001
+E: BUSNUM=008
+E: DEVNAME=/dev/bus/usb/008/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:10.1/usb8
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_xhci_hcd_xHCI_Host_Controller_0000:00:10.1
+E: ID_SERIAL_SHORT=0000:00:10.1
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=896
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=993505
+
+P: /devices/pci0000:00/0000:00:10.1/usb8/8-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:10.1/usb8/8-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0305dc09dsc00dp03ic09isc00ip00
+E: PRODUCT=1d6b/3/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=Hudson SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD]
+E: MODALIAS=pci:v00001022d00007804sv000017AAsd0000510Abc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=1022:7804
+E: PCI_SLOT_NAME=0000:00:11.0
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10315391
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A
+S: disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A
+S: disk/by-id/wwn-0x5000cca6c6db96d3
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A /dev/disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A /dev/disk/by-id/wwn-0x5000cca6c6db96d3 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=214
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=212
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=HGST_HTS541010A9E680
+E: ID_MODEL_ENC=HGST\x20HTS541010A9E680\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=JA0ZB600
+E: ID_SCSI_COMPAT=SATA_HGST_HTS541010A_JD10501VHYPG8A
+E: ID_SERIAL=HGST_HTS541010A9E680_JD10501VHYPG8A
+E: ID_SERIAL_SHORT=JD10501VHYPG8A
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6c6db96d3
+E: ID_WWN_WITH_EXTENSION=0x5000cca6c6db96d3
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=5
+E: UDISKS_PARTITION_TABLE_SCHEME=gpt
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1796455
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part1
+S: disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part1
+S: disk/by-id/wwn-0x5000cca6c6db96d3-part1
+S: disk/by-partlabel/EFI\x20System\x20Partition
+S: disk/by-partuuid/5f65784a-bac1-4582-b4d7-676ae1df4f1b
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/1851-DC38
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part1 /dev/disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part1 /dev/disk/by-id/wwn-0x5000cca6c6db96d3-part1 /dev/disk/by-partlabel/EFI\x20System\x20Partition /dev/disk/by-partuuid/5f65784a-bac1-4582-b4d7-676ae1df4f1b /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/1851-DC38
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=214
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=212
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=1851-DC38
+E: ID_FS_UUID_ENC=1851-DC38
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=HGST_HTS541010A9E680
+E: ID_MODEL_ENC=HGST\x20HTS541010A9E680\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=EFI\x20System\x20Partition
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=40
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=97616
+E: ID_PART_ENTRY_TYPE=c12a7328-f81f-11d2-ba4b-00a0c93ec93b
+E: ID_PART_ENTRY_UUID=5f65784a-bac1-4582-b4d7-676ae1df4f1b
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=JA0ZB600
+E: ID_SCSI_COMPAT=SATA_HGST_HTS541010A_JD10501VHYPG8A
+E: ID_SERIAL=HGST_HTS541010A9E680_JD10501VHYPG8A
+E: ID_SERIAL_SHORT=JD10501VHYPG8A
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6c6db96d3
+E: ID_WWN_WITH_EXTENSION=0x5000cca6c6db96d3
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=EFI System Partition
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=20480
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=49979392
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=C12A7328-F81F-11D2-BA4B-00A0C93EC93B
+E: UDISKS_PARTITION_UUID=5F65784A-BAC1-4582-B4D7-676AE1DF4F1B
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1971243
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part2
+S: disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part2
+S: disk/by-id/wwn-0x5000cca6c6db96d3-part2
+S: disk/by-label/PQSERVICE
+S: disk/by-partlabel/Recovery\x20Partition
+S: disk/by-partuuid/e4baba02-99a6-41da-b07c-ca21b04c7e67
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part2
+S: disk/by-uuid/F4F5-833E
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part2 /dev/disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part2 /dev/disk/by-id/wwn-0x5000cca6c6db96d3-part2 /dev/disk/by-label/PQSERVICE /dev/disk/by-partlabel/Recovery\x20Partition /dev/disk/by-partuuid/e4baba02-99a6-41da-b07c-ca21b04c7e67 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part2 /dev/disk/by-uuid/F4F5-833E
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=214
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=212
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=PQSERVICE
+E: ID_FS_LABEL_ENC=PQSERVICE
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=F4F5-833E
+E: ID_FS_UUID_ENC=F4F5-833E
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=HGST_HTS541010A9E680
+E: ID_MODEL_ENC=HGST\x20HTS541010A9E680\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=Recovery\x20Partition
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=97656
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=3146488
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=e4baba02-99a6-41da-b07c-ca21b04c7e67
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=JA0ZB600
+E: ID_SCSI_COMPAT=SATA_HGST_HTS541010A_JD10501VHYPG8A
+E: ID_SERIAL=HGST_HTS541010A9E680_JD10501VHYPG8A
+E: ID_SERIAL_SHORT=JD10501VHYPG8A
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6c6db96d3
+E: ID_WWN_WITH_EXTENSION=0x5000cca6c6db96d3
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=Recovery Partition
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=49999872
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=1611001856
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=E4BABA02-99A6-41DA-B07C-CA21B04C7E67
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2096777
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part3
+S: disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part3
+S: disk/by-id/wwn-0x5000cca6c6db96d3-part3
+S: disk/by-label/Ubuntu
+S: disk/by-partuuid/7df4f323-a46a-46a1-831a-38cab5459531
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part3
+S: disk/by-uuid/dc034cc5-d9f4-44de-84d3-8cedbc61d052
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part3 /dev/disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part3 /dev/disk/by-id/wwn-0x5000cca6c6db96d3-part3 /dev/disk/by-label/Ubuntu /dev/disk/by-partuuid/7df4f323-a46a-46a1-831a-38cab5459531 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part3 /dev/disk/by-uuid/dc034cc5-d9f4-44de-84d3-8cedbc61d052
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=214
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=212
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Ubuntu
+E: ID_FS_LABEL_ENC=Ubuntu
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=dc034cc5-d9f4-44de-84d3-8cedbc61d052
+E: ID_FS_UUID_ENC=dc034cc5-d9f4-44de-84d3-8cedbc61d052
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=HGST_HTS541010A9E680
+E: ID_MODEL_ENC=HGST\x20HTS541010A9E680\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=3246080
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=39061504
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=7df4f323-a46a-46a1-831a-38cab5459531
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=JA0ZB600
+E: ID_SCSI_COMPAT=SATA_HGST_HTS541010A_JD10501VHYPG8A
+E: ID_SERIAL=HGST_HTS541010A9E680_JD10501VHYPG8A
+E: ID_SERIAL_SHORT=JD10501VHYPG8A
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6c6db96d3
+E: ID_WWN_WITH_EXTENSION=0x5000cca6c6db96d3
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=1661992960
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=19999490048
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=7DF4F323-A46A-46A1-831A-38CAB5459531
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2152989
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+N: sda4
+S: disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part4
+S: disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part4
+S: disk/by-id/wwn-0x5000cca6c6db96d3-part4
+S: disk/by-label/Swap
+S: disk/by-partlabel/primary
+S: disk/by-partuuid/b3512120-6415-4f15-af19-932efcad5ef2
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part4
+S: disk/by-uuid/032ed05e-9af8-426f-8418-25ef27cfb0e3
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part4 /dev/disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part4 /dev/disk/by-id/wwn-0x5000cca6c6db96d3-part4 /dev/disk/by-label/Swap /dev/disk/by-partlabel/primary /dev/disk/by-partuuid/b3512120-6415-4f15-af19-932efcad5ef2 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part4 /dev/disk/by-uuid/032ed05e-9af8-426f-8418-25ef27cfb0e3
+E: DEVNAME=/dev/sda4
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=214
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=212
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Swap
+E: ID_FS_LABEL_ENC=Swap
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=032ed05e-9af8-426f-8418-25ef27cfb0e3
+E: ID_FS_UUID_ENC=032ed05e-9af8-426f-8418-25ef27cfb0e3
+E: ID_FS_VERSION=2
+E: ID_MODEL=HGST_HTS541010A9E680
+E: ID_MODEL_ENC=HGST\x20HTS541010A9E680\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=primary
+E: ID_PART_ENTRY_NUMBER=4
+E: ID_PART_ENTRY_OFFSET=42307584
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=16896000
+E: ID_PART_ENTRY_TYPE=0657fd6d-a4ab-43c4-84e5-0933c84b4f4f
+E: ID_PART_ENTRY_UUID=b3512120-6415-4f15-af19-932efcad5ef2
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=JA0ZB600
+E: ID_SCSI_COMPAT=SATA_HGST_HTS541010A_JD10501VHYPG8A
+E: ID_SERIAL=HGST_HTS541010A9E680_JD10501VHYPG8A
+E: ID_SERIAL_SHORT=JD10501VHYPG8A
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6c6db96d3
+E: ID_WWN_WITH_EXTENSION=0x5000cca6c6db96d3
+E: MAJOR=8
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=primary
+E: UDISKS_PARTITION_NUMBER=4
+E: UDISKS_PARTITION_OFFSET=21661483008
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=8650752000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0657FD6D-A4AB-43C4-84E5-0933C84B4F4F
+E: UDISKS_PARTITION_UUID=B3512120-6415-4F15-AF19-932EFCAD5EF2
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2131148
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part5
+S: disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part5
+S: disk/by-id/wwn-0x5000cca6c6db96d3-part5
+S: disk/by-label/User_Data
+S: disk/by-partlabel/primary
+S: disk/by-partuuid/bc7ecaeb-7ef4-43e3-b5b6-2e3b0c97c11f
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part5
+S: disk/by-uuid/413b1e39-a338-464c-aa31-013760233835
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS541010A9E680_JD10501VHYPG8A-part5 /dev/disk/by-id/scsi-SATA_HGST_HTS541010A_JD10501VHYPG8A-part5 /dev/disk/by-id/wwn-0x5000cca6c6db96d3-part5 /dev/disk/by-label/User_Data /dev/disk/by-partlabel/primary /dev/disk/by-partuuid/bc7ecaeb-7ef4-43e3-b5b6-2e3b0c97c11f /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0-part5 /dev/disk/by-uuid/413b1e39-a338-464c-aa31-013760233835
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=214
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=212
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=5400
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=User_Data
+E: ID_FS_LABEL_ENC=User_Data
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=413b1e39-a338-464c-aa31-013760233835
+E: ID_FS_UUID_ENC=413b1e39-a338-464c-aa31-013760233835
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=HGST_HTS541010A9E680
+E: ID_MODEL_ENC=HGST\x20HTS541010A9E680\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=primary
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=59203584
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=1894320128
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=bc7ecaeb-7ef4-43e3-b5b6-2e3b0c97c11f
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=JA0ZB600
+E: ID_SCSI_COMPAT=SATA_HGST_HTS541010A_JD10501VHYPG8A
+E: ID_SERIAL=HGST_HTS541010A9E680_JD10501VHYPG8A
+E: ID_SERIAL_SHORT=JD10501VHYPG8A
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca6c6db96d3
+E: ID_WWN_WITH_EXTENSION=0x5000cca6c6db96d3
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=primary
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=30312235008
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=969891905536
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=BC7ECAEB-7EF4-43E3-B5B6-2E3B0C97C11F
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2183324
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-HL-DT-ST_DVDRAM_GT80N_M5MD2LI3447
+S: disk/by-id/wwn-0x5001480000000000
+S: disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-HL-DT-ST_DVDRAM_GT80N_M5MD2LI3447 /dev/disk/by-id/wwn-0x5001480000000000 /dev/disk/by-path/pci-0000:00:11.0-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=HL-DT-ST_DVDRAM_GT80N
+E: ID_MODEL_ENC=HL-DT-ST\x20DVDRAM\x20GT80N\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:11.0-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_11_0-scsi-0_0_0_0
+E: ID_REVISION=LN81
+E: ID_SERIAL=HL-DT-ST_DVDRAM_GT80N_M5MD2LI3447
+E: ID_SERIAL_SHORT=M5MD2LI3447
+E: ID_TYPE=cd
+E: ID_WWN=0x5001480000000000
+E: ID_WWN_WITH_EXTENSION=0x5001480000000000
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1602239
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10387156
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:11.0/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:11.0/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.0
+E: DRIVER=ohci_hcd
+E: MODALIAS=pci:v00001022d00007807sv000017AAsd0000510Abc0Csc03i10
+E: PCI_CLASS=C0310
+E: PCI_ID=1022:7807
+E: PCI_SLOT_NAME=0000:00:12.0
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:12.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OHCI_Host_Controller
+E: ID_MODEL_ENC=OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_ohci_hcd_OHCI_Host_Controller_0000:00:12.0
+E: ID_SERIAL_SHORT=0000:00:12.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1013461
+
+P: /devices/pci0000:00/0000:00:12.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00001022d00007808sv000017AAsd0000510Abc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=1022:7808
+E: PCI_SLOT_NAME=0000:00:12.2
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:12.2/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_ehci_hcd_EHCI_Host_Controller_0000:00:12.2
+E: ID_SERIAL_SHORT=0000:00:12.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1014132
+
+P: /devices/pci0000:00/0000:00:12.2/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:12.2/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0
+E: DRIVER=ohci_hcd
+E: MODALIAS=pci:v00001022d00007807sv000017AAsd0000510Abc0Csc03i10
+E: PCI_CLASS=C0310
+E: PCI_ID=1022:7807
+E: PCI_SLOT_NAME=0000:00:13.0
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OHCI_Host_Controller
+E: ID_MODEL_ENC=OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_ohci_hcd_OHCI_Host_Controller_0000:00:13.0
+E: ID_SERIAL_SHORT=0000:00:13.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=995415
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1
+N: bus/usb/004/062
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/062
+E: DEVNUM=062
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BCM43142A0
+E: ID_MODEL_ENC=BCM43142A0
+E: ID_MODEL_ID=2007
+E: ID_REVISION=0112
+E: ID_SERIAL=Broadcom_Corp_BCM43142A0_2CD05A466F25
+E: ID_SERIAL_SHORT=2CD05A466F25
+E: ID_USB_INTERFACES=:ff0101:ffffff:fe0101:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=04ca
+E: MAJOR=189
+E: MINOR=445
+E: PRODUCT=4ca/2007/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6287467749
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v04CAp2007d0112dcFFdsc01dp01icFFisc01ip01
+E: PRODUCT=4ca/2007/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.0/bluetooth/hci0/rfkill63
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.0/bluetooth/hci0/rfkill63
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v04CAp2007d0112dcFFdsc01dp01icFFisc01ip01
+E: PRODUCT=4ca/2007/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v04CAp2007d0112dcFFdsc01dp01icFFiscFFipFF
+E: PRODUCT=4ca/2007/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:13.0/usb4/4-1/4-1:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v04CAp2007d0112dcFFdsc01dp01icFEisc01ip01
+E: PRODUCT=4ca/2007/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2
+E: DRIVER=ehci_hcd
+E: MODALIAS=pci:v00001022d00007808sv000017AAsd0000510Abc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=1022:7808
+E: PCI_SLOT_NAME=0000:00:13.2
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-26-generic_ehci_hcd_EHCI_Host_Controller_0000:00:13.2
+E: ID_SERIAL_SHORT=0000:00:13.2
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-26-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-26-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=996634
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-2
+N: bus/usb/002/003
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=1823
+E: ID_REVISION=0008
+E: ID_SERIAL=C6JD2LG8M_Integrated_Camera
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=C6JD2LG8M
+E: ID_VENDOR_ENC=C6JD2LG8M
+E: ID_VENDOR_ID=05ca
+E: MAJOR=189
+E: MINOR=130
+E: PRODUCT=5ca/1823/8
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1076160
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v05CAp1823d0008dcEFdsc02dp01ic0Eisc01ip00
+E: PRODUCT=5ca/1823/8
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0/input/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0/input/input6
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=1823
+E: ID_PATH=pci-0000:00:13.2-usb-0:2:1.0
+E: ID_PATH_TAG=pci-0000_00_13_2-usb-0_2_1_0
+E: ID_REVISION=0008
+E: ID_SERIAL=C6JD2LG8M_Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=C6JD2LG8M
+E: ID_VENDOR_ENC=C6JD2LG8M
+E: ID_VENDOR_ID=05ca
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v05CAp1823e0008-e0,1,kD4,ramlsfw
+E: NAME="Integrated Camera"
+E: PHYS="usb-0000:00:13.2-2/button"
+E: PRODUCT=3/5ca/1823/8
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10567689
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0/input/input6/event6
+N: input/event6
+S: input/by-id/usb-C6JD2LG8M_Integrated_Camera-event-if00
+S: input/by-path/pci-0000:00:13.2-usb-0:2:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-C6JD2LG8M_Integrated_Camera-event-if00 /dev/input/by-path/pci-0000:00:13.2-usb-0:2:1.0-event
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0/input/input6/event6
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=1823
+E: ID_PATH=pci-0000:00:13.2-usb-0:2:1.0
+E: ID_PATH_TAG=pci-0000_00_13_2-usb-0_2_1_0
+E: ID_REVISION=0008
+E: ID_SERIAL=C6JD2LG8M_Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=C6JD2LG8M
+E: ID_VENDOR_ENC=C6JD2LG8M
+E: ID_VENDOR_ID=05ca
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10570352
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-C6JD2LG8M_Integrated_Camera-video-index0
+S: v4l/by-path/pci-0000:00:13.2-usb-0:2:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-C6JD2LG8M_Integrated_Camera-video-index0 /dev/v4l/by-path/pci-0000:00:13.2-usb-0:2:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=1823
+E: ID_PATH=pci-0000:00:13.2-usb-0:2:1.0
+E: ID_PATH_TAG=pci-0000_00_13_2-usb-0_2_1_0
+E: ID_REVISION=0008
+E: ID_SERIAL=C6JD2LG8M_Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Integrated Camera
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=C6JD2LG8M
+E: ID_VENDOR_ENC=C6JD2LG8M
+E: ID_VENDOR_ID=05ca
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10569020
+
+P: /devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:13.2/usb2/2-2/2-2:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v05CAp1823d0008dcEFdsc02dp01ic0Eisc02ip00
+E: PRODUCT=5ca/1823/8
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: MODALIAS=pci:v00001022d0000780Bsv000017AAsd0000510Abc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=1022:780B
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00001022d0000780Dsv000017AAsd0000510Abc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=1022:780D
+E: PCI_SLOT_NAME=0000:00:14.2
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Hudson Azalia Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:14.2
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: ID_VENDOR_FROM_DATABASE=Advanced Micro Devices [AMD]
+E: ID_VENDOR_ID=0x1022
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10633198
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/hwC1D0
+N: snd/hwC1D0
+E: DEVNAME=/dev/snd/hwC1D0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/hwC1D0
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10619818
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HD-Audio Generic Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10619785
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10623508
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HD-Audio Generic Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10619644
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10622483
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0c
+N: snd/pcmC1D0c
+E: DEVNAME=/dev/snd/pcmC1D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0c
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10620668
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0p
+N: snd/pcmC1D0p
+E: DEVNAME=/dev/snd/pcmC1D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/pcmC1D0p
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10620051
+
+P: /devices/pci0000:00/0000:00:14.2/sound/card1/controlC1
+N: snd/controlC1
+S: snd/by-path/pci-0000:00:14.2
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:14.2
+E: DEVNAME=/dev/snd/controlC1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.2/sound/card1/controlC1
+E: ID_PATH=pci-0000:00:14.2
+E: ID_PATH_TAG=pci-0000_00_14_2
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10620206
+
+P: /devices/pci0000:00/0000:00:14.3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.3
+E: MODALIAS=pci:v00001022d0000780Esv000017AAsd0000510Abc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=1022:780E
+E: PCI_SLOT_NAME=0000:00:14.3
+E: PCI_SUBSYS_ID=17AA:510A
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.4
+E: MODALIAS=pci:v00001022d0000780Fsv00000000sd00000000bc06sc04i01
+E: PCI_CLASS=60401
+E: PCI_ID=1022:780F
+E: PCI_SLOT_NAME=0000:00:14.4
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.4/pci_bus/0000:05
+E: DEVPATH=/devices/pci0000:00/0000:00:14.4/pci_bus/0000:05
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.0
+E: DEVPATH=/devices/pci0000:00/0000:00:18.0
+E: MODALIAS=pci:v00001022d00001400sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1400
+E: PCI_SLOT_NAME=0000:00:18.0
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.1
+E: DEVPATH=/devices/pci0000:00/0000:00:18.1
+E: MODALIAS=pci:v00001022d00001401sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1401
+E: PCI_SLOT_NAME=0000:00:18.1
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.2
+E: DEVPATH=/devices/pci0000:00/0000:00:18.2
+E: MODALIAS=pci:v00001022d00001402sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1402
+E: PCI_SLOT_NAME=0000:00:18.2
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.3
+E: DEVPATH=/devices/pci0000:00/0000:00:18.3
+E: DRIVER=k10temp
+E: MODALIAS=pci:v00001022d00001403sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1403
+E: PCI_SLOT_NAME=0000:00:18.3
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.3/hwmon/hwmon1
+E: DEVPATH=/devices/pci0000:00/0000:00:18.3/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.4
+E: DEVPATH=/devices/pci0000:00/0000:00:18.4
+E: MODALIAS=pci:v00001022d00001404sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1404
+E: PCI_SLOT_NAME=0000:00:18.4
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:18.5
+E: DEVPATH=/devices/pci0000:00/0000:00:18.5
+E: MODALIAS=pci:v00001022d00001405sv00000000sd00000000bc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=1022:1405
+E: PCI_SLOT_NAME=0000:00:18.5
+E: PCI_SUBSYS_ID=0000:0000
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/efifb.0
+E: DEVPATH=/devices/platform/efifb.0
+E: DRIVER=efifb
+E: MODALIAS=platform:efifb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/efifb.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/platform/efifb.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: PRIMARY_DEVICE_FOR_DISPLAY=1
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10388878
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=LENOVO
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10389501
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=402000000 3803078f800d001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8E,8F,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,D9,E2,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab41
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1022491
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1026232
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input131
+E: ABS=660800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input131
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=e520 10000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,145,148,14A,14D,14E,14F,ra0,1,18,1C,2F,35,36,39,3A,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=5
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6287540684
+
+P: /devices/platform/i8042/serio1/input/input131/event11
+N: input/event11
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/platform/i8042/serio1/input/input131/event11
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6287543664
+
+P: /devices/platform/i8042/serio1/input/input131/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input131/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6287544337
+
+P: /devices/platform/i8042/serio1/serio62
+E: DEVPATH=/devices/platform/i8042/serio1/serio62
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty05pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=05
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/serio62/input/input132
+E: DEVPATH=/devices/platform/i8042/serio1/serio62/input/input132
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-62
+E: ID_PATH_TAG=platform-i8042-serio-62
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p000Ae0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="TPPS/2 IBM TrackPoint"
+E: PHYS="synaptics-pt/serio0/input0"
+E: PRODUCT=11/2/a/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6296755842
+
+P: /devices/platform/i8042/serio1/serio62/input/input132/event12
+N: input/event12
+S: input/by-path/platform-i8042-serio-62-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-62-event-mouse
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/platform/i8042/serio1/serio62/input/input132/event12
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-62
+E: ID_PATH_TAG=platform-i8042-serio-62
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6296758884
+
+P: /devices/platform/i8042/serio1/serio62/input/input132/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-62-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-62-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/serio62/input/input132/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-62
+E: ID_PATH_TAG=platform-i8042-serio-62
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6296758486
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10393531
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10394070
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10394658
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10395212
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10395778
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10396318
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10396264
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10396652
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10397231
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10397497
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10397410
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10397994
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10397885
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10397934
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10399375
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10400066
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10400661
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10401321
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10401763
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10402265
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10402729
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10403161
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10405029
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10405407
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10405788
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10406171
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10406748
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10407215
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10407700
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10408682
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10408298
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10409399
+
+P: /devices/platform/thinkpad_acpi
+E: DEVPATH=/devices/platform/thinkpad_acpi
+E: DRIVER=thinkpad_acpi
+E: MODALIAS=platform:thinkpad_acpi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/input/input8
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input8
+E: EV=13
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: KEY=18040000 0 10000000000000 0 101501b00102004 8000000001104000 e000000000000 0
+E: MODALIAS=input:b0019v17AAp5054e4101-e0,1,4,k71,72,73,8E,94,98,BF,C2,CD,D4,E0,E1,E3,E4,EC,EE,F0,F8,174,1D2,1DB,1DC,ram4,lsfw
+E: MSC=10
+E: NAME="ThinkPad Extra Buttons"
+E: PHYS="thinkpad_acpi/input0"
+E: PRODUCT=19/17aa/5054/4101
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10584659
+
+P: /devices/platform/thinkpad_acpi/input/input8/event8
+N: input/event8
+S: input/by-path/platform-thinkpad_acpi-event
+E: DEVLINKS=/dev/input/by-path/platform-thinkpad_acpi-event
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input8/event8
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10586839
+E: XKBLAYOUT=cn
+E: XKBMODEL=pc105
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/rfkill/rfkill1
+E: DEVPATH=/devices/platform/thinkpad_acpi/rfkill/rfkill1
+E: RFKILL_NAME=tpacpi_bluetooth_sw
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/sound/card29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: PULSE_IGNORE=1
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10615938
+
+P: /devices/platform/thinkpad_acpi/sound/card29/controlC29
+N: snd/controlC29
+S: snd/by-path/platform-thinkpad_acpi
+E: DEVLINKS=/dev/snd/by-path/platform-thinkpad_acpi
+E: DEVNAME=/dev/snd/controlC29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29/controlC29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10578330
+
+P: /devices/platform/thinkpad_hwmon
+E: DEVPATH=/devices/platform/thinkpad_hwmon
+E: DRIVER=thinkpad_hwmon
+E: MODALIAS=platform:thinkpad_hwmon
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_hwmon/hwmon/hwmon0
+E: DEVPATH=/devices/platform/thinkpad_hwmon/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:04/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1028270
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:0a
+E: DEVPATH=/devices/pnp0/00:0a
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0002:family:0015:model:0013:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0017,0018,0019,001A,001C,0020,0021,0022,0023,0024,0025,0026,0027,0028,0029,002B,002C,002D,002E,002F,0030,0031,0034,0036,0037,0038,0039,003A,003B,003D,0064,0068,006A,006E,0070,0071,0074,0078,007A,007C,0080,0081,0083,0089,008C,008D,0093,0094,0097,0099,009A,009B,009C,009D,00C0,00C1,00C2,00C3,00C4,00C5,00C6,00C7,00C8,00C9,00CA,00CB,00CC,00CD,00CF,00D0,00D1,00D3,00D5,00D6,00D7,00D8,00E1,00E2,00E8,0105,0106,0107,0108,0109,010A,010B,010C,010D,010E,0123
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0002:family:0015:model:0013:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0017,0018,0019,001A,001C,0020,0021,0022,0023,0024,0025,0026,0027,0028,0029,002B,002C,002D,002E,002F,0030,0031,0034,0036,0037,0038,0039,003A,003B,003D,0064,0068,006A,006E,0070,0071,0074,0078,007A,007C,0080,0081,0083,0089,008C,008D,0093,0094,0097,0099,009A,009B,009C,009D,00C0,00C1,00C2,00C3,00C4,00C5,00C6,00C7,00C8,00C9,00CA,00CB,00CC,00CD,00CF,00D0,00D1,00D3,00D5,00D6,00D7,00D8,00E1,00E2,00E8,0105,0106,0107,0108,0109,010A,010B,010C,010D,010E,0123
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0002:family:0015:model:0013:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0017,0018,0019,001A,001C,0020,0021,0022,0023,0024,0025,0026,0027,0028,0029,002B,002C,002D,002E,002F,0030,0031,0034,0036,0037,0038,0039,003A,003B,003D,0064,0068,006A,006E,0070,0071,0074,0078,007A,007C,0080,0081,0083,0089,008C,008D,0093,0094,0097,0099,009A,009B,009C,009D,00C0,00C1,00C2,00C3,00C4,00C5,00C6,00C7,00C8,00C9,00CA,00CB,00CC,00CD,00CF,00D0,00D1,00D3,00D5,00D6,00D7,00D8,00E1,00E2,00E8,0105,0106,0107,0108,0109,010A,010B,010C,010D,010E,0123
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0002:family:0015:model:0013:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0017,0018,0019,001A,001C,0020,0021,0022,0023,0024,0025,0026,0027,0028,0029,002B,002C,002D,002E,002F,0030,0031,0034,0036,0037,0038,0039,003A,003B,003D,0064,0068,006A,006E,0070,0071,0074,0078,007A,007C,0080,0081,0083,0089,008C,008D,0093,0094,0097,0099,009A,009B,009C,009D,00C0,00C1,00C2,00C3,00C4,00C5,00C6,00C7,00C8,00C9,00CA,00CB,00CC,00CD,00CF,00D0,00D1,00D3,00D5,00D6,00D7,00D8,00E1,00E2,00E8,0105,0106,0107,0108,0109,010A,010B,010C,010D,010E,0123
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory40
+E: DEVPATH=/devices/system/memory/memory40
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory41
+E: DEVPATH=/devices/system/memory/memory41
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory42
+E: DEVPATH=/devices/system/memory/memory42
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory43
+E: DEVPATH=/devices/system/memory/memory43
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory44
+E: DEVPATH=/devices/system/memory/memory44
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory45
+E: DEVPATH=/devices/system/memory/memory45
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory46
+E: DEVPATH=/devices/system/memory/memory46
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory47
+E: DEVPATH=/devices/system/memory/memory47
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory48
+E: DEVPATH=/devices/system/memory/memory48
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory49
+E: DEVPATH=/devices/system/memory/memory49
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory50
+E: DEVPATH=/devices/system/memory/memory50
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory51
+E: DEVPATH=/devices/system/memory/memory51
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory52
+E: DEVPATH=/devices/system/memory/memory52
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory53
+E: DEVPATH=/devices/system/memory/memory53
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory54
+E: DEVPATH=/devices/system/memory/memory54
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory55
+E: DEVPATH=/devices/system/memory/memory55
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory56
+E: DEVPATH=/devices/system/memory/memory56
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory57
+E: DEVPATH=/devices/system/memory/memory57
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory58
+E: DEVPATH=/devices/system/memory/memory58
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory59
+E: DEVPATH=/devices/system/memory/memory59
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory60
+E: DEVPATH=/devices/system/memory/memory60
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory61
+E: DEVPATH=/devices/system/memory/memory61
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory62
+E: DEVPATH=/devices/system/memory/memory62
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory63
+E: DEVPATH=/devices/system/memory/memory63
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory64
+E: DEVPATH=/devices/system/memory/memory64
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory65
+E: DEVPATH=/devices/system/memory/memory65
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory66
+E: DEVPATH=/devices/system/memory/memory66
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory67
+E: DEVPATH=/devices/system/memory/memory67
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory68
+E: DEVPATH=/devices/system/memory/memory68
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory69
+E: DEVPATH=/devices/system/memory/memory69
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=966175
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=966350
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=966508
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=966717
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=966906
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=967101
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=967313
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=967508
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=967703
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=967863
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=968072
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=968241
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=968434
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=968573
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=968782
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=968912
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=969144
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=969294
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=969502
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=969695
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=977918
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=969964
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=970159
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=970319
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnLENOVO:bvrHRET14WW(1.02):bd04/02/2013:svnLENOVO:pn20B1Z008CN:pvrThinkPadEdgeE445:rvnLENOVO:rn20B1Z008CN:rvrWin8STDPRCDPKTPG:cvnLENOVO:ct10:cvrNotAvailable:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/btrfs-control
+N: btrfs-control
+E: DEVNAME=/dev/btrfs-control
+E: DEVPATH=/devices/virtual/misc/btrfs-control
+E: MAJOR=10
+E: MINOR=234
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10532339
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/nvram
+N: nvram
+E: DEVNAME=/dev/nvram
+E: DEVPATH=/devices/virtual/misc/nvram
+E: MAJOR=10
+E: MINOR=144
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10440048
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr0
+N: cpu/0/msr
+E: DEVNAME=/dev/cpu/0/msr
+E: DEVPATH=/devices/virtual/msr/msr0
+E: MAJOR=202
+E: MINOR=0
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr1
+N: cpu/1/msr
+E: DEVNAME=/dev/cpu/1/msr
+E: DEVPATH=/devices/virtual/msr/msr1
+E: MAJOR=202
+E: MINOR=1
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr2
+N: cpu/2/msr
+E: DEVNAME=/dev/cpu/2/msr
+E: DEVPATH=/devices/virtual/msr/msr2
+E: MAJOR=202
+E: MINOR=2
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr3
+N: cpu/3/msr
+E: DEVNAME=/dev/cpu/3/msr
+E: DEVPATH=/devices/virtual/msr/msr3
+E: MAJOR=202
+E: MINOR=3
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10441530
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10482406
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10481681
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device5
+E: DEVPATH=/devices/virtual/thermal/cooling_device5
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10443346
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10443657
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10443990
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10444355
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10444674
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10445135
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10445484
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10445800
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10446137
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10446465
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10446820
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10447115
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10447438
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10447769
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10448138
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10448445
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10448900
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10449253
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10449926
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10450234
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10450554
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10450885
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10451208
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10451504
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10451794
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10452138
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10452856
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10453332
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10453655
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10454015
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10455510
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10455835
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10456993
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10457352
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10457878
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10458301
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10458746
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10459222
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10459642
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10460110
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10460560
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10461100
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10462221
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10463189
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10463599
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10463996
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10464427
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10464842
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10465161
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10465883
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10466185
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10466520
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10466812
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10467097
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10467381
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10467667
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10468235
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10468579
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10468893
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10469268
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10469704
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10470083
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10470440
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10470749
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10471038
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10471326
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10471657
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=10471989
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: DEVPATH=/devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: MODALIAS=wmi:E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: DEVPATH=/devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: MODALIAS=wmi:FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_T420.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_T420.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_T420.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,5034 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=560984
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=563861
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input14
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8662597
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input14/event14
+N: input/event14
+E: DEVNAME=/dev/input/event14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input14/event14
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=78
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8671959
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/LEN0015:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/LEN0015:00
+E: MODALIAS=acpi:LEN0015:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0303:00
+E: MODALIAS=acpi:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LEN0068:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LEN0068:00
+E: DRIVER=thinkpad_hotkey
+E: MODALIAS=acpi:LEN0068:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LNXPOWER:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LNXPOWER:00
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/SMO1200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/SMO1200:00
+E: MODALIAS=acpi:SMO1200:PNP0C31:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:17/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/LNXIOBAY:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/LNXIOBAY:00
+E: MODALIAS=acpi:LNXIOBAY:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:19/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21/device:22/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:2b/device:2c/device:2d/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=565012
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=571242
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=565081
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1/event1
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=571265
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:01
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000104sv000017AAsd000021CEbc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0104
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000126sv000017AAsd000021CEbc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0126
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8664305
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001C3Asv000017AAsd000021CEbc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1C3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3
+E: DRIVER=serial
+E: MODALIAS=pci:v00008086d00001C3Dsv000017AAsd000021CEbc07sc00i02
+E: PCI_CLASS=70002
+E: PCI_ID=8086:1C3D
+E: PCI_SLOT_NAME=0000:00:16.3
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3/tty/ttyS4
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=6 Series/C200 Series Chipset Family KT Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:16.3
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7910130
+
+P: /devices/pci0000:00/0000:00:19.0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0
+E: DRIVER=e1000e
+E: MODALIAS=pci:v00008086d00001502sv000017AAsd000021CEbc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=8086:1502
+E: PCI_SLOT_NAME=0000:00:19.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0/net/eth0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=82579LM Gigabit Network Connection
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:19.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7835053
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001C2Dsv000017AAsd000021CEbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1C2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=541277
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=921262
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Biometric_Coprocessor
+E: ID_MODEL_ENC=Biometric\x20Coprocessor
+E: ID_MODEL_ID=2016
+E: ID_REVISION=0002
+E: ID_SERIAL=UPEK_Biometric_Coprocessor
+E: ID_USB_INTERFACES=:ff0000:
+E: ID_VENDOR=UPEK
+E: ID_VENDOR_ENC=UPEK
+E: ID_VENDOR_ID=147e
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=147e/2016/2
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1330221
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/0/0
+E: MODALIAS=usb:v147Ep2016d0002dc00dsc00dp00icFFisc00ip00in00
+E: PRODUCT=147e/2016/2
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Broadcom_Bluetooth_Device
+E: ID_MODEL_ENC=Broadcom\x20Bluetooth\x20Device
+E: ID_MODEL_ID=217f
+E: ID_REVISION=0748
+E: ID_SERIAL=Broadcom_Corp_Broadcom_Bluetooth_Device_889FFAF74402
+E: ID_SERIAL_SHORT=889FFAF74402
+E: ID_USB_INTERFACES=:e00101:ffffff:fe0101:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=0a5c
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=a5c/217f/748
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1498248
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0A5Cp217Fd0748dcE0dsc01dp01icE0isc01ip01in00
+E: PRODUCT=a5c/217f/748
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill1
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0A5Cp217Fd0748dcE0dsc01dp01icE0isc01ip01in01
+E: PRODUCT=a5c/217f/748
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0A5Cp217Fd0748dcE0dsc01dp01icFFiscFFipFFin02
+E: PRODUCT=a5c/217f/748
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v0A5Cp217Fd0748dcE0dsc01dp01icFEisc01ip01in03
+E: PRODUCT=a5c/217f/748
+E: SUBSYSTEM=usb
+E: TYPE=224/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6
+N: bus/usb/001/005
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b221
+E: ID_REVISION=0751
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: MAJOR=189
+E: MINOR=4
+E: PRODUCT=4f2/b221/751
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1668015
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v04F2pB221d0751dcEFdsc02dp01ic0Eisc01ip00in00
+E: PRODUCT=4f2/b221/751
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input5
+E: EV=3
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b221
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=0751
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v04F2pB221e0751-e0,1,kD4,ramlsfw
+E: NAME="Integrated Camera"
+E: PHYS="usb-0000:00:1a.0-1.6/button"
+E: PRODUCT=3/4f2/b221/751
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7315955
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-event
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b221
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=0751
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7317586
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b221
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=0751
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Integrated Camera
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7354948
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v04F2pB221d0751dcEFdsc02dp01ic0Eisc02ip00in01
+E: PRODUCT=4f2/b221/751
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001C20sv000017AAsd000021CEbc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1C20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=6 Series/C200 Series Chipset Family High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7910536
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: DEVNAME=/dev/snd/hwC0D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433360
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+N: snd/hwC0D3
+E: DEVNAME=/dev/snd/hwC0D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D3
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433955
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7434081
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+N: input/event10
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input10/event10
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7438346
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7434807
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+N: input/event11
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input11/event11
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7438029
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Dock Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433059
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+N: input/event12
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input12/event12
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7436053
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input6
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input6
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=8"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7432578
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input6/event6
+N: input/event6
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input6/event6
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7436565
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input7
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=7"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7434335
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input7/event7
+N: input/event7
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input7/event7
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7449930
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7432670
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+N: input/event8
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7438718
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Dock Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7434828
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7441086
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433707
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433598
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433835
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+N: snd/pcmC0D7p
+E: DEVNAME=/dev/snd/pcmC0D7p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D7p
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433265
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D8p
+N: snd/pcmC0D8p
+E: DEVNAME=/dev/snd/pcmC0D8p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D8p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7434043
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=10
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7433754
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C10sv000017AAsd000021CEbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C12sv000017AAsd000021CEbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0
+E: DRIVER=iwlwifi
+E: MODALIAS=pci:v00008086d00000085sv00008086sd00001311bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=8086:0085
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=8086:1311
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0/rfkill2
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/leds/phy0-led
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/leds/phy0-led
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/net/wlan0
+E: COMMENT=PCI device 0x8086:/sys/devices/pci0000:00/0000:00:1c.1/0000:03:00.0 (iwlwifi)
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MODEL_FROM_DATABASE=Centrino Advanced-N 6205 [Taylor Peak]
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:03:00.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: MATCHADDR=a0:88:b4:00:49:58
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7930851
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C16sv000017AAsd000021CEbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C16
+E: PCI_SLOT_NAME=0000:00:1c.3
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.3/pci_bus/0000:05
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.3/pci_bus/0000:05
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001C18sv000017AAsd000021CEbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1C18
+E: PCI_SLOT_NAME=0000:00:1c.4
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0d:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0d:00.0
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v00001180d0000E822sv000017AAsd00002133bc08sc80i01
+E: PCI_CLASS=88001
+E: PCI_ID=1180:E822
+E: PCI_SLOT_NAME=0000:0d:00.0
+E: PCI_SUBSYS_ID=17AA:2133
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0d:00.0/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0d:00.0/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/0000:0d:00.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/0000:0d:00.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/pci_bus/0000:0d
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/pci_bus/0000:0d
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001C26sv000017AAsd000021CEbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1C26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-19-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-19-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-19-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=544063
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1164933
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: DRIVER=lpc_ich
+E: MODALIAS=pci:v00008086d00001C4Fsv000017AAsd000021CEbc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1C4F
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVTYPE=mfd_device
+E: MODALIAS=platform:iTCO_wdt
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=6 Series/C200 Series Chipset Family 6 port SATA AHCI Controller
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001C03sv000017AAsd000021CEbc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1C03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6686480
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA
+S: disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA
+S: disk/by-id/wwn-0x5000cca61dc1b95c
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA /dev/disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA /dev/disk/by-id/wwn-0x5000cca61dc1b95c /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=254
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=78
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=76
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=Hitachi_HTS723232A7A364
+E: ID_MODEL_ENC=Hitachi\x20HTS723232A7A364\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=EC2OA7B0
+E: ID_SCSI_COMPAT=SATA_Hitachi_HTS7232110115E3830063G3TKTA
+E: ID_SERIAL=Hitachi_HTS723232A7A364_110115E3830063G3TKTA
+E: ID_SERIAL_SHORT=110115E3830063G3TKTA
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca61dc1b95c
+E: ID_WWN_WITH_EXTENSION=0x5000cca61dc1b95c
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2210510
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA-part1
+S: disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA-part1
+S: disk/by-id/wwn-0x5000cca61dc1b95c-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/39cda2c6-6dd9-4d9a-acae-a3390cfa37a9
+E: DEVLINKS=/dev/disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA-part1 /dev/disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA-part1 /dev/disk/by-id/wwn-0x5000cca61dc1b95c-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/39cda2c6-6dd9-4d9a-acae-a3390cfa37a9
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=78
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=76
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=39cda2c6-6dd9-4d9a-acae-a3390cfa37a9
+E: ID_FS_UUID_ENC=39cda2c6-6dd9-4d9a-acae-a3390cfa37a9
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=Hitachi_HTS723232A7A364
+E: ID_MODEL_ENC=Hitachi\x20HTS723232A7A364\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=616982528
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=EC2OA7B0
+E: ID_SCSI_COMPAT=SATA_Hitachi_HTS7232110115E3830063G3TKTA
+E: ID_SERIAL=Hitachi_HTS723232A7A364_110115E3830063G3TKTA
+E: ID_SERIAL_SHORT=110115E3830063G3TKTA
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca61dc1b95c
+E: ID_WWN_WITH_EXTENSION=0x5000cca61dc1b95c
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=315895054336
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2335277
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA-part2
+S: disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA-part2
+S: disk/by-id/wwn-0x5000cca61dc1b95c-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVLINKS=/dev/disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA-part2 /dev/disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA-part2 /dev/disk/by-id/wwn-0x5000cca61dc1b95c-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=78
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=76
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=Hitachi_HTS723232A7A364
+E: ID_MODEL_ENC=Hitachi\x20HTS723232A7A364\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=616986622
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8155138
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=EC2OA7B0
+E: ID_SCSI_COMPAT=SATA_Hitachi_HTS7232110115E3830063G3TKTA
+E: ID_SERIAL=Hitachi_HTS723232A7A364_110115E3830063G3TKTA
+E: ID_SERIAL_SHORT=110115E3830063G3TKTA
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca61dc1b95c
+E: ID_WWN_WITH_EXTENSION=0x5000cca61dc1b95c
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=315897150464
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4175430656
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2241381
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA-part5
+S: disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA-part5
+S: disk/by-id/wwn-0x5000cca61dc1b95c-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/27719bc4-3e02-4680-96dd-86190c316d02
+E: DEVLINKS=/dev/disk/by-id/ata-Hitachi_HTS723232A7A364_110115E3830063G3TKTA-part5 /dev/disk/by-id/scsi-SATA_Hitachi_HTS7232110115E3830063G3TKTA-part5 /dev/disk/by-id/wwn-0x5000cca61dc1b95c-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/27719bc4-3e02-4680-96dd-86190c316d02
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=78
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=76
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=27719bc4-3e02-4680-96dd-86190c316d02
+E: ID_FS_UUID_ENC=27719bc4-3e02-4680-96dd-86190c316d02
+E: ID_FS_VERSION=2
+E: ID_MODEL=Hitachi_HTS723232A7A364
+E: ID_MODEL_ENC=Hitachi\x20HTS723232A7A364\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=616986624
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=8155136
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=EC2OA7B0
+E: ID_SCSI_COMPAT=SATA_Hitachi_HTS7232110115E3830063G3TKTA
+E: ID_SERIAL=Hitachi_HTS723232A7A364_110115E3830063G3TKTA
+E: ID_SERIAL_SHORT=110115E3830063G3TKTA
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca61dc1b95c
+E: ID_WWN_WITH_EXTENSION=0x5000cca61dc1b95c
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=315897151488
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_SIZE=4175429632
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2306839
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-HL-DT-STDVDRAM_GT33N_M00AC1L4512
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-HL-DT-STDVDRAM_GT33N_M00AC1L4512 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_MODEL=HL-DT-STDVDRAM_GT33N
+E: ID_MODEL_ENC=HL-DT-STDVDRAM\x20GT33N\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=LT20
+E: ID_SERIAL=HL-DT-STDVDRAM_GT33N_M00AC1L4512
+E: ID_SERIAL_SHORT=M00AC1L4512
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2094815
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7917547
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001C22sv000017AAsd000021CEbc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1C22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=17AA:21CE
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon2
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon2
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dock.0
+E: DEVPATH=/devices/platform/dock.0
+E: MODALIAS=platform:dock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dock.1
+E: DEVPATH=/devices/platform/dock.1
+E: MODALIAS=platform:dock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=LENOVO
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6728826
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=402000000 3803078f800d001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB54-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8E,8F,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,D9,E2,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab54
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=563524
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=568820
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input13
+E: ABS=260800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input13
+E: EV=b
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=6420 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=9
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7918770
+
+P: /devices/platform/i8042/serio1/input/input13/event13
+N: input/event13
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event13
+E: DEVPATH=/devices/platform/i8042/serio1/input/input13/event13
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=77
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7971618
+
+P: /devices/platform/i8042/serio1/input/input13/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/i8042/serio1/input/input13/mouse0
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7971254
+
+P: /devices/platform/i8042/serio1/serio2
+E: DEVPATH=/devices/platform/i8042/serio1/serio2
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty05pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=05
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/serio2/input/input15
+E: DEVPATH=/devices/platform/i8042/serio1/serio2/input/input15
+E: EV=7
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-2
+E: ID_PATH_TAG=platform-i8042-serio-2
+E: ID_SERIAL=noserial
+E: KEY=70000 0 0 0 0
+E: MODALIAS=input:b0011v0002p000Ae0000-e0,1,2,k110,111,112,r0,1,amlsfw
+E: NAME="TPPS/2 IBM TrackPoint"
+E: PHYS="synaptics-pt/serio0/input0"
+E: PRODUCT=11/2/a/0
+E: PROP=0
+E: REL=3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15833766
+
+P: /devices/platform/i8042/serio1/serio2/input/input15/event15
+N: input/event15
+S: input/by-path/platform-i8042-serio-2-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-2-event-mouse
+E: DEVNAME=/dev/input/event15
+E: DEVPATH=/devices/platform/i8042/serio1/serio2/input/input15/event15
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-2
+E: ID_PATH_TAG=platform-i8042-serio-2
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=79
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15835405
+
+P: /devices/platform/i8042/serio1/serio2/input/input15/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-2-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-2-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/serio2/input/input15/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_PATH=platform-i8042-serio-2
+E: ID_PATH_TAG=platform-i8042-serio-2
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15835307
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi
+E: DEVPATH=/devices/platform/thinkpad_acpi
+E: DRIVER=thinkpad_acpi
+E: MODALIAS=platform:thinkpad_acpi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/input/input4
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input4
+E: EV=33
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: KEY=18040000 0 10000000000000 0 101501b00102004 8000000001104000 e000000000000 0
+E: MODALIAS=input:b0019v17AAp5054e4101-e0,1,4,5,k71,72,73,8E,94,98,BF,C2,CD,D4,E0,E1,E3,E4,EC,EE,F0,F8,174,1D2,1DB,1DC,ram4,lsfw3,
+E: MSC=10
+E: NAME="ThinkPad Extra Buttons"
+E: PHYS="thinkpad_acpi/input0"
+E: PRODUCT=19/17aa/5054/4101
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=8
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6947050
+
+P: /devices/platform/thinkpad_acpi/input/input4/event4
+N: input/event4
+S: input/by-path/platform-thinkpad_acpi-event
+E: DEVLINKS=/dev/input/by-path/platform-thinkpad_acpi-event
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input4/event4
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6948540
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/rfkill/rfkill0
+E: DEVPATH=/devices/platform/thinkpad_acpi/rfkill/rfkill0
+E: RFKILL_NAME=tpacpi_bluetooth_sw
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/sound/card29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6946136
+
+P: /devices/platform/thinkpad_acpi/sound/card29/controlC29
+N: snd/controlC29
+S: snd/by-path/platform-thinkpad_acpi
+E: DEVLINKS=/dev/snd/by-path/platform-thinkpad_acpi
+E: DEVNAME=/dev/snd/controlC29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29/controlC29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6945977
+
+P: /devices/platform/thinkpad_hwmon
+E: DEVPATH=/devices/platform/thinkpad_hwmon
+E: DRIVER=thinkpad_hwmon
+E: MODALIAS=platform:thinkpad_hwmon
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_hwmon/hwmon/hwmon1
+E: DEVPATH=/devices/platform/thinkpad_hwmon/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=573936
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=tpm_tis
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09/misc/tpm0
+N: tpm0
+E: DEVNAME=/dev/tpm0
+E: DEVPATH=/devices/pnp0/00:09/misc/tpm0
+E: MAJOR=10
+E: MINOR=224
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:002A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory22
+E: DEVPATH=/devices/system/memory/memory22
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory23
+E: DEVPATH=/devices/system/memory/memory23
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/uncore_cbox_0
+E: DEVPATH=/devices/uncore_cbox_0
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/uncore_cbox_1
+E: DEVPATH=/devices/uncore_cbox_1
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531027
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531168
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531265
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531361
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531457
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531561
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531677
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=531776
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=531869
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=531966
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532078
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=534013
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532418
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532524
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532618
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532720
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532827
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=532926
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=533021
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=535814
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=533369
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=533466
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=533569
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=533670
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnLENOVO:bvr83ET53WW(1.23):bd03/31/2011:svnLENOVO:pn4177Q2U:pvrThinkPadT420:rvnLENOVO:rn4177Q2U:rvrNotAvailable:cvnLENOVO:ct10:cvrNotAvailable:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=8104382
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/nvram
+N: nvram
+E: DEVNAME=/dev/nvram
+E: DEVPATH=/devices/virtual/misc/nvram
+E: MAJOR=10
+E: MINOR=144
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/watchdog
+N: watchdog
+E: DEVNAME=/dev/watchdog
+E: DEVPATH=/devices/virtual/misc/watchdog
+E: MAJOR=10
+E: MINOR=130
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr0
+N: cpu/0/msr
+E: DEVNAME=/dev/cpu/0/msr
+E: DEVPATH=/devices/virtual/msr/msr0
+E: MAJOR=202
+E: MINOR=0
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr1
+N: cpu/1/msr
+E: DEVNAME=/dev/cpu/1/msr
+E: DEVPATH=/devices/virtual/msr/msr1
+E: MAJOR=202
+E: MINOR=1
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr2
+N: cpu/2/msr
+E: DEVNAME=/dev/cpu/2/msr
+E: DEVPATH=/devices/virtual/msr/msr2
+E: MAJOR=202
+E: MINOR=2
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/msr/msr3
+N: cpu/3/msr
+E: DEVNAME=/dev/cpu/3/msr
+E: DEVPATH=/devices/virtual/msr/msr3
+E: MAJOR=202
+E: MINOR=3
+E: SUBSYSTEM=msr
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6893525
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog0
+N: watchdog0
+E: DEVNAME=/dev/watchdog0
+E: DEVPATH=/devices/virtual/watchdog/watchdog0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2651D9FD-911C-4B69-B94E-D0DED5963BD7
+E: DEVPATH=/devices/virtual/wmi/2651D9FD-911C-4B69-B94E-D0DED5963BD7
+E: MODALIAS=wmi:2651D9FD-911C-4B69-B94E-D0DED5963BD7
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/51F5230E-9677-46CD-A1CF-C0B23EE34DB7
+E: DEVPATH=/devices/virtual/wmi/51F5230E-9677-46CD-A1CF-C0B23EE34DB7
+E: MODALIAS=wmi:51F5230E-9677-46CD-A1CF-C0B23EE34DB7
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3
+E: DEVPATH=/devices/virtual/wmi/6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3
+E: MODALIAS=wmi:6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/74F1EBB6-927A-4C7D-95DF-698E21E80EB5
+E: DEVPATH=/devices/virtual/wmi/74F1EBB6-927A-4C7D-95DF-698E21E80EB5
+E: MODALIAS=wmi:74F1EBB6-927A-4C7D-95DF-698E21E80EB5
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/7EEF04FF-4328-447C-B5BB-D449925D538D
+E: DEVPATH=/devices/virtual/wmi/7EEF04FF-4328-447C-B5BB-D449925D538D
+E: MODALIAS=wmi:7EEF04FF-4328-447C-B5BB-D449925D538D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8ADB159E-1E32-455C-BC93-308A7ED98246
+E: DEVPATH=/devices/virtual/wmi/8ADB159E-1E32-455C-BC93-308A7ED98246
+E: MODALIAS=wmi:8ADB159E-1E32-455C-BC93-308A7ED98246
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/98479A64-33F5-4E33-A707-8E251EBBC3A1
+E: DEVPATH=/devices/virtual/wmi/98479A64-33F5-4E33-A707-8E251EBBC3A1
+E: MODALIAS=wmi:98479A64-33F5-4E33-A707-8E251EBBC3A1
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: DEVPATH=/devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: MODALIAS=wmi:E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: DEVPATH=/devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: MODALIAS=wmi:FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_T430S.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_T430S.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/LENOVO_T430S.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,7630 @@
+P: /devices/LNXSYSTM:00
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:02
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:03
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:04
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:05
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:06
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXCPU:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:07
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-LNXPWRBN_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: KEY=10000000000000 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PRODUCT=19/0/1/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=516569
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+N: input/event2
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input2/event2
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: TAGS=:power-switch:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=538452
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:00
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:06
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/device:07
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input13
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-LNXVIDEO_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: KEY=3e000b00000000 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PRODUCT=19/0/6/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16449859
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input13/event13
+N: input/event13
+E: DEVNAME=/dev/input/event13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/LNXVIDEO:00/input/input13/event13
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: MAJOR=13
+E: MINOR=77
+E: SUBSYSTEM=input
+E: TAGS=:power-switch:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16453994
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/LEN0015:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/LEN0015:00
+E: MODALIAS=acpi:LEN0015:PNP0F13:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0000:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0100:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0103:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0103:00
+E: MODALIAS=acpi:PNP0103:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0303:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0303:00
+E: MODALIAS=acpi:PNP0303:PNP0303:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0800:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0800:00
+E: MODALIAS=acpi:PNP0800:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0B00:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C02:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C04:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/ACPI0003:00/power_supply/AC
+E: POWER_SUPPLY_NAME=AC
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LEN0068:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LEN0068:00
+E: DRIVER=thinkpad_hotkey
+E: MODALIAS=acpi:LEN0068:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LNXPOWER:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/LNXPOWER:00
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/PNP0C0A:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/PNP0C09:00/PNP0C0A:00/power_supply/BAT0
+E: POWER_SUPPLY_CAPACITY=99
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_ENERGY_FULL=42990000
+E: POWER_SUPPLY_ENERGY_FULL_DESIGN=44000000
+E: POWER_SUPPLY_ENERGY_NOW=42950000
+E: POWER_SUPPLY_MANUFACTURER=SANYO
+E: POWER_SUPPLY_MODEL_NAME=45N1037
+E: POWER_SUPPLY_NAME=BAT0
+E: POWER_SUPPLY_POWER_NOW=0
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_SERIAL_NUMBER= 1586
+E: POWER_SUPPLY_STATUS=Unknown
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=11100000
+E: POWER_SUPPLY_VOLTAGE_NOW=12515000
+E: SUBSYSTEM=power_supply
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/SMO1200:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:08/SMO1200:00
+E: MODALIAS=acpi:SMO1200:PNP0C31:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:0f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:10
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:10
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:11
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:09/LNXVIDEO:01/device:11
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:12
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:13/device:14
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:15
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:16/device:17
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:18/device:19
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a/device:1b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1a/device:1b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c/device:1d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1c/device:1d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:1e/device:1f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/LNXIOBAY:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/LNXIOBAY:00
+E: MODALIAS=acpi:LNXIOBAY:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:21
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:22
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:23
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:23
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:24
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:20/device:24
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:25
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:26
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:26
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:29
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:29
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:2f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:30
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:27/device:28/device:30
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:34
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:34
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:35
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:35
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:36
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:36
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:37
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:37
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:38
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:38
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:39
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:39
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:3a
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:3a
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:3b
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:31/device:32/device:33/device:3b
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:3f
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:3f
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:40
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:40
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:41
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:41
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:42
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:42
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:43
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:43
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:44
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:3c/device:3d/device:3e/device:44
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0A08:00/device:45
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C01:00
+E: MODALIAS=acpi:PNP0C01:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0
+E: EV=21
+E: ID_FOR_SEAT=input-acpi-PNP0C0D_00
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PRODUCT=19/0/5/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=1
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=524486
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0D:00/input/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: TAGS=:power-switch:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=543468
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1
+E: EV=3
+E: ID_FOR_SEAT=input-acpi-PNP0C0E_00
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: KEY=4000 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PRODUCT=19/0/3/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=501958
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1/event1
+N: input/event1
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0E:00/input/input1/event1
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: TAGS=:power-switch:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=548601
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:00
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:00/PNP0C14:01
+E: DRIVER=wmi
+E: MODALIAS=acpi:PNP0C14:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01
+E: MODALIAS=acpi:LNXSYBUS:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DEVPATH=/devices/LNXSYSTM:00/LNXSYBUS:01/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+E: UDEV_LOG=3
+
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: MODALIAS=pci:v00008086d00000154sv000017AAsd000021FBbc06sc00i00
+E: PCI_CLASS=60000
+E: PCI_ID=8086:0154
+E: PCI_SLOT_NAME=0000:00:00.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: MODALIAS=pci:v00008086d00000166sv000017AAsd000021FBbc03sc00i00
+E: PCI_CLASS=30000
+E: PCI_ID=8086:0166
+E: PCI_SLOT_NAME=0000:00:02.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/backlight/acpi_video0
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: DEVTYPE=drm_minor
+E: ID_FOR_SEAT=drm-pci-0000_00_02_0
+E: ID_PATH=pci-0000:00:02.0
+E: ID_PATH_TAG=pci-0000_00_02_0
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16451639
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-1/i2c-6
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-7
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-2/i2c-7
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-8
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-DP-3/i2c-8
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-2
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-HDMI-A-3
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: ID_FOR_SEAT=graphics-pci-0000_00_02_0
+E: ID_PATH=pci-0000:00:02.0
+E: ID_PATH_TAG=pci-0000_00_02_0
+E: MAJOR=29
+E: MINOR=0
+E: SUBSYSTEM=graphics
+E: TAGS=:master-of-seat:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16452849
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0
+E: DRIVER=xhci_hcd
+E: MODALIAS=pci:v00008086d00001E31sv000017AAsd000021FBbc0Csc03i30
+E: PCI_CLASS=C0330
+E: PCI_ID=8086:1E31
+E: PCI_SLOT_NAME=0000:00:14.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3
+N: bus/usb/003/001
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_14_0
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:14.0
+E: ID_PATH_TAG=pci-0000_00_14_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-25-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-25-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-25-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=256
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=506474
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1
+N: bus/usb/003/002
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_14_0-usb-0_1
+E: ID_MODEL=Generic_USB_Hub
+E: ID_MODEL_ENC=Generic\x20USB\x20Hub
+E: ID_MODEL_ID=9254
+E: ID_PATH=pci-0000:00:14.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1
+E: ID_REVISION=0312
+E: ID_SERIAL=ALCOR_Generic_USB_Hub
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=ALCOR
+E: ID_VENDOR_ENC=ALCOR
+E: ID_VENDOR_ID=058f
+E: MAJOR=189
+E: MINOR=257
+E: PRODUCT=58f/9254/312
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1313890
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1
+N: bus/usb/003/005
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=189
+E: MINOR=260
+E: PRODUCT=46d/c318/5501
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: UPOWER_VENDOR=Logitech, Inc.
+E: USEC_INITIALIZED=15103198
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/1
+E: MODALIAS=usb:v046DpC318d5501dc00dsc00dp00ic03isc01ip01in00
+E: PRODUCT=46d/c318/5501
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/0003:046D:C318.0002
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/0003:046D:C318.0002
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000046D:0000C318
+E: HID_NAME=Logitech Logitech Illuminated Keyboard
+E: HID_PHYS=usb-0000:00:14.0-1.1/input0
+E: MODALIAS=hid:b0003g0001v0000046Dp0000C318
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/0003:046D:C318.0002/hidraw/hidraw1
+N: hidraw1
+E: DEVNAME=/dev/hidraw1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/0003:046D:C318.0002/hidraw/hidraw1
+E: MAJOR=251
+E: MINOR=1
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/input/input5
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/input/input5
+E: EV=120013
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_14_0-usb-0_1_1_1_0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_1_0
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: KEY=1000000000007 ff9f207ac14057ff febeffdfffefffff fffffffffffffffe
+E: LED=1f
+E: MODALIAS=input:b0003v046DpC318e0111-e0,1,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8C,8E,96,98,9E,9F,A1,A3,A4,A5,A6,AD,B0,B1,B2,B3,B4,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,3,4,sfw
+E: MSC=10
+E: NAME="Logitech Logitech Illuminated Keyboard"
+E: PHYS="usb-0000:00:14.0-1.1/input0"
+E: PRODUCT=3/46d/c318/111
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=15123770
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/input/input5/event5
+N: input/event5
+S: input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-kbd
+S: input/by-path/pci-0000:00:14.0-usb-0:1.1:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-kbd /dev/input/by-path/pci-0000:00:14.0-usb-0:1.1:1.0-event-kbd
+E: DEVNAME=/dev/input/event5
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.0/input/input5/event5
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.1:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_1_0
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=69
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15134967
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/2
+E: MODALIAS=usb:v046DpC318d5501dc00dsc00dp00ic03isc00ip02in01
+E: PRODUCT=46d/c318/5501
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/0003:046D:C318.0003
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/0003:046D:C318.0003
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000046D:0000C318
+E: HID_NAME=Logitech Logitech Illuminated Keyboard
+E: HID_PHYS=usb-0000:00:14.0-1.1/input1
+E: MODALIAS=hid:b0003g0001v0000046Dp0000C318
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/0003:046D:C318.0003/hidraw/hidraw2
+N: hidraw2
+E: DEVNAME=/dev/hidraw2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/0003:046D:C318.0003/hidraw/hidraw2
+E: MAJOR=251
+E: MINOR=2
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/input/input6
+E: ABS=100000000
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/input/input6
+E: EV=1f
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_14_0-usb-0_1_1_1_1
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.1:1.1
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_1_1
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: KEY=4837fff072ff32d bf54444600000000 1 20f908b17c000 677bfad9415fed 9ed68000004400 10000002
+E: MODALIAS=input:b0003v046DpC318e0111-e0,1,2,3,4,k71,72,73,74,77,80,82,83,85,86,87,88,89,8A,8B,8C,8E,90,96,98,9B,9C,9E,9F,A1,A3,A4,A5,A6,A7,A8,A9,AB,AC,AD,AE,B0,B1,B2,B5,B6,CE,CF,D0,D1,D2,D4,D8,D9,DB,DF,E4,E7,E8,E9,EA,EB,F1,100,161,162,166,16A,16E,172,174,176,178,179,17A,17B,17C,17D,17F,180,182,183,185,188,189,18C,18D,18E,18F,190,191,192,193,195,198,199,19A,1A0,1A1,1A2,1A3,1A4,1A5,1A6,1A7,1A8,1A9,1AA,1AB,1AC,1AD,1AE,1B0,1B1,1B7,1BA,r6,a20,m4,lsfw
+E: MSC=10
+E: NAME="Logitech Logitech Illuminated Keyboard"
+E: PHYS="usb-0000:00:14.0-1.1/input1"
+E: PRODUCT=3/46d/c318/111
+E: PROP=0
+E: REL=40
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=15121533
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/input/input6/event6
+N: input/event6
+S: input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-if01
+S: input/by-path/pci-0000:00:14.0-usb-0:1.1:1.1-event
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_Logitech_Illuminated_Keyboard-event-if01 /dev/input/by-path/pci-0000:00:14.0-usb-0:1.1:1.1-event
+E: DEVNAME=/dev/input/event6
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/input/input6/event6
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Logitech_Illuminated_Keyboard
+E: ID_MODEL_ENC=Logitech\x20Illuminated\x20Keyboard
+E: ID_MODEL_ID=c318
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.1:1.1
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_1_1_1
+E: ID_REVISION=5501
+E: ID_SERIAL=Logitech_Logitech_Illuminated_Keyboard
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030002:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=70
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15130834
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/usbmisc/hiddev0
+N: usb/hiddev0
+E: DEVNAME=/dev/usb/hiddev0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.1/3-1.1:1.1/usbmisc/hiddev0
+E: MAJOR=180
+E: MINOR=0
+E: SUBSYSTEM=usbmisc
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2
+N: bus/usb/003/006
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/006
+E: DEVNUM=006
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_USB_INTERFACES=:030102:
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: MAJOR=189
+E: MINOR=261
+E: PRODUCT=45e/47/300
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15102907
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v045Ep0047d0300dc00dsc00dp00ic03isc01ip02in00
+E: PRODUCT=45e/47/300
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/0003:045E:0047.0004
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/0003:045E:0047.0004
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000045E:00000047
+E: HID_NAME=Microsoft Microsoft 5-Button Mouse with IntelliEye(TM)
+E: HID_PHYS=usb-0000:00:14.0-1.2/input0
+E: MODALIAS=hid:b0003g0001v0000045Ep00000047
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/0003:045E:0047.0004/hidraw/hidraw3
+N: hidraw3
+E: DEVNAME=/dev/hidraw3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/0003:045E:0047.0004/hidraw/hidraw3
+E: MAJOR=251
+E: MINOR=3
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/input/input7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/input/input7
+E: EV=17
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_14_0-usb-0_1_2_1_0
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_2_1_0
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: KEY=1f0000 0 0 0 0
+E: MODALIAS=input:b0003v045Ep0047e0110-e0,1,2,4,k110,111,112,113,114,r0,1,8,am4,lsfw
+E: MSC=10
+E: NAME="Microsoft Microsoft 5-Button Mouse with IntelliEye(TM)"
+E: PHYS="usb-0000:00:14.0-1.2/input0"
+E: PRODUCT=3/45e/47/110
+E: PROP=0
+E: REL=103
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=15114255
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/input/input7/event7
+N: input/event7
+S: input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-event-mouse
+S: input/by-path/pci-0000:00:14.0-usb-0:1.2:1.0-event-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-event-mouse /dev/input/by-path/pci-0000:00:14.0-usb-0:1.2:1.0-event-mouse
+E: DEVNAME=/dev/input/event7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/input/input7/event7
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_2_1_0
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: MAJOR=13
+E: MINOR=71
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15118109
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/input/input7/mouse0
+N: input/mouse0
+S: input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-mouse
+S: input/by-path/pci-0000:00:14.0-usb-0:1.2:1.0-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_-mouse /dev/input/by-path/pci-0000:00:14.0-usb-0:1.2:1.0-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.2/3-1.2:1.0/input/input7/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_MODEL_ENC=Microsoft\x205-Button\x20Mouse\x20with\x20IntelliEye\x28TM\x29
+E: ID_MODEL_ID=0047
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_2_1_0
+E: ID_REVISION=0300
+E: ID_SERIAL=Microsoft_Microsoft_5-Button_Mouse_with_IntelliEye_TM_
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030102:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Microsoft
+E: ID_VENDOR_ENC=Microsoft
+E: ID_VENDOR_ID=045e
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15118146
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3
+N: bus/usb/003/007
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/007
+E: DEVNUM=007
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=2Port_KVMSwicther
+E: ID_MODEL_ENC=2Port\x20KVMSwicther
+E: ID_MODEL_ID=55a2
+E: ID_REVISION=0100
+E: ID_SERIAL=No_brand_2Port_KVMSwicther_12²
+E: ID_SERIAL_SHORT=12²
+E: ID_USB_INTERFACES=:030000:
+E: ID_VENDOR=No_brand
+E: ID_VENDOR_ENC=No\x20brand
+E: ID_VENDOR_ID=10d5
+E: MAJOR=189
+E: MINOR=262
+E: PRODUCT=10d5/55a2/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15103061
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v10D5p55A2d0100dc00dsc00dp00ic03isc00ip00in00
+E: PRODUCT=10d5/55a2/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/0003:10D5:55A2.0005
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/0003:10D5:55A2.0005
+E: DRIVER=hid-generic
+E: HID_ID=0003:000010D5:000055A2
+E: HID_NAME=No brand 2Port KVMSwicther
+E: HID_PHYS=usb-0000:00:14.0-1.3/input0
+E: HID_UNIQ=12²
+E: MODALIAS=hid:b0003g0001v000010D5p000055A2
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/0003:10D5:55A2.0005/hidraw/hidraw4
+N: hidraw4
+E: DEVNAME=/dev/hidraw4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/0003:10D5:55A2.0005/hidraw/hidraw4
+E: MAJOR=251
+E: MINOR=4
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/input/input8
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/input/input8
+E: EV=120013
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_14_0-usb-0_1_3_1_0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=2Port_KVMSwicther
+E: ID_MODEL_ENC=2Port\x20KVMSwicther
+E: ID_MODEL_ID=55a2
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_3_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=No_brand_2Port_KVMSwicther_12²
+E: ID_SERIAL_SHORT=12²
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=No_brand
+E: ID_VENDOR_ENC=No\x20brand
+E: ID_VENDOR_ID=10d5
+E: KEY=1000000000007 ff9f207ac14057ff febeffdfffefffff fffffffffffffffe
+E: LED=1f
+E: MODALIAS=input:b0003v10D5p55A2e0110-e0,1,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8C,8E,96,98,9E,9F,A1,A3,A4,A5,A6,AD,B0,B1,B2,B3,B4,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,F0,ram4,l0,1,2,3,4,sfw
+E: MSC=10
+E: NAME="No brand 2Port KVMSwicther"
+E: PHYS="usb-0000:00:14.0-1.3/input0"
+E: PRODUCT=3/10d5/55a2/110
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: UNIQ="12²"
+E: USEC_INITIALIZED=15125549
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/input/input8/event8
+N: input/event8
+S: input/by-id/usb-No_brand_2Port_KVMSwicther_12²-event-kbd
+S: input/by-path/pci-0000:00:14.0-usb-0:1.3:1.0-event-kbd
+E: DEVLINKS=/dev/input/by-id/usb-No_brand_2Port_KVMSwicther_12²-event-kbd /dev/input/by-path/pci-0000:00:14.0-usb-0:1.3:1.0-event-kbd
+E: DEVNAME=/dev/input/event8
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.0/input/input8/event8
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_MODEL=2Port_KVMSwicther
+E: ID_MODEL_ENC=2Port\x20KVMSwicther
+E: ID_MODEL_ID=55a2
+E: ID_PATH=pci-0000:00:14.0-usb-0:1.3:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_1_3_1_0
+E: ID_REVISION=0100
+E: ID_SERIAL=No_brand_2Port_KVMSwicther_12²
+E: ID_SERIAL_SHORT=12²
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=No_brand
+E: ID_VENDOR_ENC=No\x20brand
+E: ID_VENDOR_ID=10d5
+E: MAJOR=13
+E: MINOR=72
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15138649
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1.3/3-1.3:1.1
+E: DEVTYPE=usb_interface
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v10D5p55A2d0100dc00dsc00dp00ic03isc00ip00in01
+E: PRODUCT=10d5/55a2/100
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-1/3-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v058Fp9254d0312dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=58f/9254/312
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2
+N: bus/usb/003/003
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Logitech_USB_Headset
+E: ID_MODEL_ENC=Logitech\x20USB\x20Headset
+E: ID_MODEL_ID=0a0b
+E: ID_REVISION=1013
+E: ID_SERIAL=Logitech_Logitech_USB_Headset
+E: ID_USB_INTERFACES=:010100:010200:030000:
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=189
+E: MINOR=258
+E: PRODUCT=46d/a0b/1013
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: UPOWER_VENDOR=Logitech, Inc.
+E: USEC_INITIALIZED=1502953
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=snd-usb-audio
+E: INTERFACE=1/1/0
+E: MODALIAS=usb:v046Dp0A0Bd1013dc00dsc00dp00ic01isc01ip00in00
+E: PRODUCT=46d/a0b/1013
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1
+E: ID_BUS=usb
+E: ID_FOR_SEAT=sound-pci-0000_00_14_0-usb-0_2_1_0
+E: ID_ID=usb-Logitech_Logitech_USB_Headset-00-Headset
+E: ID_MODEL=Logitech_USB_Headset
+E: ID_MODEL_ENC=Logitech\x20USB\x20Headset
+E: ID_MODEL_FROM_DATABASE=ClearChat Pro USB
+E: ID_MODEL_ID=0a0b
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_0
+E: ID_REVISION=1013
+E: ID_SERIAL=Logitech_Logitech_USB_Headset
+E: ID_TYPE=audio
+E: ID_USB_DRIVER=snd-usb-audio
+E: ID_USB_INTERFACES=:010100:010200:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_FROM_DATABASE=Logitech, Inc.
+E: ID_VENDOR_ID=046d
+E: SOUND_FORM_FACTOR=headset
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15344589
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1/pcmC1D0c
+N: snd/pcmC1D0c
+E: DEVNAME=/dev/snd/pcmC1D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1/pcmC1D0c
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15345089
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1/pcmC1D0p
+N: snd/pcmC1D0p
+E: DEVNAME=/dev/snd/pcmC1D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1/pcmC1D0p
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15345966
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1/controlC1
+N: snd/controlC1
+S: snd/by-id/usb-Logitech_Logitech_USB_Headset-00
+S: snd/by-path/pci-0000:00:14.0-usb-0:2:1.0
+E: DEVLINKS=/dev/snd/by-id/usb-Logitech_Logitech_USB_Headset-00 /dev/snd/by-path/pci-0000:00:14.0-usb-0:2:1.0
+E: DEVNAME=/dev/snd/controlC1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.0/sound/card1/controlC1
+E: ID_BUS=usb
+E: ID_MODEL=Logitech_USB_Headset
+E: ID_MODEL_ENC=Logitech\x20USB\x20Headset
+E: ID_MODEL_ID=0a0b
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.0
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_0
+E: ID_REVISION=1013
+E: ID_SERIAL=Logitech_Logitech_USB_Headset
+E: ID_TYPE=audio
+E: ID_USB_DRIVER=snd-usb-audio
+E: ID_USB_INTERFACES=:010100:010200:030000:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15345310
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=snd-usb-audio
+E: INTERFACE=1/2/0
+E: MODALIAS=usb:v046Dp0A0Bd1013dc00dsc00dp00ic01isc02ip00in01
+E: PRODUCT=46d/a0b/1013
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.2
+E: DEVTYPE=usb_interface
+E: DRIVER=snd-usb-audio
+E: INTERFACE=1/2/0
+E: MODALIAS=usb:v046Dp0A0Bd1013dc00dsc00dp00ic01isc02ip00in02
+E: PRODUCT=46d/a0b/1013
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v046Dp0A0Bd1013dc00dsc00dp00ic03isc00ip00in03
+E: PRODUCT=46d/a0b/1013
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/0003:046D:0A0B.0001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/0003:046D:0A0B.0001
+E: DRIVER=hid-generic
+E: HID_ID=0003:0000046D:00000A0B
+E: HID_NAME=Logitech Logitech USB Headset
+E: HID_PHYS=usb-0000:00:14.0-2/input3
+E: MODALIAS=hid:b0003g0001v0000046Dp00000A0B
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/0003:046D:0A0B.0001/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/0003:046D:0A0B.0001/hidraw/hidraw0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/input/input4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/input/input4
+E: EV=13
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_14_0-usb-0_2_1_3
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Logitech_USB_Headset
+E: ID_MODEL_ENC=Logitech\x20USB\x20Headset
+E: ID_MODEL_ID=0a0b
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.3
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_3
+E: ID_REVISION=1013
+E: ID_SERIAL=Logitech_Logitech_USB_Headset
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:010100:010200:030000:
+E: ID_USB_INTERFACE_NUM=03
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: KEY=c000000000000 0
+E: MODALIAS=input:b0003v046Dp0A0Be0100-e0,1,4,k72,73,ram4,lsfw
+E: MSC=10
+E: NAME="Logitech Logitech USB Headset"
+E: PHYS="usb-0000:00:14.0-2/input3"
+E: PRODUCT=3/46d/a0b/100
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=1511089
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/input/input4/event4
+N: input/event4
+S: input/by-id/usb-Logitech_Logitech_USB_Headset-event-if03
+S: input/by-path/pci-0000:00:14.0-usb-0:2:1.3-event
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_Logitech_USB_Headset-event-if03 /dev/input/by-path/pci-0000:00:14.0-usb-0:2:1.3-event
+E: DEVNAME=/dev/input/event4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-2/3-2:1.3/input/input4/event4
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Logitech_USB_Headset
+E: ID_MODEL_ENC=Logitech\x20USB\x20Headset
+E: ID_MODEL_ID=0a0b
+E: ID_PATH=pci-0000:00:14.0-usb-0:2:1.3
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_2_1_3
+E: ID_REVISION=1013
+E: ID_SERIAL=Logitech_Logitech_USB_Headset
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:010100:010200:030000:
+E: ID_USB_INTERFACE_NUM=03
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=68
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1512055
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4
+N: bus/usb/003/004
+E: BUSNUM=003
+E: DEVNAME=/dev/bus/usb/003/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MM_ERICSSON_MBM=1
+E: ID_MODEL=H5321_gw
+E: ID_MODEL_ENC=H5321\x20gw
+E: ID_MODEL_ID=1926
+E: ID_REVISION=0000
+E: ID_SERIAL=Lenovo_H5321_gw_07CE4B878053FDM0
+E: ID_SERIAL_SHORT=07CE4B878053FDM0
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:020e00:0a0001:0a0002:
+E: ID_VENDOR=Lenovo
+E: ID_VENDOR_ENC=Lenovo
+E: ID_VENDOR_ID=0bdb
+E: MAJOR=189
+E: MINOR=259
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1720160
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.0
+E: DEVTYPE=usb_interface
+E: INTERFACE=2/8/0
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc08ip00in00
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=2/2/1
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc02ip01in01
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.1/tty/ttyACM0
+N: ttyACM0
+S: serial/by-id/usb-Lenovo_H5321_gw_07CE4B878053FDM0-if01
+S: serial/by-path/pci-0000:00:14.0-usb-0:4:1.1
+E: DEVLINKS=/dev/serial/by-id/usb-Lenovo_H5321_gw_07CE4B878053FDM0-if01 /dev/serial/by-path/pci-0000:00:14.0-usb-0:4:1.1
+E: DEVNAME=/dev/ttyACM0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.1/tty/ttyACM0
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=H5321_gw
+E: ID_MODEL_ENC=H5321\x20gw
+E: ID_MODEL_ID=1926
+E: ID_PATH=pci-0000:00:14.0-usb-0:4:1.1
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_4_1_1
+E: ID_REVISION=0000
+E: ID_SERIAL=Lenovo_H5321_gw_07CE4B878053FDM0
+E: ID_SERIAL_SHORT=07CE4B878053FDM0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_acm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:020e00:0a0001:0a0002:
+E: ID_USB_INTERFACE_NUM=01
+E: ID_VENDOR=Lenovo
+E: ID_VENDOR_ENC=Lenovo
+E: ID_VENDOR_FROM_DATABASE=Ericsson Business Mobile Networks BV
+E: ID_VENDOR_ID=0bdb
+E: MAJOR=166
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15199369
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.10
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.10
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=10/0/0
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic0Aisc00ip00in0A
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.2
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=10/0/0
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic0Aisc00ip00in02
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.3
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=2/2/1
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc02ip01in03
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.3/tty/ttyACM1
+N: ttyACM1
+S: serial/by-id/usb-Lenovo_H5321_gw_07CE4B878053FDM0-if03
+S: serial/by-path/pci-0000:00:14.0-usb-0:4:1.3
+E: DEVLINKS=/dev/serial/by-id/usb-Lenovo_H5321_gw_07CE4B878053FDM0-if03 /dev/serial/by-path/pci-0000:00:14.0-usb-0:4:1.3
+E: DEVNAME=/dev/ttyACM1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.3/tty/ttyACM1
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=H5321_gw
+E: ID_MODEL_ENC=H5321\x20gw
+E: ID_MODEL_ID=1926
+E: ID_PATH=pci-0000:00:14.0-usb-0:4:1.3
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_4_1_3
+E: ID_REVISION=0000
+E: ID_SERIAL=Lenovo_H5321_gw_07CE4B878053FDM0
+E: ID_SERIAL_SHORT=07CE4B878053FDM0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_acm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:020e00:0a0001:0a0002:
+E: ID_USB_INTERFACE_NUM=03
+E: ID_VENDOR=Lenovo
+E: ID_VENDOR_ENC=Lenovo
+E: ID_VENDOR_FROM_DATABASE=Ericsson Business Mobile Networks BV
+E: ID_VENDOR_ID=0bdb
+E: MAJOR=166
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15195396
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.4
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.4
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=10/0/0
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic0Aisc00ip00in04
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.5
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.5
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_wdm
+E: INTERFACE=2/9/1
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc09ip01in05
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.5/usbmisc/cdc-wdm1
+N: cdc-wdm1
+E: DEVNAME=/dev/cdc-wdm1
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.5/usbmisc/cdc-wdm1
+E: MAJOR=180
+E: MINOR=1
+E: SUBSYSTEM=usbmisc
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.6
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.6
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_mbim
+E: INTERFACE=2/14/0
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc0Eip00in06
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.6/net/wwan0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.6/net/wwan0
+E: DEVTYPE=wwan
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=H5321_gw
+E: ID_MODEL_ENC=H5321\x20gw
+E: ID_MODEL_ID=1926
+E: ID_REVISION=0000
+E: ID_SERIAL=Lenovo_H5321_gw_07CE4B878053FDM0
+E: ID_SERIAL_SHORT=07CE4B878053FDM0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_mbim
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:020e00:0a0001:0a0002:
+E: ID_USB_INTERFACE_NUM=06
+E: ID_VENDOR=Lenovo
+E: ID_VENDOR_ENC=Lenovo
+E: ID_VENDOR_FROM_DATABASE=Ericsson Business Mobile Networks BV
+E: ID_VENDOR_ID=0bdb
+E: IFINDEX=4
+E: INTERFACE=wwan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15199755
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.6/usbmisc/cdc-wdm3
+N: cdc-wdm3
+E: DEVNAME=/dev/cdc-wdm3
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.6/usbmisc/cdc-wdm3
+E: MAJOR=180
+E: MINOR=3
+E: SUBSYSTEM=usbmisc
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.7
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.7
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_mbim
+E: INTERFACE=10/0/2
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic0Aisc00ip02in07
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.8
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.8
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_wdm
+E: INTERFACE=2/9/1
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc09ip01in08
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.8/usbmisc/cdc-wdm2
+N: cdc-wdm2
+E: DEVNAME=/dev/cdc-wdm2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.8/usbmisc/cdc-wdm2
+E: MAJOR=180
+E: MINOR=2
+E: SUBSYSTEM=usbmisc
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.9
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.9
+E: DEVTYPE=usb_interface
+E: DRIVER=cdc_acm
+E: INTERFACE=2/2/1
+E: MODALIAS=usb:v0BDBp1926d0000dc00dsc00dp00ic02isc02ip01in09
+E: PRODUCT=bdb/1926/0
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.9/tty/ttyACM2
+N: ttyACM2
+S: serial/by-id/usb-Lenovo_H5321_gw_07CE4B878053FDM0-if09
+S: serial/by-path/pci-0000:00:14.0-usb-0:4:1.9
+E: DEVLINKS=/dev/serial/by-id/usb-Lenovo_H5321_gw_07CE4B878053FDM0-if09 /dev/serial/by-path/pci-0000:00:14.0-usb-0:4:1.9
+E: DEVNAME=/dev/ttyACM2
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb3/3-4/3-4:1.9/tty/ttyACM2
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=H5321_gw
+E: ID_MODEL_ENC=H5321\x20gw
+E: ID_MODEL_ID=1926
+E: ID_PATH=pci-0000:00:14.0-usb-0:4:1.9
+E: ID_PATH_TAG=pci-0000_00_14_0-usb-0_4_1_9
+E: ID_REVISION=0000
+E: ID_SERIAL=Lenovo_H5321_gw_07CE4B878053FDM0
+E: ID_SERIAL_SHORT=07CE4B878053FDM0
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=cdc_acm
+E: ID_USB_INTERFACES=:020800:020201:0a0000:020901:020d00:020e00:0a0001:0a0002:
+E: ID_USB_INTERFACE_NUM=09
+E: ID_VENDOR=Lenovo
+E: ID_VENDOR_ENC=Lenovo
+E: ID_VENDOR_FROM_DATABASE=Ericsson Business Mobile Networks BV
+E: ID_VENDOR_ID=0bdb
+E: MAJOR=166
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15194576
+
+P: /devices/pci0000:00/0000:00:14.0/usb4
+N: bus/usb/004/001
+E: BUSNUM=004
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_14_0
+E: ID_MODEL=xHCI_Host_Controller
+E: ID_MODEL_ENC=xHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0003
+E: ID_PATH=pci-0000:00:14.0
+E: ID_PATH_TAG=pci-0000_00_14_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-25-generic_xhci_hcd_xHCI_Host_Controller_0000:00:14.0
+E: ID_SERIAL_SHORT=0000:00:14.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-25-generic_xhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-25-generic\x20xhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=384
+E: PRODUCT=1d6b/3/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=506344
+
+P: /devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:14.0/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0003d0308dc09dsc00dp03ic09isc00ip00in00
+E: PRODUCT=1d6b/3/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/3
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.0
+E: DEVPATH=/devices/pci0000:00/0000:00:16.0
+E: DRIVER=mei
+E: MODALIAS=pci:v00008086d00001E3Asv000017AAsd000021FBbc07sc80i00
+E: PCI_CLASS=78000
+E: PCI_ID=8086:1E3A
+E: PCI_SLOT_NAME=0000:00:16.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3
+E: DRIVER=serial
+E: MODALIAS=pci:v00008086d00001E3Dsv000017AAsd000021FBbc07sc00i02
+E: PCI_CLASS=70002
+E: PCI_ID=8086:1E3D
+E: PCI_SLOT_NAME=0000:00:16.3
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:16.3/tty/ttyS4
+N: ttyS4
+E: DEVNAME=/dev/ttyS4
+E: DEVPATH=/devices/pci0000:00/0000:00:16.3/tty/ttyS4
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=7 Series/C210 Series Chipset Family KT Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:16.3
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: MAJOR=4
+E: MINOR=68
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14746735
+
+P: /devices/pci0000:00/0000:00:19.0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0
+E: DRIVER=e1000e
+E: MODALIAS=pci:v00008086d00001502sv000017AAsd000021F3bc02sc00i00
+E: PCI_CLASS=20000
+E: PCI_ID=8086:1502
+E: PCI_SLOT_NAME=0000:00:19.0
+E: PCI_SUBSYS_ID=17AA:21F3
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:19.0/net/eth0
+E: DEVPATH=/devices/pci0000:00/0000:00:19.0/net/eth0
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=82579LM Gigabit Network Connection
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:19.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14750355
+
+P: /devices/pci0000:00/0000:00:1a.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001E2Dsv000017AAsd000021FBbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E2D
+E: PCI_SLOT_NAME=0000:00:1a.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1a_0
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:1a.0
+E: ID_PATH_TAG=pci-0000_00_1a_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-25-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1a.0
+E: ID_SERIAL_SHORT=0000:00:1a.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-25-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-25-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=506494
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1a_0-usb-0_1
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=884925
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=HD_Pro_Webcam_C920
+E: ID_MODEL_ENC=HD\x20Pro\x20Webcam\x20C920
+E: ID_MODEL_ID=082d
+E: ID_REVISION=0011
+E: ID_SERIAL=046d_HD_Pro_Webcam_C920_73BD39DF
+E: ID_SERIAL_SHORT=73BD39DF
+E: ID_USB_INTERFACES=:0e0100:0e0200:010100:010200:
+E: ID_VENDOR=046d
+E: ID_VENDOR_ENC=046d
+E: ID_VENDOR_ID=046d
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=46d/82d/11
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: UPOWER_VENDOR=Logitech, Inc.
+E: USEC_INITIALIZED=1886803
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v046Dp082Dd0011dcEFdsc02dp01ic0Eisc01ip00in00
+E: PRODUCT=46d/82d/11
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input10
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input10
+E: EV=3
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=HD_Pro_Webcam_C920
+E: ID_MODEL_ENC=HD\x20Pro\x20Webcam\x20C920
+E: ID_MODEL_ID=082d
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_REVISION=0011
+E: ID_SERIAL=046d_HD_Pro_Webcam_C920_73BD39DF
+E: ID_SERIAL_SHORT=73BD39DF
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:010100:010200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=046d
+E: ID_VENDOR_ENC=046d
+E: ID_VENDOR_ID=046d
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v046Dp082De0011-e0,1,kD4,ramlsfw
+E: NAME="HD Pro Webcam C920"
+E: PHYS="usb-0000:00:1a.0-1.2/button"
+E: PRODUCT=3/46d/82d/11
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15443331
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input10/event10
+N: input/event10
+S: input/by-id/usb-046d_HD_Pro_Webcam_C920_73BD39DF-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.2:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-046d_HD_Pro_Webcam_C920_73BD39DF-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.2:1.0-event
+E: DEVNAME=/dev/input/event10
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/input/input10/event10
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=HD_Pro_Webcam_C920
+E: ID_MODEL_ENC=HD\x20Pro\x20Webcam\x20C920
+E: ID_MODEL_ID=082d
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_REVISION=0011
+E: ID_SERIAL=046d_HD_Pro_Webcam_C920_73BD39DF
+E: ID_SERIAL_SHORT=73BD39DF
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:010100:010200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=046d
+E: ID_VENDOR_ENC=046d
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=74
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15445655
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-046d_HD_Pro_Webcam_C920_73BD39DF-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.2:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-046d_HD_Pro_Webcam_C920_73BD39DF-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.2:1.0-video-index0
+E: DEVNAME=/dev/video0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.0/video4linux/video0
+E: ID_BUS=usb
+E: ID_FOR_SEAT=video4linux-pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_MODEL=HD_Pro_Webcam_C920
+E: ID_MODEL_ENC=HD\x20Pro\x20Webcam\x20C920
+E: ID_MODEL_ID=082d
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_0
+E: ID_REVISION=0011
+E: ID_SERIAL=046d_HD_Pro_Webcam_C920_73BD39DF
+E: ID_SERIAL_SHORT=73BD39DF
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:010100:010200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=HD Pro Webcam C920
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=046d
+E: ID_VENDOR_ENC=046d
+E: ID_VENDOR_ID=046d
+E: MAJOR=81
+E: MINOR=0
+E: SUBSYSTEM=video4linux
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15509642
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v046Dp082Dd0011dcEFdsc02dp01ic0Eisc02ip00in01
+E: PRODUCT=46d/82d/11
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2
+E: DEVTYPE=usb_interface
+E: DRIVER=snd-usb-audio
+E: INTERFACE=1/1/0
+E: MODALIAS=usb:v046Dp082Dd0011dcEFdsc02dp01ic01isc01ip00in02
+E: PRODUCT=46d/82d/11
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2/sound/card0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2/sound/card0
+E: ID_BUS=usb
+E: ID_FOR_SEAT=sound-pci-0000_00_1a_0-usb-0_1_2_1_2
+E: ID_ID=usb-046d_HD_Pro_Webcam_C920_73BD39DF-02-C920
+E: ID_MODEL=HD_Pro_Webcam_C920
+E: ID_MODEL_ENC=HD\x20Pro\x20Webcam\x20C920
+E: ID_MODEL_ID=082d
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.2
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_2
+E: ID_REVISION=0011
+E: ID_SERIAL=046d_HD_Pro_Webcam_C920_73BD39DF
+E: ID_SERIAL_SHORT=73BD39DF
+E: ID_TYPE=audio
+E: ID_USB_DRIVER=snd-usb-audio
+E: ID_USB_INTERFACES=:0e0100:0e0200:010100:010200:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=046d
+E: ID_VENDOR_ENC=046d
+E: ID_VENDOR_FROM_DATABASE=Logitech, Inc.
+E: ID_VENDOR_ID=046d
+E: SOUND_FORM_FACTOR=webcam
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15344313
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15346410
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-id/usb-046d_HD_Pro_Webcam_C920_73BD39DF-02
+S: snd/by-path/pci-0000:00:1a.0-usb-0:1.2:1.2
+E: DEVLINKS=/dev/snd/by-id/usb-046d_HD_Pro_Webcam_C920_73BD39DF-02 /dev/snd/by-path/pci-0000:00:1a.0-usb-0:1.2:1.2
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.2/sound/card0/controlC0
+E: ID_BUS=usb
+E: ID_MODEL=HD_Pro_Webcam_C920
+E: ID_MODEL_ENC=HD\x20Pro\x20Webcam\x20C920
+E: ID_MODEL_ID=082d
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.2:1.2
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_2_1_2
+E: ID_REVISION=0011
+E: ID_SERIAL=046d_HD_Pro_Webcam_C920_73BD39DF
+E: ID_SERIAL_SHORT=73BD39DF
+E: ID_TYPE=audio
+E: ID_USB_DRIVER=snd-usb-audio
+E: ID_USB_INTERFACES=:0e0100:0e0200:010100:010200:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=046d
+E: ID_VENDOR_ENC=046d
+E: ID_VENDOR_ID=046d
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15346822
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.2/1-1.2:1.3
+E: DEVTYPE=usb_interface
+E: DRIVER=snd-usb-audio
+E: INTERFACE=1/2/0
+E: MODALIAS=usb:v046Dp082Dd0011dcEFdsc02dp01ic01isc02ip00in03
+E: PRODUCT=46d/82d/11
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=BCM20702A0
+E: ID_MODEL_ENC=BCM20702A0
+E: ID_MODEL_ID=21e6
+E: ID_REVISION=0112
+E: ID_SERIAL=Broadcom_Corp_BCM20702A0_F4B7E2E8A8EF
+E: ID_SERIAL_SHORT=F4B7E2E8A8EF
+E: ID_USB_INTERFACES=:ff0101:ffffff:fe0101:
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=0a5c
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=a5c/21e6/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2052308
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v0A5Cp21E6d0112dcFFdsc01dp01icFFisc01ip01in00
+E: PRODUCT=a5c/21e6/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.0/bluetooth/hci0/rfkill3
+E: RFKILL_NAME=hci0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: INTERFACE=255/1/1
+E: MODALIAS=usb:v0A5Cp21E6d0112dcFFdsc01dp01icFFisc01ip01in01
+E: PRODUCT=a5c/21e6/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.2
+E: DEVTYPE=usb_interface
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0A5Cp21E6d0112dcFFdsc01dp01icFFiscFFipFFin02
+E: PRODUCT=a5c/21e6/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.4/1-1.4:1.3
+E: DEVTYPE=usb_interface
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v0A5Cp21E6d0112dcFFdsc01dp01icFEisc01ip01in03
+E: PRODUCT=a5c/21e6/112
+E: SUBSYSTEM=usb
+E: TYPE=255/1/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6
+N: bus/usb/001/005
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/005
+E: DEVNUM=005
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b2da
+E: ID_REVISION=0518
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: MAJOR=189
+E: MINOR=4
+E: PRODUCT=4f2/b2da/518
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=7221211
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v04F2pB2DAd0518dcEFdsc02dp01ic0Eisc01ip00in00
+E: PRODUCT=4f2/b2da/518
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11
+E: EV=3
+E: ID_BUS=usb
+E: ID_FOR_SEAT=input-pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b2da
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=0518
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0003v04F2pB2DAe0518-e0,1,kD4,ramlsfw
+E: NAME="Integrated Camera"
+E: PHYS="usb-0000:00:1a.0-1.6/button"
+E: PRODUCT=3/4f2/b2da/518
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15442818
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11/event11
+N: input/event11
+S: input/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-event-if00
+S: input/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-event
+E: DEVLINKS=/dev/input/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-event-if00 /dev/input/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-event
+E: DEVNAME=/dev/input/event11
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/input/input11/event11
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b2da
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=0518
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: MAJOR=13
+E: MINOR=75
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15444855
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/video4linux/video1
+N: video1
+S: v4l/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-video-index0
+S: v4l/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-video-index0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-Chicony_Electronics_Co.__Ltd._Integrated_Camera-video-index0 /dev/v4l/by-path/pci-0000:00:1a.0-usb-0:1.6:1.0-video-index0
+E: DEVNAME=/dev/video1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.0/video4linux/video1
+E: ID_BUS=usb
+E: ID_FOR_SEAT=video4linux-pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_MODEL=Integrated_Camera
+E: ID_MODEL_ENC=Integrated\x20Camera
+E: ID_MODEL_ID=b2da
+E: ID_PATH=pci-0000:00:1a.0-usb-0:1.6:1.0
+E: ID_PATH_TAG=pci-0000_00_1a_0-usb-0_1_6_1_0
+E: ID_REVISION=0518
+E: ID_SERIAL=Chicony_Electronics_Co.__Ltd._Integrated_Camera
+E: ID_TYPE=video
+E: ID_USB_DRIVER=uvcvideo
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_V4L_PRODUCT=Integrated Camera
+E: ID_V4L_VERSION=2
+E: ID_VENDOR=Chicony_Electronics_Co.__Ltd.
+E: ID_VENDOR_ENC=Chicony\x20Electronics\x20Co.\x2c\x20Ltd.
+E: ID_VENDOR_ID=04f2
+E: MAJOR=81
+E: MINOR=1
+E: SUBSYSTEM=video4linux
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15511770
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1.6/1-1.6:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v04F2pB2DAd0518dcEFdsc02dp01ic0Eisc02ip00in01
+E: PRODUCT=4f2/b2da/518
+E: SUBSYSTEM=usb
+E: TYPE=239/2/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1a.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=snd_hda_intel
+E: MODALIAS=pci:v00008086d00001E20sv000017AAsd000021FBbc04sc03i00
+E: PCI_CLASS=40300
+E: PCI_ID=8086:1E20
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2
+E: ID_BUS=pci
+E: ID_FOR_SEAT=sound-pci-0000_00_1b_0
+E: ID_MODEL_FROM_DATABASE=7 Series/C210 Series Chipset Family High Definition Audio Controller
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1b.0
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+E: SOUND_FORM_FACTOR=internal
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16480061
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/hwC2D0
+N: snd/hwC2D0
+E: DEVNAME=/dev/snd/hwC2D0
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/hwC2D0
+E: MAJOR=116
+E: MINOR=14
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16481550
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/hwC2D3
+N: snd/hwC2D3
+E: DEVNAME=/dev/snd/hwC2D3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/hwC2D3
+E: MAJOR=116
+E: MINOR=13
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16485073
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input14
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=8"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16482291
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input14/event14
+N: input/event14
+E: DEVNAME=/dev/input/event14
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input14/event14
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=78
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16486955
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input15
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input15
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=7"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16480803
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input15/event15
+N: input/event15
+E: DEVNAME=/dev/input/event15
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input15/event15
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=79
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16490536
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input16
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input16
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw6,8,
+E: NAME="HDA Intel PCH HDMI/DP,pcm=3"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=140
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16480815
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input16/event16
+N: input/event16
+E: DEVNAME=/dev/input/event16
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input16/event16
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=80
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16486066
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input17
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input17
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Dock Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16481660
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input17/event17
+N: input/event17
+E: DEVNAME=/dev/input/event17
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input17/event17
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=81
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16486380
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input18
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input18
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: NAME="HDA Intel PCH Mic"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=10
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16481925
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input18/event18
+N: input/event18
+E: DEVNAME=/dev/input/event18
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input18/event18
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=82
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16486954
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input19
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input19
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Dock Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16483609
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input19/event19
+N: input/event19
+E: DEVNAME=/dev/input/event19
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input19/event19
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=83
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16488099
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input20
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input20
+E: EV=21
+E: ID_FOR_SEAT=input-pci-0000_00_1b_0
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: NAME="HDA Intel PCH Headphone"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=4
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16485217
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/input20/event20
+N: input/event20
+E: DEVNAME=/dev/input/event20
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/input20/event20
+E: ID_INPUT=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=13
+E: MINOR=84
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16489373
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D0c
+N: snd/pcmC2D0c
+E: DEVNAME=/dev/snd/pcmC2D0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D0c
+E: MAJOR=116
+E: MINOR=12
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16481335
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D0p
+N: snd/pcmC2D0p
+E: DEVNAME=/dev/snd/pcmC2D0p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D0p
+E: MAJOR=116
+E: MINOR=11
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16482557
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D3p
+N: snd/pcmC2D3p
+E: DEVNAME=/dev/snd/pcmC2D3p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D3p
+E: MAJOR=116
+E: MINOR=10
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16485123
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D7p
+N: snd/pcmC2D7p
+E: DEVNAME=/dev/snd/pcmC2D7p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D7p
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16484214
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D8p
+N: snd/pcmC2D8p
+E: DEVNAME=/dev/snd/pcmC2D8p
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/pcmC2D8p
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16484778
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card2/controlC2
+N: snd/controlC2
+S: snd/by-path/pci-0000:00:1b.0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: DEVNAME=/dev/snd/controlC2
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card2/controlC2
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: MAJOR=116
+E: MINOR=15
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=16481179
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E10sv000017AAsd000021FBbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E10
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:02
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E12sv000017AAsd000021FBbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E12
+E: PCI_SLOT_NAME=0000:00:1c.1
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0
+E: DRIVER=iwlwifi
+E: MODALIAS=pci:v00008086d00004238sv00008086sd00001111bc02sc80i00
+E: PCI_CLASS=28000
+E: PCI_ID=8086:4238
+E: PCI_SLOT_NAME=0000:03:00.0
+E: PCI_SUBSYS_ID=8086:1111
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0/rfkill2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/ieee80211/phy0/rfkill2
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/leds/phy0-led
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/leds/phy0-led
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.1/0000:03:00.0/net/wlan0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/0000:03:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: ID_BUS=pci
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL_FROM_DATABASE=Centrino Ultimate-N 6300
+E: ID_MODEL_ID=/sys/devices/pci0000:00/0000:00:1c.1/0000:03:00.0
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_VENDOR_ID=0x8086
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15079967
+
+P: /devices/pci0000:00/0000:00:1c.1/pci_bus/0000:03
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.1/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E14sv000017AAsd000021FBbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E14
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:04:00.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:04:00.0
+E: DRIVER=sdhci-pci
+E: MODALIAS=pci:v00001180d0000E823sv000017AAsd000021FBbc08sc80i00
+E: PCI_CLASS=88000
+E: PCI_ID=1180:E823
+E: PCI_SLOT_NAME=0000:04:00.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:04:00.0/leds/mmc0::
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:04:00.0/leds/mmc0::
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:04:00.0/mmc_host/mmc0
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:04:00.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:04
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4
+E: DRIVER=pcieport
+E: MODALIAS=pci:v00008086d00001E18sv000017AAsd000021FBbc06sc04i00
+E: PCI_CLASS=60400
+E: PCI_ID=8086:1E18
+E: PCI_SLOT_NAME=0000:00:1c.4
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1c.4/pci_bus/0000:0c
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.4/pci_bus/0000:0c
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=ehci-pci
+E: MODALIAS=pci:v00008086d00001E26sv000017AAsd000021FBbc0Csc03i20
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:1E26
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1d_0
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_PATH=pci-0000:00:1d.0
+E: ID_PATH_TAG=pci-0000_00_1d_0
+E: ID_REVISION=0308
+E: ID_SERIAL=Linux_3.8.0-25-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.8.0-25-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.8.0-25-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=512264
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0308dc09dsc00dp00ic09isc00ip00in00
+E: PRODUCT=1d6b/2/308
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1
+N: bus/usb/002/002
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/002
+E: DEVNUM=002
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_FOR_SEAT=usb-pci-0000_00_1d_0-usb-0_1
+E: ID_MODEL=0024
+E: ID_MODEL_ENC=0024
+E: ID_MODEL_ID=0024
+E: ID_PATH=pci-0000:00:1d.0-usb-0:1
+E: ID_PATH_TAG=pci-0000_00_1d_0-usb-0_1
+E: ID_REVISION=0000
+E: ID_SERIAL=8087_0024
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=8087
+E: ID_VENDOR_ENC=8087
+E: ID_VENDOR_ID=8087
+E: MAJOR=189
+E: MINOR=129
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TAGS=:seat:
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1128865
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-1/2-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v8087p0024d0000dc09dsc00dp01ic09isc00ip00in00
+E: PRODUCT=8087/24/0
+E: SUBSYSTEM=usb
+E: TYPE=9/0/1
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: DRIVER=lpc_ich
+E: MODALIAS=pci:v00008086d00001E55sv000017AAsd000021FBbc06sc01i00
+E: PCI_CLASS=60100
+E: PCI_ID=8086:1E55
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0/iTCO_wdt
+E: DEVTYPE=mfd_device
+E: MODALIAS=platform:iTCO_wdt
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ahci
+E: ID_MODEL_FROM_DATABASE=7 Series Chipset Family 6-port SATA Controller [AHCI mode]
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: MODALIAS=pci:v00008086d00001E03sv000017AAsd000021FBbc01sc06i01
+E: PCI_CLASS=10601
+E: PCI_ID=8086:1E03
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14741955
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M
+S: disk/by-id/wwn-0x5000cca77fc2b2dc
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M /dev/disk/by-id/wwn-0x5000cca77fc2b2dc /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_COUNT=7
+E: UDISKS_PARTITION_TABLE_SCHEME=gpt
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1883378
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part1
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part1
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part1
+S: disk/by-label/WINRE_DRV
+S: disk/by-partuuid/58c0030d-7957-4c21-b0cd-53b952d2d692
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/7EB4BDFAB4BDB4CD
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part1 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part1 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part1 /dev/disk/by-label/WINRE_DRV /dev/disk/by-partuuid/58c0030d-7957-4c21-b0cd-53b952d2d692 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/7EB4BDFAB4BDB4CD
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=WINRE_DRV
+E: ID_FS_LABEL_ENC=WINRE_DRV
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=7EB4BDFAB4BDB4CD
+E: ID_FS_UUID_ENC=7EB4BDFAB4BDB4CD
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x1
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=2048000
+E: ID_PART_ENTRY_TYPE=de94bba4-06d1-4d40-a16a-bfd50179d6ac
+E: ID_PART_ENTRY_UUID=58c0030d-7957-4c21-b0cd-53b952d2d692
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=required
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=1048576000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=DE94BBA4-06D1-4D40-A16A-BFD50179D6AC
+E: UDISKS_PARTITION_UUID=58C0030D-7957-4C21-B0CD-53B952D2D692
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2291793
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part2
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part2
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part2
+S: disk/by-label/SYSTEM_DRV
+S: disk/by-partlabel/EFI\x20system\x20partition
+S: disk/by-partuuid/9b9b6a09-2c0c-4949-b1de-aae9b9ff53c7
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-uuid/00BF-6DB5
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part2 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part2 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part2 /dev/disk/by-label/SYSTEM_DRV /dev/disk/by-partlabel/EFI\x20system\x20partition /dev/disk/by-partuuid/9b9b6a09-2c0c-4949-b1de-aae9b9ff53c7 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-uuid/00BF-6DB5
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=SYSTEM_DRV
+E: ID_FS_LABEL_ENC=SYSTEM_DRV
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=00BF-6DB5
+E: ID_FS_UUID_ENC=00BF-6DB5
+E: ID_FS_VERSION=FAT32
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=EFI\x20system\x20partition
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=2050048
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=532480
+E: ID_PART_ENTRY_TYPE=c12a7328-f81f-11d2-ba4b-00a0c93ec93b
+E: ID_PART_ENTRY_UUID=9b9b6a09-2c0c-4949-b1de-aae9b9ff53c7
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_IGNORE=1
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=EFI system partition
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_OFFSET=1049624576
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=272629760
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=C12A7328-F81F-11D2-BA4B-00A0C93EC93B
+E: UDISKS_PARTITION_UUID=9B9B6A09-2C0C-4949-B1DE-AAE9B9FF53C7
+E: UDISKS_PRESENTATION_HIDE=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2288316
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part3
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part3
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part3
+S: disk/by-partlabel/Microsoft\x20reserved\x20partition
+S: disk/by-partuuid/be544b95-63ea-485d-9f08-c27dcbe1468a
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part3 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part3 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part3 /dev/disk/by-partlabel/Microsoft\x20reserved\x20partition /dev/disk/by-partuuid/be544b95-63ea-485d-9f08-c27dcbe1468a /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part3
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=Microsoft\x20reserved\x20partition
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=2582528
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=262144
+E: ID_PART_ENTRY_TYPE=e3c9e316-0b5c-4db8-817d-f92df00215ae
+E: ID_PART_ENTRY_UUID=be544b95-63ea-485d-9f08-c27dcbe1468a
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=Microsoft reserved partition
+E: UDISKS_PARTITION_NUMBER=3
+E: UDISKS_PARTITION_OFFSET=1322254336
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=134217728
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=E3C9E316-0B5C-4DB8-817D-F92DF00215AE
+E: UDISKS_PARTITION_UUID=BE544B95-63EA-485D-9F08-C27DCBE1468A
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2288291
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+N: sda4
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part4
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part4
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part4
+S: disk/by-label/Windows8_OS
+S: disk/by-partlabel/Basic\x20data\x20partition
+S: disk/by-partuuid/14ce6635-5b49-4d09-bfd0-75b9c55848cd
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4
+S: disk/by-uuid/C898C2E198C2CCDE
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part4 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part4 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part4 /dev/disk/by-label/Windows8_OS /dev/disk/by-partlabel/Basic\x20data\x20partition /dev/disk/by-partuuid/14ce6635-5b49-4d09-bfd0-75b9c55848cd /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part4 /dev/disk/by-uuid/C898C2E198C2CCDE
+E: DEVNAME=/dev/sda4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda4
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Windows8_OS
+E: ID_FS_LABEL_ENC=Windows8_OS
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=C898C2E198C2CCDE
+E: ID_FS_UUID_ENC=C898C2E198C2CCDE
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NAME=Basic\x20data\x20partition
+E: ID_PART_ENTRY_NUMBER=4
+E: ID_PART_ENTRY_OFFSET=2844672
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=108677120
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=14ce6635-5b49-4d09-bfd0-75b9c55848cd
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_LABEL=Basic data partition
+E: UDISKS_PARTITION_NUMBER=4
+E: UDISKS_PARTITION_OFFSET=1456472064
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=55642685440
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=14CE6635-5B49-4D09-BFD0-75B9C55848CD
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2305583
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part5
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part5
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part5
+S: disk/by-label/Lenovo_Recovery
+S: disk/by-partuuid/115e2c6b-d93e-4986-b0c1-44a684309104
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/FC6ABADA6ABA913E
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part5 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part5 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part5 /dev/disk/by-label/Lenovo_Recovery /dev/disk/by-partuuid/115e2c6b-d93e-4986-b0c1-44a684309104 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/FC6ABADA6ABA913E
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_LABEL=Lenovo_Recovery
+E: ID_FS_LABEL_ENC=Lenovo_Recovery
+E: ID_FS_TYPE=ntfs
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=FC6ABADA6ABA913E
+E: ID_FS_UUID_ENC=FC6ABADA6ABA913E
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x1
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=951201792
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=25571328
+E: ID_PART_ENTRY_TYPE=de94bba4-06d1-4d40-a16a-bfd50179d6ac
+E: ID_PART_ENTRY_UUID=115e2c6b-d93e-4986-b0c1-44a684309104
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_FLAGS=required
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_OFFSET=487015317504
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=13092519936
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=DE94BBA4-06D1-4D40-A16A-BFD50179D6AC
+E: UDISKS_PARTITION_UUID=115E2C6B-D93E-4986-B0C1-44A684309104
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2475607
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda6
+N: sda6
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part6
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part6
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part6
+S: disk/by-partuuid/0265ccc3-91fc-4cfe-b676-3c3392edbda0
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part6
+S: disk/by-uuid/f16baa04-f2eb-4d9d-a5bb-ab3f36138e3b
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part6 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part6 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part6 /dev/disk/by-partuuid/0265ccc3-91fc-4cfe-b676-3c3392edbda0 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part6 /dev/disk/by-uuid/f16baa04-f2eb-4d9d-a5bb-ab3f36138e3b
+E: DEVNAME=/dev/sda6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda6
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=f16baa04-f2eb-4d9d-a5bb-ab3f36138e3b
+E: ID_FS_UUID_ENC=f16baa04-f2eb-4d9d-a5bb-ab3f36138e3b
+E: ID_FS_VERSION=1.0
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=6
+E: ID_PART_ENTRY_OFFSET=111521792
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=390625280
+E: ID_PART_ENTRY_TYPE=ebd0a0a2-b9e5-4433-87c0-68b6b72699c7
+E: ID_PART_ENTRY_UUID=0265ccc3-91fc-4cfe-b676-3c3392edbda0
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=6
+E: UDISKS_PARTITION_OFFSET=57099157504
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=200000143360
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=EBD0A0A2-B9E5-4433-87C0-68B6B72699C7
+E: UDISKS_PARTITION_UUID=0265CCC3-91FC-4CFE-B676-3C3392EDBDA0
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2360333
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda7
+N: sda7
+S: disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part7
+S: disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part7
+S: disk/by-id/wwn-0x5000cca77fc2b2dc-part7
+S: disk/by-partuuid/13620ab6-6ef9-4b92-8449-7886beae2045
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part7
+S: disk/by-uuid/2bc700f3-bc24-479f-b922-a4fb10772aaa
+E: DEVLINKS=/dev/disk/by-id/ata-HGST_HTS725050A7E630_TF755AWHG5Y15M-part7 /dev/disk/by-id/scsi-SATA_HGST_HTS725050A_TF755AWHG5Y15M-part7 /dev/disk/by-id/wwn-0x5000cca77fc2b2dc-part7 /dev/disk/by-partuuid/13620ab6-6ef9-4b92-8449-7886beae2045 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part7 /dev/disk/by-uuid/2bc700f3-bc24-479f-b922-a4fb10772aaa
+E: DEVNAME=/dev/sda7
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda/sda7
+E: DEVTYPE=partition
+E: ID_ATA=1
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=1
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_PUIS=1
+E: ID_ATA_FEATURE_SET_PUIS_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ENHANCED_ERASE_UNIT_MIN=94
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=92
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_ROTATION_RATE_RPM=7200
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_BUS=ata
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=2bc700f3-bc24-479f-b922-a4fb10772aaa
+E: ID_FS_UUID_ENC=2bc700f3-bc24-479f-b922-a4fb10772aaa
+E: ID_FS_VERSION=2
+E: ID_MODEL=HGST_HTS725050A7E630
+E: ID_MODEL_ENC=HGST\x20HTS725050A7E630\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=7
+E: ID_PART_ENTRY_OFFSET=502147072
+E: ID_PART_ENTRY_SCHEME=gpt
+E: ID_PART_ENTRY_SIZE=32000000
+E: ID_PART_ENTRY_TYPE=0657fd6d-a4ab-43c4-84e5-0933c84b4f4f
+E: ID_PART_ENTRY_UUID=13620ab6-6ef9-4b92-8449-7886beae2045
+E: ID_PART_TABLE_TYPE=gpt
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=GH2ZB505
+E: ID_SCSI_COMPAT=SATA_HGST_HTS725050A_TF755AWHG5Y15M
+E: ID_SERIAL=HGST_HTS725050A7E630_TF755AWHG5Y15M
+E: ID_SERIAL_SHORT=TF755AWHG5Y15M
+E: ID_TYPE=disk
+E: ID_WWN=0x5000cca77fc2b2dc
+E: ID_WWN_WITH_EXTENSION=0x5000cca77fc2b2dc
+E: MAJOR=8
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: UDISKS_PARTITION_NUMBER=7
+E: UDISKS_PARTITION_OFFSET=257099300864
+E: UDISKS_PARTITION_SCHEME=gpt
+E: UDISKS_PARTITION_SIZE=16384000000
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_TYPE=0657FD6D-A4AB-43C4-84E5-0933C84B4F4F
+E: UDISKS_PARTITION_UUID=13620AB6-6EF9-4B92-8449-7886BEAE2045
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=2380149
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=252
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sr
+E: MODALIAS=scsi:t-0x05
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+N: sr0
+S: cdrom
+S: cdrw
+S: disk/by-id/ata-MATSHITADVD-RAM_UJ8C2_HP23_653601
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: dvd
+S: dvdrw
+E: DEVLINKS=/dev/cdrom /dev/cdrw /dev/disk/by-id/ata-MATSHITADVD-RAM_UJ8C2_HP23_653601 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/dvd /dev/dvdrw
+E: DEVNAME=/dev/sr0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/block/sr0
+E: DEVTYPE=disk
+E: GENERATED=1
+E: ID_ATA=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_BUS=ata
+E: ID_CDROM=1
+E: ID_CDROM_CD=1
+E: ID_CDROM_CD_R=1
+E: ID_CDROM_CD_RW=1
+E: ID_CDROM_DVD=1
+E: ID_CDROM_DVD_PLUS_R=1
+E: ID_CDROM_DVD_PLUS_RW=1
+E: ID_CDROM_DVD_PLUS_R_DL=1
+E: ID_CDROM_DVD_R=1
+E: ID_CDROM_DVD_RAM=1
+E: ID_CDROM_DVD_RW=1
+E: ID_CDROM_MRW=1
+E: ID_CDROM_MRW_W=1
+E: ID_FOR_SEAT=block-pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_MODEL=MATSHITADVD-RAM_UJ8C2
+E: ID_MODEL_ENC=MATSHITADVD-RAM\x20UJ8C2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_REVISION=SB01
+E: ID_SERIAL=MATSHITADVD-RAM_UJ8C2_HP23_653601
+E: ID_SERIAL_SHORT=HP23_653601
+E: ID_TYPE=cd
+E: MAJOR=11
+E: MINOR=0
+E: SUBSYSTEM=block
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: USEC_INITIALIZED=1722053
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+N: bsg/1:0:0:0
+E: DEVNAME=/dev/bsg/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/bsg/1:0:0:0
+E: MAJOR=252
+E: MINOR=1
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_device/1:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+N: sg1
+E: DEVNAME=/dev/sg1
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/host1/target1:0:0/1:0:0:0/scsi_generic/sg1
+E: ID_FOR_SEAT=scsi_generic-pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: MAJOR=21
+E: MINOR=1
+E: SUBSYSTEM=scsi_generic
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14796436
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/ata_port/ata3
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/host2/scsi_host/host2
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/ata_link/link3
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata3/link3/dev3.0/ata_device/dev3.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/ata_port/ata4
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/host3/scsi_host/host3
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/ata_link/link4
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata4/link4/dev4.0/ata_device/dev4.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/ata_port/ata5
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/host4/scsi_host/host4
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/ata_link/link5
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata5/link5/dev5.0/ata_device/dev5.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/ata_port/ata6
+E: SUBSYSTEM=ata_port
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/host5/scsi_host/host5
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/ata_link/link6
+E: SUBSYSTEM=ata_link
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata6/link6/dev6.0/ata_device/dev6.0
+E: SUBSYSTEM=ata_device
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: MODALIAS=pci:v00008086d00001E22sv000017AAsd000021FBbc0Csc05i00
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:1E22
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: PCI_SUBSYS_ID=17AA:21FB
+E: SUBSYSTEM=pci
+E: UDEV_LOG=3
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0
+E: DEVPATH=/devices/platform/coretemp.0
+E: DRIVER=coretemp
+E: MODALIAS=platform:coretemp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/coretemp.0/hwmon/hwmon2
+E: DEVPATH=/devices/platform/coretemp.0/hwmon/hwmon2
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/dock.0
+E: DEVPATH=/devices/platform/dock.0
+E: MODALIAS=platform:dock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dock.1
+E: DEVPATH=/devices/platform/dock.1
+E: MODALIAS=platform:dock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/efifb.0
+E: DEVPATH=/devices/platform/efifb.0
+E: DRIVER=efifb
+E: MODALIAS=platform:efifb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio0
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DMI_VENDOR=LENOVO
+E: DRIVER=atkbd
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=06
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14756829
+
+P: /devices/platform/i8042/serio0/input/input3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3
+E: EV=120013
+E: ID_FOR_SEAT=input-platform-i8042-serio-0
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: KEY=402000000 3803078f800d001 feffffdfffefffff fffffffffffffffe
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB54-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8E,8F,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,D9,E2,ram4,l0,1,2,sfw
+E: MSC=10
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PRODUCT=11/1/1/ab54
+E: PROP=0
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=539614
+
+P: /devices/platform/i8042/serio0/input/input3/event3
+N: input/event3
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DEVNAME=/dev/input/event3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input3/event3
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=67
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=548772
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/platform/i8042/serio1
+E: DEVPATH=/devices/platform/i8042/serio1
+E: DRIVER=psmouse
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=01
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/i8042/serio1/input/input12
+E: ABS=260800011000003
+E: DEVPATH=/devices/platform/i8042/serio1/input/input12
+E: EV=b
+E: ID_FOR_SEAT=input-platform-i8042-serio-1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: KEY=6420 30000 0 0 0 0
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio1/input0"
+E: PRODUCT=11/2/7/1b1
+E: PROP=9
+E: SUBSYSTEM=input
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15691804
+
+P: /devices/platform/i8042/serio1/input/input12/event12
+N: input/event12
+S: input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-event-mouse
+E: DEVNAME=/dev/input/event12
+E: DEVPATH=/devices/platform/i8042/serio1/input/input12/event12
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=76
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15693594
+
+P: /devices/platform/i8042/serio1/input/input12/mouse1
+N: input/mouse1
+S: input/by-path/platform-i8042-serio-1-mouse
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-1-mouse
+E: DEVNAME=/dev/input/mouse1
+E: DEVPATH=/devices/platform/i8042/serio1/input/input12/mouse1
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_PATH=platform-i8042-serio-1
+E: ID_PATH_TAG=platform-i8042-serio-1
+E: ID_SERIAL=noserial
+E: MAJOR=13
+E: MINOR=33
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15693245
+
+P: /devices/platform/i8042/serio1/serio2
+E: DEVPATH=/devices/platform/i8042/serio1/serio2
+E: MODALIAS=serio:ty05pr00id00ex00
+E: SERIO_EXTRA=00
+E: SERIO_ID=00
+E: SERIO_PROTO=00
+E: SERIO_TYPE=05
+E: SUBSYSTEM=serio
+E: UDEV_LOG=3
+
+P: /devices/platform/microcode
+E: DEVPATH=/devices/platform/microcode
+E: MODALIAS=platform:microcode
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/pcspkr
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: DEVNAME=/dev/ttyS0
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=64
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14766907
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: DEVNAME=/dev/ttyS1
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=65
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14767921
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: DEVNAME=/dev/ttyS10
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=74
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14768196
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: DEVNAME=/dev/ttyS11
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=75
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14767935
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: DEVNAME=/dev/ttyS12
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=76
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14757849
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: DEVNAME=/dev/ttyS13
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=77
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14757953
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: DEVNAME=/dev/ttyS14
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=78
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758087
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: DEVNAME=/dev/ttyS15
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=79
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758193
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: DEVNAME=/dev/ttyS16
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=80
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758304
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: DEVNAME=/dev/ttyS17
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=81
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758415
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: DEVNAME=/dev/ttyS18
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=82
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758527
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: DEVNAME=/dev/ttyS19
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=83
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758640
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: DEVNAME=/dev/ttyS2
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=66
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758756
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: DEVNAME=/dev/ttyS20
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=84
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758876
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: DEVNAME=/dev/ttyS21
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=85
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14758995
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: DEVNAME=/dev/ttyS22
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=86
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759117
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: DEVNAME=/dev/ttyS23
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=87
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759238
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: DEVNAME=/dev/ttyS24
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=88
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759364
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: DEVNAME=/dev/ttyS25
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=89
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759490
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: DEVNAME=/dev/ttyS26
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=90
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759615
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: DEVNAME=/dev/ttyS27
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=91
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759746
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: DEVNAME=/dev/ttyS28
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=92
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14759874
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: DEVNAME=/dev/ttyS29
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=93
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760013
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: DEVNAME=/dev/ttyS3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=67
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760148
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: DEVNAME=/dev/ttyS30
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=94
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760261
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: DEVNAME=/dev/ttyS31
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=95
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760378
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: DEVNAME=/dev/ttyS5
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=69
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760494
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: DEVNAME=/dev/ttyS6
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=70
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760612
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: DEVNAME=/dev/ttyS7
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=71
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760733
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: DEVNAME=/dev/ttyS8
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=72
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14760853
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: DEVNAME=/dev/ttyS9
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=73
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14761005
+
+P: /devices/platform/thinkpad_acpi
+E: DEVPATH=/devices/platform/thinkpad_acpi
+E: DRIVER=thinkpad_acpi
+E: MODALIAS=platform:thinkpad_acpi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/input/input9
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input9
+E: EV=33
+E: ID_FOR_SEAT=input-platform-thinkpad_acpi
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: KEY=18040000 0 10000000000000 0 101501b00102004 8000000001104000 e000000000000 0
+E: MODALIAS=input:b0019v17AAp5054e4101-e0,1,4,5,k71,72,73,8E,94,98,BF,C2,CD,D4,E0,E1,E3,E4,EC,EE,F0,F8,174,1D2,1DB,1DC,ram4,lsfw3,
+E: MSC=10
+E: NAME="ThinkPad Extra Buttons"
+E: PHYS="thinkpad_acpi/input0"
+E: PRODUCT=19/17aa/5054/4101
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=8
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14916745
+
+P: /devices/platform/thinkpad_acpi/input/input9/event9
+N: input/event9
+S: input/by-path/platform-thinkpad_acpi-event
+E: DEVLINKS=/dev/input/by-path/platform-thinkpad_acpi-event
+E: DEVNAME=/dev/input/event9
+E: DEVPATH=/devices/platform/thinkpad_acpi/input/input9/event9
+E: DMI_VENDOR=LENOVO
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=13
+E: MINOR=73
+E: SUBSYSTEM=input
+E: TAGS=:power-switch:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14918298
+E: XKBLAYOUT=fr
+E: XKBMODEL=pc105
+E: XKBVARIANT=latin9
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::power
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::standby
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinklight
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: DEVPATH=/devices/platform/thinkpad_acpi/leds/tpacpi::thinkvantage
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/rfkill/rfkill0
+E: DEVPATH=/devices/platform/thinkpad_acpi/rfkill/rfkill0
+E: RFKILL_NAME=tpacpi_bluetooth_sw
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=bluetooth
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/rfkill/rfkill1
+E: DEVPATH=/devices/platform/thinkpad_acpi/rfkill/rfkill1
+E: RFKILL_NAME=tpacpi_wwan_sw
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wwan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_acpi/sound/card29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29
+E: ID_FOR_SEAT=sound-platform-thinkpad_acpi
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: PULSE_IGNORE=1
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: TAGS=:seat:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14915613
+
+P: /devices/platform/thinkpad_acpi/sound/card29/controlC29
+N: snd/controlC29
+S: snd/by-path/platform-thinkpad_acpi
+E: DEVLINKS=/dev/snd/by-path/platform-thinkpad_acpi
+E: DEVNAME=/dev/snd/controlC29
+E: DEVPATH=/devices/platform/thinkpad_acpi/sound/card29/controlC29
+E: ID_PATH=platform-thinkpad_acpi
+E: ID_PATH_TAG=platform-thinkpad_acpi
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14916322
+
+P: /devices/platform/thinkpad_hwmon
+E: DEVPATH=/devices/platform/thinkpad_hwmon
+E: DRIVER=thinkpad_hwmon
+E: MODALIAS=platform:thinkpad_hwmon
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/thinkpad_hwmon/hwmon/hwmon1
+E: DEVPATH=/devices/platform/thinkpad_hwmon/hwmon/hwmon1
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/platform/vboxdrv.0
+E: DEVPATH=/devices/platform/vboxdrv.0
+E: DRIVER=vboxdrv
+E: MODALIAS=platform:vboxdrv
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:00
+E: DEVPATH=/devices/pnp0/00:00
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:01
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:02
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:03
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:04
+E: DEVPATH=/devices/pnp0/00:04
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:05
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:06/rtc/rtc0
+N: rtc0
+S: rtc
+E: DEVLINKS=/dev/rtc
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/pnp0/00:06/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=543189
+
+P: /devices/pnp0/00:07
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:08
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=tpm_tis
+E: SUBSYSTEM=pnp
+E: UDEV_LOG=3
+
+P: /devices/pnp0/00:09/misc/tpm0
+N: tpm0
+E: DEVNAME=/dev/tpm0
+E: DEVPATH=/devices/pnp0/00:09/misc/tpm0
+E: MAJOR=10
+E: MINOR=224
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu2
+E: DEVPATH=/devices/system/cpu/cpu2
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu3
+E: DEVPATH=/devices/system/cpu/cpu3
+E: MODALIAS=x86cpu:vendor:0000:family:0006:model:003A:feature:,0000,0001,0002,0003,0004,0005,0006,0007,0008,0009,000B,000C,000D,000E,000F,0010,0011,0013,0015,0016,0017,0018,0019,001A,001B,001C,001D,001F,002B,0034,003B,003D,0068,006B,006C,006D,006F,0070,0072,0074,0076,0078,007C,007D,0080,0081,0082,0083,0084,0085,0086,0087,0088,0089,008D,008E,008F,0091,0093,0094,0095,0097,0098,0099,009A,009B,009C,009D,009E,00C0,00E0,00E1,00E3,00E4,00E5,00E6,00E7,0100,0101,0102,0103,0104,0120,0127,0129
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck0
+E: DEVPATH=/devices/system/machinecheck/machinecheck0
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck1
+E: DEVPATH=/devices/system/machinecheck/machinecheck1
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck2
+E: DEVPATH=/devices/system/machinecheck/machinecheck2
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/machinecheck/machinecheck3
+E: DEVPATH=/devices/system/machinecheck/machinecheck3
+E: SUBSYSTEM=machinecheck
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory0
+E: DEVPATH=/devices/system/memory/memory0
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory1
+E: DEVPATH=/devices/system/memory/memory1
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory10
+E: DEVPATH=/devices/system/memory/memory10
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory100
+E: DEVPATH=/devices/system/memory/memory100
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory101
+E: DEVPATH=/devices/system/memory/memory101
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory102
+E: DEVPATH=/devices/system/memory/memory102
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory103
+E: DEVPATH=/devices/system/memory/memory103
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory104
+E: DEVPATH=/devices/system/memory/memory104
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory105
+E: DEVPATH=/devices/system/memory/memory105
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory106
+E: DEVPATH=/devices/system/memory/memory106
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory107
+E: DEVPATH=/devices/system/memory/memory107
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory108
+E: DEVPATH=/devices/system/memory/memory108
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory109
+E: DEVPATH=/devices/system/memory/memory109
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory11
+E: DEVPATH=/devices/system/memory/memory11
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory110
+E: DEVPATH=/devices/system/memory/memory110
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory111
+E: DEVPATH=/devices/system/memory/memory111
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory112
+E: DEVPATH=/devices/system/memory/memory112
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory113
+E: DEVPATH=/devices/system/memory/memory113
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory114
+E: DEVPATH=/devices/system/memory/memory114
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory115
+E: DEVPATH=/devices/system/memory/memory115
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory116
+E: DEVPATH=/devices/system/memory/memory116
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory117
+E: DEVPATH=/devices/system/memory/memory117
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory118
+E: DEVPATH=/devices/system/memory/memory118
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory119
+E: DEVPATH=/devices/system/memory/memory119
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory12
+E: DEVPATH=/devices/system/memory/memory12
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory120
+E: DEVPATH=/devices/system/memory/memory120
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory121
+E: DEVPATH=/devices/system/memory/memory121
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory122
+E: DEVPATH=/devices/system/memory/memory122
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory123
+E: DEVPATH=/devices/system/memory/memory123
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory124
+E: DEVPATH=/devices/system/memory/memory124
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory125
+E: DEVPATH=/devices/system/memory/memory125
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory126
+E: DEVPATH=/devices/system/memory/memory126
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory127
+E: DEVPATH=/devices/system/memory/memory127
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory128
+E: DEVPATH=/devices/system/memory/memory128
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory129
+E: DEVPATH=/devices/system/memory/memory129
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory13
+E: DEVPATH=/devices/system/memory/memory13
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory130
+E: DEVPATH=/devices/system/memory/memory130
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory131
+E: DEVPATH=/devices/system/memory/memory131
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory132
+E: DEVPATH=/devices/system/memory/memory132
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory133
+E: DEVPATH=/devices/system/memory/memory133
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory134
+E: DEVPATH=/devices/system/memory/memory134
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory135
+E: DEVPATH=/devices/system/memory/memory135
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory14
+E: DEVPATH=/devices/system/memory/memory14
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory15
+E: DEVPATH=/devices/system/memory/memory15
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory16
+E: DEVPATH=/devices/system/memory/memory16
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory17
+E: DEVPATH=/devices/system/memory/memory17
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory18
+E: DEVPATH=/devices/system/memory/memory18
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory19
+E: DEVPATH=/devices/system/memory/memory19
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory2
+E: DEVPATH=/devices/system/memory/memory2
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory20
+E: DEVPATH=/devices/system/memory/memory20
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory21
+E: DEVPATH=/devices/system/memory/memory21
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory22
+E: DEVPATH=/devices/system/memory/memory22
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory23
+E: DEVPATH=/devices/system/memory/memory23
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory3
+E: DEVPATH=/devices/system/memory/memory3
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory32
+E: DEVPATH=/devices/system/memory/memory32
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory33
+E: DEVPATH=/devices/system/memory/memory33
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory34
+E: DEVPATH=/devices/system/memory/memory34
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory35
+E: DEVPATH=/devices/system/memory/memory35
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory36
+E: DEVPATH=/devices/system/memory/memory36
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory37
+E: DEVPATH=/devices/system/memory/memory37
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory38
+E: DEVPATH=/devices/system/memory/memory38
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory39
+E: DEVPATH=/devices/system/memory/memory39
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory4
+E: DEVPATH=/devices/system/memory/memory4
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory40
+E: DEVPATH=/devices/system/memory/memory40
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory41
+E: DEVPATH=/devices/system/memory/memory41
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory42
+E: DEVPATH=/devices/system/memory/memory42
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory43
+E: DEVPATH=/devices/system/memory/memory43
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory44
+E: DEVPATH=/devices/system/memory/memory44
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory45
+E: DEVPATH=/devices/system/memory/memory45
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory46
+E: DEVPATH=/devices/system/memory/memory46
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory47
+E: DEVPATH=/devices/system/memory/memory47
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory48
+E: DEVPATH=/devices/system/memory/memory48
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory49
+E: DEVPATH=/devices/system/memory/memory49
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory5
+E: DEVPATH=/devices/system/memory/memory5
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory50
+E: DEVPATH=/devices/system/memory/memory50
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory51
+E: DEVPATH=/devices/system/memory/memory51
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory52
+E: DEVPATH=/devices/system/memory/memory52
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory53
+E: DEVPATH=/devices/system/memory/memory53
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory54
+E: DEVPATH=/devices/system/memory/memory54
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory55
+E: DEVPATH=/devices/system/memory/memory55
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory56
+E: DEVPATH=/devices/system/memory/memory56
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory57
+E: DEVPATH=/devices/system/memory/memory57
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory58
+E: DEVPATH=/devices/system/memory/memory58
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory59
+E: DEVPATH=/devices/system/memory/memory59
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory6
+E: DEVPATH=/devices/system/memory/memory6
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory60
+E: DEVPATH=/devices/system/memory/memory60
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory61
+E: DEVPATH=/devices/system/memory/memory61
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory62
+E: DEVPATH=/devices/system/memory/memory62
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory63
+E: DEVPATH=/devices/system/memory/memory63
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory64
+E: DEVPATH=/devices/system/memory/memory64
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory65
+E: DEVPATH=/devices/system/memory/memory65
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory66
+E: DEVPATH=/devices/system/memory/memory66
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory67
+E: DEVPATH=/devices/system/memory/memory67
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory68
+E: DEVPATH=/devices/system/memory/memory68
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory69
+E: DEVPATH=/devices/system/memory/memory69
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory7
+E: DEVPATH=/devices/system/memory/memory7
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory70
+E: DEVPATH=/devices/system/memory/memory70
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory71
+E: DEVPATH=/devices/system/memory/memory71
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory72
+E: DEVPATH=/devices/system/memory/memory72
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory73
+E: DEVPATH=/devices/system/memory/memory73
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory74
+E: DEVPATH=/devices/system/memory/memory74
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory75
+E: DEVPATH=/devices/system/memory/memory75
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory76
+E: DEVPATH=/devices/system/memory/memory76
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory77
+E: DEVPATH=/devices/system/memory/memory77
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory78
+E: DEVPATH=/devices/system/memory/memory78
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory79
+E: DEVPATH=/devices/system/memory/memory79
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory8
+E: DEVPATH=/devices/system/memory/memory8
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory80
+E: DEVPATH=/devices/system/memory/memory80
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory81
+E: DEVPATH=/devices/system/memory/memory81
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory82
+E: DEVPATH=/devices/system/memory/memory82
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory83
+E: DEVPATH=/devices/system/memory/memory83
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory84
+E: DEVPATH=/devices/system/memory/memory84
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory85
+E: DEVPATH=/devices/system/memory/memory85
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory86
+E: DEVPATH=/devices/system/memory/memory86
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory87
+E: DEVPATH=/devices/system/memory/memory87
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory88
+E: DEVPATH=/devices/system/memory/memory88
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory89
+E: DEVPATH=/devices/system/memory/memory89
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory9
+E: DEVPATH=/devices/system/memory/memory9
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory90
+E: DEVPATH=/devices/system/memory/memory90
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory91
+E: DEVPATH=/devices/system/memory/memory91
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory92
+E: DEVPATH=/devices/system/memory/memory92
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory93
+E: DEVPATH=/devices/system/memory/memory93
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory94
+E: DEVPATH=/devices/system/memory/memory94
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory95
+E: DEVPATH=/devices/system/memory/memory95
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory96
+E: DEVPATH=/devices/system/memory/memory96
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory97
+E: DEVPATH=/devices/system/memory/memory97
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory98
+E: DEVPATH=/devices/system/memory/memory98
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/memory/memory99
+E: DEVPATH=/devices/system/memory/memory99
+E: SUBSYSTEM=memory
+E: UDEV_LOG=3
+
+P: /devices/system/node/node0
+E: DEVPATH=/devices/system/node/node0
+E: SUBSYSTEM=node
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/uncore_cbox_0
+E: DEVPATH=/devices/uncore_cbox_0
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/uncore_cbox_1
+E: DEVPATH=/devices/uncore_cbox_1
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:22
+E: DEVPATH=/devices/virtual/bdi/0:22
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/11:0
+E: DEVPATH=/devices/virtual/bdi/11:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494211
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494305
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494388
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494473
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494559
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494648
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494738
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_PRESENTATION_NOPOLICY=1
+E: USEC_INITIALIZED=494825
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=494910
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=494995
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495085
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495171
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=499980
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495309
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495396
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495498
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495593
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=495686
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=496968
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=507384
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=508555
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=508554
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=507541
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=508690
+
+P: /devices/virtual/dmi/id
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnLENOVO:bvrG7ET92WW(2.52):bd02/18/2013:svnLENOVO:pn2355CTO:pvrThinkPadT430s:rvnLENOVO:rn2355CTO:rvrWin8STDDPKTPG:cvnLENOVO:ct10:cvrNotAvailable:
+E: SUBSYSTEM=dmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/hwmon/hwmon0
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/port
+N: port
+E: DEVNAME=/dev/port
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/alarm
+N: alarm
+E: DEVNAME=/dev/alarm
+E: DEVPATH=/devices/virtual/misc/alarm
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ashmem
+N: ashmem
+E: DEVNAME=/dev/ashmem
+E: DEVPATH=/devices/virtual/misc/ashmem
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/binder
+N: binder
+E: DEVNAME=/dev/binder
+E: DEVPATH=/devices/virtual/misc/binder
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=57
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: DEVNAME=/dev/hpet
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/kvm
+N: kvm
+E: DEVNAME=/dev/kvm
+E: DEVPATH=/devices/virtual/misc/kvm
+E: MAJOR=10
+E: MINOR=232
+E: SUBSYSTEM=misc
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=15021616
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: DEVNAME=/dev/mcelog
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/mei
+N: mei
+E: DEVNAME=/dev/mei
+E: DEVPATH=/devices/virtual/misc/mei
+E: MAJOR=10
+E: MINOR=54
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/microcode
+N: cpu/microcode
+E: DEVNAME=/dev/cpu/microcode
+E: DEVPATH=/devices/virtual/misc/microcode
+E: MAJOR=10
+E: MINOR=184
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=56
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=55
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/nvram
+N: nvram
+E: DEVNAME=/dev/nvram
+E: DEVPATH=/devices/virtual/misc/nvram
+E: MAJOR=10
+E: MINOR=144
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: TAGS=:seat:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14832198
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: DEVNAME=/dev/snapshot
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vboxdrv
+N: vboxdrv
+E: DEVNAME=/dev/vboxdrv
+E: DEVPATH=/devices/virtual/misc/vboxdrv
+E: MAJOR=10
+E: MINOR=53
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vboxnetctl
+N: vboxnetctl
+E: DEVNAME=/dev/vboxnetctl
+E: DEVPATH=/devices/virtual/misc/vboxnetctl
+E: MAJOR=10
+E: MINOR=52
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: DEVNAME=/dev/vga_arbiter
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/watchdog
+N: watchdog
+E: DEVNAME=/dev/watchdog
+E: DEVPATH=/devices/virtual/misc/watchdog
+E: MAJOR=10
+E: MINOR=130
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14833048
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: DEVNAME=/dev/snd/seq
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14901584
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:uaccess:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14900698
+
+P: /devices/virtual/thermal/cooling_device0
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device1
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device2
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device3
+E: DEVPATH=/devices/virtual/thermal/cooling_device3
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/cooling_device4
+E: DEVPATH=/devices/virtual/thermal/cooling_device4
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/thermal/thermal_zone0
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+E: UDEV_LOG=3
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14834047
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14834154
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14834232
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14834546
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14834671
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14834727
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14835006
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14835087
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14835399
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14835664
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14835929
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14836394
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14836822
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14837094
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14837364
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14837627
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14837984
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14838246
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14838505
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14838807
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14838928
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14838995
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14839252
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14839356
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14839406
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14839665
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14839727
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14839818
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14840081
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14840164
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14840488
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14840915
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14844015
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14844392
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14853226
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14853014
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14844658
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14844946
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14845216
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14845404
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14845283
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14845283
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14845842
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14845999
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14846025
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14846351
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14846714
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14847102
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14847616
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14847999
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14848332
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14848707
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14848996
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14849282
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14849700
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14850152
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14853719
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14850567
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14850834
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14851056
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14852659
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14851437
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14851520
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14851773
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14851875
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14852128
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14852401
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=14854137
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/watchdog/watchdog0
+N: watchdog0
+E: DEVNAME=/dev/watchdog0
+E: DEVPATH=/devices/virtual/watchdog/watchdog0
+E: MAJOR=253
+E: MINOR=0
+E: SUBSYSTEM=watchdog
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: DEVPATH=/devices/virtual/wmi/05901221-D566-11D1-B2F0-00A0C9062910
+E: MODALIAS=wmi:05901221-D566-11D1-B2F0-00A0C9062910
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/2651D9FD-911C-4B69-B94E-D0DED5963BD7
+E: DEVPATH=/devices/virtual/wmi/2651D9FD-911C-4B69-B94E-D0DED5963BD7
+E: MODALIAS=wmi:2651D9FD-911C-4B69-B94E-D0DED5963BD7
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/51F5230E-9677-46CD-A1CF-C0B23EE34DB7
+E: DEVPATH=/devices/virtual/wmi/51F5230E-9677-46CD-A1CF-C0B23EE34DB7
+E: MODALIAS=wmi:51F5230E-9677-46CD-A1CF-C0B23EE34DB7
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3
+E: DEVPATH=/devices/virtual/wmi/6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3
+E: MODALIAS=wmi:6A4B54EF-A5ED-4D33-9455-B0D9B48DF4B3
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/7364651A-132F-4FE7-ADAA-40C6C7EE2E3B
+E: DEVPATH=/devices/virtual/wmi/7364651A-132F-4FE7-ADAA-40C6C7EE2E3B
+E: MODALIAS=wmi:7364651A-132F-4FE7-ADAA-40C6C7EE2E3B
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/7430019A-DCE9-4548-BAB0-9FDE0935CAFF
+E: DEVPATH=/devices/virtual/wmi/7430019A-DCE9-4548-BAB0-9FDE0935CAFF
+E: MODALIAS=wmi:7430019A-DCE9-4548-BAB0-9FDE0935CAFF
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/74F1EBB6-927A-4C7D-95DF-698E21E80EB5
+E: DEVPATH=/devices/virtual/wmi/74F1EBB6-927A-4C7D-95DF-698E21E80EB5
+E: MODALIAS=wmi:74F1EBB6-927A-4C7D-95DF-698E21E80EB5
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/7EEF04FF-4328-447C-B5BB-D449925D538D
+E: DEVPATH=/devices/virtual/wmi/7EEF04FF-4328-447C-B5BB-D449925D538D
+E: MODALIAS=wmi:7EEF04FF-4328-447C-B5BB-D449925D538D
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/7FF47003-3B6C-4E5E-A227-E979824A85D1
+E: DEVPATH=/devices/virtual/wmi/7FF47003-3B6C-4E5E-A227-E979824A85D1
+E: MODALIAS=wmi:7FF47003-3B6C-4E5E-A227-E979824A85D1
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/8ADB159E-1E32-455C-BC93-308A7ED98246
+E: DEVPATH=/devices/virtual/wmi/8ADB159E-1E32-455C-BC93-308A7ED98246
+E: MODALIAS=wmi:8ADB159E-1E32-455C-BC93-308A7ED98246
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/98479A64-33F5-4E33-A707-8E251EBBC3A1
+E: DEVPATH=/devices/virtual/wmi/98479A64-33F5-4E33-A707-8E251EBBC3A1
+E: MODALIAS=wmi:98479A64-33F5-4E33-A707-8E251EBBC3A1
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: DEVPATH=/devices/virtual/wmi/E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: MODALIAS=wmi:E2BE5EE3-42DA-49DB-8378-1F5247388202
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+
+P: /devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: DEVPATH=/devices/virtual/wmi/FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: MODALIAS=wmi:FCB424F1-075A-4E0E-BFC4-62F3E71771FA
+E: SUBSYSTEM=wmi
+E: UDEV_LOG=3
+

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/PANDABOARD.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/PANDABOARD.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/PANDABOARD.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,4237 @@
+P: /devices/breakpoint
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/cpu
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/fixed-0
+E: SUBSYSTEM=mdio_bus
+E: UDEV_LOG=3
+
+P: /devices/platform/aess
+E: DEVPATH=/devices/platform/aess
+E: DRIVER=aess
+E: MODALIAS=platform:aess
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/alarmtimer
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/btwilink
+E: DEVPATH=/devices/platform/btwilink
+E: MODALIAS=platform:btwilink
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dmic-codec.0
+E: DEVPATH=/devices/platform/dmic-codec.0
+E: DRIVER=dmic-codec
+E: MODALIAS=platform:dmic-codec
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dmic-codec.1
+E: DEVPATH=/devices/platform/dmic-codec.1
+E: DRIVER=dmic-codec
+E: MODALIAS=platform:dmic-codec
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dmic-codec.2
+E: DEVPATH=/devices/platform/dmic-codec.2
+E: DRIVER=dmic-codec
+E: MODALIAS=platform:dmic-codec
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dmm
+E: DEVPATH=/devices/platform/dmm
+E: DRIVER=dmm
+E: MODALIAS=platform:dmm
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/dsp.0
+E: DEVPATH=/devices/platform/dsp.0
+E: MODALIAS=platform:dsp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/emif.1
+E: DEVPATH=/devices/platform/emif.1
+E: DRIVER=emif
+E: MODALIAS=platform:emif
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/emif.2
+E: DEVPATH=/devices/platform/emif.2
+E: DRIVER=emif
+E: MODALIAS=platform:emif
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/fdif
+E: DEVPATH=/devices/platform/fdif
+E: ID_DRIVE_FLOPPY=1
+E: MODALIAS=platform:fdif
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53192169
+
+P: /devices/platform/gpio-keys
+E: DEVPATH=/devices/platform/gpio-keys
+E: DRIVER=gpio-keys
+E: MODALIAS=platform:gpio-keys
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/gpio-keys/input/input1
+E: DEVPATH=/devices/platform/gpio-keys/input/input1
+E: EV=3
+E: ID_INPUT=1
+E: ID_PATH=platform-gpio-keys
+E: ID_PATH_TAG=platform-gpio-keys
+E: KEY=100000 0 0 0 0 0 0 0 0
+E: MODALIAS=input:b0019v0001p0001e0100-e0,1,k114,ramlsfw
+E: NAME="gpio-keys"
+E: PHYS="gpio-keys/input0"
+E: PRODUCT=19/1/1/100
+E: PROP=0
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=55074218
+
+P: /devices/platform/gpio-keys/input/input1/event1
+N: input/event1
+S: input/by-path/platform-gpio-keys-event
+E: DEVLINKS=/dev/input/by-path/platform-gpio-keys-event
+E: DEVNAME=/dev/input/event1
+E: DEVPATH=/devices/platform/gpio-keys/input/input1/event1
+E: ID_INPUT=1
+E: ID_PATH=platform-gpio-keys
+E: ID_PATH_TAG=platform-gpio-keys
+E: MAJOR=13
+E: MINOR=65
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=55204711
+
+P: /devices/platform/hdmi-audio-codec
+E: DEVPATH=/devices/platform/hdmi-audio-codec
+E: DRIVER=hdmi-audio-codec
+E: MODALIAS=platform:hdmi-audio-codec
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/iss
+E: DEVPATH=/devices/platform/iss
+E: MODALIAS=platform:iss
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/iva.0
+E: DEVPATH=/devices/platform/iva.0
+E: MODALIAS=platform:iva
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/kim
+E: DEVPATH=/devices/platform/kim
+E: DRIVER=kim
+E: MODALIAS=platform:kim
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/l3_main_1.0
+E: DEVPATH=/devices/platform/l3_main_1.0
+E: MODALIAS=platform:l3_main_1
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/leds-gpio
+E: DEVPATH=/devices/platform/leds-gpio
+E: DRIVER=leds-gpio
+E: MODALIAS=platform:leds-gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/leds-gpio/leds/pandaboard::status1
+E: DEVPATH=/devices/platform/leds-gpio/leds/pandaboard::status1
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/leds-gpio/leds/pandaboard::status2
+E: DEVPATH=/devices/platform/leds-gpio/leds/pandaboard::status2
+E: SUBSYSTEM=leds
+E: UDEV_LOG=3
+
+P: /devices/platform/mpu.0
+E: DEVPATH=/devices/platform/mpu.0
+E: MODALIAS=platform:mpu
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/musb-omap2430
+E: DEVPATH=/devices/platform/musb-omap2430
+E: MODALIAS=platform:musb-omap2430
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-abe-twl6040
+E: DEVPATH=/devices/platform/omap-abe-twl6040
+E: DRIVER=omap-abe-twl6040
+E: MODALIAS=platform:omap-abe-twl6040
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-abe-twl6040/sound/card0
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0
+E: ID_PATH=platform-omap-abe-twl6040
+E: ID_PATH_TAG=platform-omap-abe-twl6040
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=55430847
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/input0
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/input0
+E: EV=21
+E: ID_INPUT=1
+E: ID_PATH=platform-omap-abe-twl6040
+E: ID_PATH_TAG=platform-omap-abe-twl6040
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,4,
+E: NAME="PandaBoard Headset Jack"
+E: PHYS="ALSA"
+E: PRODUCT=0/0/0/0
+E: PROP=0
+E: SUBSYSTEM=input
+E: SW=14
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1970886
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/input0/event0
+N: input/event0
+S: input/by-path/platform-omap-abe-twl6040-event
+E: DEVLINKS=/dev/input/by-path/platform-omap-abe-twl6040-event
+E: DEVNAME=/dev/input/event0
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/input0/event0
+E: ID_INPUT=1
+E: ID_PATH=platform-omap-abe-twl6040
+E: ID_PATH_TAG=platform-omap-abe-twl6040
+E: MAJOR=13
+E: MINOR=64
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1996490
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=13
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53258026
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=12
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53261230
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D1c
+N: snd/pcmC0D1c
+E: DEVNAME=/dev/snd/pcmC0D1c
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D1c
+E: MAJOR=116
+E: MINOR=11
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53264373
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D2c
+N: snd/pcmC0D2c
+E: DEVNAME=/dev/snd/pcmC0D2c
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D2c
+E: MAJOR=116
+E: MINOR=10
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53213714
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D2p
+N: snd/pcmC0D2p
+E: DEVNAME=/dev/snd/pcmC0D2p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D2p
+E: MAJOR=116
+E: MINOR=9
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53213806
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D3p
+N: snd/pcmC0D3p
+E: DEVNAME=/dev/snd/pcmC0D3p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D3p
+E: MAJOR=116
+E: MINOR=8
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53213897
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D4p
+N: snd/pcmC0D4p
+E: DEVNAME=/dev/snd/pcmC0D4p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D4p
+E: MAJOR=116
+E: MINOR=7
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53213958
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D5c
+N: snd/pcmC0D5c
+E: DEVNAME=/dev/snd/pcmC0D5c
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D5c
+E: MAJOR=116
+E: MINOR=6
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53214050
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D5p
+N: snd/pcmC0D5p
+E: DEVNAME=/dev/snd/pcmC0D5p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D5p
+E: MAJOR=116
+E: MINOR=5
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53214141
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D6p
+N: snd/pcmC0D6p
+E: DEVNAME=/dev/snd/pcmC0D6p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D6p
+E: MAJOR=116
+E: MINOR=4
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53214233
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D8c
+N: snd/pcmC0D8c
+E: DEVNAME=/dev/snd/pcmC0D8c
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D8c
+E: MAJOR=116
+E: MINOR=3
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53214355
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/pcmC0D8p
+N: snd/pcmC0D8p
+E: DEVNAME=/dev/snd/pcmC0D8p
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/pcmC0D8p
+E: MAJOR=116
+E: MINOR=2
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53214416
+
+P: /devices/platform/omap-abe-twl6040/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/platform-omap-abe-twl6040
+E: DEVLINKS=/dev/snd/by-path/platform-omap-abe-twl6040
+E: DEVNAME=/dev/snd/controlC0
+E: DEVPATH=/devices/platform/omap-abe-twl6040/sound/card0/controlC0
+E: ID_PATH=platform-omap-abe-twl6040
+E: ID_PATH_TAG=platform-omap-abe-twl6040
+E: MAJOR=116
+E: MINOR=14
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53214508
+
+P: /devices/platform/omap-dmic
+E: DEVPATH=/devices/platform/omap-dmic
+E: DRIVER=omap-dmic
+E: MODALIAS=platform:omap-dmic
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-hdmi-audio
+E: DEVPATH=/devices/platform/omap-hdmi-audio
+E: DRIVER=omap-hdmi-audio
+E: MODALIAS=platform:omap-hdmi-audio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-hdmi-audio-dai
+E: DEVPATH=/devices/platform/omap-hdmi-audio-dai
+E: DRIVER=omap-hdmi-audio-dai
+E: MODALIAS=platform:omap-hdmi-audio-dai
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-hdmi-audio/sound/card1
+E: DEVPATH=/devices/platform/omap-hdmi-audio/sound/card1
+E: ID_PATH=platform-omap-hdmi-audio
+E: ID_PATH_TAG=platform-omap-hdmi-audio
+E: SOUND_INITIALIZED=1
+E: SUBSYSTEM=sound
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=55420501
+
+P: /devices/platform/omap-hdmi-audio/sound/card1/pcmC1D0p
+N: snd/pcmC1D0p
+E: DEVNAME=/dev/snd/pcmC1D0p
+E: DEVPATH=/devices/platform/omap-hdmi-audio/sound/card1/pcmC1D0p
+E: MAJOR=116
+E: MINOR=15
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53217071
+
+P: /devices/platform/omap-hdmi-audio/sound/card1/controlC1
+N: snd/controlC1
+S: snd/by-path/platform-omap-hdmi-audio
+E: DEVLINKS=/dev/snd/by-path/platform-omap-hdmi-audio
+E: DEVNAME=/dev/snd/controlC1
+E: DEVPATH=/devices/platform/omap-hdmi-audio/sound/card1/controlC1
+E: ID_PATH=platform-omap-hdmi-audio
+E: ID_PATH_TAG=platform-omap-hdmi-audio
+E: MAJOR=116
+E: MINOR=16
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53217163
+
+P: /devices/platform/omap-iommu.0
+E: DEVPATH=/devices/platform/omap-iommu.0
+E: DRIVER=omap-iommu
+E: MODALIAS=platform:omap-iommu
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-iommu.1
+E: DEVPATH=/devices/platform/omap-iommu.1
+E: DRIVER=omap-iommu
+E: MODALIAS=platform:omap-iommu
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mailbox
+E: DEVPATH=/devices/platform/omap-mailbox
+E: DRIVER=omap-mailbox
+E: MODALIAS=platform:omap-mailbox
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mailbox/mbox/mailbox-1
+E: DEVPATH=/devices/platform/omap-mailbox/mbox/mailbox-1
+E: SUBSYSTEM=mbox
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mailbox/mbox/mailbox-2
+E: DEVPATH=/devices/platform/omap-mailbox/mbox/mailbox-2
+E: SUBSYSTEM=mbox
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp-dai.0
+E: DEVPATH=/devices/platform/omap-mcbsp-dai.0
+E: MODALIAS=platform:omap-mcbsp-dai
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp-dai.1
+E: DEVPATH=/devices/platform/omap-mcbsp-dai.1
+E: MODALIAS=platform:omap-mcbsp-dai
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp-dai.2
+E: DEVPATH=/devices/platform/omap-mcbsp-dai.2
+E: MODALIAS=platform:omap-mcbsp-dai
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp-dai.3
+E: DEVPATH=/devices/platform/omap-mcbsp-dai.3
+E: MODALIAS=platform:omap-mcbsp-dai
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp.1
+E: DEVPATH=/devices/platform/omap-mcbsp.1
+E: DRIVER=omap-mcbsp
+E: MODALIAS=platform:omap-mcbsp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp.2
+E: DEVPATH=/devices/platform/omap-mcbsp.2
+E: DRIVER=omap-mcbsp
+E: MODALIAS=platform:omap-mcbsp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp.3
+E: DEVPATH=/devices/platform/omap-mcbsp.3
+E: DRIVER=omap-mcbsp
+E: MODALIAS=platform:omap-mcbsp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcbsp.4
+E: DEVPATH=/devices/platform/omap-mcbsp.4
+E: DRIVER=omap-mcbsp
+E: MODALIAS=platform:omap-mcbsp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-mcpdm
+E: DEVPATH=/devices/platform/omap-mcpdm
+E: DRIVER=omap-mcpdm
+E: MODALIAS=platform:omap-mcpdm
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap-pcm-audio
+E: DEVPATH=/devices/platform/omap-pcm-audio
+E: DRIVER=omap-pcm-audio
+E: MODALIAS=platform:omap-pcm-audio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.1
+E: DEVPATH=/devices/platform/omap2_mcspi.1
+E: DRIVER=omap2_mcspi
+E: MODALIAS=platform:omap2_mcspi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.1/spi_master/spi1
+E: DEVPATH=/devices/platform/omap2_mcspi.1/spi_master/spi1
+E: SUBSYSTEM=spi_master
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.2
+E: DEVPATH=/devices/platform/omap2_mcspi.2
+E: DRIVER=omap2_mcspi
+E: MODALIAS=platform:omap2_mcspi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.2/spi_master/spi2
+E: DEVPATH=/devices/platform/omap2_mcspi.2/spi_master/spi2
+E: SUBSYSTEM=spi_master
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.3
+E: DEVPATH=/devices/platform/omap2_mcspi.3
+E: DRIVER=omap2_mcspi
+E: MODALIAS=platform:omap2_mcspi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.3/spi_master/spi3
+E: DEVPATH=/devices/platform/omap2_mcspi.3/spi_master/spi3
+E: SUBSYSTEM=spi_master
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.4
+E: DEVPATH=/devices/platform/omap2_mcspi.4
+E: DRIVER=omap2_mcspi
+E: MODALIAS=platform:omap2_mcspi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap2_mcspi.4/spi_master/spi4
+E: DEVPATH=/devices/platform/omap2_mcspi.4/spi_master/spi4
+E: SUBSYSTEM=spi_master
+E: UDEV_LOG=3
+
+P: /devices/platform/omap3isp
+E: DEVPATH=/devices/platform/omap3isp
+E: MODALIAS=platform:omap3isp
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap4plus_scm.0
+E: DEVPATH=/devices/platform/omap4plus_scm.0
+E: DRIVER=omap4plus_scm
+E: MODALIAS=platform:omap4plus_scm
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_dma_system.0
+E: DEVPATH=/devices/platform/omap_dma_system.0
+E: DRIVER=omap_dma_system
+E: MODALIAS=platform:omap_dma_system
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_gpio.0
+E: DEVPATH=/devices/platform/omap_gpio.0
+E: DRIVER=omap_gpio
+E: MODALIAS=platform:omap_gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_gpio.1
+E: DEVPATH=/devices/platform/omap_gpio.1
+E: DRIVER=omap_gpio
+E: MODALIAS=platform:omap_gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_gpio.2
+E: DEVPATH=/devices/platform/omap_gpio.2
+E: DRIVER=omap_gpio
+E: MODALIAS=platform:omap_gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_gpio.3
+E: DEVPATH=/devices/platform/omap_gpio.3
+E: DRIVER=omap_gpio
+E: MODALIAS=platform:omap_gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_gpio.4
+E: DEVPATH=/devices/platform/omap_gpio.4
+E: DRIVER=omap_gpio
+E: MODALIAS=platform:omap_gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_gpio.5
+E: DEVPATH=/devices/platform/omap_gpio.5
+E: DRIVER=omap_gpio
+E: MODALIAS=platform:omap_gpio
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.0
+E: DEVPATH=/devices/platform/omap_hsmmc.0
+E: DRIVER=omap_hsmmc
+E: MODALIAS=platform:omap_hsmmc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.0/mmc_host/mmc0
+E: DEVPATH=/devices/platform/omap_hsmmc.0/mmc_host/mmc0
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007
+E: DEVPATH=/devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007
+E: DRIVER=mmcblk
+E: MMC_NAME=SD8GB
+E: MMC_TYPE=SD
+E: MODALIAS=mmc:block
+E: SUBSYSTEM=mmc
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007/block/mmcblk0
+N: mmcblk0
+S: disk/by-id/mmc-SD8GB_0x7cc85d1e
+S: disk/by-path/platform-omap_hsmmc.0
+E: DEVLINKS=/dev/disk/by-id/mmc-SD8GB_0x7cc85d1e /dev/disk/by-path/platform-omap_hsmmc.0
+E: DEVNAME=/dev/mmcblk0
+E: DEVPATH=/devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007/block/mmcblk0
+E: DEVTYPE=disk
+E: ID_DRIVE_FLASH_SD=1
+E: ID_DRIVE_MEDIA_FLASH_SD=1
+E: ID_NAME=SD8GB
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-omap_hsmmc.0
+E: ID_PATH_TAG=platform-omap_hsmmc_0
+E: ID_SERIAL=0x7cc85d1e
+E: MAJOR=179
+E: MINOR=0
+E: NPARTS=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1691284
+
+P: /devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007/block/mmcblk0/mmcblk0p1
+N: mmcblk0p1
+S: disk/by-id/mmc-SD8GB_0x7cc85d1e-part1
+S: disk/by-label/SERVICEV001
+S: disk/by-path/platform-omap_hsmmc.0-part1
+S: disk/by-uuid/C95C-57D4
+E: DEVLINKS=/dev/disk/by-id/mmc-SD8GB_0x7cc85d1e-part1 /dev/disk/by-label/SERVICEV001 /dev/disk/by-path/platform-omap_hsmmc.0-part1 /dev/disk/by-uuid/C95C-57D4
+E: DEVNAME=/dev/mmcblk0p1
+E: DEVPATH=/devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007/block/mmcblk0/mmcblk0p1
+E: DEVTYPE=partition
+E: ID_DRIVE_FLASH_SD=1
+E: ID_DRIVE_MEDIA_FLASH_SD=1
+E: ID_FS_LABEL=SERVICEV001
+E: ID_FS_LABEL_ENC=SERVICEV001
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=C95C-57D4
+E: ID_FS_UUID_ENC=C95C-57D4
+E: ID_FS_VERSION=FAT32
+E: ID_NAME=SD8GB
+E: ID_PART_ENTRY_DISK=179:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=32
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=147424
+E: ID_PART_ENTRY_TYPE=0xc
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-omap_hsmmc.0
+E: ID_PATH_TAG=platform-omap_hsmmc_0
+E: ID_SERIAL=0x7cc85d1e
+E: MAJOR=179
+E: MINOR=1
+E: PARTN=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: UDISKS_IGNORE=1
+E: USEC_INITIALIZED=2207000
+
+P: /devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007/block/mmcblk0/mmcblk0p2
+N: mmcblk0p2
+S: disk/by-id/mmc-SD8GB_0x7cc85d1e-part2
+S: disk/by-path/platform-omap_hsmmc.0-part2
+S: disk/by-uuid/C8B7-BF9D
+E: DEVLINKS=/dev/disk/by-id/mmc-SD8GB_0x7cc85d1e-part2 /dev/disk/by-path/platform-omap_hsmmc.0-part2 /dev/disk/by-uuid/C8B7-BF9D
+E: DEVNAME=/dev/mmcblk0p2
+E: DEVPATH=/devices/platform/omap_hsmmc.0/mmc_host/mmc0/mmc0:0007/block/mmcblk0/mmcblk0p2
+E: DEVTYPE=partition
+E: ID_DRIVE_FLASH_SD=1
+E: ID_DRIVE_MEDIA_FLASH_SD=1
+E: ID_FS_TYPE=vfat
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=C8B7-BF9D
+E: ID_FS_UUID_ENC=C8B7-BF9D
+E: ID_FS_VERSION=FAT32
+E: ID_NAME=SD8GB
+E: ID_PART_ENTRY_DISK=179:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=147456
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=1336320
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-omap_hsmmc.0
+E: ID_PATH_TAG=platform-omap_hsmmc_0
+E: ID_SERIAL=0x7cc85d1e
+E: MAJOR=179
+E: MINOR=2
+E: PARTN=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2205596
+
+P: /devices/platform/omap_hsmmc.4
+E: DEVPATH=/devices/platform/omap_hsmmc.4
+E: DRIVER=omap_hsmmc
+E: MODALIAS=platform:omap_hsmmc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1
+E: SUBSYSTEM=mmc_host
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001
+E: MMC_TYPE=SDIO
+E: MODALIAS=mmc:block
+E: SUBSYSTEM=mmc
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:1
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:1
+E: MODALIAS=sdio:c00v0097d4076
+E: SDIO_CLASS=00
+E: SDIO_ID=0097:4076
+E: SUBSYSTEM=sdio
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2
+E: DRIVER=wl1271_sdio
+E: MODALIAS=sdio:c00v0097d4076
+E: SDIO_CLASS=00
+E: SDIO_ID=0097:4076
+E: SUBSYSTEM=sdio
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx
+E: DRIVER=wl12xx_driver
+E: MODALIAS=platform:wl12xx
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx/ieee80211/phy0
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx/ieee80211/phy0/rfkill0
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx/ieee80211/phy0/rfkill0
+E: RFKILL_NAME=phy0
+E: RFKILL_STATE=1
+E: RFKILL_TYPE=wlan
+E: SUBSYSTEM=rfkill
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx/net/wlan0
+E: DEVPATH=/devices/platform/omap_hsmmc.4/mmc_host/mmc1/mmc1:0001/mmc1:0001:2/wl12xx/net/wlan0
+E: DEVTYPE=wlan
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=3
+E: INTERFACE=wlan0
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=57803070
+
+P: /devices/platform/omap_hwspinlock.0
+E: DEVPATH=/devices/platform/omap_hwspinlock.0
+E: DRIVER=omap_hwspinlock
+E: MODALIAS=platform:omap_hwspinlock
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1
+E: DEVPATH=/devices/platform/omap_i2c.1
+E: DRIVER=omap_i2c
+E: MODALIAS=platform:omap_i2c
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048
+E: DRIVER=twl
+E: MODALIAS=i2c:twl6030
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl6030_usb
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl6030_usb
+E: DRIVER=twl6030_usb
+E: MODALIAS=platform:twl6030_usb
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.30
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.30
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.30/regulator/regulator.3
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.30/regulator/regulator.3
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.31
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.31
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.31/regulator/regulator.4
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.31/regulator/regulator.4
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.32
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.32
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.32/regulator/regulator.5
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.32/regulator/regulator.5
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.34
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.34
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.34/regulator/regulator.7
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.34/regulator/regulator.7
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.36
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.36
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.36/regulator/regulator.6
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.36/regulator/regulator.6
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.38
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.38
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.38/regulator/regulator.12
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.38/regulator/regulator.12
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.39
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.39
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.39/regulator/regulator.13
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.39/regulator/regulator.13
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.40
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.40
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.40/regulator/regulator.8
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.40/regulator/regulator.8
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.41
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.41
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.41/regulator/regulator.9
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.41/regulator/regulator.9
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.43
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.43
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.43/regulator/regulator.15
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.43/regulator/regulator.15
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.44
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.44
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.44/regulator/regulator.10
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.44/regulator/regulator.10
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.45
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.45
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.45/regulator/regulator.11
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.45/regulator/regulator.11
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.46
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.46
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.46/regulator/regulator.2
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.46/regulator/regulator.2
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.48
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.48
+E: DRIVER=twl_reg
+E: MODALIAS=platform:twl_reg
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.48/regulator/regulator.14
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_reg.48/regulator/regulator.14
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_rtc
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_rtc
+E: DRIVER=twl_rtc
+E: MODALIAS=platform:twl_rtc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0048/twl_rtc/rtc/rtc0
+N: rtc0
+E: DEVNAME=/dev/rtc0
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0048/twl_rtc/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: SUBSYSTEM=rtc
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-0049
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-0049
+E: DRIVER=dummy
+E: MODALIAS=i2c:dummy
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-004a
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-004a
+E: DRIVER=dummy
+E: MODALIAS=i2c:dummy
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-004b
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-004b
+E: DRIVER=twl6040
+E: MODALIAS=i2c:twl6040
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.1/i2c-1/1-004b/twl6040-codec
+E: DEVPATH=/devices/platform/omap_i2c.1/i2c-1/1-004b/twl6040-codec
+E: DRIVER=twl6040-codec
+E: MODALIAS=platform:twl6040-codec
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.2
+E: DEVPATH=/devices/platform/omap_i2c.2
+E: DRIVER=omap_i2c
+E: MODALIAS=platform:omap_i2c
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.2/i2c-2
+E: DEVPATH=/devices/platform/omap_i2c.2/i2c-2
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.3
+E: DEVPATH=/devices/platform/omap_i2c.3
+E: DRIVER=omap_i2c
+E: MODALIAS=platform:omap_i2c
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.3/i2c-3
+E: DEVPATH=/devices/platform/omap_i2c.3/i2c-3
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.3/i2c-3/3-0050
+E: DEVPATH=/devices/platform/omap_i2c.3/i2c-3/3-0050
+E: MODALIAS=i2c:eeprom
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.4
+E: DEVPATH=/devices/platform/omap_i2c.4
+E: DRIVER=omap_i2c
+E: MODALIAS=platform:omap_i2c
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_i2c.4/i2c-4
+E: DEVPATH=/devices/platform/omap_i2c.4/i2c-4
+E: SUBSYSTEM=i2c
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_l3_noc.0
+E: DEVPATH=/devices/platform/omap_l3_noc.0
+E: DRIVER=omap_l3_noc
+E: MODALIAS=platform:omap_l3_noc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.1
+E: DEVPATH=/devices/platform/omap_timer.1
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.10
+E: DEVPATH=/devices/platform/omap_timer.10
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.11
+E: DEVPATH=/devices/platform/omap_timer.11
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.2
+E: DEVPATH=/devices/platform/omap_timer.2
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.3
+E: DEVPATH=/devices/platform/omap_timer.3
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.4
+E: DEVPATH=/devices/platform/omap_timer.4
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.5
+E: DEVPATH=/devices/platform/omap_timer.5
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.6
+E: DEVPATH=/devices/platform/omap_timer.6
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.7
+E: DEVPATH=/devices/platform/omap_timer.7
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.8
+E: DEVPATH=/devices/platform/omap_timer.8
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_timer.9
+E: DEVPATH=/devices/platform/omap_timer.9
+E: DRIVER=omap_timer
+E: MODALIAS=platform:omap_timer
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_uart.0
+E: DEVPATH=/devices/platform/omap_uart.0
+E: DRIVER=omap_uart
+E: MODALIAS=platform:omap_uart
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_uart.0/tty/ttyO0
+N: ttyO0
+E: DEVNAME=/dev/ttyO0
+E: DEVPATH=/devices/platform/omap_uart.0/tty/ttyO0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=250
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53451660
+
+P: /devices/platform/omap_uart.1
+E: DEVPATH=/devices/platform/omap_uart.1
+E: DRIVER=omap_uart
+E: MODALIAS=platform:omap_uart
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_uart.1/tty/ttyO1
+N: ttyO1
+E: DEVNAME=/dev/ttyO1
+E: DEVPATH=/devices/platform/omap_uart.1/tty/ttyO1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=250
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53450439
+
+P: /devices/platform/omap_uart.2
+E: DEVPATH=/devices/platform/omap_uart.2
+E: DRIVER=omap_uart
+E: MODALIAS=platform:omap_uart
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_uart.2/tty/ttyO2
+N: ttyO2
+E: DEVNAME=/dev/ttyO2
+E: DEVPATH=/devices/platform/omap_uart.2/tty/ttyO2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=250
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53449096
+
+P: /devices/platform/omap_uart.3
+E: DEVPATH=/devices/platform/omap_uart.3
+E: DRIVER=omap_uart
+E: MODALIAS=platform:omap_uart
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_uart.3/tty/ttyO3
+N: ttyO3
+E: DEVNAME=/dev/ttyO3
+E: DEVPATH=/devices/platform/omap_uart.3/tty/ttyO3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=250
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53461517
+
+P: /devices/platform/omap_wdt
+E: DEVPATH=/devices/platform/omap_wdt
+E: DRIVER=omap_wdt
+E: MODALIAS=platform:omap_wdt
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omap_wdt/misc/watchdog
+N: watchdog
+E: DEVNAME=/dev/watchdog
+E: DEVPATH=/devices/platform/omap_wdt/misc/watchdog
+E: MAJOR=10
+E: MINOR=130
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdrm
+E: DEVPATH=/devices/platform/omapdrm
+E: DRIVER=omapdrm
+E: MODALIAS=platform:omapdrm
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdrm/drm/card0
+N: dri/card0
+E: DEVNAME=/dev/dri/card0
+E: DEVPATH=/devices/platform/omapdrm/drm/card0
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=0
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53464569
+
+P: /devices/platform/omapdrm/drm/card0/card0-DVI-D-1
+E: DEVPATH=/devices/platform/omapdrm/drm/card0/card0-DVI-D-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdrm/drm/card0/card0-HDMI-A-1
+E: DEVPATH=/devices/platform/omapdrm/drm/card0/card0-HDMI-A-1
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdrm/drm/controlD64
+N: dri/controlD64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVPATH=/devices/platform/omapdrm/drm/controlD64
+E: DEVTYPE=drm_minor
+E: MAJOR=226
+E: MINOR=64
+E: SUBSYSTEM=drm
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdrm/graphics/fb0
+N: fb0
+E: DEVNAME=/dev/fb0
+E: DEVPATH=/devices/platform/omapdrm/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: PRIMARY_DEVICE_FOR_DISPLAY=1
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53467285
+
+P: /devices/platform/omapdrm_pvr.0
+E: DEVPATH=/devices/platform/omapdrm_pvr.0
+E: DRIVER=omapdrm_pvr
+E: MODALIAS=platform:omapdrm_pvr
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss
+E: DEVPATH=/devices/platform/omapdss
+E: DRIVER=omapdss
+E: MODALIAS=platform:omapdss
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss
+E: DEVPATH=/devices/platform/omapdss_dss
+E: DRIVER=omapdss_dss
+E: MODALIAS=platform:omapdss_dss
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_dispc
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_dispc
+E: DRIVER=omapdss_dispc
+E: MODALIAS=platform:omapdss_dispc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_dpi
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_dpi
+E: DRIVER=omapdss_dpi
+E: MODALIAS=platform:omapdss_dpi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_dpi/display0
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_dpi/display0
+E: DRIVER=tfp410
+E: SUBSYSTEM=omapdss
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_dsi.0
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_dsi.0
+E: MODALIAS=platform:omapdss_dsi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_dsi.1
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_dsi.1
+E: MODALIAS=platform:omapdss_dsi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_hdmi
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_hdmi
+E: DRIVER=omapdss_hdmi
+E: MODALIAS=platform:omapdss_hdmi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_hdmi/display1
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_hdmi/display1
+E: DRIVER=hdmi_panel
+E: SUBSYSTEM=omapdss
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_rfbi
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_rfbi
+E: MODALIAS=platform:omapdss_rfbi
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/omapdss_dss/omapdss_venc
+E: DEVPATH=/devices/platform/omapdss_dss/omapdss_venc
+E: MODALIAS=platform:omapdss_venc
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy
+E: DEVPATH=/devices/platform/reg-dummy
+E: DRIVER=reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-dummy/regulator/regulator.0
+E: DEVPATH=/devices/platform/reg-dummy/regulator/regulator.0
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-fixed-voltage.1
+E: DEVPATH=/devices/platform/reg-fixed-voltage.1
+E: DRIVER=reg-fixed-voltage
+E: MODALIAS=platform:reg-fixed-voltage
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/reg-fixed-voltage.1/regulator/regulator.1
+E: DEVPATH=/devices/platform/reg-fixed-voltage.1/regulator/regulator.1
+E: SUBSYSTEM=regulator
+E: UDEV_LOG=3
+
+P: /devices/platform/regulatory.0
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/sl2if
+E: DEVPATH=/devices/platform/sl2if
+E: MODALIAS=platform:sl2if
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/smartreflex.0
+E: DEVPATH=/devices/platform/smartreflex.0
+E: DRIVER=smartreflex
+E: MODALIAS=platform:smartreflex
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/smartreflex.1
+E: DEVPATH=/devices/platform/smartreflex.1
+E: DRIVER=smartreflex
+E: MODALIAS=platform:smartreflex
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/smartreflex.2
+E: DEVPATH=/devices/platform/smartreflex.2
+E: DRIVER=smartreflex
+E: MODALIAS=platform:smartreflex
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/snd-soc-dummy
+E: DEVPATH=/devices/platform/snd-soc-dummy
+E: DRIVER=snd-soc-dummy
+E: MODALIAS=platform:snd-soc-dummy
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap
+E: DEVPATH=/devices/platform/usbhs_omap
+E: DRIVER=usbhs_omap
+E: MODALIAS=platform:usbhs_omap
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0
+E: DRIVER=ehci-omap
+E: MODALIAS=platform:ehci-omap
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1
+N: bus/usb/001/001
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVNUM=001
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OMAP-EHCI_Host_Controller
+E: ID_MODEL_ENC=OMAP-EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-212-omap4_ehci_hcd_OMAP-EHCI_Host_Controller_ehci-omap.0
+E: ID_SERIAL_SHORT=ehci-omap.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-212-omap4_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-212-omap4\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=0
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2180969
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-0:1.0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/2/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1
+N: bus/usb/001/002
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/002
+E: DEVNUM=002
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=9514
+E: ID_MODEL_ENC=9514
+E: ID_MODEL_ID=9514
+E: ID_REVISION=0200
+E: ID_SERIAL=0424_9514
+E: ID_USB_INTERFACES=:090001:090002:
+E: ID_VENDOR=0424
+E: ID_VENDOR_ENC=0424
+E: ID_VENDOR_ID=0424
+E: MAJOR=189
+E: MINOR=1
+E: PRODUCT=424/9514/200
+E: SUBSYSTEM=usb
+E: TYPE=9/0/2
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2182922
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.1
+N: bus/usb/001/003
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/003
+E: DEVNUM=003
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.1
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=ec00
+E: ID_MODEL_ENC=ec00
+E: ID_MODEL_ID=ec00
+E: ID_REVISION=0200
+E: ID_SERIAL=0424_ec00
+E: ID_USB_INTERFACES=:ff00ff:
+E: ID_VENDOR=0424
+E: ID_VENDOR_ENC=0424
+E: ID_VENDOR_ID=0424
+E: MAJOR=189
+E: MINOR=2
+E: PRODUCT=424/ec00/200
+E: SUBSYSTEM=usb
+E: TYPE=255/0/1
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1683868
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.1/1-1.1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=smsc95xx
+E: INTERFACE=255/0/255
+E: MODALIAS=usb:v0424pEC00d0200dcFFdsc00dp01icFFisc00ipFF
+E: PRODUCT=424/ec00/200
+E: SUBSYSTEM=usb
+E: TYPE=255/0/1
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.1/1-1.1:1.0/net/eth0
+E: COMMENT=USB device 0x0424:0xec00 (usb)
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.1/1-1.1:1.0/net/eth0
+E: ID_BUS=usb
+E: ID_MM_CANDIDATE=1
+E: ID_MODEL=ec00
+E: ID_MODEL_ENC=ec00
+E: ID_MODEL_ID=ec00
+E: ID_REVISION=0200
+E: ID_SERIAL=0424_ec00
+E: ID_TYPE=generic
+E: ID_USB_DRIVER=smsc95xx
+E: ID_USB_INTERFACES=:ff00ff:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=0424
+E: ID_VENDOR_ENC=0424
+E: ID_VENDOR_FROM_DATABASE=Standard Microsystems Corp.
+E: ID_VENDOR_ID=0424
+E: IFINDEX=2
+E: INTERFACE=eth0
+E: MATCHDEVID=0x0
+E: MATCHIFTYPE=1
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=55221466
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2
+N: bus/usb/001/004
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVNUM=004
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB_2.0_FD
+E: ID_MODEL_ENC=USB\x202.0\x20FD
+E: ID_MODEL_ID=0059
+E: ID_REVISION=8192
+E: ID_SERIAL=PNY_Technologies_USB_2.0_FD_AC7BHC04000000047
+E: ID_SERIAL_SHORT=AC7BHC04000000047
+E: ID_USB_INTERFACES=:080650:
+E: ID_VENDOR=PNY_Technologies
+E: ID_VENDOR_ENC=PNY\x20Technologies
+E: ID_VENDOR_ID=154b
+E: MAJOR=189
+E: MINOR=3
+E: PRODUCT=154b/59/8192
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2458709
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usb-storage
+E: INTERFACE=8/6/80
+E: MODALIAS=usb:v154Bp0059d8192dc00dsc00dp00ic08isc06ip50
+E: PRODUCT=154b/59/8192
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/scsi_host/host0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0
+S: disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: DEVLINKS=/dev/disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0 /dev/disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: DEVNAME=/dev/sda
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda
+E: DEVTYPE=disk
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_2.0_FD
+E: ID_MODEL_ENC=USB\x202.0\x20FD\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0059
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8192
+E: ID_SERIAL=PNY_USB_2.0_FD_AC7BHC04000000047-0:0
+E: ID_SERIAL_SHORT=AC7BHC04000000047
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=PNY
+E: ID_VENDOR_ENC=PNY\x20\x20\x20\x20\x20
+E: ID_VENDOR_ID=154b
+E: MAJOR=8
+E: MINOR=0
+E: NPARTS=4
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=4892639
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part1
+S: disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part1
+S: disk/by-uuid/cb70234c-2aee-4612-985f-9b6844aed5db
+E: DEVLINKS=/dev/disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part1 /dev/disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part1 /dev/disk/by-uuid/cb70234c-2aee-4612-985f-9b6844aed5db
+E: DEVNAME=/dev/sda1
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_TYPE=ext2
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=cb70234c-2aee-4612-985f-9b6844aed5db
+E: ID_FS_UUID_ENC=cb70234c-2aee-4612-985f-9b6844aed5db
+E: ID_FS_VERSION=1.0
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_2.0_FD
+E: ID_MODEL_ENC=USB\x202.0\x20FD\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0059
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: ID_PART_ENTRY_OFFSET=2048
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=497664
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8192
+E: ID_SERIAL=PNY_USB_2.0_FD_AC7BHC04000000047-0:0
+E: ID_SERIAL_SHORT=AC7BHC04000000047
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=PNY
+E: ID_VENDOR_ENC=PNY\x20\x20\x20\x20\x20
+E: ID_VENDOR_ID=154b
+E: MAJOR=8
+E: MINOR=1
+E: PARTN=1
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6281890
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part2
+S: disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part2
+S: disk/by-uuid/c9544f2f-9112-4e7f-b522-7a88f5f08938
+E: DEVLINKS=/dev/disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part2 /dev/disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part2 /dev/disk/by-uuid/c9544f2f-9112-4e7f-b522-7a88f5f08938
+E: DEVNAME=/dev/sda2
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_FS_UUID=c9544f2f-9112-4e7f-b522-7a88f5f08938
+E: ID_FS_UUID_ENC=c9544f2f-9112-4e7f-b522-7a88f5f08938
+E: ID_FS_VERSION=1.0
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_2.0_FD
+E: ID_MODEL_ENC=USB\x202.0\x20FD\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0059
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=2
+E: ID_PART_ENTRY_OFFSET=499712
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=14548992
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8192
+E: ID_SERIAL=PNY_USB_2.0_FD_AC7BHC04000000047-0:0
+E: ID_SERIAL_SHORT=AC7BHC04000000047
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=PNY
+E: ID_VENDOR_ENC=PNY\x20\x20\x20\x20\x20
+E: ID_VENDOR_ID=154b
+E: MAJOR=8
+E: MINOR=2
+E: PARTN=2
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6263793
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda3
+N: sda3
+S: disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part3
+S: disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part3
+E: DEVLINKS=/dev/disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part3 /dev/disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part3
+E: DEVNAME=/dev/sda3
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda3
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_2.0_FD
+E: ID_MODEL_ENC=USB\x202.0\x20FD\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0059
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=3
+E: ID_PART_ENTRY_OFFSET=15050750
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=774146
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8192
+E: ID_SERIAL=PNY_USB_2.0_FD_AC7BHC04000000047-0:0
+E: ID_SERIAL_SHORT=AC7BHC04000000047
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=PNY
+E: ID_VENDOR_ENC=PNY\x20\x20\x20\x20\x20
+E: ID_VENDOR_ID=154b
+E: MAJOR=8
+E: MINOR=3
+E: PARTN=3
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=4941955
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part5
+S: disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part5
+E: DEVLINKS=/dev/disk/by-id/usb-PNY_USB_2.0_FD_AC7BHC04000000047-0:0-part5 /dev/disk/by-path/platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0-part5
+E: DEVNAME=/dev/sda5
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: DEVTYPE=partition
+E: ID_BUS=usb
+E: ID_INSTANCE=0:0
+E: ID_MODEL=USB_2.0_FD
+E: ID_MODEL_ENC=USB\x202.0\x20FD\x20\x20\x20\x20\x20\x20
+E: ID_MODEL_ID=0059
+E: ID_PART_ENTRY_DISK=8:0
+E: ID_PART_ENTRY_NUMBER=5
+E: ID_PART_ENTRY_OFFSET=15050752
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_SIZE=774144
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.2:1.0-scsi-0:0:0:0
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_2_1_0-scsi-0_0_0_0
+E: ID_REVISION=8192
+E: ID_SERIAL=PNY_USB_2.0_FD_AC7BHC04000000047-0:0
+E: ID_SERIAL_SHORT=AC7BHC04000000047
+E: ID_TYPE=disk
+E: ID_USB_DRIVER=usb-storage
+E: ID_USB_INTERFACES=:080650:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_VENDOR=PNY
+E: ID_VENDOR_ENC=PNY\x20\x20\x20\x20\x20
+E: ID_VENDOR_ID=154b
+E: MAJOR=8
+E: MINOR=5
+E: PARTN=5
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=6282196
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=251
+E: MINOR=0
+E: SUBSYSTEM=bsg
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: DEVNAME=/dev/sg0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.2/1-1.2:1.0/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: SUBSYSTEM=scsi_generic
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3
+N: bus/usb/001/006
+E: BUSNUM=001
+E: DEVNAME=/dev/bus/usb/001/006
+E: DEVNUM=006
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=USB_Receiver
+E: ID_MODEL_ENC=USB\x20Receiver
+E: ID_MODEL_ID=c52b
+E: ID_REVISION=1201
+E: ID_SERIAL=Logitech_USB_Receiver
+E: ID_USB_INTERFACES=:030101:030102:030000:
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=189
+E: MINOR=5
+E: PRODUCT=46d/c52b/1201
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+E: UPOWER_VENDOR=Logitech, Inc.
+E: USEC_INITIALIZED=124730560
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/1
+E: MODALIAS=usb:v046DpC52Bd1201dc00dsc00dp00ic03isc01ip01
+E: PRODUCT=46d/c52b/1201
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.0/0003:046D:C52B.0004
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.0/0003:046D:C52B.0004
+E: HID_ID=0003:0000046D:0000C52B
+E: HID_NAME=Logitech USB Receiver
+E: HID_PHYS=usb-ehci-omap.0-1.3/input0
+E: MODALIAS=hid:b0003g0000v0000046Dp0000C52B
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.1
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/1/2
+E: MODALIAS=usb:v046DpC52Bd1201dc00dsc00dp00ic03isc01ip02
+E: PRODUCT=46d/c52b/1201
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.1/0003:046D:C52B.0005
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.1/0003:046D:C52B.0005
+E: HID_ID=0003:0000046D:0000C52B
+E: HID_NAME=Logitech USB Receiver
+E: HID_PHYS=usb-ehci-omap.0-1.3/input1
+E: MODALIAS=hid:b0003g0000v0000046Dp0000C52B
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2
+E: DEVTYPE=usb_interface
+E: DRIVER=usbhid
+E: INTERFACE=3/0/0
+E: MODALIAS=usb:v046DpC52Bd1201dc00dsc00dp00ic03isc00ip00
+E: PRODUCT=46d/c52b/1201
+E: SUBSYSTEM=usb
+E: TYPE=0/0/0
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006
+E: DRIVER=logitech-djreceiver
+E: HID_ID=0003:0000046D:0000C52B
+E: HID_NAME=Logitech USB Receiver
+E: HID_PHYS=usb-ehci-omap.0-1.3/input2
+E: MODALIAS=hid:b0003g0000v0000046Dp0000C52B
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/0003:046D:C52B.0007
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/0003:046D:C52B.0007
+E: DRIVER=logitech-djdevice
+E: HID_ID=0003:0000046D:0000C52B
+E: HID_NAME=Logitech Unifying Device. Wireless PID:400e
+E: HID_PHYS=usb-ehci-omap.0-1.3:1
+E: MODALIAS=hid:b0003g0000v0000046Dp0000C52B
+E: SUBSYSTEM=hid
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/0003:046D:C52B.0007/hidraw/hidraw1
+N: hidraw1
+E: DEVNAME=/dev/hidraw1
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/0003:046D:C52B.0007/hidraw/hidraw1
+E: MAJOR=249
+E: MINOR=1
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/hidraw/hidraw0
+N: hidraw0
+E: DEVNAME=/dev/hidraw0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/hidraw/hidraw0
+E: MAJOR=249
+E: MINOR=0
+E: SUBSYSTEM=hidraw
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/input/input2
+E: ABS=1 0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/input/input2
+E: EV=12001f
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=USB_Receiver
+E: ID_MODEL_ENC=USB\x20Receiver
+E: ID_MODEL_ID=c52b
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.3:1.2
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_3_1_2
+E: ID_REVISION=1201
+E: ID_SERIAL=Logitech_USB_Receiver
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:030000:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: KEY=4837fff 72ff32d bf544446 0 0 ffff0001 30f90 8b17c007 ffff7bfa d9415fff febeffdf ffefffff ffffffff fffffffe
+E: LED=1f
+E: MODALIAS=input:b0003v046DpC52Be0111-e0,1,2,3,4,11,14,k71,72,73,74,75,77,79,7A,7B,7C,7D,7E,7F,80,81,82,83,84,85,86,87,88,89,8A,8B,8C,8E,90,96,98,9B,9C,9E,9F,A1,A3,A4,A5,A6,A7,A8,A9,AB,AC,AD,AE,B0,B1,B2,B3,B4,B5,B6,B7,B8,B9,BA,BB,BC,BD,BE,BF,C0,C1,C2,CE,CF,D0,D1,D2,D4,D8,D9,DB,DF,E4,E7,E8,E9,EA,EB,F0,F1,100,110,111,112,113,114,115,116,117,118,119,11A,11B,11C,11D,11E,11F,161,162,166,16A,16E,172,174,176,178,179,17A,17B,17C,17D,17F,180,182,183,185,188,189,18C,18D,18E,18F,190,191,192,193,195,198,199,19A,1A0,1A1,1A2,1A3,1A4,1A5,1A6,1A7,1A8,1A9,1AA,1AB,1AC,1AD,1AE,1B0,1B1,1B7,1BA,r0,1,6,7,8,a20,m4,l0,1,2,3,4,sfw
+E: MSC=10
+E: NAME="Logitech Unifying Device. Wireless PID:400e"
+E: PHYS="usb-ehci-omap.0-1.3:1"
+E: PRODUCT=3/46d/c52b/111
+E: PROP=0
+E: REL=1c3
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: UNIQ=""
+E: USEC_INITIALIZED=124733215
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/input/input2/event2
+N: input/event2
+S: input/by-id/usb-Logitech_USB_Receiver-event-mouse
+S: input/by-id/usb-Logitech_USB_Receiver-if02-event-mouse
+S: input/by-path/platform-ehci-omap.0-usb-0:1.3:1.2-event-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_USB_Receiver-event-mouse /dev/input/by-id/usb-Logitech_USB_Receiver-if02-event-mouse /dev/input/by-path/platform-ehci-omap.0-usb-0:1.3:1.2-event-mouse
+E: DEVNAME=/dev/input/event2
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/input/input2/event2
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=USB_Receiver
+E: ID_MODEL_ENC=USB\x20Receiver
+E: ID_MODEL_ID=c52b
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.3:1.2
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_3_1_2
+E: ID_REVISION=1201
+E: ID_SERIAL=Logitech_USB_Receiver
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:030000:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=66
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=128344696
+E: XKBLAYOUT=us
+E: XKBMODEL=pc105
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/input/input2/mouse0
+N: input/mouse0
+S: input/by-id/usb-Logitech_USB_Receiver-if02-mouse
+S: input/by-id/usb-Logitech_USB_Receiver-mouse
+S: input/by-path/platform-ehci-omap.0-usb-0:1.3:1.2-mouse
+E: DEVLINKS=/dev/input/by-id/usb-Logitech_USB_Receiver-if02-mouse /dev/input/by-id/usb-Logitech_USB_Receiver-mouse /dev/input/by-path/platform-ehci-omap.0-usb-0:1.3:1.2-mouse
+E: DEVNAME=/dev/input/mouse0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/0003:046D:C52B.0006/input/input2/mouse0
+E: ID_BUS=usb
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_INPUT_MOUSE=1
+E: ID_MODEL=USB_Receiver
+E: ID_MODEL_ENC=USB\x20Receiver
+E: ID_MODEL_ID=c52b
+E: ID_PATH=platform-ehci-omap.0-usb-0:1.3:1.2
+E: ID_PATH_TAG=platform-ehci-omap_0-usb-0_1_3_1_2
+E: ID_REVISION=1201
+E: ID_SERIAL=Logitech_USB_Receiver
+E: ID_TYPE=hid
+E: ID_USB_DRIVER=usbhid
+E: ID_USB_INTERFACES=:030101:030102:030000:
+E: ID_USB_INTERFACE_NUM=02
+E: ID_VENDOR=Logitech
+E: ID_VENDOR_ENC=Logitech
+E: ID_VENDOR_ID=046d
+E: MAJOR=13
+E: MINOR=32
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=128340454
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/usb/hiddev0
+N: usb/hiddev0
+E: DEVNAME=/dev/usb/hiddev0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1.3/1-1.3:1.2/usb/hiddev0
+E: MAJOR=180
+E: MINOR=0
+E: SUBSYSTEM=usb
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1:1.0
+E: DEVPATH=/devices/platform/usbhs_omap/ehci-omap.0/usb1/1-1/1-1:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/2
+E: MODALIAS=usb:v0424p9514d0200dc09dsc00dp02ic09isc00ip02
+E: PRODUCT=424/9514/200
+E: SUBSYSTEM=usb
+E: TYPE=9/0/2
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ohci-omap3.0
+E: DEVPATH=/devices/platform/usbhs_omap/ohci-omap3.0
+E: DRIVER=ohci-omap3
+E: MODALIAS=platform:ohci-omap3
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_omap/ohci-omap3.0/usb2
+N: bus/usb/002/001
+E: BUSNUM=002
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVNUM=001
+E: DEVPATH=/devices/platform/usbhs_omap/ohci-omap3.0/usb2
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: ID_BUS=usb
+E: ID_MODEL=OMAP3_OHCI_Host_Controller
+E: ID_MODEL_ENC=OMAP3\x20OHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0305
+E: ID_SERIAL=Linux_3.5.0-212-omap4_ohci_hcd_OMAP3_OHCI_Host_Controller_ohci-omap3.0
+E: ID_SERIAL_SHORT=ohci-omap3.0
+E: ID_USB_INTERFACES=:090000:
+E: ID_VENDOR=Linux_3.5.0-212-omap4_ohci_hcd
+E: ID_VENDOR_ENC=Linux\x203.5.0-212-omap4\x20ohci_hcd
+E: ID_VENDOR_ID=1d6b
+E: MAJOR=189
+E: MINOR=128
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=2188964
+
+P: /devices/platform/usbhs_omap/ohci-omap3.0/usb2/2-0:1.0
+E: DEVPATH=/devices/platform/usbhs_omap/ohci-omap3.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0305dc09dsc00dp00ic09isc00ip00
+E: PRODUCT=1d6b/1/305
+E: SUBSYSTEM=usb
+E: TYPE=9/0/0
+E: UDEV_LOG=3
+
+P: /devices/platform/usbhs_tll
+E: DEVPATH=/devices/platform/usbhs_tll
+E: DRIVER=usbhs_tll
+E: MODALIAS=platform:usbhs_tll
+E: SUBSYSTEM=platform
+E: UDEV_LOG=3
+
+P: /devices/software
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/system/clocksource/clocksource0
+E: DEVPATH=/devices/system/clocksource/clocksource0
+E: SUBSYSTEM=clocksource
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu0
+E: DEVPATH=/devices/system/cpu/cpu0
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/system/cpu/cpu1
+E: DEVPATH=/devices/system/cpu/cpu1
+E: SUBSYSTEM=cpu
+E: UDEV_LOG=3
+
+P: /devices/tracepoint
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/0:20
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/179:0
+E: DEVPATH=/devices/virtual/bdi/179:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:0
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:1
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:10
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:11
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:12
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:13
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:14
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:15
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:2
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:4
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:5
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:6
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:7
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:8
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/1:9
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/253:0
+E: DEVPATH=/devices/virtual/bdi/253:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:0
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:1
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:2
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:4
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:5
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:6
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/7:7
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/8:0
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/default
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/bdi/ecryptfs-1
+E: DEVPATH=/devices/virtual/bdi/ecryptfs-1
+E: SUBSYSTEM=bdi
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: DEVNAME=/dev/loop0
+E: DEVPATH=/devices/virtual/block/loop0
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=0
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1692108
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: DEVNAME=/dev/loop1
+E: DEVPATH=/devices/virtual/block/loop1
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=1
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1692718
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: DEVNAME=/dev/loop2
+E: DEVPATH=/devices/virtual/block/loop2
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=2
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1693298
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: DEVNAME=/dev/loop3
+E: DEVPATH=/devices/virtual/block/loop3
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=3
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1745635
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: DEVNAME=/dev/loop4
+E: DEVPATH=/devices/virtual/block/loop4
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=4
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1694213
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: DEVNAME=/dev/loop5
+E: DEVPATH=/devices/virtual/block/loop5
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=5
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1694854
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: DEVNAME=/dev/loop6
+E: DEVPATH=/devices/virtual/block/loop6
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=6
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1715698
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: DEVNAME=/dev/loop7
+E: DEVPATH=/devices/virtual/block/loop7
+E: DEVTYPE=disk
+E: MAJOR=7
+E: MINOR=7
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1716339
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: DEVNAME=/dev/ram0
+E: DEVPATH=/devices/virtual/block/ram0
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=0
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1716949
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: DEVNAME=/dev/ram1
+E: DEVPATH=/devices/virtual/block/ram1
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=1
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1829620
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: DEVNAME=/dev/ram10
+E: DEVPATH=/devices/virtual/block/ram10
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=10
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1836547
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: DEVNAME=/dev/ram11
+E: DEVPATH=/devices/virtual/block/ram11
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=11
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1759368
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: DEVNAME=/dev/ram12
+E: DEVPATH=/devices/virtual/block/ram12
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=12
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1774688
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: DEVNAME=/dev/ram13
+E: DEVPATH=/devices/virtual/block/ram13
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=13
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1775512
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: DEVNAME=/dev/ram14
+E: DEVPATH=/devices/virtual/block/ram14
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=14
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1776184
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: DEVNAME=/dev/ram15
+E: DEVPATH=/devices/virtual/block/ram15
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=15
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1777008
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: DEVNAME=/dev/ram2
+E: DEVPATH=/devices/virtual/block/ram2
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=2
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1777709
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: DEVNAME=/dev/ram3
+E: DEVPATH=/devices/virtual/block/ram3
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=3
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1778381
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: DEVNAME=/dev/ram4
+E: DEVPATH=/devices/virtual/block/ram4
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=4
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1779113
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: DEVNAME=/dev/ram5
+E: DEVPATH=/devices/virtual/block/ram5
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=5
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1779785
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: DEVNAME=/dev/ram6
+E: DEVPATH=/devices/virtual/block/ram6
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=6
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1900390
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: DEVNAME=/dev/ram7
+E: DEVPATH=/devices/virtual/block/ram7
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=7
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1901062
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: DEVNAME=/dev/ram8
+E: DEVPATH=/devices/virtual/block/ram8
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=8
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1873382
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: DEVNAME=/dev/ram9
+E: DEVPATH=/devices/virtual/block/ram9
+E: DEVTYPE=disk
+E: MAJOR=1
+E: MINOR=9
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=1902526
+
+P: /devices/virtual/gpio/gpio1
+E: DEVPATH=/devices/virtual/gpio/gpio1
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpio62
+E: DEVPATH=/devices/virtual/gpio/gpio62
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpiochip0
+E: DEVPATH=/devices/virtual/gpio/gpiochip0
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpiochip128
+E: DEVPATH=/devices/virtual/gpio/gpiochip128
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpiochip160
+E: DEVPATH=/devices/virtual/gpio/gpiochip160
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpiochip32
+E: DEVPATH=/devices/virtual/gpio/gpiochip32
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpiochip64
+E: DEVPATH=/devices/virtual/gpio/gpiochip64
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/gpio/gpiochip96
+E: DEVPATH=/devices/virtual/gpio/gpiochip96
+E: SUBSYSTEM=gpio
+E: UDEV_LOG=3
+
+P: /devices/virtual/graphics/fbcon
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+E: UDEV_LOG=3
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: DEVNAME=/dev/input/mice
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: SUBSYSTEM=input
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/full
+N: full
+E: DEVMODE=0666
+E: DEVNAME=/dev/full
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: DEVMODE=0644
+E: DEVNAME=/dev/kmsg
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/mem
+N: mem
+E: DEVNAME=/dev/mem
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/null
+N: null
+E: DEVMODE=0666
+E: DEVNAME=/dev/null
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: DEVNAME=/dev/oldmem
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/random
+N: random
+E: DEVMODE=0666
+E: DEVNAME=/dev/random
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: DEVMODE=0666
+E: DEVNAME=/dev/urandom
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/mem/zero
+N: zero
+E: DEVMODE=0666
+E: DEVNAME=/dev/zero
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: SUBSYSTEM=mem
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: DEVNAME=/dev/cpu_dma_latency
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=61
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: DEVNAME=/dev/mapper/control
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: DEVNAME=/dev/ecryptfs
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=62
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: DEVNAME=/dev/fuse
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/loop-control
+N: loop-control
+E: DEVNAME=/dev/loop-control
+E: DEVPATH=/devices/virtual/misc/loop-control
+E: MAJOR=10
+E: MINOR=237
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/memory_throughput
+N: memory_throughput
+E: DEVNAME=/dev/memory_throughput
+E: DEVPATH=/devices/virtual/misc/memory_throughput
+E: MAJOR=10
+E: MINOR=59
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: DEVNAME=/dev/network_latency
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=60
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: DEVNAME=/dev/network_throughput
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: DEVNAME=/dev/psaux
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: DEVNAME=/dev/rfkill
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=63
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53721405
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: DEVNAME=/dev/net/tun
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: DEVNAME=/dev/uinput
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: SUBSYSTEM=misc
+E: UDEV_LOG=3
+
+P: /devices/virtual/net/lo
+E: DEVPATH=/devices/virtual/net/lo
+E: ID_MM_CANDIDATE=1
+E: IFINDEX=1
+E: INTERFACE=lo
+E: SUBSYSTEM=net
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53727508
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: DEVNAME=/dev/ppp
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: SUBSYSTEM=ppp
+E: UDEV_LOG=3
+
+P: /devices/virtual/pvr/omapdrm_pvr
+E: DEVPATH=/devices/virtual/pvr/omapdrm_pvr
+E: SUBSYSTEM=pvr
+E: UDEV_LOG=3
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: DEVNAME=/dev/snd/timer
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53730468
+
+P: /devices/virtual/tty/console
+N: console
+E: DEVNAME=/dev/console
+E: DEVPATH=/devices/virtual/tty/console
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53729339
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: DEVMODE=0666
+E: DEVNAME=/dev/ptmx
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53734619
+
+P: /devices/virtual/tty/ptyp0
+N: ptyp0
+E: DEVNAME=/dev/ptyp0
+E: DEVPATH=/devices/virtual/tty/ptyp0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53733337
+
+P: /devices/virtual/tty/ptyp1
+N: ptyp1
+E: DEVNAME=/dev/ptyp1
+E: DEVPATH=/devices/virtual/tty/ptyp1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53736267
+
+P: /devices/virtual/tty/ptyp2
+N: ptyp2
+E: DEVNAME=/dev/ptyp2
+E: DEVPATH=/devices/virtual/tty/ptyp2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53740142
+
+P: /devices/virtual/tty/ptyp3
+N: ptyp3
+E: DEVNAME=/dev/ptyp3
+E: DEVPATH=/devices/virtual/tty/ptyp3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53739593
+
+P: /devices/virtual/tty/ptyp4
+N: ptyp4
+E: DEVNAME=/dev/ptyp4
+E: DEVPATH=/devices/virtual/tty/ptyp4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53738250
+
+P: /devices/virtual/tty/ptyp5
+N: ptyp5
+E: DEVNAME=/dev/ptyp5
+E: DEVPATH=/devices/virtual/tty/ptyp5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53738616
+
+P: /devices/virtual/tty/ptyp6
+N: ptyp6
+E: DEVNAME=/dev/ptyp6
+E: DEVPATH=/devices/virtual/tty/ptyp6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53742004
+
+P: /devices/virtual/tty/ptyp7
+N: ptyp7
+E: DEVNAME=/dev/ptyp7
+E: DEVPATH=/devices/virtual/tty/ptyp7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53741790
+
+P: /devices/virtual/tty/ptyp8
+N: ptyp8
+E: DEVNAME=/dev/ptyp8
+E: DEVPATH=/devices/virtual/tty/ptyp8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53743957
+
+P: /devices/virtual/tty/ptyp9
+N: ptyp9
+E: DEVNAME=/dev/ptyp9
+E: DEVPATH=/devices/virtual/tty/ptyp9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53743499
+
+P: /devices/virtual/tty/ptypa
+N: ptypa
+E: DEVNAME=/dev/ptypa
+E: DEVPATH=/devices/virtual/tty/ptypa
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53745758
+
+P: /devices/virtual/tty/ptypb
+N: ptypb
+E: DEVNAME=/dev/ptypb
+E: DEVPATH=/devices/virtual/tty/ptypb
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53744995
+
+P: /devices/virtual/tty/ptypc
+N: ptypc
+E: DEVNAME=/dev/ptypc
+E: DEVPATH=/devices/virtual/tty/ptypc
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53747406
+
+P: /devices/virtual/tty/ptypd
+N: ptypd
+E: DEVNAME=/dev/ptypd
+E: DEVPATH=/devices/virtual/tty/ptypd
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53746490
+
+P: /devices/virtual/tty/ptype
+N: ptype
+E: DEVNAME=/dev/ptype
+E: DEVPATH=/devices/virtual/tty/ptype
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53750152
+
+P: /devices/virtual/tty/ptypf
+N: ptypf
+E: DEVNAME=/dev/ptypf
+E: DEVPATH=/devices/virtual/tty/ptypf
+E: ID_MM_CANDIDATE=1
+E: MAJOR=2
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53750793
+
+P: /devices/virtual/tty/tty
+N: tty
+E: DEVMODE=0666
+E: DEVNAME=/dev/tty
+E: DEVPATH=/devices/virtual/tty/tty
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53748840
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: DEVNAME=/dev/tty0
+E: DEVPATH=/devices/virtual/tty/tty0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53749145
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: DEVNAME=/dev/tty1
+E: DEVPATH=/devices/virtual/tty/tty1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53753906
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: DEVNAME=/dev/tty10
+E: DEVPATH=/devices/virtual/tty/tty10
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53751739
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: DEVNAME=/dev/tty11
+E: DEVPATH=/devices/virtual/tty/tty11
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53752502
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: DEVNAME=/dev/tty12
+E: DEVPATH=/devices/virtual/tty/tty12
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53755706
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: DEVNAME=/dev/tty13
+E: DEVPATH=/devices/virtual/tty/tty13
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53754211
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: DEVNAME=/dev/tty14
+E: DEVPATH=/devices/virtual/tty/tty14
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53755706
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: DEVNAME=/dev/tty15
+E: DEVPATH=/devices/virtual/tty/tty15
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53759643
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: DEVNAME=/dev/tty16
+E: DEVPATH=/devices/virtual/tty/tty16
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=16
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53757537
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: DEVNAME=/dev/tty17
+E: DEVPATH=/devices/virtual/tty/tty17
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=17
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53760345
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: DEVNAME=/dev/tty18
+E: DEVPATH=/devices/virtual/tty/tty18
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=18
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53758270
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: DEVNAME=/dev/tty19
+E: DEVPATH=/devices/virtual/tty/tty19
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=19
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53761596
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: DEVNAME=/dev/tty2
+E: DEVPATH=/devices/virtual/tty/tty2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53763061
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: DEVNAME=/dev/tty20
+E: DEVPATH=/devices/virtual/tty/tty20
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=20
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53764831
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: DEVNAME=/dev/tty21
+E: DEVPATH=/devices/virtual/tty/tty21
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=21
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53765045
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: DEVNAME=/dev/tty22
+E: DEVPATH=/devices/virtual/tty/tty22
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=22
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53767456
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: DEVNAME=/dev/tty23
+E: DEVPATH=/devices/virtual/tty/tty23
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=23
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53769195
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: DEVNAME=/dev/tty24
+E: DEVPATH=/devices/virtual/tty/tty24
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=24
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53770874
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: DEVNAME=/dev/tty25
+E: DEVPATH=/devices/virtual/tty/tty25
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=25
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53772552
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: DEVNAME=/dev/tty26
+E: DEVPATH=/devices/virtual/tty/tty26
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=26
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53774291
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: DEVNAME=/dev/tty27
+E: DEVPATH=/devices/virtual/tty/tty27
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=27
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53777984
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: DEVNAME=/dev/tty28
+E: DEVPATH=/devices/virtual/tty/tty28
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=28
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53776245
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: DEVNAME=/dev/tty29
+E: DEVPATH=/devices/virtual/tty/tty29
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=29
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53776489
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: DEVNAME=/dev/tty3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53780761
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: DEVNAME=/dev/tty30
+E: DEVPATH=/devices/virtual/tty/tty30
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=30
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53778289
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: DEVNAME=/dev/tty31
+E: DEVPATH=/devices/virtual/tty/tty31
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=31
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53779785
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: DEVNAME=/dev/tty32
+E: DEVPATH=/devices/virtual/tty/tty32
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=32
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53781677
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: DEVNAME=/dev/tty33
+E: DEVPATH=/devices/virtual/tty/tty33
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=33
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53783752
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: DEVNAME=/dev/tty34
+E: DEVPATH=/devices/virtual/tty/tty34
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=34
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53783935
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: DEVNAME=/dev/tty35
+E: DEVPATH=/devices/virtual/tty/tty35
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=35
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53785491
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: DEVNAME=/dev/tty36
+E: DEVPATH=/devices/virtual/tty/tty36
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=36
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53785705
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: DEVNAME=/dev/tty37
+E: DEVPATH=/devices/virtual/tty/tty37
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=37
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53787109
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: DEVNAME=/dev/tty38
+E: DEVPATH=/devices/virtual/tty/tty38
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=38
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53788360
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: DEVNAME=/dev/tty39
+E: DEVPATH=/devices/virtual/tty/tty39
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=39
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53789642
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: DEVNAME=/dev/tty4
+E: DEVPATH=/devices/virtual/tty/tty4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53792449
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: DEVNAME=/dev/tty40
+E: DEVPATH=/devices/virtual/tty/tty40
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=40
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53791168
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: DEVNAME=/dev/tty41
+E: DEVPATH=/devices/virtual/tty/tty41
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=41
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53791503
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: DEVNAME=/dev/tty42
+E: DEVPATH=/devices/virtual/tty/tty42
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=42
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53793548
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: DEVNAME=/dev/tty43
+E: DEVPATH=/devices/virtual/tty/tty43
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=43
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53801025
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: DEVNAME=/dev/tty44
+E: DEVPATH=/devices/virtual/tty/tty44
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=44
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53795806
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: DEVNAME=/dev/tty45
+E: DEVPATH=/devices/virtual/tty/tty45
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=45
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53796112
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: DEVNAME=/dev/tty46
+E: DEVPATH=/devices/virtual/tty/tty46
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=46
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53797821
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: DEVNAME=/dev/tty47
+E: DEVPATH=/devices/virtual/tty/tty47
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=47
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53798034
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: DEVNAME=/dev/tty48
+E: DEVPATH=/devices/virtual/tty/tty48
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=48
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53800994
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: DEVNAME=/dev/tty49
+E: DEVPATH=/devices/virtual/tty/tty49
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=49
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53799865
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: DEVNAME=/dev/tty5
+E: DEVPATH=/devices/virtual/tty/tty5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53802337
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: DEVNAME=/dev/tty50
+E: DEVPATH=/devices/virtual/tty/tty50
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=50
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53806396
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: DEVNAME=/dev/tty51
+E: DEVPATH=/devices/virtual/tty/tty51
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=51
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53804473
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: DEVNAME=/dev/tty52
+E: DEVPATH=/devices/virtual/tty/tty52
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=52
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53806396
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: DEVNAME=/dev/tty53
+E: DEVPATH=/devices/virtual/tty/tty53
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=53
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53805236
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: DEVNAME=/dev/tty54
+E: DEVPATH=/devices/virtual/tty/tty54
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=54
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53809234
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: DEVNAME=/dev/tty55
+E: DEVPATH=/devices/virtual/tty/tty55
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=55
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53808166
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: DEVNAME=/dev/tty56
+E: DEVPATH=/devices/virtual/tty/tty56
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=56
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53810333
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: DEVNAME=/dev/tty57
+E: DEVPATH=/devices/virtual/tty/tty57
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=57
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53814147
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: DEVNAME=/dev/tty58
+E: DEVPATH=/devices/virtual/tty/tty58
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=58
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53811981
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: DEVNAME=/dev/tty59
+E: DEVPATH=/devices/virtual/tty/tty59
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=59
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53813385
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: DEVNAME=/dev/tty6
+E: DEVPATH=/devices/virtual/tty/tty6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53812622
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: DEVNAME=/dev/tty60
+E: DEVPATH=/devices/virtual/tty/tty60
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=60
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54439300
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: DEVNAME=/dev/tty61
+E: DEVPATH=/devices/virtual/tty/tty61
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=61
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53818145
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: DEVNAME=/dev/tty62
+E: DEVPATH=/devices/virtual/tty/tty62
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=62
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=53821868
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: DEVNAME=/dev/tty63
+E: DEVPATH=/devices/virtual/tty/tty63
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=63
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54334289
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: DEVNAME=/dev/tty7
+E: DEVPATH=/devices/virtual/tty/tty7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54338165
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: DEVNAME=/dev/tty8
+E: DEVPATH=/devices/virtual/tty/tty8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54494262
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: DEVNAME=/dev/tty9
+E: DEVPATH=/devices/virtual/tty/tty9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=4
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54498901
+
+P: /devices/virtual/tty/ttyp0
+N: ttyp0
+E: DEVNAME=/dev/ttyp0
+E: DEVPATH=/devices/virtual/tty/ttyp0
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=0
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54509338
+
+P: /devices/virtual/tty/ttyp1
+N: ttyp1
+E: DEVNAME=/dev/ttyp1
+E: DEVPATH=/devices/virtual/tty/ttyp1
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=1
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54513427
+
+P: /devices/virtual/tty/ttyp2
+N: ttyp2
+E: DEVNAME=/dev/ttyp2
+E: DEVPATH=/devices/virtual/tty/ttyp2
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=2
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54520355
+
+P: /devices/virtual/tty/ttyp3
+N: ttyp3
+E: DEVNAME=/dev/ttyp3
+E: DEVPATH=/devices/virtual/tty/ttyp3
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54583129
+
+P: /devices/virtual/tty/ttyp4
+N: ttyp4
+E: DEVNAME=/dev/ttyp4
+E: DEVPATH=/devices/virtual/tty/ttyp4
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=4
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54587585
+
+P: /devices/virtual/tty/ttyp5
+N: ttyp5
+E: DEVNAME=/dev/ttyp5
+E: DEVPATH=/devices/virtual/tty/ttyp5
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=5
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54612457
+
+P: /devices/virtual/tty/ttyp6
+N: ttyp6
+E: DEVNAME=/dev/ttyp6
+E: DEVPATH=/devices/virtual/tty/ttyp6
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=6
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54618347
+
+P: /devices/virtual/tty/ttyp7
+N: ttyp7
+E: DEVNAME=/dev/ttyp7
+E: DEVPATH=/devices/virtual/tty/ttyp7
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=7
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54642181
+
+P: /devices/virtual/tty/ttyp8
+N: ttyp8
+E: DEVNAME=/dev/ttyp8
+E: DEVPATH=/devices/virtual/tty/ttyp8
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=8
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54667541
+
+P: /devices/virtual/tty/ttyp9
+N: ttyp9
+E: DEVNAME=/dev/ttyp9
+E: DEVPATH=/devices/virtual/tty/ttyp9
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=9
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54677215
+
+P: /devices/virtual/tty/ttypa
+N: ttypa
+E: DEVNAME=/dev/ttypa
+E: DEVPATH=/devices/virtual/tty/ttypa
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=10
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54686981
+
+P: /devices/virtual/tty/ttypb
+N: ttypb
+E: DEVNAME=/dev/ttypb
+E: DEVPATH=/devices/virtual/tty/ttypb
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=11
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54721923
+
+P: /devices/virtual/tty/ttypc
+N: ttypc
+E: DEVNAME=/dev/ttypc
+E: DEVPATH=/devices/virtual/tty/ttypc
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=12
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54748687
+
+P: /devices/virtual/tty/ttypd
+N: ttypd
+E: DEVNAME=/dev/ttypd
+E: DEVPATH=/devices/virtual/tty/ttypd
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=13
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54811401
+
+P: /devices/virtual/tty/ttype
+N: ttype
+E: DEVNAME=/dev/ttype
+E: DEVPATH=/devices/virtual/tty/ttype
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=14
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54836883
+
+P: /devices/virtual/tty/ttypf
+N: ttypf
+E: DEVNAME=/dev/ttypf
+E: DEVPATH=/devices/virtual/tty/ttypf
+E: ID_MM_CANDIDATE=1
+E: MAJOR=3
+E: MINOR=15
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54838409
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: DEVNAME=/dev/ttyprintk
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: ID_MM_CANDIDATE=1
+E: MAJOR=5
+E: MINOR=3
+E: SUBSYSTEM=tty
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=54842712
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: DEVNAME=/dev/vcs
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: DEVNAME=/dev/vcs1
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: DEVNAME=/dev/vcs2
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: DEVNAME=/dev/vcs3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: DEVNAME=/dev/vcs4
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: DEVNAME=/dev/vcs5
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: DEVNAME=/dev/vcs6
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcs7
+N: vcs7
+E: DEVNAME=/dev/vcs7
+E: DEVPATH=/devices/virtual/vc/vcs7
+E: MAJOR=7
+E: MINOR=7
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: DEVNAME=/dev/vcsa
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: DEVNAME=/dev/vcsa1
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: DEVNAME=/dev/vcsa2
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: DEVNAME=/dev/vcsa3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: DEVNAME=/dev/vcsa4
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: DEVNAME=/dev/vcsa5
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: DEVNAME=/dev/vcsa6
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vc/vcsa7
+N: vcsa7
+E: DEVNAME=/dev/vcsa7
+E: DEVPATH=/devices/virtual/vc/vcsa7
+E: MAJOR=7
+E: MINOR=135
+E: SUBSYSTEM=vc
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon0
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/vtconsole/vtcon1
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+E: UDEV_LOG=3
+
+P: /devices/virtual/block/dm-0
+N: dm-0
+S: disk/by-id/dm-name-cryptswap1
+S: disk/by-id/dm-uuid-CRYPT-PLAIN-cryptswap1_unformatted
+S: disk/by-uuid/54c5ef5e-06b5-4c30-9e1f-27da907aed98
+S: mapper/cryptswap1
+E: DEVLINKS=/dev/disk/by-id/dm-name-cryptswap1 /dev/disk/by-id/dm-uuid-CRYPT-PLAIN-cryptswap1_unformatted /dev/disk/by-uuid/54c5ef5e-06b5-4c30-9e1f-27da907aed98 /dev/mapper/cryptswap1
+E: DEVNAME=/dev/dm-0
+E: DEVPATH=/devices/virtual/block/dm-0
+E: DEVTYPE=disk
+E: DM_NAME=cryptswap1
+E: DM_SUSPENDED=0
+E: DM_UDEV_DISABLE_LIBRARY_FALLBACK_FLAG=1
+E: DM_UDEV_PRIMARY_SOURCE_FLAG=1
+E: DM_UDEV_RULES=1
+E: DM_UUID=CRYPT-PLAIN-cryptswap1_unformatted
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_FS_UUID=54c5ef5e-06b5-4c30-9e1f-27da907aed98
+E: ID_FS_UUID_ENC=54c5ef5e-06b5-4c30-9e1f-27da907aed98
+E: ID_FS_VERSION=2
+E: MAJOR=253
+E: MINOR=0
+E: NPARTS=0
+E: SUBSYSTEM=block
+E: UDEV_LOG=3
+E: USEC_INITIALIZED=58841583
\ No newline at end of file

=== added file 'checkbox-support/checkbox_support/parsers/tests/udevadm_data/SAMSUNG_N310.txt'
--- checkbox-support/checkbox_support/parsers/tests/udevadm_data/SAMSUNG_N310.txt	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/tests/udevadm_data/SAMSUNG_N310.txt	2014-01-07 13:39:38 +0000
@@ -0,0 +1,4092 @@
+P: /devices/LNXSYSTM:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00
+E: MODALIAS=acpi:LNXSYSTM:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/LNXCPU:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:00
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/LNXCPU:01
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXCPU:01
+E: DRIVER=processor
+E: MODALIAS=acpi:LNXCPU:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00
+E: DRIVER=button
+E: MODALIAS=acpi:LNXPWRBN:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3
+E: PRODUCT=19/0/1/0
+E: NAME="Power Button"
+E: PHYS="LNXPWRBN/button/input0"
+E: PROP=0
+E: EV=3
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+
+P: /devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+N: input/event3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/LNXPWRBN:00/input/input3/event3
+E: MAJOR=13
+E: MINOR=67
+E: DEVNAME=/dev/input/event3
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXPWRBN:00
+E: ID_PATH_TAG=acpi-LNXPWRBN_00
+E: XKBMODEL=pc105
+E: XKBLAYOUT=us
+E: DMI_VENDOR=SAMSUNG ELECTRONICS CO., LTD.
+
+P: /devices/LNXSYSTM:00/device:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00
+E: DRIVER=ac
+E: MODALIAS=acpi:ACPI0003:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/ADP1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/ACPI0003:00/power_supply/ADP1
+E: POWER_SUPPLY_NAME=ADP1
+E: POWER_SUPPLY_ONLINE=1
+E: SUBSYSTEM=power_supply
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00
+E: DRIVER=pci_root
+E: MODALIAS=acpi:PNP0A08:PNP0A03:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00
+E: DRIVER=video
+E: MODALIAS=acpi:LNXVIDEO:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:01
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:02
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:03
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:04
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/device:05
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input5
+E: PRODUCT=19/0/6/0
+E: NAME="Video Bus"
+E: PHYS="LNXVIDEO/video/input0"
+E: PROP=0
+E: EV=3
+E: KEY=3e000b 0 0 0 0 0 0 0
+E: MODALIAS=input:b0019v0000p0006e0000-e0,1,kE0,E1,E3,F1,F2,F3,F4,F5,ramlsfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input5/event5
+N: input/event5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/LNXVIDEO:00/input/input5/event5
+E: MAJOR=13
+E: MINOR=69
+E: DEVNAME=/dev/input/event5
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-LNXVIDEO:00
+E: ID_PATH_TAG=acpi-LNXVIDEO_00
+E: XKBMODEL=pc105
+E: XKBLAYOUT=us
+E: DMI_VENDOR=SAMSUNG ELECTRONICS CO., LTD.
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/PNP0C02:00
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:06
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:07
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:07
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:07/device:08
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:07/device:08
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09/device:0a
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:09/device:0a
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b/device:0c
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0b/device:0c
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0d
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0e
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0e
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0f
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:0f
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:10
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:10
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:13
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:13
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:14
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:14
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:15
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:15
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:16
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:16
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:17
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:17
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:18
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:18
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:19
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:19
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:1a
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:11/device:12/device:1a
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1c
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1c
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1d
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1d
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1e
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1e
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1f
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:1f
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:20
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:20
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:21
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:1b/device:21
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/INT0800:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/INT0800:00
+E: MODALIAS=acpi:INT0800:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0000:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0000:00
+E: MODALIAS=acpi:PNP0000:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0100:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0100:00
+E: MODALIAS=acpi:PNP0100:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0103:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0103:00
+E: MODALIAS=acpi:PNP0103:PNP0C01:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0200:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0200:00
+E: MODALIAS=acpi:PNP0200:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0303:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0303:00
+E: MODALIAS=acpi:PNP0303:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0B00:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0B00:00
+E: MODALIAS=acpi:PNP0B00:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C02:01
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C02:01
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C02:02
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C02:02
+E: MODALIAS=acpi:PNP0C02:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C04:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C04:00
+E: MODALIAS=acpi:PNP0C04:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C09:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C09:00
+E: DRIVER=ec
+E: MODALIAS=acpi:PNP0C09:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C09:00/PNP0C0A:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C09:00/PNP0C0A:00
+E: DRIVER=battery
+E: MODALIAS=acpi:PNP0C0A:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C09:00/PNP0C0A:00/power_supply/BAT1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C09:00/PNP0C0A:00/power_supply/BAT1
+E: POWER_SUPPLY_NAME=BAT1
+E: POWER_SUPPLY_STATUS=Charging
+E: POWER_SUPPLY_PRESENT=1
+E: POWER_SUPPLY_TECHNOLOGY=Li-ion
+E: POWER_SUPPLY_CYCLE_COUNT=0
+E: POWER_SUPPLY_VOLTAGE_MIN_DESIGN=7500000
+E: POWER_SUPPLY_VOLTAGE_NOW=7770000
+E: POWER_SUPPLY_CURRENT_NOW=3196000
+E: POWER_SUPPLY_CHARGE_FULL_DESIGN=8850000
+E: POWER_SUPPLY_CHARGE_FULL=7900000
+E: POWER_SUPPLY_CHARGE_NOW=869000
+E: SUBSYSTEM=power_supply
+E: POWER_SUPPLY_MANUFACTURER=SAMSUNG Electronics
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:00
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:01
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:01
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:02
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:02
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:03
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:03
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:04
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:04
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:05
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:05
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:06
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:06
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:07
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0C0F:07
+E: DRIVER=pci_link
+E: MODALIAS=acpi:PNP0C0F:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0F13:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:22/PNP0F13:00
+E: MODALIAS=acpi:PNP0F13:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:24
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:24
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:24/device:25
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:24/device:25
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:24/device:26
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:24/device:26
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:27
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:27
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:27/device:28
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:27/device:28
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:27/device:29
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:23/device:27/device:29
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2a
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0A08:00/device:2a
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0C:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1
+E: PRODUCT=19/0/1/0
+E: NAME="Power Button"
+E: PHYS="PNP0C0C/button/input0"
+E: PROP=0
+E: EV=3
+E: KEY=100000 0 0 0
+E: MODALIAS=input:b0019v0000p0001e0000-e0,1,k74,ramlsfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+N: input/event1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0C:00/input/input1/event1
+E: MAJOR=13
+E: MINOR=65
+E: DEVNAME=/dev/input/event1
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0C:00
+E: ID_PATH_TAG=acpi-PNP0C0C_00
+E: XKBMODEL=pc105
+E: XKBLAYOUT=us
+E: DMI_VENDOR=SAMSUNG ELECTRONICS CO., LTD.
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0D:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0
+E: PRODUCT=19/0/5/0
+E: NAME="Lid Switch"
+E: PHYS="PNP0C0D/button/input0"
+E: PROP=0
+E: EV=21
+E: SW=1
+E: MODALIAS=input:b0019v0000p0005e0000-e0,5,kramlsfw0,
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+N: input/event0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0D:00/input/input0/event0
+E: MAJOR=13
+E: MINOR=64
+E: DEVNAME=/dev/input/event0
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_PATH=acpi-PNP0C0D:00
+E: ID_PATH_TAG=acpi-PNP0C0D_00
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00
+E: DRIVER=button
+E: MODALIAS=acpi:PNP0C0E:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2
+E: PRODUCT=19/0/3/0
+E: NAME="Sleep Button"
+E: PHYS="PNP0C0E/button/input0"
+E: PROP=0
+E: EV=3
+E: KEY=4000 0 0 0 0
+E: MODALIAS=input:b0019v0000p0003e0000-e0,1,k8E,ramlsfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+
+P: /devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2/event2
+N: input/event2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:00/PNP0C0E:00/input/input2/event2
+E: MAJOR=13
+E: MINOR=66
+E: DEVNAME=/dev/input/event2
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_PATH=acpi-PNP0C0E:00
+E: ID_PATH_TAG=acpi-PNP0C0E_00
+E: XKBMODEL=pc105
+E: XKBLAYOUT=us
+E: DMI_VENDOR=SAMSUNG ELECTRONICS CO., LTD.
+
+P: /devices/LNXSYSTM:00/device:2b
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:2b
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:2b/LNXPOWER:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:2b/LNXPOWER:00
+E: DRIVER=power
+E: MODALIAS=acpi:LNXPOWER:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:2b/LNXTHERM:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:2b/LNXTHERM:00
+E: DRIVER=thermal
+E: MODALIAS=acpi:LNXTHERM:
+E: SUBSYSTEM=acpi
+
+P: /devices/LNXSYSTM:00/device:2b/PNP0C0B:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/LNXSYSTM:00/device:2b/PNP0C0B:00
+E: DRIVER=fan
+E: MODALIAS=acpi:PNP0C0B:
+E: SUBSYSTEM=acpi
+
+P: /devices/breakpoint
+E: UDEV_LOG=3
+E: DEVPATH=/devices/breakpoint
+E: SUBSYSTEM=event_source
+
+P: /devices/cpu
+E: UDEV_LOG=3
+E: DEVPATH=/devices/cpu
+E: SUBSYSTEM=event_source
+
+P: /devices/pci0000:00/0000:00:00.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:00.0
+E: DRIVER=agpgart-intel
+E: PCI_CLASS=60000
+E: PCI_ID=8086:27AC
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:00.0
+E: MODALIAS=pci:v00008086d000027ACsv0000144Dsd0000C052bc06sc00i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:02.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0
+E: DRIVER=i915
+E: PCI_CLASS=30000
+E: PCI_ID=8086:27AE
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:02.0
+E: MODALIAS=pci:v00008086d000027AEsv0000144Dsd0000C052bc03sc00i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0
+N: dri/card0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0
+E: MAJOR=226
+E: MINOR=0
+E: DEVNAME=/dev/dri/card0
+E: DEVTYPE=drm_minor
+E: SUBSYSTEM=drm
+E: TAGS=:udev-acl:
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1
+E: SUBSYSTEM=drm
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-LVDS-1/intel_backlight
+E: SUBSYSTEM=backlight
+
+P: /devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/card0/card0-VGA-1
+E: SUBSYSTEM=drm
+
+P: /devices/pci0000:00/0000:00:02.0/drm/controlD64
+N: dri/controlD64
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/drm/controlD64
+E: MAJOR=226
+E: MINOR=64
+E: DEVNAME=/dev/dri/controlD64
+E: DEVTYPE=drm_minor
+E: SUBSYSTEM=drm
+
+P: /devices/pci0000:00/0000:00:02.0/graphics/fb0
+N: fb0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/graphics/fb0
+E: MAJOR=29
+E: MINOR=0
+E: DEVNAME=/dev/fb0
+E: SUBSYSTEM=graphics
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-0
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-1
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-10
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-10
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-11
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-11
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-12
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-12
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-13
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-13
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-2
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-3
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-4
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-5
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-6
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-7
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-8
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-8
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.0/i2c-9
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.0/i2c-9
+E: SUBSYSTEM=i2c
+
+P: /devices/pci0000:00/0000:00:02.1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:02.1
+E: PCI_CLASS=38000
+E: PCI_ID=8086:27A6
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:02.1
+E: MODALIAS=pci:v00008086d000027A6sv0000144Dsd0000C052bc03sc80i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1b.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0
+E: DRIVER=HDA Intel
+E: PCI_CLASS=40300
+E: PCI_ID=8086:27D8
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1b.0
+E: MODALIAS=pci:v00008086d000027D8sv0000144Dsd0000C052bc04sc03i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0
+E: SUBSYSTEM=sound
+E: SOUND_INITIALIZED=1
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_MODEL_FROM_DATABASE=N10/ICH 7 Family High Definition Audio Controller
+E: ID_BUS=pci
+E: ID_VENDOR_ID=0x8086
+E: ID_MODEL_ID=0x27d8
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: SOUND_FORM_FACTOR=internal
+E: PULSE_PROFILE_SET=extra-hdmi.conf
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+N: snd/hwC0D0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/hwC0D0
+E: MAJOR=116
+E: MINOR=4
+E: DEVNAME=/dev/snd/hwC0D0
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8
+E: PRODUCT=0/0/0/0
+E: NAME="HDA Intel Mic"
+E: PHYS="ALSA"
+E: PROP=0
+E: EV=21
+E: SW=10
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw4,
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_SNDJACK=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+N: input/event8
+S: input/by-path/pci-0000:00:1b.0-event-sndjack
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input8/event8
+E: MAJOR=13
+E: MINOR=72
+E: DEVNAME=/dev/input/event8
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_SNDJACK=1
+E: ID_SERIAL=noserial
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: DEVLINKS=/dev/input/by-path/pci-0000:00:1b.0-event-sndjack
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9
+E: PRODUCT=0/0/0/0
+E: NAME="HDA Intel Headphone"
+E: PHYS="ALSA"
+E: PROP=0
+E: EV=21
+E: SW=4
+E: MODALIAS=input:b0000v0000p0000e0000-e0,5,kramlsfw2,
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_SNDJACK=1
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+N: input/event9
+S: input/by-path/pci-0000:00:1b.0-event-sndjack
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/input9/event9
+E: MAJOR=13
+E: MINOR=73
+E: DEVNAME=/dev/input/event9
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_SNDJACK=1
+E: ID_SERIAL=noserial
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: DEVLINKS=/dev/input/by-path/pci-0000:00:1b.0-event-sndjack
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+N: snd/pcmC0D0c
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0c
+E: MAJOR=116
+E: MINOR=3
+E: DEVNAME=/dev/snd/pcmC0D0c
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+N: snd/pcmC0D0p
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/pcmC0D0p
+E: MAJOR=116
+E: MINOR=2
+E: DEVNAME=/dev/snd/pcmC0D0p
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+
+P: /devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+N: snd/controlC0
+S: snd/by-path/pci-0000:00:1b.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1b.0/sound/card0/controlC0
+E: MAJOR=116
+E: MINOR=5
+E: DEVNAME=/dev/snd/controlC0
+E: SUBSYSTEM=sound
+E: ID_PATH=pci-0000:00:1b.0
+E: ID_PATH_TAG=pci-0000_00_1b_0
+E: DEVLINKS=/dev/snd/by-path/pci-0000:00:1b.0
+E: TAGS=:udev-acl:
+
+P: /devices/pci0000:00/0000:00:1c.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0
+E: DRIVER=pcieport
+E: PCI_CLASS=60400
+E: PCI_ID=8086:27D0
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1c.0
+E: MODALIAS=pci:v00008086d000027D0sv0000144Dsd0000C052bc06sc04i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie08
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:00:1c.0:pcie08
+E: SUBSYSTEM=pci_express
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:02:00.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:02:00.0
+E: DRIVER=ath5k
+E: PCI_CLASS=20000
+E: PCI_ID=168C:001C
+E: PCI_SUBSYS_ID=144F:7130
+E: PCI_SLOT_NAME=0000:02:00.0
+E: MODALIAS=pci:v0000168Cd0000001Csv0000144Fsd00007130bc02sc00i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:02:00.0/ieee80211/phy0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:02:00.0/ieee80211/phy0
+E: SUBSYSTEM=ieee80211
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:02:00.0/ieee80211/phy0/rfkill1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:02:00.0/ieee80211/phy0/rfkill1
+E: RFKILL_NAME=phy0
+E: RFKILL_TYPE=wlan
+E: RFKILL_STATE=1
+E: SUBSYSTEM=rfkill
+
+P: /devices/pci0000:00/0000:00:1c.0/0000:02:00.0/net/wlan0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/0000:02:00.0/net/wlan0
+E: DEVTYPE=wlan
+E: INTERFACE=wlan0
+E: IFINDEX=3
+E: SUBSYSTEM=net
+E: ID_VENDOR_FROM_DATABASE=Atheros Communications Inc.
+E: ID_MODEL_FROM_DATABASE=AR242x / AR542x Wireless Network Adapter (PCI-Express)
+E: ID_BUS=pci
+E: ID_VENDOR_ID=0x168c
+E: ID_MODEL_ID=0x001c
+E: ID_MM_CANDIDATE=1
+
+P: /devices/pci0000:00/0000:00:1c.0/pci_bus/0000:02
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.0/pci_bus/0000:02
+E: SUBSYSTEM=pci_bus
+
+P: /devices/pci0000:00/0000:00:1c.2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2
+E: DRIVER=pcieport
+E: PCI_CLASS=60400
+E: PCI_ID=8086:27D4
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1c.2
+E: MODALIAS=pci:v00008086d000027D4sv0000144Dsd0000C052bc06sc04i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:00:1c.2:pcie08
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:00:1c.2:pcie08
+E: SUBSYSTEM=pci_express
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0
+E: DRIVER=sky2
+E: PCI_CLASS=20000
+E: PCI_ID=11AB:4354
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:03:00.0
+E: MODALIAS=pci:v000011ABd00004354sv0000144Dsd0000C052bc02sc00i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1c.2/0000:03:00.0/net/eth0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/0000:03:00.0/net/eth0
+E: INTERFACE=eth0
+E: IFINDEX=2
+E: SUBSYSTEM=net
+E: ID_VENDOR_FROM_DATABASE=Marvell Technology Group Ltd.
+E: ID_MODEL_FROM_DATABASE=88E8040 PCI-E Fast Ethernet Controller
+E: ID_BUS=pci
+E: ID_VENDOR_ID=0x11ab
+E: ID_MODEL_ID=0x4354
+E: ID_MM_CANDIDATE=1
+
+P: /devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1c.2/pci_bus/0000:03
+E: SUBSYSTEM=pci_bus
+
+P: /devices/pci0000:00/0000:00:1d.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0
+E: DRIVER=uhci_hcd
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27C8
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1d.0
+E: MODALIAS=pci:v00008086d000027C8sv0000144Dsd0000C052bc0Csc03i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2
+N: bus/usb/002/001
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2
+E: MAJOR=189
+E: MINOR=128
+E: DEVNAME=/dev/bus/usb/002/001
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: BUSNUM=002
+E: DEVNUM=001
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Linux_3.0.0-11-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.0.0-11-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0300
+E: ID_SERIAL=Linux_3.0.0-11-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.0
+E: ID_SERIAL_SHORT=0000:00:1d.0
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:090000:
+
+P: /devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usb2/2-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0300dc09dsc00dp00ic09isc00ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+N: usbmon2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.0/usbmon/usbmon2
+E: MAJOR=252
+E: MINOR=2
+E: DEVNAME=/dev/usbmon2
+E: SUBSYSTEM=usbmon
+
+P: /devices/pci0000:00/0000:00:1d.1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1
+E: DRIVER=uhci_hcd
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27C9
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1d.1
+E: MODALIAS=pci:v00008086d000027C9sv0000144Dsd0000C052bc0Csc03i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1d.1/usb3
+N: bus/usb/003/001
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usb3
+E: MAJOR=189
+E: MINOR=256
+E: DEVNAME=/dev/bus/usb/003/001
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: BUSNUM=003
+E: DEVNUM=001
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Linux_3.0.0-11-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.0.0-11-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0300
+E: ID_SERIAL=Linux_3.0.0-11-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.1
+E: ID_SERIAL_SHORT=0000:00:1d.1
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:090000:
+
+P: /devices/pci0000:00/0000:00:1d.1/usb3/3-0:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usb3/3-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0300dc09dsc00dp00ic09isc00ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.1/usbmon/usbmon3
+N: usbmon3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.1/usbmon/usbmon3
+E: MAJOR=252
+E: MINOR=3
+E: DEVNAME=/dev/usbmon3
+E: SUBSYSTEM=usbmon
+
+P: /devices/pci0000:00/0000:00:1d.2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2
+E: DRIVER=uhci_hcd
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27CA
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1d.2
+E: MODALIAS=pci:v00008086d000027CAsv0000144Dsd0000C052bc0Csc03i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4
+N: bus/usb/004/001
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4
+E: MAJOR=189
+E: MINOR=384
+E: DEVNAME=/dev/bus/usb/004/001
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: BUSNUM=004
+E: DEVNUM=001
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Linux_3.0.0-11-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.0.0-11-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0300
+E: ID_SERIAL=Linux_3.0.0-11-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.2
+E: ID_SERIAL_SHORT=0000:00:1d.2
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:090000:
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-0:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0300dc09dsc00dp00ic09isc00ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2
+N: bus/usb/004/002
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2
+E: MAJOR=189
+E: MINOR=385
+E: DEVNAME=/dev/bus/usb/004/002
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=a5c/2151/847
+E: TYPE=224/1/1
+E: BUSNUM=004
+E: DEVNUM=002
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Broadcom_Corp
+E: ID_VENDOR_ENC=Broadcom\x20Corp
+E: ID_VENDOR_ID=0a5c
+E: ID_MODEL=BCM2046_Bluetooth_Device
+E: ID_MODEL_ENC=BCM2046\x20Bluetooth\x20Device
+E: ID_MODEL_ID=2151
+E: ID_REVISION=0847
+E: ID_SERIAL=Broadcom_Corp_BCM2046_Bluetooth_Device_0C6076C5FB74
+E: ID_SERIAL_SHORT=0C6076C5FB74
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:e00101:ffffff:fe0101:
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: PRODUCT=a5c/2151/847
+E: TYPE=224/1/1
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0A5Cp2151d0847dcE0dsc01dp01icE0isc01ip01
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.0/bluetooth/hci0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.0/bluetooth/hci0
+E: DEVTYPE=host
+E: SUBSYSTEM=bluetooth
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.0/bluetooth/hci0/rfkill3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.0/bluetooth/hci0/rfkill3
+E: RFKILL_NAME=hci0
+E: RFKILL_TYPE=bluetooth
+E: RFKILL_STATE=1
+E: SUBSYSTEM=rfkill
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=btusb
+E: PRODUCT=a5c/2151/847
+E: TYPE=224/1/1
+E: INTERFACE=224/1/1
+E: MODALIAS=usb:v0A5Cp2151d0847dcE0dsc01dp01icE0isc01ip01
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.2
+E: DEVTYPE=usb_interface
+E: PRODUCT=a5c/2151/847
+E: TYPE=224/1/1
+E: INTERFACE=255/255/255
+E: MODALIAS=usb:v0A5Cp2151d0847dcE0dsc01dp01icFFiscFFipFF
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usb4/4-2/4-2:1.3
+E: DEVTYPE=usb_interface
+E: PRODUCT=a5c/2151/847
+E: TYPE=224/1/1
+E: INTERFACE=254/1/1
+E: MODALIAS=usb:v0A5Cp2151d0847dcE0dsc01dp01icFEisc01ip01
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.2/usbmon/usbmon4
+N: usbmon4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.2/usbmon/usbmon4
+E: MAJOR=252
+E: MINOR=4
+E: DEVNAME=/dev/usbmon4
+E: SUBSYSTEM=usbmon
+
+P: /devices/pci0000:00/0000:00:1d.3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3
+E: DRIVER=uhci_hcd
+E: PCI_CLASS=C0300
+E: PCI_ID=8086:27CB
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1d.3
+E: MODALIAS=pci:v00008086d000027CBsv0000144Dsd0000C052bc0Csc03i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1d.3/usb5
+N: bus/usb/005/001
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3/usb5
+E: MAJOR=189
+E: MINOR=512
+E: DEVNAME=/dev/bus/usb/005/001
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: BUSNUM=005
+E: DEVNUM=001
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Linux_3.0.0-11-generic_uhci_hcd
+E: ID_VENDOR_ENC=Linux\x203.0.0-11-generic\x20uhci_hcd
+E: ID_VENDOR_ID=1d6b
+E: ID_MODEL=UHCI_Host_Controller
+E: ID_MODEL_ENC=UHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0001
+E: ID_REVISION=0300
+E: ID_SERIAL=Linux_3.0.0-11-generic_uhci_hcd_UHCI_Host_Controller_0000:00:1d.3
+E: ID_SERIAL_SHORT=0000:00:1d.3
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:090000:
+
+P: /devices/pci0000:00/0000:00:1d.3/usb5/5-0:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3/usb5/5-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: PRODUCT=1d6b/1/300
+E: TYPE=9/0/0
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0001d0300dc09dsc00dp00ic09isc00ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.3/usbmon/usbmon5
+N: usbmon5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.3/usbmon/usbmon5
+E: MAJOR=252
+E: MINOR=5
+E: DEVNAME=/dev/usbmon5
+E: SUBSYSTEM=usbmon
+
+P: /devices/pci0000:00/0000:00:1d.7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7
+E: DRIVER=ehci_hcd
+E: PCI_CLASS=C0320
+E: PCI_ID=8086:27CC
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1d.7
+E: MODALIAS=pci:v00008086d000027CCsv0000144Dsd0000C052bc0Csc03i20
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1
+N: bus/usb/001/001
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1
+E: MAJOR=189
+E: MINOR=0
+E: DEVNAME=/dev/bus/usb/001/001
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=1d6b/2/300
+E: TYPE=9/0/0
+E: BUSNUM=001
+E: DEVNUM=001
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Linux_3.0.0-11-generic_ehci_hcd
+E: ID_VENDOR_ENC=Linux\x203.0.0-11-generic\x20ehci_hcd
+E: ID_VENDOR_ID=1d6b
+E: ID_MODEL=EHCI_Host_Controller
+E: ID_MODEL_ENC=EHCI\x20Host\x20Controller
+E: ID_MODEL_ID=0002
+E: ID_REVISION=0300
+E: ID_SERIAL=Linux_3.0.0-11-generic_ehci_hcd_EHCI_Host_Controller_0000:00:1d.7
+E: ID_SERIAL_SHORT=0000:00:1d.7
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:090000:
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-0:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-0:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=hub
+E: PRODUCT=1d6b/2/300
+E: TYPE=9/0/0
+E: INTERFACE=9/0/0
+E: MODALIAS=usb:v1D6Bp0002d0300dc09dsc00dp00ic09isc00ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-8
+N: bus/usb/001/004
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-8
+E: MAJOR=189
+E: MINOR=3
+E: DEVNAME=/dev/bus/usb/001/004
+E: DEVTYPE=usb_device
+E: DRIVER=usb
+E: PRODUCT=ac8/c335/100
+E: TYPE=239/2/1
+E: BUSNUM=001
+E: DEVNUM=004
+E: SUBSYSTEM=usb
+E: ID_VENDOR=Vimicro_Corp.
+E: ID_VENDOR_ENC=Vimicro\x20Corp.
+E: ID_VENDOR_ID=0ac8
+E: ID_MODEL=Namuga_1.3M_Webcam
+E: ID_MODEL_ENC=Namuga\x201.3M\x20Webcam
+E: ID_MODEL_ID=c335
+E: ID_REVISION=0100
+E: ID_SERIAL=Vimicro_Corp._Namuga_1.3M_Webcam
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: PRODUCT=ac8/c335/100
+E: TYPE=239/2/1
+E: INTERFACE=14/1/0
+E: MODALIAS=usb:v0AC8pC335d0100dcEFdsc02dp01ic0Eisc01ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0/input/input7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0/input/input7
+E: PRODUCT=3/ac8/c335/100
+E: NAME="Namuga 1.3M Webcam"
+E: PHYS="usb-0000:00:1d.7-8/button"
+E: PROP=0
+E: EV=3
+E: KEY=100000 0 0 0 0 0 0
+E: MODALIAS=input:b0003v0AC8pC335e0100-e0,1,kD4,ramlsfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_VENDOR=Vimicro_Corp.
+E: ID_VENDOR_ENC=Vimicro\x20Corp.
+E: ID_VENDOR_ID=0ac8
+E: ID_MODEL=Namuga_1.3M_Webcam
+E: ID_MODEL_ENC=Namuga\x201.3M\x20Webcam
+E: ID_MODEL_ID=c335
+E: ID_REVISION=0100
+E: ID_SERIAL=Vimicro_Corp._Namuga_1.3M_Webcam
+E: ID_TYPE=video
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_USB_DRIVER=uvcvideo
+E: ID_PATH=pci-0000:00:1d.7-usb-0:8:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_8_1_0
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0/input/input7/event7
+N: input/event7
+S: input/by-id/usb-Vimicro_Corp._Namuga_1.3M_Webcam-event-if00
+S: input/by-path/pci-0000:00:1d.7-usb-0:8:1.0-event
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0/input/input7/event7
+E: MAJOR=13
+E: MINOR=71
+E: DEVNAME=/dev/input/event7
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_VENDOR=Vimicro_Corp.
+E: ID_VENDOR_ENC=Vimicro\x20Corp.
+E: ID_VENDOR_ID=0ac8
+E: ID_MODEL=Namuga_1.3M_Webcam
+E: ID_MODEL_ENC=Namuga\x201.3M\x20Webcam
+E: ID_MODEL_ID=c335
+E: ID_REVISION=0100
+E: ID_SERIAL=Vimicro_Corp._Namuga_1.3M_Webcam
+E: ID_TYPE=video
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_USB_DRIVER=uvcvideo
+E: ID_PATH=pci-0000:00:1d.7-usb-0:8:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_8_1_0
+E: XKBMODEL=pc105
+E: XKBLAYOUT=us
+E: DEVLINKS=/dev/input/by-id/usb-Vimicro_Corp._Namuga_1.3M_Webcam-event-if00 /dev/input/by-path/pci-0000:00:1d.7-usb-0:8:1.0-event
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0/video4linux/video0
+N: video0
+S: v4l/by-id/usb-Vimicro_Corp._Namuga_1.3M_Webcam-video-index0
+S: v4l/by-path/pci-0000:00:1d.7-usb-0:8:1.0-video-index0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.0/video4linux/video0
+E: MAJOR=81
+E: MINOR=0
+E: DEVNAME=/dev/video0
+E: SUBSYSTEM=video4linux
+E: ID_V4L_VERSION=2
+E: ID_V4L_PRODUCT=Namuga 1.3M Webcam
+E: ID_V4L_CAPABILITIES=:capture:
+E: ID_VENDOR=Vimicro_Corp.
+E: ID_VENDOR_ENC=Vimicro\x20Corp.
+E: ID_VENDOR_ID=0ac8
+E: ID_MODEL=Namuga_1.3M_Webcam
+E: ID_MODEL_ENC=Namuga\x201.3M\x20Webcam
+E: ID_MODEL_ID=c335
+E: ID_REVISION=0100
+E: ID_SERIAL=Vimicro_Corp._Namuga_1.3M_Webcam
+E: ID_TYPE=video
+E: ID_BUS=usb
+E: ID_USB_INTERFACES=:0e0100:0e0200:
+E: ID_USB_INTERFACE_NUM=00
+E: ID_USB_DRIVER=uvcvideo
+E: ID_PATH=pci-0000:00:1d.7-usb-0:8:1.0
+E: ID_PATH_TAG=pci-0000_00_1d_7-usb-0_8_1_0
+E: COLORD_DEVICE=1
+E: COLORD_KIND=camera
+E: DEVLINKS=/dev/v4l/by-id/usb-Vimicro_Corp._Namuga_1.3M_Webcam-video-index0 /dev/v4l/by-path/pci-0000:00:1d.7-usb-0:8:1.0-video-index0
+E: TAGS=:udev-acl:
+
+P: /devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usb1/1-8/1-8:1.1
+E: DEVTYPE=usb_interface
+E: DRIVER=uvcvideo
+E: PRODUCT=ac8/c335/100
+E: TYPE=239/2/1
+E: INTERFACE=14/2/0
+E: MODALIAS=usb:v0AC8pC335d0100dcEFdsc02dp01ic0Eisc02ip00
+E: SUBSYSTEM=usb
+
+P: /devices/pci0000:00/0000:00:1d.7/usbmon/usbmon1
+N: usbmon1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1d.7/usbmon/usbmon1
+E: MAJOR=252
+E: MINOR=1
+E: DEVNAME=/dev/usbmon1
+E: SUBSYSTEM=usbmon
+
+P: /devices/pci0000:00/0000:00:1e.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0
+E: PCI_CLASS=60401
+E: PCI_ID=8086:2448
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1e.0
+E: MODALIAS=pci:v00008086d00002448sv0000144Dsd0000C052bc06sc04i01
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1e.0/pci_bus/0000:04
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1e.0/pci_bus/0000:04
+E: SUBSYSTEM=pci_bus
+
+P: /devices/pci0000:00/0000:00:1f.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.0
+E: PCI_CLASS=60100
+E: PCI_ID=8086:27B9
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1f.0
+E: MODALIAS=pci:v00008086d000027B9sv0000144Dsd0000C052bc06sc01i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/0000:00:1f.2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2
+E: DRIVER=ata_piix
+E: PCI_CLASS=10180
+E: PCI_ID=8086:27C4
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1f.2
+E: MODALIAS=pci:v00008086d000027C4sv0000144Dsd0000C052bc01sc01i80
+E: SUBSYSTEM=pci
+E: ID_VENDOR_FROM_DATABASE=Intel Corporation
+E: ID_MODEL_FROM_DATABASE=82801GBM/GHM (ICH7 Family) SATA IDE Controller
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/ata_port/ata1
+E: SUBSYSTEM=ata_port
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/ata_link/link1
+E: SUBSYSTEM=ata_link
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.0/ata_device/dev1.0
+E: SUBSYSTEM=ata_device
+
+P: /devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.1/ata_device/dev1.1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata1/link1/dev1.1/ata_device/dev1.1
+E: SUBSYSTEM=ata_device
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/ata_port/ata2
+E: SUBSYSTEM=ata_port
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/ata_link/link2
+E: SUBSYSTEM=ata_link
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.0/ata_device/dev2.0
+E: SUBSYSTEM=ata_device
+
+P: /devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.1/ata_device/dev2.1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/ata2/link2/dev2.1/ata_device/dev2.1
+E: SUBSYSTEM=ata_device
+
+P: /devices/pci0000:00/0000:00:1f.2/host0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/scsi_host/host0
+E: SUBSYSTEM=scsi_host
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0
+E: DEVTYPE=scsi_target
+E: SUBSYSTEM=scsi
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0
+E: DEVTYPE=scsi_device
+E: DRIVER=sd
+E: MODALIAS=scsi:t-0x00
+E: SUBSYSTEM=scsi
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+N: sda
+S: disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK
+S: disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0
+S: disk/by-id/wwn-0x500000e043e238d7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: MAJOR=8
+E: MINOR=0
+E: DEVNAME=/dev/sda
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: ID_ATA=1
+E: ID_TYPE=disk
+E: ID_BUS=ata
+E: ID_MODEL=FUJITSU_MHZ2160BH_G2
+E: ID_MODEL_ENC=FUJITSU\x20MHZ2160BH\x20G2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_REVISION=008B00B0
+E: ID_SERIAL=FUJITSU_MHZ2160BH_G2_K62TT982L0DK
+E: ID_SERIAL_SHORT=K62TT982L0DK
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=0
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=160
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_WWN=0x500000e043e238d7
+E: ID_WWN_WITH_EXTENSION=0x500000e043e238d7
+E: ID_SCSI_COMPAT=SATA_FUJITSU_MHZ2160_K62TT982L0DK
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_PART_TABLE_TYPE=dos
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: UDISKS_PARTITION_TABLE=1
+E: UDISKS_PARTITION_TABLE_SCHEME=mbr
+E: UDISKS_PARTITION_TABLE_COUNT=3
+E: UDISKS_ATA_SMART_IS_AVAILABLE=1
+E: DEVLINKS=/dev/disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK /dev/disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0 /dev/disk/by-id/wwn-0x500000e043e238d7
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+N: sda1
+S: disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK-part1
+S: disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK-part1
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1
+S: disk/by-uuid/1bb119c7-8018-4a18-bb28-81ef1b112bc2
+S: disk/by-id/wwn-0x500000e043e238d7-part1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda1
+E: MAJOR=8
+E: MINOR=1
+E: DEVNAME=/dev/sda1
+E: DEVTYPE=partition
+E: SUBSYSTEM=block
+E: ID_ATA=1
+E: ID_TYPE=disk
+E: ID_BUS=ata
+E: ID_MODEL=FUJITSU_MHZ2160BH_G2
+E: ID_MODEL_ENC=FUJITSU\x20MHZ2160BH\x20G2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_REVISION=008B00B0
+E: ID_SERIAL=FUJITSU_MHZ2160BH_G2_K62TT982L0DK
+E: ID_SERIAL_SHORT=K62TT982L0DK
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=0
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=160
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_WWN=0x500000e043e238d7
+E: ID_WWN_WITH_EXTENSION=0x500000e043e238d7
+E: ID_SCSI_COMPAT=SATA_FUJITSU_MHZ2160_K62TT982L0DK
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_PART_TABLE_TYPE=dos
+E: ID_FS_UUID=1bb119c7-8018-4a18-bb28-81ef1b112bc2
+E: ID_FS_UUID_ENC=1bb119c7-8018-4a18-bb28-81ef1b112bc2
+E: ID_FS_VERSION=1.0
+E: ID_FS_TYPE=ext4
+E: ID_FS_USAGE=filesystem
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_TYPE=0x83
+E: ID_PART_ENTRY_FLAGS=0x80
+E: ID_PART_ENTRY_NUMBER=1
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_NUMBER=1
+E: UDISKS_PARTITION_TYPE=0x83
+E: UDISKS_PARTITION_SIZE=158976704512
+E: UDISKS_PARTITION_FLAGS=boot
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_OFFSET=1048576
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: DEVLINKS=/dev/disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK-part1 /dev/disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK-part1 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part1 /dev/disk/by-uuid/1bb119c7-8018-4a18-bb28-81ef1b112bc2 /dev/disk/by-id/wwn-0x500000e043e238d7-part1
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+N: sda2
+S: disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK-part2
+S: disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK-part2
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2
+S: disk/by-id/wwn-0x500000e043e238d7-part2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda2
+E: MAJOR=8
+E: MINOR=2
+E: DEVNAME=/dev/sda2
+E: DEVTYPE=partition
+E: SUBSYSTEM=block
+E: ID_ATA=1
+E: ID_TYPE=disk
+E: ID_BUS=ata
+E: ID_MODEL=FUJITSU_MHZ2160BH_G2
+E: ID_MODEL_ENC=FUJITSU\x20MHZ2160BH\x20G2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_REVISION=008B00B0
+E: ID_SERIAL=FUJITSU_MHZ2160BH_G2_K62TT982L0DK
+E: ID_SERIAL_SHORT=K62TT982L0DK
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=0
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=160
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_WWN=0x500000e043e238d7
+E: ID_WWN_WITH_EXTENSION=0x500000e043e238d7
+E: ID_SCSI_COMPAT=SATA_FUJITSU_MHZ2160_K62TT982L0DK
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_PART_TABLE_TYPE=dos
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_TYPE=0x5
+E: ID_PART_ENTRY_NUMBER=2
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_NUMBER=2
+E: UDISKS_PARTITION_TYPE=0x05
+E: UDISKS_PARTITION_SIZE=1062208512
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_OFFSET=158978800640
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: DEVLINKS=/dev/disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK-part2 /dev/disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK-part2 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part2 /dev/disk/by-id/wwn-0x500000e043e238d7-part2
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+N: sda5
+S: disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK-part5
+S: disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK-part5
+S: disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5
+S: disk/by-uuid/709e8d46-2d28-47bb-af52-bab2bba6bb8b
+S: disk/by-id/wwn-0x500000e043e238d7-part5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda/sda5
+E: MAJOR=8
+E: MINOR=5
+E: DEVNAME=/dev/sda5
+E: DEVTYPE=partition
+E: SUBSYSTEM=block
+E: ID_ATA=1
+E: ID_TYPE=disk
+E: ID_BUS=ata
+E: ID_MODEL=FUJITSU_MHZ2160BH_G2
+E: ID_MODEL_ENC=FUJITSU\x20MHZ2160BH\x20G2\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20
+E: ID_REVISION=008B00B0
+E: ID_SERIAL=FUJITSU_MHZ2160BH_G2_K62TT982L0DK
+E: ID_SERIAL_SHORT=K62TT982L0DK
+E: ID_ATA_WRITE_CACHE=1
+E: ID_ATA_WRITE_CACHE_ENABLED=1
+E: ID_ATA_FEATURE_SET_HPA=1
+E: ID_ATA_FEATURE_SET_HPA_ENABLED=0
+E: ID_ATA_FEATURE_SET_PM=1
+E: ID_ATA_FEATURE_SET_PM_ENABLED=1
+E: ID_ATA_FEATURE_SET_SECURITY=1
+E: ID_ATA_FEATURE_SET_SECURITY_ENABLED=0
+E: ID_ATA_FEATURE_SET_SECURITY_ERASE_UNIT_MIN=160
+E: ID_ATA_FEATURE_SET_SECURITY_FROZEN=1
+E: ID_ATA_FEATURE_SET_SMART=1
+E: ID_ATA_FEATURE_SET_SMART_ENABLED=1
+E: ID_ATA_FEATURE_SET_AAM=1
+E: ID_ATA_FEATURE_SET_AAM_ENABLED=0
+E: ID_ATA_FEATURE_SET_AAM_VENDOR_RECOMMENDED_VALUE=254
+E: ID_ATA_FEATURE_SET_AAM_CURRENT_VALUE=0
+E: ID_ATA_FEATURE_SET_APM=1
+E: ID_ATA_FEATURE_SET_APM_ENABLED=1
+E: ID_ATA_FEATURE_SET_APM_CURRENT_VALUE=128
+E: ID_ATA_DOWNLOAD_MICROCODE=1
+E: ID_ATA_SATA=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN2=1
+E: ID_ATA_SATA_SIGNAL_RATE_GEN1=1
+E: ID_WWN=0x500000e043e238d7
+E: ID_WWN_WITH_EXTENSION=0x500000e043e238d7
+E: ID_SCSI_COMPAT=SATA_FUJITSU_MHZ2160_K62TT982L0DK
+E: ID_PATH=pci-0000:00:1f.2-scsi-0:0:0:0
+E: ID_PATH_TAG=pci-0000_00_1f_2-scsi-0_0_0_0
+E: ID_PART_TABLE_TYPE=dos
+E: ID_FS_UUID=709e8d46-2d28-47bb-af52-bab2bba6bb8b
+E: ID_FS_UUID_ENC=709e8d46-2d28-47bb-af52-bab2bba6bb8b
+E: ID_FS_VERSION=2
+E: ID_FS_TYPE=swap
+E: ID_FS_USAGE=other
+E: ID_PART_ENTRY_SCHEME=dos
+E: ID_PART_ENTRY_TYPE=0x82
+E: ID_PART_ENTRY_NUMBER=5
+E: UDISKS_PRESENTATION_NOPOLICY=0
+E: UDISKS_PARTITION=1
+E: UDISKS_PARTITION_SCHEME=mbr
+E: UDISKS_PARTITION_NUMBER=5
+E: UDISKS_PARTITION_TYPE=0x82
+E: UDISKS_PARTITION_SIZE=1062207488
+E: UDISKS_PARTITION_SLAVE=/sys/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/block/sda
+E: UDISKS_PARTITION_OFFSET=158978801664
+E: UDISKS_PARTITION_ALIGNMENT_OFFSET=0
+E: DEVLINKS=/dev/disk/by-id/ata-FUJITSU_MHZ2160BH_G2_K62TT982L0DK-part5 /dev/disk/by-id/scsi-SATA_FUJITSU_MHZ2160_K62TT982L0DK-part5 /dev/disk/by-path/pci-0000:00:1f.2-scsi-0:0:0:0-part5 /dev/disk/by-uuid/709e8d46-2d28-47bb-af52-bab2bba6bb8b /dev/disk/by-id/wwn-0x500000e043e238d7-part5
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+N: bsg/0:0:0:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/bsg/0:0:0:0
+E: MAJOR=253
+E: MINOR=0
+E: DEVNAME=/dev/bsg/0:0:0:0
+E: SUBSYSTEM=bsg
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_device/0:0:0:0
+E: SUBSYSTEM=scsi_device
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_disk/0:0:0:0
+E: SUBSYSTEM=scsi_disk
+
+P: /devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+N: sg0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host0/target0:0:0/0:0:0:0/scsi_generic/sg0
+E: MAJOR=21
+E: MINOR=0
+E: DEVNAME=/dev/sg0
+E: SUBSYSTEM=scsi_generic
+
+P: /devices/pci0000:00/0000:00:1f.2/host1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1
+E: DEVTYPE=scsi_host
+E: SUBSYSTEM=scsi
+
+P: /devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.2/host1/scsi_host/host1
+E: SUBSYSTEM=scsi_host
+
+P: /devices/pci0000:00/0000:00:1f.3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/0000:00:1f.3
+E: PCI_CLASS=C0500
+E: PCI_ID=8086:27DA
+E: PCI_SUBSYS_ID=144D:C052
+E: PCI_SLOT_NAME=0000:00:1f.3
+E: MODALIAS=pci:v00008086d000027DAsv0000144Dsd0000C052bc0Csc05i00
+E: SUBSYSTEM=pci
+
+P: /devices/pci0000:00/pci_bus/0000:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pci0000:00/pci_bus/0000:00
+E: SUBSYSTEM=pci_bus
+
+P: /devices/platform/Fixed MDIO bus.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0
+E: MODALIAS=platform:Fixed MDIO bus
+E: SUBSYSTEM=platform
+
+P: /devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/Fixed MDIO bus.0/mdio_bus/0
+E: SUBSYSTEM=mdio_bus
+
+P: /devices/platform/alarmtimer
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/alarmtimer
+E: DRIVER=alarmtimer
+E: MODALIAS=platform:alarmtimer
+E: SUBSYSTEM=platform
+
+P: /devices/platform/eisa.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/eisa.0
+E: MODALIAS=platform:eisa
+E: SUBSYSTEM=platform
+
+P: /devices/platform/i8042
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042
+E: DRIVER=i8042
+E: MODALIAS=platform:i8042
+E: SUBSYSTEM=platform
+
+P: /devices/platform/i8042/serio0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio0
+E: DRIVER=atkbd
+E: SERIO_TYPE=06
+E: SERIO_PROTO=00
+E: SERIO_ID=00
+E: SERIO_EXTRA=00
+E: MODALIAS=serio:ty06pr00id00ex00
+E: SUBSYSTEM=serio
+E: DMI_VENDOR=SAMSUNG ELECTRONICS CO., LTD.
+
+P: /devices/platform/i8042/serio0/input/input4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4
+E: PRODUCT=11/1/1/ab41
+E: NAME="AT Translated Set 2 keyboard"
+E: PHYS="isa0060/serio0/input0"
+E: PROP=0
+E: EV=120013
+E: KEY=500f 2000403 3803078 f870d001 feffffdf fbefffff ffffffff fffffffe
+E: MSC=10
+E: LED=7
+E: MODALIAS=input:b0011v0001p0001eAB41-e0,1,4,11,14,k71,72,73,74,75,76,77,79,7A,7B,7C,7D,7E,7F,80,8C,8E,8F,94,95,96,9B,9C,9D,9E,9F,A3,A4,A5,A6,AC,AD,B7,B8,B9,C0,C1,CA,D9,E0,E1,E2,E3,EC,EE,ram4,l0,1,2,sfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_SERIAL=noserial
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+
+P: /devices/platform/i8042/serio0/input/input4/event4
+N: input/event4
+S: input/by-path/platform-i8042-serio-0-event-kbd
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio0/input/input4/event4
+E: MAJOR=13
+E: MINOR=68
+E: DEVNAME=/dev/input/event4
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_KEY=1
+E: ID_INPUT_KEYBOARD=1
+E: ID_SERIAL=noserial
+E: ID_PATH=platform-i8042-serio-0
+E: ID_PATH_TAG=platform-i8042-serio-0
+E: XKBMODEL=pc105
+E: XKBLAYOUT=us
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-0-event-kbd
+E: DMI_VENDOR=SAMSUNG ELECTRONICS CO., LTD.
+
+P: /devices/platform/i8042/serio1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio1
+E: SERIO_TYPE=01
+E: SERIO_PROTO=00
+E: SERIO_ID=00
+E: SERIO_EXTRA=00
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SUBSYSTEM=serio
+
+P: /devices/platform/i8042/serio2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio2
+E: SERIO_TYPE=01
+E: SERIO_PROTO=00
+E: SERIO_ID=00
+E: SERIO_EXTRA=00
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SUBSYSTEM=serio
+
+P: /devices/platform/i8042/serio3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio3
+E: SERIO_TYPE=01
+E: SERIO_PROTO=00
+E: SERIO_ID=00
+E: SERIO_EXTRA=00
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SUBSYSTEM=serio
+
+P: /devices/platform/i8042/serio4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio4
+E: DRIVER=psmouse
+E: SERIO_TYPE=01
+E: SERIO_PROTO=00
+E: SERIO_ID=00
+E: SERIO_EXTRA=00
+E: MODALIAS=serio:ty01pr00id00ex00
+E: SUBSYSTEM=serio
+
+P: /devices/platform/i8042/serio4/input/input6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio4/input/input6
+E: PRODUCT=11/2/7/1b1
+E: NAME="SynPS/2 Synaptics TouchPad"
+E: PHYS="isa0060/serio4/input0"
+E: PROP=9
+E: EV=b
+E: KEY=6420 0 30000 0 0 0 0 0 0 0 0
+E: ABS=2608000 11000003
+E: MODALIAS=input:b0011v0002p0007e01B1-e0,1,3,k110,111,145,14A,14D,14E,ra0,1,18,1C,2F,35,36,39,mlsfw
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_SERIAL=noserial
+E: ID_PATH=platform-i8042-serio-4
+E: ID_PATH_TAG=platform-i8042-serio-4
+
+P: /devices/platform/i8042/serio4/input/input6/event6
+N: input/event6
+S: input/by-path/platform-i8042-serio-4-event-mouse
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio4/input/input6/event6
+E: MAJOR=13
+E: MINOR=70
+E: DEVNAME=/dev/input/event6
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_SERIAL=noserial
+E: ID_PATH=platform-i8042-serio-4
+E: ID_PATH_TAG=platform-i8042-serio-4
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-4-event-mouse
+
+P: /devices/platform/i8042/serio4/input/input6/mouse0
+N: input/mouse0
+S: input/by-path/platform-i8042-serio-4-mouse
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/i8042/serio4/input/input6/mouse0
+E: MAJOR=13
+E: MINOR=32
+E: DEVNAME=/dev/input/mouse0
+E: SUBSYSTEM=input
+E: ID_INPUT=1
+E: ID_INPUT_TOUCHPAD=1
+E: ID_SERIAL=noserial
+E: ID_PATH=platform-i8042-serio-4
+E: ID_PATH_TAG=platform-i8042-serio-4
+E: DEVLINKS=/dev/input/by-path/platform-i8042-serio-4-mouse
+
+P: /devices/platform/pcspkr
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/pcspkr
+E: MODALIAS=platform:pcspkr
+E: SUBSYSTEM=platform
+
+P: /devices/platform/reg-dummy
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/reg-dummy
+E: MODALIAS=platform:reg-dummy
+E: SUBSYSTEM=platform
+
+P: /devices/platform/regulatory.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/regulatory.0
+E: MODALIAS=platform:regulatory
+E: SUBSYSTEM=platform
+
+P: /devices/platform/serial8250
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250
+E: DRIVER=serial8250
+E: MODALIAS=platform:serial8250
+E: SUBSYSTEM=platform
+
+P: /devices/platform/serial8250/tty/ttyS0
+N: ttyS0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS0
+E: MAJOR=4
+E: MINOR=64
+E: DEVNAME=/dev/ttyS0
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS1
+N: ttyS1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS1
+E: MAJOR=4
+E: MINOR=65
+E: DEVNAME=/dev/ttyS1
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS10
+N: ttyS10
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS10
+E: MAJOR=4
+E: MINOR=74
+E: DEVNAME=/dev/ttyS10
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS11
+N: ttyS11
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS11
+E: MAJOR=4
+E: MINOR=75
+E: DEVNAME=/dev/ttyS11
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS12
+N: ttyS12
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS12
+E: MAJOR=4
+E: MINOR=76
+E: DEVNAME=/dev/ttyS12
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS13
+N: ttyS13
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS13
+E: MAJOR=4
+E: MINOR=77
+E: DEVNAME=/dev/ttyS13
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS14
+N: ttyS14
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS14
+E: MAJOR=4
+E: MINOR=78
+E: DEVNAME=/dev/ttyS14
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS15
+N: ttyS15
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS15
+E: MAJOR=4
+E: MINOR=79
+E: DEVNAME=/dev/ttyS15
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS16
+N: ttyS16
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS16
+E: MAJOR=4
+E: MINOR=80
+E: DEVNAME=/dev/ttyS16
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS17
+N: ttyS17
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS17
+E: MAJOR=4
+E: MINOR=81
+E: DEVNAME=/dev/ttyS17
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS18
+N: ttyS18
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS18
+E: MAJOR=4
+E: MINOR=82
+E: DEVNAME=/dev/ttyS18
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS19
+N: ttyS19
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS19
+E: MAJOR=4
+E: MINOR=83
+E: DEVNAME=/dev/ttyS19
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS2
+N: ttyS2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS2
+E: MAJOR=4
+E: MINOR=66
+E: DEVNAME=/dev/ttyS2
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS20
+N: ttyS20
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS20
+E: MAJOR=4
+E: MINOR=84
+E: DEVNAME=/dev/ttyS20
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS21
+N: ttyS21
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS21
+E: MAJOR=4
+E: MINOR=85
+E: DEVNAME=/dev/ttyS21
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS22
+N: ttyS22
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS22
+E: MAJOR=4
+E: MINOR=86
+E: DEVNAME=/dev/ttyS22
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS23
+N: ttyS23
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS23
+E: MAJOR=4
+E: MINOR=87
+E: DEVNAME=/dev/ttyS23
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS24
+N: ttyS24
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS24
+E: MAJOR=4
+E: MINOR=88
+E: DEVNAME=/dev/ttyS24
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS25
+N: ttyS25
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS25
+E: MAJOR=4
+E: MINOR=89
+E: DEVNAME=/dev/ttyS25
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS26
+N: ttyS26
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS26
+E: MAJOR=4
+E: MINOR=90
+E: DEVNAME=/dev/ttyS26
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS27
+N: ttyS27
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS27
+E: MAJOR=4
+E: MINOR=91
+E: DEVNAME=/dev/ttyS27
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS28
+N: ttyS28
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS28
+E: MAJOR=4
+E: MINOR=92
+E: DEVNAME=/dev/ttyS28
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS29
+N: ttyS29
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS29
+E: MAJOR=4
+E: MINOR=93
+E: DEVNAME=/dev/ttyS29
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS3
+N: ttyS3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS3
+E: MAJOR=4
+E: MINOR=67
+E: DEVNAME=/dev/ttyS3
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS30
+N: ttyS30
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS30
+E: MAJOR=4
+E: MINOR=94
+E: DEVNAME=/dev/ttyS30
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS31
+N: ttyS31
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS31
+E: MAJOR=4
+E: MINOR=95
+E: DEVNAME=/dev/ttyS31
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS4
+N: ttyS4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS4
+E: MAJOR=4
+E: MINOR=68
+E: DEVNAME=/dev/ttyS4
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS5
+N: ttyS5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS5
+E: MAJOR=4
+E: MINOR=69
+E: DEVNAME=/dev/ttyS5
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS6
+N: ttyS6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS6
+E: MAJOR=4
+E: MINOR=70
+E: DEVNAME=/dev/ttyS6
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS7
+N: ttyS7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS7
+E: MAJOR=4
+E: MINOR=71
+E: DEVNAME=/dev/ttyS7
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS8
+N: ttyS8
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS8
+E: MAJOR=4
+E: MINOR=72
+E: DEVNAME=/dev/ttyS8
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/platform/serial8250/tty/ttyS9
+N: ttyS9
+E: UDEV_LOG=3
+E: DEVPATH=/devices/platform/serial8250/tty/ttyS9
+E: MAJOR=4
+E: MINOR=73
+E: DEVNAME=/dev/ttyS9
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/pnp0/00:00
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:00
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:01
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:01
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:02
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:02
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:03
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:03
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:04
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:04
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:05
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:05
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:06
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:06
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:07
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:07
+E: DRIVER=system
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:08
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:08
+E: DRIVER=rtc_cmos
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:08/rtc/rtc0
+N: rtc0
+S: rtc
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:08/rtc/rtc0
+E: MAJOR=254
+E: MINOR=0
+E: DEVNAME=/dev/rtc0
+E: SUBSYSTEM=rtc
+E: DEVLINKS=/dev/rtc
+
+P: /devices/pnp0/00:09
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:09
+E: DRIVER=i8042 kbd
+E: SUBSYSTEM=pnp
+
+P: /devices/pnp0/00:0a
+E: UDEV_LOG=3
+E: DEVPATH=/devices/pnp0/00:0a
+E: DRIVER=i8042 aux
+E: SUBSYSTEM=pnp
+
+P: /devices/software
+E: UDEV_LOG=3
+E: DEVPATH=/devices/software
+E: SUBSYSTEM=event_source
+
+P: /devices/tracepoint
+E: UDEV_LOG=3
+E: DEVPATH=/devices/tracepoint
+E: SUBSYSTEM=event_source
+
+P: /devices/virtual/bdi/0:20
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/0:20
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:0
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:1
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:10
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:10
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:11
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:11
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:12
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:12
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:13
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:13
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:14
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:14
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:15
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:15
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:2
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:3
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:4
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:5
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:6
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:7
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:8
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:8
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/1:9
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/1:9
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:0
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:1
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:2
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:3
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:4
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:5
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:6
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/7:7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/7:7
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/8:0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/8:0
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/bdi/default
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/bdi/default
+E: SUBSYSTEM=bdi
+
+P: /devices/virtual/block/loop0
+N: loop0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop0
+E: MAJOR=7
+E: MINOR=0
+E: DEVNAME=/dev/loop0
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop1
+N: loop1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop1
+E: MAJOR=7
+E: MINOR=1
+E: DEVNAME=/dev/loop1
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop2
+N: loop2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop2
+E: MAJOR=7
+E: MINOR=2
+E: DEVNAME=/dev/loop2
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop3
+N: loop3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop3
+E: MAJOR=7
+E: MINOR=3
+E: DEVNAME=/dev/loop3
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop4
+N: loop4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop4
+E: MAJOR=7
+E: MINOR=4
+E: DEVNAME=/dev/loop4
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop5
+N: loop5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop5
+E: MAJOR=7
+E: MINOR=5
+E: DEVNAME=/dev/loop5
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop6
+N: loop6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop6
+E: MAJOR=7
+E: MINOR=6
+E: DEVNAME=/dev/loop6
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/loop7
+N: loop7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/loop7
+E: MAJOR=7
+E: MINOR=7
+E: DEVNAME=/dev/loop7
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+E: UDISKS_PRESENTATION_NOPOLICY=1
+
+P: /devices/virtual/block/ram0
+N: ram0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram0
+E: MAJOR=1
+E: MINOR=0
+E: DEVNAME=/dev/ram0
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram1
+N: ram1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram1
+E: MAJOR=1
+E: MINOR=1
+E: DEVNAME=/dev/ram1
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram10
+N: ram10
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram10
+E: MAJOR=1
+E: MINOR=10
+E: DEVNAME=/dev/ram10
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram11
+N: ram11
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram11
+E: MAJOR=1
+E: MINOR=11
+E: DEVNAME=/dev/ram11
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram12
+N: ram12
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram12
+E: MAJOR=1
+E: MINOR=12
+E: DEVNAME=/dev/ram12
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram13
+N: ram13
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram13
+E: MAJOR=1
+E: MINOR=13
+E: DEVNAME=/dev/ram13
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram14
+N: ram14
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram14
+E: MAJOR=1
+E: MINOR=14
+E: DEVNAME=/dev/ram14
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram15
+N: ram15
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram15
+E: MAJOR=1
+E: MINOR=15
+E: DEVNAME=/dev/ram15
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram2
+N: ram2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram2
+E: MAJOR=1
+E: MINOR=2
+E: DEVNAME=/dev/ram2
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram3
+N: ram3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram3
+E: MAJOR=1
+E: MINOR=3
+E: DEVNAME=/dev/ram3
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram4
+N: ram4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram4
+E: MAJOR=1
+E: MINOR=4
+E: DEVNAME=/dev/ram4
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram5
+N: ram5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram5
+E: MAJOR=1
+E: MINOR=5
+E: DEVNAME=/dev/ram5
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram6
+N: ram6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram6
+E: MAJOR=1
+E: MINOR=6
+E: DEVNAME=/dev/ram6
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram7
+N: ram7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram7
+E: MAJOR=1
+E: MINOR=7
+E: DEVNAME=/dev/ram7
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram8
+N: ram8
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram8
+E: MAJOR=1
+E: MINOR=8
+E: DEVNAME=/dev/ram8
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/block/ram9
+N: ram9
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/block/ram9
+E: MAJOR=1
+E: MINOR=9
+E: DEVNAME=/dev/ram9
+E: DEVTYPE=disk
+E: SUBSYSTEM=block
+
+P: /devices/virtual/dmi/id
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/dmi/id
+E: MODALIAS=dmi:bvnPhoenixTechnologiesLtd.:bvr03BA.M030.20090427.CYH:bd04/27/2009:svnSAMSUNGELECTRONICSCO.,LTD.:pnN310:pvrNotApplicable:rvnSAMSUNGELECTRONICSCO.,LTD.:rnN310:rvrNotApplicable:cvnSAMSUNGELECTRONICSCO.,LTD.:ct10:cvrN/A:
+E: SUBSYSTEM=dmi
+
+P: /devices/virtual/graphics/fbcon
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/graphics/fbcon
+E: SUBSYSTEM=graphics
+
+P: /devices/virtual/hwmon/hwmon0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/hwmon/hwmon0
+E: SUBSYSTEM=hwmon
+
+P: /devices/virtual/input/mice
+N: input/mice
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/input/mice
+E: MAJOR=13
+E: MINOR=63
+E: DEVNAME=/dev/input/mice
+E: SUBSYSTEM=input
+
+P: /devices/virtual/mem/full
+N: full
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/full
+E: MAJOR=1
+E: MINOR=7
+E: DEVNAME=/dev/full
+E: DEVMODE=0666
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/kmsg
+N: kmsg
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/kmsg
+E: MAJOR=1
+E: MINOR=11
+E: DEVNAME=/dev/kmsg
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/mem
+N: mem
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/mem
+E: MAJOR=1
+E: MINOR=1
+E: DEVNAME=/dev/mem
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/null
+N: null
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/null
+E: MAJOR=1
+E: MINOR=3
+E: DEVNAME=/dev/null
+E: DEVMODE=0666
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/oldmem
+N: oldmem
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/oldmem
+E: MAJOR=1
+E: MINOR=12
+E: DEVNAME=/dev/oldmem
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/port
+N: port
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/port
+E: MAJOR=1
+E: MINOR=4
+E: DEVNAME=/dev/port
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/random
+N: random
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/random
+E: MAJOR=1
+E: MINOR=8
+E: DEVNAME=/dev/random
+E: DEVMODE=0666
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/urandom
+N: urandom
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/urandom
+E: MAJOR=1
+E: MINOR=9
+E: DEVNAME=/dev/urandom
+E: DEVMODE=0666
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/mem/zero
+N: zero
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/mem/zero
+E: MAJOR=1
+E: MINOR=5
+E: DEVNAME=/dev/zero
+E: DEVMODE=0666
+E: SUBSYSTEM=mem
+
+P: /devices/virtual/misc/agpgart
+N: agpgart
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/agpgart
+E: MAJOR=10
+E: MINOR=175
+E: DEVNAME=/dev/agpgart
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/cpu_dma_latency
+N: cpu_dma_latency
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/cpu_dma_latency
+E: MAJOR=10
+E: MINOR=60
+E: DEVNAME=/dev/cpu_dma_latency
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/device-mapper
+N: mapper/control
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/device-mapper
+E: MAJOR=10
+E: MINOR=236
+E: DEVNAME=/dev/mapper/control
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/ecryptfs
+N: ecryptfs
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/ecryptfs
+E: MAJOR=10
+E: MINOR=61
+E: DEVNAME=/dev/ecryptfs
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/fuse
+N: fuse
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/fuse
+E: MAJOR=10
+E: MINOR=229
+E: DEVNAME=/dev/fuse
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/hpet
+N: hpet
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/hpet
+E: MAJOR=10
+E: MINOR=228
+E: DEVNAME=/dev/hpet
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/mcelog
+N: mcelog
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/mcelog
+E: MAJOR=10
+E: MINOR=227
+E: DEVNAME=/dev/mcelog
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/network_latency
+N: network_latency
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/network_latency
+E: MAJOR=10
+E: MINOR=59
+E: DEVNAME=/dev/network_latency
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/network_throughput
+N: network_throughput
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/network_throughput
+E: MAJOR=10
+E: MINOR=58
+E: DEVNAME=/dev/network_throughput
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/psaux
+N: psaux
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/psaux
+E: MAJOR=10
+E: MINOR=1
+E: DEVNAME=/dev/psaux
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/rfkill
+N: rfkill
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/rfkill
+E: MAJOR=10
+E: MINOR=62
+E: DEVNAME=/dev/rfkill
+E: SUBSYSTEM=misc
+E: TAGS=:udev-acl:
+
+P: /devices/virtual/misc/snapshot
+N: snapshot
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/snapshot
+E: MAJOR=10
+E: MINOR=231
+E: DEVNAME=/dev/snapshot
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/tun
+N: net/tun
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/tun
+E: MAJOR=10
+E: MINOR=200
+E: DEVNAME=/dev/net/tun
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/uinput
+N: uinput
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/uinput
+E: MAJOR=10
+E: MINOR=223
+E: DEVNAME=/dev/uinput
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/misc/vga_arbiter
+N: vga_arbiter
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/misc/vga_arbiter
+E: MAJOR=10
+E: MINOR=63
+E: DEVNAME=/dev/vga_arbiter
+E: SUBSYSTEM=misc
+
+P: /devices/virtual/net/lo
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/net/lo
+E: INTERFACE=lo
+E: IFINDEX=1
+E: SUBSYSTEM=net
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/ppp/ppp
+N: ppp
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/ppp/ppp
+E: MAJOR=108
+E: MINOR=0
+E: DEVNAME=/dev/ppp
+E: SUBSYSTEM=ppp
+
+P: /devices/virtual/regulator/regulator.0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/regulator/regulator.0
+E: SUBSYSTEM=regulator
+
+P: /devices/virtual/sound/seq
+N: snd/seq
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/sound/seq
+E: MAJOR=116
+E: MINOR=1
+E: DEVNAME=/dev/snd/seq
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+
+P: /devices/virtual/sound/timer
+N: snd/timer
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/sound/timer
+E: MAJOR=116
+E: MINOR=33
+E: DEVNAME=/dev/snd/timer
+E: SUBSYSTEM=sound
+E: TAGS=:udev-acl:
+
+P: /devices/virtual/thermal/cooling_device0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/thermal/cooling_device0
+E: SUBSYSTEM=thermal
+
+P: /devices/virtual/thermal/cooling_device1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/thermal/cooling_device1
+E: SUBSYSTEM=thermal
+
+P: /devices/virtual/thermal/cooling_device2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/thermal/cooling_device2
+E: SUBSYSTEM=thermal
+
+P: /devices/virtual/thermal/thermal_zone0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/thermal/thermal_zone0
+E: SUBSYSTEM=thermal
+
+P: /devices/virtual/tty/console
+N: console
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/console
+E: MAJOR=5
+E: MINOR=1
+E: DEVNAME=/dev/console
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/ptmx
+N: ptmx
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/ptmx
+E: MAJOR=5
+E: MINOR=2
+E: DEVNAME=/dev/ptmx
+E: DEVMODE=0666
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty
+N: tty
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty
+E: MAJOR=5
+E: MINOR=0
+E: DEVNAME=/dev/tty
+E: DEVMODE=0666
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty0
+N: tty0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty0
+E: MAJOR=4
+E: MINOR=0
+E: DEVNAME=/dev/tty0
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty1
+N: tty1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty1
+E: MAJOR=4
+E: MINOR=1
+E: DEVNAME=/dev/tty1
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty10
+N: tty10
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty10
+E: MAJOR=4
+E: MINOR=10
+E: DEVNAME=/dev/tty10
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty11
+N: tty11
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty11
+E: MAJOR=4
+E: MINOR=11
+E: DEVNAME=/dev/tty11
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty12
+N: tty12
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty12
+E: MAJOR=4
+E: MINOR=12
+E: DEVNAME=/dev/tty12
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty13
+N: tty13
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty13
+E: MAJOR=4
+E: MINOR=13
+E: DEVNAME=/dev/tty13
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty14
+N: tty14
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty14
+E: MAJOR=4
+E: MINOR=14
+E: DEVNAME=/dev/tty14
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty15
+N: tty15
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty15
+E: MAJOR=4
+E: MINOR=15
+E: DEVNAME=/dev/tty15
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty16
+N: tty16
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty16
+E: MAJOR=4
+E: MINOR=16
+E: DEVNAME=/dev/tty16
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty17
+N: tty17
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty17
+E: MAJOR=4
+E: MINOR=17
+E: DEVNAME=/dev/tty17
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty18
+N: tty18
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty18
+E: MAJOR=4
+E: MINOR=18
+E: DEVNAME=/dev/tty18
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty19
+N: tty19
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty19
+E: MAJOR=4
+E: MINOR=19
+E: DEVNAME=/dev/tty19
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty2
+N: tty2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty2
+E: MAJOR=4
+E: MINOR=2
+E: DEVNAME=/dev/tty2
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty20
+N: tty20
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty20
+E: MAJOR=4
+E: MINOR=20
+E: DEVNAME=/dev/tty20
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty21
+N: tty21
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty21
+E: MAJOR=4
+E: MINOR=21
+E: DEVNAME=/dev/tty21
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty22
+N: tty22
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty22
+E: MAJOR=4
+E: MINOR=22
+E: DEVNAME=/dev/tty22
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty23
+N: tty23
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty23
+E: MAJOR=4
+E: MINOR=23
+E: DEVNAME=/dev/tty23
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty24
+N: tty24
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty24
+E: MAJOR=4
+E: MINOR=24
+E: DEVNAME=/dev/tty24
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty25
+N: tty25
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty25
+E: MAJOR=4
+E: MINOR=25
+E: DEVNAME=/dev/tty25
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty26
+N: tty26
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty26
+E: MAJOR=4
+E: MINOR=26
+E: DEVNAME=/dev/tty26
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty27
+N: tty27
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty27
+E: MAJOR=4
+E: MINOR=27
+E: DEVNAME=/dev/tty27
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty28
+N: tty28
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty28
+E: MAJOR=4
+E: MINOR=28
+E: DEVNAME=/dev/tty28
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty29
+N: tty29
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty29
+E: MAJOR=4
+E: MINOR=29
+E: DEVNAME=/dev/tty29
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty3
+N: tty3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty3
+E: MAJOR=4
+E: MINOR=3
+E: DEVNAME=/dev/tty3
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty30
+N: tty30
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty30
+E: MAJOR=4
+E: MINOR=30
+E: DEVNAME=/dev/tty30
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty31
+N: tty31
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty31
+E: MAJOR=4
+E: MINOR=31
+E: DEVNAME=/dev/tty31
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty32
+N: tty32
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty32
+E: MAJOR=4
+E: MINOR=32
+E: DEVNAME=/dev/tty32
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty33
+N: tty33
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty33
+E: MAJOR=4
+E: MINOR=33
+E: DEVNAME=/dev/tty33
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty34
+N: tty34
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty34
+E: MAJOR=4
+E: MINOR=34
+E: DEVNAME=/dev/tty34
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty35
+N: tty35
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty35
+E: MAJOR=4
+E: MINOR=35
+E: DEVNAME=/dev/tty35
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty36
+N: tty36
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty36
+E: MAJOR=4
+E: MINOR=36
+E: DEVNAME=/dev/tty36
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty37
+N: tty37
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty37
+E: MAJOR=4
+E: MINOR=37
+E: DEVNAME=/dev/tty37
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty38
+N: tty38
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty38
+E: MAJOR=4
+E: MINOR=38
+E: DEVNAME=/dev/tty38
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty39
+N: tty39
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty39
+E: MAJOR=4
+E: MINOR=39
+E: DEVNAME=/dev/tty39
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty4
+N: tty4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty4
+E: MAJOR=4
+E: MINOR=4
+E: DEVNAME=/dev/tty4
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty40
+N: tty40
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty40
+E: MAJOR=4
+E: MINOR=40
+E: DEVNAME=/dev/tty40
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty41
+N: tty41
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty41
+E: MAJOR=4
+E: MINOR=41
+E: DEVNAME=/dev/tty41
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty42
+N: tty42
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty42
+E: MAJOR=4
+E: MINOR=42
+E: DEVNAME=/dev/tty42
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty43
+N: tty43
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty43
+E: MAJOR=4
+E: MINOR=43
+E: DEVNAME=/dev/tty43
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty44
+N: tty44
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty44
+E: MAJOR=4
+E: MINOR=44
+E: DEVNAME=/dev/tty44
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty45
+N: tty45
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty45
+E: MAJOR=4
+E: MINOR=45
+E: DEVNAME=/dev/tty45
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty46
+N: tty46
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty46
+E: MAJOR=4
+E: MINOR=46
+E: DEVNAME=/dev/tty46
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty47
+N: tty47
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty47
+E: MAJOR=4
+E: MINOR=47
+E: DEVNAME=/dev/tty47
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty48
+N: tty48
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty48
+E: MAJOR=4
+E: MINOR=48
+E: DEVNAME=/dev/tty48
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty49
+N: tty49
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty49
+E: MAJOR=4
+E: MINOR=49
+E: DEVNAME=/dev/tty49
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty5
+N: tty5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty5
+E: MAJOR=4
+E: MINOR=5
+E: DEVNAME=/dev/tty5
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty50
+N: tty50
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty50
+E: MAJOR=4
+E: MINOR=50
+E: DEVNAME=/dev/tty50
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty51
+N: tty51
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty51
+E: MAJOR=4
+E: MINOR=51
+E: DEVNAME=/dev/tty51
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty52
+N: tty52
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty52
+E: MAJOR=4
+E: MINOR=52
+E: DEVNAME=/dev/tty52
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty53
+N: tty53
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty53
+E: MAJOR=4
+E: MINOR=53
+E: DEVNAME=/dev/tty53
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty54
+N: tty54
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty54
+E: MAJOR=4
+E: MINOR=54
+E: DEVNAME=/dev/tty54
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty55
+N: tty55
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty55
+E: MAJOR=4
+E: MINOR=55
+E: DEVNAME=/dev/tty55
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty56
+N: tty56
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty56
+E: MAJOR=4
+E: MINOR=56
+E: DEVNAME=/dev/tty56
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty57
+N: tty57
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty57
+E: MAJOR=4
+E: MINOR=57
+E: DEVNAME=/dev/tty57
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty58
+N: tty58
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty58
+E: MAJOR=4
+E: MINOR=58
+E: DEVNAME=/dev/tty58
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty59
+N: tty59
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty59
+E: MAJOR=4
+E: MINOR=59
+E: DEVNAME=/dev/tty59
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty6
+N: tty6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty6
+E: MAJOR=4
+E: MINOR=6
+E: DEVNAME=/dev/tty6
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty60
+N: tty60
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty60
+E: MAJOR=4
+E: MINOR=60
+E: DEVNAME=/dev/tty60
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty61
+N: tty61
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty61
+E: MAJOR=4
+E: MINOR=61
+E: DEVNAME=/dev/tty61
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty62
+N: tty62
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty62
+E: MAJOR=4
+E: MINOR=62
+E: DEVNAME=/dev/tty62
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty63
+N: tty63
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty63
+E: MAJOR=4
+E: MINOR=63
+E: DEVNAME=/dev/tty63
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty7
+N: tty7
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty7
+E: MAJOR=4
+E: MINOR=7
+E: DEVNAME=/dev/tty7
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty8
+N: tty8
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty8
+E: MAJOR=4
+E: MINOR=8
+E: DEVNAME=/dev/tty8
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/tty9
+N: tty9
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/tty9
+E: MAJOR=4
+E: MINOR=9
+E: DEVNAME=/dev/tty9
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/tty/ttyprintk
+N: ttyprintk
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/tty/ttyprintk
+E: MAJOR=5
+E: MINOR=3
+E: DEVNAME=/dev/ttyprintk
+E: SUBSYSTEM=tty
+E: ID_MM_CANDIDATE=1
+
+P: /devices/virtual/usbmon/usbmon0
+N: usbmon0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/usbmon/usbmon0
+E: MAJOR=252
+E: MINOR=0
+E: DEVNAME=/dev/usbmon0
+E: SUBSYSTEM=usbmon
+
+P: /devices/virtual/vc/vcs
+N: vcs
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs
+E: MAJOR=7
+E: MINOR=0
+E: DEVNAME=/dev/vcs
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs1
+N: vcs1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs1
+E: MAJOR=7
+E: MINOR=1
+E: DEVNAME=/dev/vcs1
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs2
+N: vcs2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs2
+E: MAJOR=7
+E: MINOR=2
+E: DEVNAME=/dev/vcs2
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs3
+N: vcs3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs3
+E: MAJOR=7
+E: MINOR=3
+E: DEVNAME=/dev/vcs3
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs4
+N: vcs4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs4
+E: MAJOR=7
+E: MINOR=4
+E: DEVNAME=/dev/vcs4
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs5
+N: vcs5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs5
+E: MAJOR=7
+E: MINOR=5
+E: DEVNAME=/dev/vcs5
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs6
+N: vcs6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs6
+E: MAJOR=7
+E: MINOR=6
+E: DEVNAME=/dev/vcs6
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcs63
+N: vcs63
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcs63
+E: MAJOR=7
+E: MINOR=63
+E: DEVNAME=/dev/vcs63
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa
+N: vcsa
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa
+E: MAJOR=7
+E: MINOR=128
+E: DEVNAME=/dev/vcsa
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa1
+N: vcsa1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa1
+E: MAJOR=7
+E: MINOR=129
+E: DEVNAME=/dev/vcsa1
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa2
+N: vcsa2
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa2
+E: MAJOR=7
+E: MINOR=130
+E: DEVNAME=/dev/vcsa2
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa3
+N: vcsa3
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa3
+E: MAJOR=7
+E: MINOR=131
+E: DEVNAME=/dev/vcsa3
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa4
+N: vcsa4
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa4
+E: MAJOR=7
+E: MINOR=132
+E: DEVNAME=/dev/vcsa4
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa5
+N: vcsa5
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa5
+E: MAJOR=7
+E: MINOR=133
+E: DEVNAME=/dev/vcsa5
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa6
+N: vcsa6
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa6
+E: MAJOR=7
+E: MINOR=134
+E: DEVNAME=/dev/vcsa6
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vc/vcsa63
+N: vcsa63
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vc/vcsa63
+E: MAJOR=7
+E: MINOR=191
+E: DEVNAME=/dev/vcsa63
+E: SUBSYSTEM=vc
+
+P: /devices/virtual/vtconsole/vtcon0
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vtconsole/vtcon0
+E: SUBSYSTEM=vtconsole
+
+P: /devices/virtual/vtconsole/vtcon1
+E: UDEV_LOG=3
+E: DEVPATH=/devices/virtual/vtconsole/vtcon1
+E: SUBSYSTEM=vtconsole
+

=== added file 'checkbox-support/checkbox_support/parsers/udevadm.py'
--- checkbox-support/checkbox_support/parsers/udevadm.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/udevadm.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,781 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2011-2013 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+import string
+
+from collections import OrderedDict
+
+from checkbox.lib.bit import get_bitmask, test_bit
+from checkbox.lib.input import Input
+from checkbox.lib.pci import Pci
+from checkbox.lib.usb import Usb
+
+
+PCI_RE = re.compile(
+    r"^pci:"
+    r"v(?P<vendor_id>[%(hex)s]{8})"
+    r"d(?P<product_id>[%(hex)s]{8})"
+    r"sv(?P<subvendor_id>[%(hex)s]{8})"
+    r"sd(?P<subproduct_id>[%(hex)s]{8})"
+    r"bc(?P<class>[%(hex)s]{2})"
+    r"sc(?P<subclass>[%(hex)s]{2})"
+    r"i(?P<interface>[%(hex)s]{2})"
+    % {"hex": string.hexdigits})
+PNP_RE = re.compile(
+    r"^acpi:"
+    r"(?P<vendor_name>[%(upper)s]{3})"
+    r"(?P<product_id>[%(hex)s]{4}):"
+    % {"upper": string.ascii_uppercase, "hex": string.hexdigits})
+USB_RE = re.compile(
+    r"^usb:"
+    r"v(?P<vendor_id>[%(hex)s]{4})"
+    r"p(?P<product_id>[%(hex)s]{4})"
+    r"d(?P<revision>[%(hex)s]{4})"
+    r"dc(?P<class>[%(hex)s]{2})"
+    r"dsc(?P<subclass>[%(hex)s]{2})"
+    r"dp(?P<protocol>[%(hex)s]{2})"
+    r"ic(?P<interface_class>[%(hex)s]{2})"
+    r"isc(?P<interface_subclass>[%(hex)s]{2})"
+    r"ip(?P<interface_protocol>[%(hex)s]{2})"
+    % {"hex": string.hexdigits})
+USB_SYSFS_CONFIG_RE = re.compile(
+    r"usb.*?:\d+\.\d+$")
+SCSI_RE = re.compile(
+    r"^scsi:"
+    r"t-0x(?P<type>[%(hex)s]{2})"
+    % {"hex": string.hexdigits})
+PLATFORM_RE = re.compile(
+    r"^platform:"
+    r"(?P<module_name>.*)")
+INPUT_RE = re.compile(
+    r"^input:"
+    r"b(?P<bus_type>[%(hex)s]{4})"
+    r"v(?P<vendor_id>[%(hex)s]{4})"
+    r"p(?P<product_id>[%(hex)s]{4})"
+    r"e(?P<version>[%(hex)s]{4})"
+    % {"hex": string.hexdigits})
+INPUT_SYSFS_ID = re.compile(
+    r"/input/input\d+$")
+OPENFIRMWARE_RE = re.compile(
+    r"^of:"
+    r"N(?P<name>.*?)"
+    r"T(?P<type>.*?)"
+    r"C(?P<compatible>.*?)")
+CARD_READER_RE = re.compile(r"SD|MMC|CF|MS|SM|xD|Card", re.I)
+GENERIC_RE = re.compile(r"Generic", re.I)
+FLASH_RE = re.compile(r"Flash", re.I)
+FLASH_DISK_RE = re.compile(r"Mass|Storage|Disk", re.I)
+
+
+class UdevadmDevice:
+    __slots__ = (
+        "_environment",
+        "_bits",
+        "_stack",
+        "_bus",
+        "_interface",
+        "_product",
+        "_product_id",
+        "_vendor",
+        "_vendor_id",)
+
+    def __init__(self, environment, bits=None, stack=[]):
+        self._environment = environment
+        self._bits = bits
+        self._stack = stack
+        self._bus = None
+        self._interface = None
+        self._product = None
+        self._product_id = None
+        self._vendor = None
+        self._vendor_id = None
+
+    def __repr__(self):
+        vid = int(self.vendor_id) if self.vendor_id else 0
+        pid = int(self.product_id) if self.product_id else 0
+        return("<{}: bus: {} id [{:x}:{:x}] {}>".format(
+            type(self).__name__, self.bus, vid, pid,
+            self.product))
+
+    @property
+    def bus(self):
+        if self._bus is not None:
+            return self._bus
+        # Change the bus from 'acpi' to 'pnp' for some devices
+        if PNP_RE.match(self._environment.get("MODALIAS", "")) \
+           and self._raw_path.endswith(":00"):
+            return "pnp"
+
+        # Change the bus from 'block' to parent
+        if self._environment.get("DEVTYPE") == "disk" and self._stack:
+            return self._stack[-1]._environment.get("SUBSYSTEM")
+
+        bus = self._environment.get("SUBSYSTEM")
+        if bus == "pnp":
+            return None
+
+        if bus == 'input' and any(d.bus == 'usb' for d in self._stack):
+            bus = 'usb'
+
+        return bus
+
+    @bus.setter
+    def bus(self, value):
+        self._bus = value
+
+    @property
+    def category(self):
+        if "IFINDEX" in self._environment:
+            if "DEVTYPE" in self._environment:
+                devtype = self._environment["DEVTYPE"]
+                if devtype in ("wlan", "wimax"):
+                    return "WIRELESS"
+            # Ralink wireless
+            if "INTERFACE" in self._environment:
+                if (
+                    self.driver.startswith('rt') and
+                    self._environment["INTERFACE"].startswith('ra')
+                ):
+                    return "WIRELESS"
+            return "NETWORK"
+
+        if self.bus == "bluetooth":
+            return "BLUETOOTH"
+
+        if "PCI_CLASS" in self._environment:
+            pci_class_string = self._environment["PCI_CLASS"]
+            pci_class = int(pci_class_string, 16)
+
+            # Strip prog_if if defined
+            if pci_class > 0xFFFF:
+                pci_class >>= 8
+
+            subclass_id = pci_class & 0xFF
+            class_id = (pci_class >> 8) & 0xFF
+
+            if class_id == Pci.BASE_CLASS_NETWORK:
+                if subclass_id == Pci.CLASS_NETWORK_WIRELESS:
+                    return "WIRELESS"
+                else:
+                    return "NETWORK"
+            if class_id == Pci.BASE_CLASS_DISPLAY:
+                if subclass_id == Pci.CLASS_DISPLAY_VGA:
+                    return "VIDEO"
+            if class_id == Pci.BASE_CLASS_SERIAL \
+               and subclass_id == Pci.CLASS_SERIAL_USB:
+                return "USB"
+            if class_id == Pci.BASE_CLASS_STORAGE:
+                if subclass_id == Pci.CLASS_STORAGE_SCSI:
+                    return "SCSI"
+                if subclass_id == Pci.CLASS_STORAGE_IDE:
+                    return "IDE"
+                if subclass_id == Pci.CLASS_STORAGE_FLOPPY:
+                    return "FLOPPY"
+                if subclass_id == Pci.CLASS_STORAGE_RAID:
+                    return "RAID"
+            if class_id == Pci.BASE_CLASS_COMMUNICATION \
+               and subclass_id == Pci.CLASS_COMMUNICATION_MODEM:
+                return "MODEM"
+            if class_id == Pci.BASE_CLASS_INPUT \
+               and subclass_id == Pci.CLASS_INPUT_SCANNER:
+                return "SCANNER"
+            if class_id == Pci.BASE_CLASS_MULTIMEDIA:
+                if subclass_id == Pci.CLASS_MULTIMEDIA_VIDEO:
+                    return "CAPTURE"
+                if subclass_id == Pci.CLASS_MULTIMEDIA_AUDIO \
+                   or subclass_id == Pci.CLASS_MULTIMEDIA_AUDIO_DEVICE:
+                    return "AUDIO"
+            if class_id == Pci.BASE_CLASS_SERIAL \
+               and subclass_id == Pci.CLASS_SERIAL_FIREWIRE:
+                return "FIREWIRE"
+            if class_id == Pci.BASE_CLASS_WIRELESS \
+               and subclass_id == Pci.CLASS_WIRELESS_BLUETOOTH:
+                return "BLUETOOTH"
+            if class_id == Pci.BASE_CLASS_BRIDGE \
+               and (subclass_id == Pci.CLASS_BRIDGE_PCMCIA
+                    or subclass_id == Pci.CLASS_BRIDGE_CARDBUS):
+                return "SOCKET"
+
+        if "TYPE" in self._environment and "INTERFACE" in self._environment:
+            interface_class, interface_subclass, interface_protocol = (
+                int(i) for i in self._environment["INTERFACE"].split("/"))
+            if interface_class == Usb.BASE_CLASS_AUDIO:
+                return "AUDIO"
+            if interface_class == Usb.BASE_CLASS_PRINTER:
+                return "PRINTER"
+            if interface_class == Usb.BASE_CLASS_STORAGE:
+                if interface_subclass == Usb.CLASS_STORAGE_FLOPPY:
+                    return "FLOPPY"
+                if interface_subclass == Usb.CLASS_STORAGE_SCSI:
+                    return "USB"
+            if interface_class == Usb.BASE_CLASS_VIDEO:
+                return "CAPTURE"
+            if interface_class == Usb.BASE_CLASS_WIRELESS:
+                if interface_protocol == Usb.PROTOCOL_BLUETOOTH:
+                    return "BLUETOOTH"
+                else:
+                    return "WIRELESS"
+            if (interface_class, interface_subclass, interface_protocol) ==\
+               (255, 255, 255) and self.driver == "btusb":
+                # This heuristic accounts for bluetooth devices which usually
+                # have INTERFACE=224/*/1, however in the "field" we've run
+                # across a few (Mediatek combo cards) that have unknown
+                # (255/255/255) values and thus break the previous heuristic.
+                # We assume that if a device has these weird INTERFACE values
+                # *but* it uses the btusb driver, then it must be a bluetooth
+                # controller.  Other devices with btusb *but* with
+                # INTERFACE=255/1/1 have been seen on systems where the actual
+                # usb controller was identified by the old heuristic, so here
+                # we need to match all three fields to avoid duplicating
+                # devices.  See http://pad.lv/1210405
+                    return "BLUETOOTH"
+
+        if 'ID_INPUT_KEYBOARD' in self._environment:
+            return "KEYBOARD"
+        if 'ID_INPUT_TOUCHPAD' in self._environment:
+            return "TOUCHPAD"
+        if 'ID_INPUT_TOUCHSCREEN' in self._environment:
+            return "TOUCHSCREEN"
+        if "ID_INPUT_ACCELEROMETER" in self._environment:
+            return "ACCELEROMETER"
+        if "KEY" in self._environment:
+            key = self._environment["KEY"].strip("=")
+            bitmask = get_bitmask(key)
+            if test_bit(Input.KEY_CAMERA, bitmask, self._bits):
+                # Avoid detecting the power button as a capture device
+                if self.vendor_id == 0:
+                    return "OTHER"
+                # Avoid identifying media/hot keys as pure capture devices
+                if not (test_bit(Input.KEY_PLAYPAUSE, bitmask, self._bits) or
+                        test_bit(Input.KEY_PLAY, bitmask, self._bits) or
+                        test_bit(Input.KEY_WLAN, bitmask, self._bits)):
+                    # Consider a device with both camera and mouse properties
+                    # as a KVM hardware device ("keyboard, video and mouse")
+                    if test_bit(Input.BTN_MOUSE, bitmask, self._bits):
+                        return "KVM"
+                    else:
+                        return "CAPTURE"
+        if 'ID_INPUT_MOUSE' in self._environment:
+            return "MOUSE"
+
+        if self.driver:
+            if self.driver.startswith("sdhci"):
+                return "CARDREADER"
+            if self.driver.startswith("mmc"):
+                return "CARDREADER"
+            if self.driver == "rts_pstor":
+                return "CARDREADER"
+            # See http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=702145
+            if self.driver.startswith("rtsx"):
+                return "CARDREADER"
+            if ((self._environment.get("DEVTYPE") not in ("disk", "partition")
+                    or 'ID_DRIVE_FLASH_SD' in self._environment)
+                    and self.driver == "sd" and self.product):
+                if any(FLASH_RE.search(k) for k in self._environment.keys()):
+                    return "CARDREADER"
+                if any(d.bus == 'usb' for d in self._stack):
+                    if (self.product is not None and
+                            CARD_READER_RE.search(self.product)):
+                        return "CARDREADER"
+                    if (self.vendor is not None and
+                            GENERIC_RE.search(self.vendor) and
+                            not FLASH_DISK_RE.search(self.product)):
+                        return "CARDREADER"
+
+        if "ID_TYPE" in self._environment:
+            id_type = self._environment["ID_TYPE"]
+            if id_type == "cd":
+                return "CDROM"
+            if (
+                id_type == "disk"
+                and not any(d.category == "CARDREADER" for d in self._stack)
+            ):
+                return "DISK"
+            if not any(d.bus == 'usb' for d in self._stack):
+                if id_type == "video":
+                    return "VIDEO"
+
+        if "DEVTYPE" in self._environment:
+            devtype = self._environment["DEVTYPE"]
+            if devtype == "disk":
+                if "ID_CDROM" in self._environment:
+                    return "CDROM"
+                if "ID_DRIVE_FLOPPY" in self._environment:
+                    return "FLOPPY"
+            if devtype == "scsi_device":
+                match = SCSI_RE.match(self._environment.get("MODALIAS", ""))
+                type = int(match.group("type"), 16) if match else -1
+
+                # Check FLASH drives, see /lib/udev/rules.d/80-udisks.rules
+                if (
+                    type in (0, 7, 14)
+                    and not any(d.driver == "rts_pstor" for d in self._stack)
+                ):
+                    return "DISK"
+                if type == 1:
+                    return "TAPE"
+                if type == 2:
+                    return "PRINTER"
+                if type in (4, 5):
+                    return "CDROM"
+                if type == 6:
+                    return "SCANNER"
+                if type == 12:
+                    return "RAID"
+
+        if "DRIVER" in self._environment:
+            if self._environment["DRIVER"] == "floppy":
+                return "FLOPPY"
+
+        # Some audio and serial devices have a product but no vendor
+        # or product id. Special-case their categories for backwards-
+        # compatibility.
+        if self.bus == "sound":
+            return "AUDIO"
+
+        if self.bus == "tty":
+            return "OTHER"
+
+        # Any devices that have a product name and proper vendor and product
+        # IDs, but had no other category, are lumped together in OTHER.
+        # A few devices may have no self.product but carry PRODUCT data in
+        # their environment.
+        if ((self.product or self._environment.get("PRODUCT")) and
+                not None in (self.vendor_id, self.product_id)):
+            return "OTHER"
+
+        # Limbo of devices I couldn't otherwise categorize. In practice
+        # having no category means the device may be uninteresting, it's
+        # up to downstream users of this class to decide what to do with
+        # those devices.
+        return None
+
+    @property
+    def driver(self):
+        if "DRIVER" in self._environment:
+            return self._environment["DRIVER"]
+        # Check parent device for driver
+        if self._stack:
+            parent = self._stack[-1]
+            if "DRIVER" in parent._environment:
+                return parent._environment["DRIVER"]
+        return None
+
+    @property
+    def path(self):
+        devpath = self._environment.get("DEVPATH")
+        if (
+            (self._environment.get("DEVTYPE") == "disk" and self._stack) or
+            "IFINDEX" in self._environment
+        ):
+            devpath = re.sub(r"/[^/]+/[^/]+$", "", devpath)
+        return devpath
+
+    @property
+    def _raw_path(self):
+        """ Returns the raw device path, this is used internally by
+            UdevadmParser only
+        """
+        return self._environment.get("DEVPATH")
+
+    @property
+    def product_id(self):
+        if self._product_id is not None:
+            return self._product_id
+        # pci
+        match = PCI_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            return int(match.group("product_id"), 16)
+        # usb
+        match = USB_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            return int(match.group("product_id"), 16)
+        # pnp
+        match = PNP_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            product_id = int(match.group("product_id"), 16)
+            # Ignore interrupt controllers
+            if product_id > 0x0100:
+                return product_id
+        # input
+        match = INPUT_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            return int(match.group("product_id"), 16)
+        return None
+
+    @product_id.setter
+    def product_id(self, value):
+        self._product_id = value
+
+    @property
+    def vendor_id(self):
+        if self._vendor_id is not None:
+            return self._vendor_id
+        # pci
+        match = PCI_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            return int(match.group("vendor_id"), 16)
+        # usb
+        match = USB_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            return int(match.group("vendor_id"), 16)
+        # input
+        match = INPUT_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            vendor_id = int(match.group("vendor_id"), 16)
+            # Vendor id <= 9 are not valid numbers, force 9 to make sure
+            # that it will not match an existing (unrelated) vendor in usb.ids
+            # nor pci.ids
+            if vendor_id and vendor_id < 9:
+                vendor_id = 9
+            return vendor_id
+        return None
+
+    @vendor_id.setter
+    def vendor_id(self, value):
+        self._vendor_id = value
+
+    @property
+    def subproduct_id(self):
+        if "PCI_SUBSYS_ID" in self._environment:
+            pci_subsys_id = self._environment["PCI_SUBSYS_ID"]
+            subvendor_id, subproduct_id = pci_subsys_id.split(":")
+            return int(subproduct_id, 16)
+        return None
+
+    @property
+    def subvendor_id(self):
+        if "PCI_SUBSYS_ID" in self._environment:
+            pci_subsys_id = self._environment["PCI_SUBSYS_ID"]
+            subvendor_id, subproduct_id = pci_subsys_id.split(":")
+            return int(subvendor_id, 16)
+        return None
+
+    @property
+    def product(self):
+        if self._product is not None:
+            return self._product
+        # disk
+        if self._environment.get("DEVTYPE") == "scsi_device":
+            for device in reversed(self._stack):
+                if device._environment.get("ID_BUS") == "usb":
+                    return decode_id(device._environment["ID_MODEL_ENC"])
+        elif (self._environment.get("DEVTYPE") == "disk" and
+                "ID_MODEL_ENC" in self._environment):
+            return decode_id(self._environment["ID_MODEL_ENC"])
+
+        # floppy
+        if self.driver == "floppy":
+            return "Platform Device"
+
+        if "ID_MODEL_FROM_DATABASE" in self._environment:
+            return self._environment["ID_MODEL_FROM_DATABASE"]
+
+        # bluetooth (if USB base class is vendor specific)
+        if self.bus == 'bluetooth':
+            vendor_specific = False
+            # Check parent device modalias
+            if self._stack:
+                parent = self._stack[-1]
+                if "MODALIAS" in parent._environment:
+                    match = USB_RE.match(
+                        parent._environment.get("MODALIAS", ""))
+                    if match:
+                        if int(match.group("class"), 16) == 0xFF:
+                            vendor_specific = True
+            if vendor_specific:
+                for device in reversed(self._stack):
+                    if "ID_MODEL_ENC" in device._environment:
+                        return decode_id(device._environment["ID_MODEL_ENC"])
+
+        if "IFINDEX" in self._environment:
+            for device in reversed(self._stack):
+                # wireless (SoC)
+                match = PLATFORM_RE.match(
+                    device._environment.get("MODALIAS", ""))
+                if match:
+                    return match.group("module_name")
+                # Network (Open Firmware)
+                match = OPENFIRMWARE_RE.match(
+                    device._environment.get("MODALIAS", ""))
+                if match:
+                    return match.group("name")
+
+        if "IFINDEX" in self._environment and "INTERFACE" in self._environment:
+            if "ID_MODEL_ENC" in self._environment:
+                return decode_id(self._environment["ID_MODEL_ENC"])
+
+        for element in ("NAME", "POWER_SUPPLY_MODEL_NAME"):
+            if element in self._environment:
+                return self._environment[element].strip('"')
+
+        return None
+
+    @product.setter
+    def product(self, value):
+        self._product = value
+
+    @property
+    def vendor(self):
+        if self._vendor is not None:
+            return self._vendor
+        if "RFKILL_NAME" in self._environment:
+            return None
+
+        if "POWER_SUPPLY_MANUFACTURER" in self._environment:
+            return self._environment["POWER_SUPPLY_MANUFACTURER"]
+
+        # pnp
+        match = PNP_RE.match(self._environment.get("MODALIAS", ""))
+        if match:
+            return match.group("vendor_name")
+
+        # disk
+        if self._environment.get("DEVTYPE") == "scsi_device":
+            for device in reversed(self._stack):
+                if device._environment.get("ID_BUS") == "usb":
+                    return decode_id(device._environment["ID_VENDOR_ENC"])
+        elif (self._environment.get("DEVTYPE") == "disk" and
+                "ID_VENDOR_ENC" in self._environment):
+            return decode_id(self._environment["ID_VENDOR_ENC"])
+
+        if "ID_VENDOR_FROM_DATABASE" in self._environment:
+            return self._environment["ID_VENDOR_FROM_DATABASE"]
+
+        # bluetooth (if USB base class is vendor specific)
+        if self.bus == 'bluetooth':
+            vendor_specific = False
+            # Check parent device modalias
+            if self._stack:
+                parent = self._stack[-1]
+                if "MODALIAS" in parent._environment:
+                    match = USB_RE.match(
+                        parent._environment.get("MODALIAS", ""))
+                    if match:
+                        if int(match.group("class"), 16) == 0xFF:
+                            vendor_specific = True
+            if vendor_specific:
+                for device in reversed(self._stack):
+                    if "ID_VENDOR_ENC" in device._environment:
+                        return decode_id(device._environment["ID_VENDOR_ENC"])
+
+        if "IFINDEX" in self._environment and "INTERFACE" in self._environment:
+            if "ID_VENDOR_ENC" in self._environment:
+                return decode_id(self._environment["ID_VENDOR_ENC"])
+
+        return None
+
+    @vendor.setter
+    def vendor(self, value):
+        self._vendor = value
+
+    @property
+    def interface(self):
+        if self._interface is not None:
+            return self._interface
+        if (self.category in ("NETWORK", "WIRELESS") and
+                "INTERFACE" in self._environment):
+            return self._environment["INTERFACE"]
+        return None
+
+    @interface.setter
+    def interface(self, value):
+        self._interface = value
+
+    def as_json(self):
+        attributes = ("path", "bus", "category", "driver", "product_id",
+                      "vendor_id", "subproduct_id", "subvendor_id", "product",
+                      "vendor", "interface",)
+
+        return {a: getattr(self, a) for a in attributes if getattr(self, a)}
+
+
+class UdevadmParser:
+    """Parser for the udevadm command."""
+
+    device_factory = UdevadmDevice
+
+    def __init__(self, stream_or_string, bits=None):
+        self.stream_or_string = stream_or_string
+        self.bits = bits
+        self.devices = OrderedDict()
+
+    def _ignoreDevice(self, device):
+        # Ignore devices without bus information
+        if not device.bus:
+            return True
+
+        # Ignore devices without product AND vendor information
+        if (device.product is None and device.product_id is None and
+                device.vendor is None and device.vendor_id is None):
+            return True
+
+        # Ignore invalid subsystem information
+        if (
+            (device.subproduct_id is None
+                and device.subvendor_id is not None)
+            or (device.subproduct_id is not None
+                and device.subvendor_id is None)):
+            return True
+
+        # Ignore ACPI devices
+        if device.bus == "acpi":
+            return True
+
+        return False
+
+    def getAttributes(self, path):
+        return {}
+
+    def run(self, result):
+        # Some attribute lines have a space character after the
+        # ':', others don't have it (see udevadm-info.c).
+        line_pattern = re.compile(r"(?P<key>[A-Z]):\s*(?P<value>.*)")
+        multi_pattern = re.compile(r"(?P<key>[^=]+)=(?P<value>.*)")
+
+        stack = []
+        if isinstance(self.stream_or_string, str):
+            output = self.stream_or_string
+        else:
+            output = self.stream_or_string.read()
+        output = output.replace('\r', '')  # Just in case...
+        for record in re.split("\n{2,}", output):
+            record = record.strip()
+            if not record:
+                continue
+
+            # Determine path and environment
+            path = None
+            element = None
+            environment = {}
+            for line in record.splitlines():
+                line_match = line_pattern.match(line)
+                if not line_match:
+                    if environment:
+                        # Append to last environment element
+                        environment[element] += line
+                    continue
+
+                key = line_match.group("key")
+                value = line_match.group("value")
+
+                if key == "P":
+                    path = value
+                elif key == "E":
+                    key_match = multi_pattern.match(value)
+                    if not key_match:
+                        raise Exception(
+                            "Device property not supported: %s" % value)
+                    element = key_match.group("key")
+                    environment[element] = key_match.group("value")
+
+            # Update stack
+            while stack:
+                if stack[-1]._raw_path + "/" in path:
+                    break
+                stack.pop()
+
+            # Set default DEVPATH
+            environment.setdefault("DEVPATH", path)
+
+            device = self.device_factory(environment, self.bits, list(stack))
+            if not self._ignoreDevice(device):
+                if device._raw_path in self.devices:
+                    if self.devices[device._raw_path].category == 'CARDREADER':
+                        [
+                            setattr(self.devices[device._raw_path],
+                                    key, getattr(device, key))
+                            for key in (
+                                "product", "vendor", "product_id", "vendor_id")
+                            if getattr(device, key) is not None
+                        ]
+                    elif device.category != "OTHER":
+                        self.devices[device._raw_path] = device
+                elif device.category == 'BLUETOOTH':
+                    usb_interface_path = USB_SYSFS_CONFIG_RE.sub(
+                        '', device._raw_path)
+                    if not [
+                        d for d in self.devices.values()
+                        if d.category == 'BLUETOOTH' and
+                        usb_interface_path in d._raw_path
+                    ]:
+                        self.devices[device._raw_path] = device
+                elif device.category == 'CAPTURE':
+                    input_id = INPUT_SYSFS_ID.sub('', device._raw_path)
+                    if [
+                        d for d in self.devices.values()
+                        if d.category == 'CAPTURE' and input_id in d._raw_path
+                    ]:
+                        self.devices[input_id].product = device.product
+                    else:
+                        usb_interface_path = USB_SYSFS_CONFIG_RE.sub(
+                            '', device._raw_path)
+                        if not [
+                            d for d in self.devices.values()
+                            if d.category == 'CAPTURE' and
+                            usb_interface_path in d._raw_path
+                        ]:
+                            self.devices[device._raw_path] = device
+                else:
+                    self.devices[device._raw_path] = device
+            stack.append(device)
+
+        for device in self.devices.values():
+            if device.category in ("NETWORK", "WIRELESS", "OTHER"):
+                dev_interface = [
+                    d for d in self.devices.values()
+                    if d.category in ("NETWORK", "WIRELESS") and
+                    device._raw_path != d._raw_path and
+                    device._raw_path in d._raw_path
+                ]
+                if dev_interface:
+                    dev_interface = dev_interface.pop()
+                    dev_interface.bus = device.bus
+                    dev_interface.product_id = device.product_id
+                    dev_interface.vendor_id = device.vendor_id
+                    self.devices.pop(device._raw_path, None)
+
+        [result.addDevice(device) for device in self.devices.values()]
+
+
+def decode_id(id):
+    encoded_id = id.encode("utf-8")
+    decoded_id = encoded_id.decode("unicode-escape")
+    return decoded_id.strip()
+
+
+class UdevResult:
+    def __init__(self):
+        self.devices = {"device_list": []}
+
+    def addDevice(self, device):
+        self.devices["device_list"].append(device)
+
+
+def parse_udevadm_output(output, bits=None):
+    """
+    Parse output of `LANG=C udevadm info --export-db`
+
+    :returns: :class:`UdevadmParser` object that corresponds to the
+    parsed input
+    """
+    udev = UdevadmParser(output, bits)
+    result = UdevResult()
+    udev.run(result)
+    return result.devices

=== added file 'checkbox-support/checkbox_support/parsers/xinput.py'
--- checkbox-support/checkbox_support/parsers/xinput.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/parsers/xinput.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,198 @@
+# -*- coding: utf-8 -*-
+#
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import re
+
+from string import (
+    ascii_letters,
+    ascii_uppercase,
+    )
+
+
+# Device string to match:
+#   ⎡ Virtual core pointer                      id=2    [master pointer  (3)]
+DEVICE_RE = re.compile(
+    r""".+?(?P<name>[%s].+?) *\sid=(?P<id>\d+)"""
+    % ascii_uppercase)
+
+# Attribute string to match:
+#   Buttons supported: 12
+ATTRIBUTE_RE = re.compile(
+    r"""(?P<key>[%s].+?): (?P<value>.+)"""
+    % ascii_letters)
+
+# Class string to match:
+#   12. Type: XIButtonClass
+CLASS_VALUE_RE = re.compile(
+    r"""\d+\. Type: (?P<class>.+)""")
+
+# List string to split:
+#   "Button Horiz Wheel Right" None None
+LIST_VALUE_RE = re.compile(
+    r"""((?:[^ "]|"[^"]*")+)""")
+
+
+class IXinputResult:
+    """
+    Base class for a result passed to the XinputParser run method.
+    """
+
+    def addXinputDevice(self, device):
+        """Method to add an xinput device to this result."""
+
+    def addXinputDeviceClass(self, device, device_class):
+        """Method to add a class under an xinput device."""
+
+
+class XinputParser:
+    """
+    Parser for the xinput command.
+    """
+
+    _key_map = {
+        "Buttons supported": "buttons_supported",
+        "Button labels": "button_labels",
+        "Button state": "button_state",
+        "Class originated from": "device_class",
+        "Keycodes supported": "keycodes_supported",
+        "Touch mode": "touch_mode",
+        "Max number of touches": "max_touch",
+        }
+
+    def __init__(self, stream):
+        """
+        Construct a parser with the given stream.
+
+        The stream is expected to contain the output of the command:
+        xinput --list --long
+        """
+        self.stream = stream
+
+    def _parseKey(self, key):
+        """
+        Parse the given key into a sanitized string.
+
+        Returns a string in lower case without any spaces, or None if
+        the key is not recognized.
+        """
+        if " " in key:
+            return self._key_map.get(key)
+        else:
+            return key.lower()
+
+    def _parseValue(self, value):
+        """
+        Parse the given value into a sanitized object.
+
+        Returns a string with leading and trailing spaces stripped,
+        or a list of the value contains double quotes, or None if the
+        value is empty.
+        """
+        if value is not None:
+            value = value.strip()
+            if not value:
+                return None
+
+            match = CLASS_VALUE_RE.match(value)
+            if match:
+                return match.group("class")
+
+            if '"' in value:
+                return list(self._parseList(value))
+
+        return value
+
+    def _parseList(self, string):
+        """
+        Parse the given string into a list.
+
+        The string can contain double quoted elements that are stripped
+        of the quotes, or the string "None" that is replaced by None,
+        or just space separated strings.
+        """
+        for element in LIST_VALUE_RE.split(string)[1::2]:
+            if element.startswith('"') and element.endswith('"'):
+                yield element.strip('"')
+            elif element == "None":
+                yield None
+
+    def run(self, result):
+        """
+        Run the parser on the stream and add to the given result.
+
+        The result is a derived instance of the IXinputResult base class
+        to which results are added incrementally as the stream is parsed.
+        """
+        output = self.stream.read()
+        for record in re.split(r"\n{2,}", output):
+            record = record.strip()
+
+            # Skip empty records
+            if not record:
+                continue
+
+            lines = record.split("\n")
+
+            # Parse device
+            line = lines.pop(0)
+            match = DEVICE_RE.match(line)
+            if not match:
+                continue
+
+            device = {
+                "id": int(match.group("id")),
+                "name": match.group("name"),
+                }
+            result.addXinputDevice(device)
+
+            # Parse device classes
+            device_class = {}
+            prefix = ""
+
+            for line in lines:
+                line = line.strip()
+
+                # Skip lines with an unsupported attribute
+                match = ATTRIBUTE_RE.match(line)
+                if not match:
+                    if line.startswith("Scroll"):
+                        prefix = "scroll_"
+                    elif line.startswith("Detail"):
+                        prefix = "detail_"
+                    continue
+
+                # Skip lines with an unsupported key
+                key = self._parseKey(match.group("key"))
+                if not key:
+                    continue
+
+                value = self._parseValue(match.group("value"))
+
+                # Special case for the class
+                if key == "device_class" and device_class:
+                    result.addXinputDeviceClass(device, device_class)
+                    device_class = {}
+                    prefix = ""
+
+                device_class[prefix + key] = value
+
+            if device_class:
+                result.addXinputDeviceClass(device, device_class)
+
+        return result

=== added directory 'checkbox-support/checkbox_support/scripts'
=== added file 'checkbox-support/checkbox_support/scripts/__init__.py'
=== added file 'checkbox-support/checkbox_support/scripts/audio_settings.py'
--- checkbox-support/checkbox_support/scripts/audio_settings.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/scripts/audio_settings.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,375 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+
+import configparser
+import logging
+import os
+import re
+import sys
+
+from argparse import ArgumentParser
+from subprocess import check_output, check_call, CalledProcessError
+
+from checkbox.parsers.pactl import parse_pactl_output
+
+TYPES = ("source", "sink")
+DIRECTIONS = {"source": "input", "sink": "output"}
+
+default_pattern = "(?<=Default %s: ).*"
+index_regex = re.compile("(?<=index: )[0-9]*")
+muted_regex = re.compile("(?<=Mute: ).*")
+volume_regex = re.compile("(?<=Volume: 0:)\s*[0-9]*")
+name_regex = re.compile("(?<=Name:).*")
+
+entry_pattern = "Name: %s.*?(?=Properties)"
+
+
+def unlocalized_env(reset={"LANG": "POSIX.UTF-8"}):
+    """
+    Create un-localized environment.
+
+    Produce an environment that is suitable for subprocess.Popen() and
+    associated subprocess functions. The returned environment is equal to a
+    copy the current environment, updated with the value of the reset argument.
+    """
+    env = dict(os.environ)
+    env.update(reset)
+    return env
+
+
+def _guess_hdmi_profile(pactl_list):
+    """
+    Use the pactl parser to get the stereo profile of the available HDMI port
+
+    :returns: (card, profile)
+    """
+    hdmi_ports = {}
+    available_port = {}
+    port_status_location = 'Sink'
+
+    # First parse all cards for HDMI / DisplayPort ports
+    for record in parse_pactl_output(pactl_list).record_list:
+        if not 'Card' in record.name:
+            continue
+        card = re.sub('.*#', '', record.name)  # save the card id
+        ports = [
+            p for p in record.attribute_map['Ports'].value
+            if 'HDMI / DisplayPort' in p.label]
+        if not ports:
+            continue
+        if [p for p in ports if p.availability]:
+            port_status_location = 'Card'
+        hdmi_ports[card] = ports
+
+    if not hdmi_ports:
+        return (None, None)
+
+    logging.info("[ HDMI / DisplayPort ports ]".center(80, '='))
+    for card, ports in hdmi_ports.items():
+        for card_port in ports:
+            logging.info("Card #{} Port: {}".format(card, card_port))
+
+    # Check the ports availability in the list of pulseaudio sinks
+    # if the status is not already available in the cards section.
+    def check_available_port():
+        match_found = False
+        for record in parse_pactl_output(pactl_list).record_list:
+            if not port_status_location in record.name:
+                continue
+            for sink_port in record.attribute_map['Ports'].value:
+                for card, ports in hdmi_ports.items():
+                    for card_port in ports:
+                        if sink_port.label == card_port.label:
+                            match_found = True
+                            if sink_port.availability != 'not available':
+                                return {card: card_port}
+        # If the availability cannot be determined then we keep the first
+        # candidate
+        if not match_found and hdmi_ports:
+            card, ports = hdmi_ports.popitem()
+            return {card: ports.pop()}
+
+    available_port = check_available_port()
+
+    if available_port:
+        card, port = available_port.popitem()
+        # Keep the shortest string in the profile_list including 'stereo'
+        # it will avoid testing 'surround' profiles
+        profile = min([p for p in port.profile_list if 'stereo' in p], key=len)
+        logging.info("[ Selected profile ]".center(80, '='))
+        logging.info("Card #{} Profile: {}".format(card, profile))
+        return (card, profile)
+    else:
+        return (None, None)
+
+
+def set_profile_hdmi():
+    """Sets desired device as active profile. This is typically
+    used as a fallback for setting HDMI / DisplayPort as the output device.
+    """
+    pactl_list = check_output(
+        ['pactl', 'list'], universal_newlines=True, env=unlocalized_env())
+
+    card, profile = _guess_hdmi_profile(pactl_list)
+    if not profile:
+        logging.error('No available port found')
+        return 1
+
+    # Try and set device as default audio output
+    try:
+        check_call(["pactl", "set-card-profile", card, profile])
+    except CalledProcessError as error:
+        logging.error("Failed setting audio output to:%s: %s" %
+                      (profile, error))
+
+
+def get_current_profiles_settings():
+    """Captures and Writes current audio profiles settings"""
+    pactl_list = check_output(
+        ['pactl', 'list'], universal_newlines=True, env=unlocalized_env())
+
+    config = configparser.ConfigParser()
+
+    for match in re.finditer(
+        "(?P<card_id>Card #\d+)\n\tName:\s+(?P<card_name>.*?)\n.*?"
+        "Active\sProfile:\s+(?P<profile>.*?)\n", pactl_list, re.M | re.S
+    ):
+        config[match.group('card_id')] = {
+            'name': match.group('card_name'),
+            'profile': match.group('profile')
+        }
+
+    try:
+        with open('active_profiles', 'w') as active_profiles:
+            config.write(active_profiles)
+    except IOError:
+        logging.error("Failed to save active profiles information: %s" %
+                      sys.exc_info()[1])
+
+
+def restore_profiles_settings():
+    config = configparser.ConfigParser()
+    try:
+        config.read('active_profiles')
+    except IOError:
+        logging.error("Failed to retrieve previous profiles information")
+
+    for card in config.sections():
+        try:
+            check_call(["pactl", "set-card-profile", config[card]['name'],
+                       config[card]['profile']])
+        except CalledProcessError as error:
+            logging.error("Failed setting card <%s> profile to <%s>: %s" %
+                          (config[card]['name'],
+                           config[card]['profile'], error))
+
+
+def move_sinks(name):
+    sink_inputs = check_output(["pacmd", "list-sink-inputs"],
+                               universal_newlines=True,
+                               env=unlocalized_env())
+    input_indexes = index_regex.findall(sink_inputs)
+
+    for input_index in input_indexes:
+        try:
+            with open(os.devnull, 'wb') as DEVNULL:
+                check_call(["pacmd", "move-sink-input", input_index, name],
+                           stdout=DEVNULL)
+        except CalledProcessError:
+            logging.error("Failed to move input %d to sink %d" %
+                          (input_index, name))
+            sys.exit(1)
+
+
+def store_audio_settings(file):
+    logging.info("[ Saving audio settings ]".center(80, '='))
+    try:
+        settings_file = open(file, 'w')
+    except IOError:
+        logging.error("Failed to save settings: %s" % sys.exc_info()[1])
+        sys.exit(1)
+
+    for type in TYPES:
+        pactl_status = check_output(["pactl", "stat"],
+                                    universal_newlines=True,
+                                    env=unlocalized_env())
+        default_regex = re.compile(default_pattern % type.title())
+        default = default_regex.search(pactl_status).group()
+
+        print("default_%s: %s" % (type, default), file=settings_file)
+
+        pactl_list = check_output(["pactl", "list", type + 's'],
+                                  universal_newlines=True,
+                                  env=unlocalized_env())
+
+        entry_regex = re.compile(entry_pattern % default, re.DOTALL)
+        entry = entry_regex.search(pactl_list).group()
+
+        muted = muted_regex.search(entry)
+        print("%s_muted: %s" % (type, muted.group().strip()),
+              file=settings_file)
+
+        volume = int(volume_regex.search(entry).group().strip())
+
+        print("%s_volume: %s%%" % (type, str(volume)),
+              file=settings_file)
+    settings_file.close()
+
+
+def set_audio_settings(device, mute, volume):
+    for type in TYPES:
+        pactl_entries = check_output(["pactl", "list", type + 's'],
+                                     universal_newlines=True,
+                                     env=unlocalized_env())
+
+        # Find the name of the sink/source we want to set
+        names = name_regex.findall(pactl_entries)
+
+        for name in names:
+            name = name.strip()
+            if device in name and DIRECTIONS[type] in name:
+                try:
+                    logging.info("[ Fallback sink ]".center(80, '='))
+                    logging.info("Name: {}".format(name))
+                    with open(os.devnull, 'wb') as DEVNULL:
+                        check_call(["pacmd", "set-default-%s" % type, name],
+                                   stdout=DEVNULL)
+                except CalledProcessError:
+                    logging.error("Failed to set default %s" % type)
+                    sys.exit(1)
+
+                if type == "sink":
+                    move_sinks(name)
+
+                try:
+                    check_call(["pactl",
+                                "set-%s-mute" % type, name, str(int(mute))])
+                except:
+                    logging.error("Failed to set mute for %s" % name)
+                    sys.exit(1)
+
+                try:
+                    check_call(["pactl", "set-%s-volume" % type,
+                               name, str(volume) + '%'])
+                except:
+                    logging.error("Failed to set volume for %s" % name)
+                    sys.exit(1)
+
+
+def restore_audio_settings(file):
+    logging.info("[ Restoring audio settings ]".center(80, '='))
+    try:
+        with open(file) as f:
+            settings_file = f.read().split()
+    except IOError:
+        logging.error("Unable to open existing settings file: %s" %
+                      sys.exc_info()[1])
+        return 1
+
+    for type in TYPES:
+        # First try to get the three elements we need.
+        # If we fail to get any of them, it means the file's format
+        # is incorrect, so we just abort.
+        try:
+            name = settings_file[
+                settings_file.index("default_%s:" % type) + 1]
+            muted = settings_file[settings_file.index("%s_muted:" % type) + 1]
+            volume = settings_file[
+                settings_file.index("%s_volume:" % type) + 1]
+        except ValueError:
+            logging.error("Unable to restore settings because settings "
+                          "file is invalid")
+            return 1
+
+        try:
+            with open(os.devnull, 'wb') as DEVNULL:
+                check_call(["pacmd", "set-default-%s" % type, name],
+                           stdout=DEVNULL)
+        except CalledProcessError:
+            logging.error("Failed to restore default %s" % name)
+            return 1
+
+        if type == "sink":
+            move_sinks(name)
+
+        try:
+            check_call(["pactl", "set-%s-mute" % type, name, muted])
+        except:
+            logging.error("Failed to restore mute for %s" % name)
+            return 1
+
+        try:
+            check_call(["pactl", "set-%s-volume" % type, name, volume])
+        except:
+            logging.error("Failed to restore volume for %s" % name)
+            return 1
+
+
+def main():
+    parser = ArgumentParser("Manipulate PulseAudio settings")
+    parser.add_argument("action",
+                        choices=['store', 'set', 'restore'],
+                        help="Action to perform with the audio settings")
+    parser.add_argument("-d", "--device",
+                        help="The device to apply the new settings to.")
+    parser.add_argument("-m", "--mute",
+                        action="store_true",
+                        help="""The new value for the mute setting
+                                of the specified device.""")
+    parser.add_argument("-v", "--volume",
+                        type=int,
+                        help="""The new value for the volume setting
+                                of the specified device.""")
+    parser.add_argument("-f", "--file",
+                        help="""The file to store settings in or restore
+                                settings from.""")
+    parser.add_argument("--verbose",
+                        action='store_true',
+                        help="Turn on verbosity")
+    args = parser.parse_args()
+
+    if args.verbose:
+        logging.basicConfig(format='%(levelname)s:%(message)s',
+                            level=logging.INFO, stream=sys.stdout)
+    if args.action == "store":
+        if not args.file:
+            logging.error("No file specified to store audio settings!")
+            return 1
+
+        store_audio_settings(args.file)
+        get_current_profiles_settings()
+    elif args.action == "set":
+        if not args.device:
+            logging.error("No device specified to change settings of!")
+            return 1
+        if not args.volume:
+            logging.error("No volume level specified!")
+            return 1
+
+        if args.device == "hdmi":
+            set_profile_hdmi()
+        set_audio_settings(args.device, args.mute, args.volume)
+    elif args.action == "restore":
+        if restore_profiles_settings() or restore_audio_settings(args.file):
+            return 1
+    else:
+        logging.error(args.action + "is not a valid action")
+        return 1
+
+    return 0

=== added file 'checkbox-support/checkbox_support/scripts/gputest_benchmark.py'
--- checkbox-support/checkbox_support/scripts/gputest_benchmark.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/scripts/gputest_benchmark.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,106 @@
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Sylvain Pineau <sylvain.pineau@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+from subprocess import check_output, CalledProcessError
+from tempfile import TemporaryDirectory
+from zipfile import ZipFile
+import argparse
+import os
+import re
+import sys
+
+
+def check_log(logfile):
+    """
+    Read and check logfile in search for the pattern 'Benchmark_Score'.
+
+    Returns:
+        False if the pattern was found
+
+    Raises:
+        SystemExit if the pattern (or logfile) was not found
+    """
+    try:
+        with open(logfile, encoding='utf-8', errors='ignore') as f:
+            log = f.read()
+            print(re.sub('^.*?>> ', '', log, flags=re.M))
+            # Try to find the score in the log file,
+            # otherwise something went wrong...
+            if not re.search('Benchmark_Score', log):
+                raise SystemExit(
+                    'Benchmark score not found, check the log for errors')
+    except EnvironmentError as error:
+        raise SystemExit(error)
+    return False
+
+
+def main():
+    parser = argparse.ArgumentParser()
+    parser.add_argument('test', metavar='TEST', help='test type',
+                        choices=['fur', 'gi', 'tess'])
+    parser.add_argument('--width',
+                        help='window width', default=1024, type=int)
+    parser.add_argument('--height',
+                        help='window height', default=640, type=int)
+    parser.add_argument('-f', '--fullscreen', action='store_true')
+    parser.add_argument('-d', '--duration', default=60, type=int,
+                        help='duration in s')
+    parser.add_argument(
+        '-p', '--path', help='GpuTest archive path',
+        default='/opt/gputest-0.2.0/GpuTest_Linux_x64_20121111.zip'
+    )
+    args = parser.parse_args()
+
+    # Unzip the archive in a temporary directory, GpuTest creates the log file
+    # in the same place Gputest.exe is. A user-writable location is needed.
+    with TemporaryDirectory() as scratch_dir:
+        with ZipFile(args.path, 'r') as z:
+            z.extractall(path=scratch_dir)
+        dirname = os.path.join(scratch_dir, 'GpuTest_Linux_x64')
+        launcher = os.path.join(dirname, 'GpuTest.exe')
+        logfile = os.path.join(dirname, '_geeks3d_gputest_log.txt')
+        os.chmod(launcher, 0o755)
+        os.unlink(logfile)
+
+        timeout_params = [
+            'timeout',
+            '-k',
+            # Adds 16 s for the Warm-up phase before sending the KILL signal
+            # See TIMEOUT(1)
+            '{}'.format(args.duration + 16),
+            # Adds 15 s for the Warm-up phase before sending the TERM signal
+            '{}'.format(args.duration + 15),
+            launcher
+        ]
+        cmd_params = [
+            '/test={}'.format(args.test),
+            '/width={}'.format(args.width),
+            '/height={}'.format(args.height),
+            '/benchmark_duration_ms={}'.format(args.duration * 1000)
+        ]
+        if args.fullscreen:
+            cmd_params = cmd_params + ['/fullscreen']
+
+        try:
+            check_output(timeout_params + cmd_params, cwd=dirname)
+        except CalledProcessError:
+            # GpuTest.exe never returns, so the timeout exit code is always
+            # set to a non-zero value. It's expected.
+            pass
+        return check_log(logfile)

=== added directory 'checkbox-support/checkbox_support/scripts/tests'
=== added file 'checkbox-support/checkbox_support/scripts/tests/__init__.py'
=== added file 'checkbox-support/checkbox_support/scripts/tests/test_audio_settings.py'
--- checkbox-support/checkbox_support/scripts/tests/test_audio_settings.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/scripts/tests/test_audio_settings.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,151 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+import os
+import unittest
+
+from checkbox.scripts.audio_settings import _guess_hdmi_profile
+from checkbox.parsers.tests.test_pactl import PactlDataMixIn
+
+
+class SetProfileTest(unittest.TestCase, PactlDataMixIn):
+
+    def test_desktop_precise_xps1340(self):
+        """
+        Precise system with a Nvidia chipset.
+        HDMI is present in the card ports list but not shown in the sinks list.
+        The port availability cannot be determined, in that case the expected
+        value is the first stereo profile listed in the identified port.
+        Meaningful lines:
+
+        Card #0
+        [...]
+            Ports:
+        [...]
+                hdmi-output-0: HDMI / DisplayPort (priority 5900)
+                    Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo, output:hdmi-surround, output:hdmi-surround+input:analog-stereo
+        """
+        self.assertEqual(
+            _guess_hdmi_profile(self.get_text("desktop-precise-xps1340")),
+            ('0', 'output:hdmi-stereo'))
+
+    def test_desktop_precise_radeon_not_available(self):
+        """
+        Home-made system running Precise with a Radeon card.
+        HDMI is present in the card ports list and shown in the sinks list.
+        But the port is "not available", both card and profile should be set
+        to None.
+        Meaningful lines:
+
+        Sink #0
+        [...]
+            Ports:
+                hdmi-output-0: HDMI / DisplayPort (priority: 5900, not available)
+        [...]
+        Card #0
+        [...]
+            Ports:
+                hdmi-output-0: HDMI / DisplayPort (priority 5900)
+                    Part of profile(s): output:hdmi-stereo
+        """
+        self.assertEqual(
+            _guess_hdmi_profile(self.get_text("desktop-precise-radeon")),
+            (None, None))
+
+    def test_desktop_precise_radeon_available(self):
+        """
+        Home-made system running Precise with a Radeon card.
+        HDMI is present in the card ports list, shown in the sinks list and
+        marked as "available", in that case the expected value is the first
+        stereo profile listed in the identified port.
+        Meaningful lines:
+
+        Sink #0
+        [...]
+            Ports:
+                hdmi-output-0: HDMI / DisplayPort (priority: 5900, available)
+        [...]
+        Card #0
+        [...]
+            Ports:
+                hdmi-output-0: HDMI / DisplayPort (priority 5900)
+                    Part of profile(s): output:hdmi-stereo
+        """
+        self.assertEqual(
+            _guess_hdmi_profile(self.get_text(
+                "desktop-precise-radeon-hdmi-available")),
+            ('0', 'output:hdmi-stereo'))
+
+    def test_desktop_raring_t430s_not_available(self):
+        """
+        Raring system with a Mini-DisplayPort.
+        DisplayPort is present in the card ports list but marked as
+        "not available". Thus both card and profile should be set
+        to None.
+        Meaningful lines:
+
+        Card #2
+        [...]
+            Ports:
+        [...]
+                hdmi-output-0: HDMI / DisplayPort (priority: 5900, latency offset: 0 usec, not available)
+                    Properties:
+                        device.icon_name = "video-display"
+                    Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo
+                hdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, latency offset: 0 usec, not available)
+                    Properties:
+                        device.icon_name = "video-display"
+                    Part of profile(s): output:hdmi-stereo-extra1, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1, output:hdmi-surround-extra1+input:analog-stereo
+                hdmi-output-2: HDMI / DisplayPort 3 (priority: 5700, latency offset: 0 usec, not available)
+                    Properties:
+                        device.icon_name = "video-display"
+                    Part of profile(s): output:hdmi-stereo-extra2, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2, output:hdmi-surround-extra2+input:analog-stereo
+        """
+        self.assertEqual(
+            _guess_hdmi_profile(self.get_text("desktop-raring-t430s")),
+            (None, None))
+
+    def test_desktop_raring_t430s_available(self):
+        """
+        Raring system with a Mini-DisplayPort.
+        DisplayPort is present in the card ports list and marked as
+        "available", in that case the expected value is the first stereo
+        profile listed in the identified port.
+        Meaningful lines:
+
+        Card #2
+        [...]
+            Ports:
+        [...]
+                hdmi-output-0: HDMI / DisplayPort (priority: 5900, latency offset: 0 usec, available)
+                    Properties:
+                        device.icon_name = "video-display"
+                    Part of profile(s): output:hdmi-stereo, output:hdmi-stereo+input:analog-stereo
+                hdmi-output-1: HDMI / DisplayPort 2 (priority: 5800, latency offset: 0 usec, not available)
+                    Properties:
+                        device.icon_name = "video-display"
+                    Part of profile(s): output:hdmi-stereo-extra1, output:hdmi-stereo-extra1+input:analog-stereo, output:hdmi-surround-extra1, output:hdmi-surround-extra1+input:analog-stereo
+                hdmi-output-2: HDMI / DisplayPort 3 (priority: 5700, latency offset: 0 usec, not available)
+                    Properties:
+                        device.icon_name = "video-display"
+                    Part of profile(s): output:hdmi-stereo-extra2, output:hdmi-stereo-extra2+input:analog-stereo, output:hdmi-surround-extra2, output:hdmi-surround-extra2+input:analog-stereo
+        """
+        self.assertEqual(
+            _guess_hdmi_profile(self.get_text(
+                "desktop-raring-t430s-dp-available")),
+            ('2', 'output:hdmi-stereo'))

=== added file 'checkbox-support/checkbox_support/scripts/tests/test_gputest_benchmark.py'
--- checkbox-support/checkbox_support/scripts/tests/test_gputest_benchmark.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/scripts/tests/test_gputest_benchmark.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,78 @@
+#
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+from tempfile import NamedTemporaryFile
+import os
+import unittest
+
+from checkbox.scripts.gputest_benchmark import check_log
+from checkbox.vendor.mock import patch
+
+
+class LogParserTest(unittest.TestCase):
+
+    def setUp(self):
+        self.logfile = NamedTemporaryFile(delete=False)
+        self.devnull = open(os.devnull, 'w')
+
+    def test_logfile_not_found(self):
+        os.unlink(self.logfile.name)
+        with self.assertRaises(SystemExit) as cm:
+            check_log(self.logfile.name)
+        self.assertEqual(
+            "[Errno 2] No such file or directory: "
+            "'{}'".format(self.logfile.name),
+            str(cm.exception))
+
+    def test_logfile_with_score(self):
+        with open(self.logfile.name, 'wt') as f:
+            f.write('FurMark : init OK.\n')
+            f.write('[Benchmark_Score] - module: FurMark - Score: 8 points'
+                    '(800x600 windowed, duration:2000 ms).')
+        with patch('sys.stdout', self.devnull):
+            self.assertFalse(check_log(self.logfile.name))
+        os.unlink(self.logfile.name)
+
+    def test_logfile_without_score(self):
+        with open(self.logfile.name, 'wt') as f:
+            f.write('FurMark : init OK.\n')
+            f.write('[No_Score] - module: FurMark - Score: _ points'
+                    '(800x600 windowed, duration:2000 ms).')
+        with patch('sys.stdout', self.devnull):
+            with self.assertRaises(SystemExit) as cm:
+                check_log(self.logfile.name)
+            self.assertEqual(
+                'Benchmark score not found, check the log for errors',
+                str(cm.exception))
+        os.unlink(self.logfile.name)
+
+    def test_logfile_with_encoding_error(self):
+        with open(self.logfile.name, 'wb') as f:
+            f.write(b'\x80abc\n')
+            f.write(b'FurMark : init OK.\n')
+            f.write(b'[Benchmark_Score] - module: FurMark - Score: 116 points'
+                    b'(800x600 windowed, duration:2000 ms).')
+        with patch('sys.stdout', self.devnull):
+            self.assertFalse(check_log(self.logfile.name))
+        os.unlink(self.logfile.name)
+
+    def tearDown(self):
+        try:
+            os.unlink(self.logfile.name)
+        except OSError:
+            pass

=== added directory 'checkbox-support/checkbox_support/tests'
=== added file 'checkbox-support/checkbox_support/tests/__init__.py'
--- checkbox-support/checkbox_support/tests/__init__.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/tests/__init__.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,49 @@
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+:mod:`checkbox.tests` -- auxiliary test loaders for checkbox and scripts
+========================================================================
+"""
+
+from inspect import getabsfile
+from unittest.loader import defaultTestLoader
+import os
+
+import checkbox
+
+
+def load_unit_tests():
+    """
+    Load all unit tests and return a TestSuite object
+    """
+    # Discover all unit tests. By simple convention those are kept in
+    # python modules that start with the word 'test_' .
+    return defaultTestLoader.discover(
+        os.path.dirname(getabsfile(checkbox)))
+
+
+def test_suite():
+    """
+    Test suite function used by setuptools test loader.
+
+    Uses unittest test discovery system to get a list of test cases defined
+    inside checkbox. See setup.py setup(test_suite=...) for a matching entry
+    """
+    return load_unit_tests()

=== added file 'checkbox-support/checkbox_support/udev.py'
--- checkbox-support/checkbox_support/udev.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/udev.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,93 @@
+# This file is part of Checkbox.
+#
+# Copyright 2012 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+#
+"""
+checkbox.udev
+=============
+
+A collection of utility function sfor interacting with GUdev
+"""
+
+from gi.repository import GUdev
+
+from checkbox.heuristics.udev import is_virtual_device
+
+
+def get_interconnect_speed(device):
+    """
+    Compute the speed of the USB interconnect of single device
+
+    This function traverses up the tree of devices all the way to the root
+    object and returns the minimum value of the 'speed' sysfs attribute, or
+    None if there was no speed in any of the devices.
+    """
+    # We'll track the actual speed of the interconnect here. The value None
+    # means that we just don't know
+    interconnect_speed = None
+    while device:
+        # For each udev device that we traverse we attempt to lookup the
+        # 'speed' attribute. If present it is converted to an ASCII string and
+        # then to an integer. That integer represents the speed of the
+        # interconnect in megabits.
+        #
+        # Here we use get_sysfs_attr_as_int that does it all for us, returning
+        # 0 if anything is wrong.
+        device_speed = device.get_sysfs_attr_as_int('speed')
+        if device_speed != 0:  # Empty values get truncated to 0
+            # As USB devices can be connected via any number of hubs we
+            # carefully use the smallest number that is encountered but it
+            # seems that the Kernel already does the right thing and shows a
+            # SuperSpeed USB 3.0 device (that normally has speed of 5000Mbit/s)
+            # which is connected to a HighSpeed USB 2.0 device (that is limited
+            # to 480Mbit/s) to also have the smaller, 480Mbit/s speed.
+            if interconnect_speed is not None:
+                interconnect_speed = min(interconnect_speed, device_speed)
+            else:
+                interconnect_speed = device_speed
+        # We walk up the tree of udev devices looking for any parent that
+        # belongs to the 'usb' subsystem having device_type of 'usb_device'. I
+        # have not managed to find any documentation about this (I've yet to
+        # check Kernel documentation) but casual observation and testing seems
+        # to indicate that this is what we want.
+        # TODO: get_parent_with_subsystem('usb', 'usb_device')
+        device = device.get_parent()
+    return interconnect_speed
+
+
+def get_udev_block_devices(udev_client):
+    """
+    Get a list of all block devices
+
+    Returns a list of GUdev.Device objects representing all block devices in
+    the system. Virtual devices are filtered away using
+    checkbox.heuristics.udev.is_virtual_device.
+    """
+    # setup an enumerator so that we can list devices
+    enumerator = GUdev.Enumerator(client=udev_client)
+    # Iterate over block devices only
+    enumerator.add_match_subsystem('block')
+    # Convert the enumerator into a plain list and filter-away all
+    # devices deemed virtual by the heuristic.
+    devices = [
+        device for device in enumerator.execute()
+        if not is_virtual_device(device.get_device_file())]
+    # Sort the list, this is not needed but makes various debugging dumps
+    # look better.
+    devices.sort(key=lambda device: device.get_device_file())
+    return devices

=== added directory 'checkbox-support/checkbox_support/vendor'
=== added file 'checkbox-support/checkbox_support/vendor/__init__.py'
--- checkbox-support/checkbox_support/vendor/__init__.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/vendor/__init__.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,28 @@
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Zygmunt Krynicki <zygmunt.krynicki@canonical.com>
+#
+# Checkbox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License version 3,
+# as published by the Free Software Foundation.
+
+#
+# Checkbox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Checkbox.  If not, see <http://www.gnu.org/licenses/>.
+
+"""
+:mod:`checkbox.vendor` -- vendorized packages
+=============================================
+
+This module contains external packages that were vendorized (shipped with a
+tree of another project) to simplify dependency management. There is no problem
+with expressing those dependencies at pypi level but it would be annoying to
+have to first package and introduce them to Ubuntu.
+"""

=== added file 'checkbox-support/checkbox_support/vendor/mock.py'
--- checkbox-support/checkbox_support/vendor/mock.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/checkbox_support/vendor/mock.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,2367 @@
+# mock.py
+# Test tools for mocking and patching.
+# Copyright (C) 2007-2012 Michael Foord & the mock team
+# E-mail: fuzzyman AT voidspace DOT org DOT uk
+
+# mock 1.0
+# http://www.voidspace.org.uk/python/mock/
+
+# Released subject to the BSD License
+# Please see http://www.voidspace.org.uk/python/license.shtml
+
+# Scripts maintained at http://www.voidspace.org.uk/python/index.shtml
+# Comments, suggestions and bug reports welcome.
+
+
+__all__ = (
+    'Mock',
+    'MagicMock',
+    'patch',
+    'sentinel',
+    'DEFAULT',
+    'ANY',
+    'call',
+    'create_autospec',
+    'FILTER_DIR',
+    'NonCallableMock',
+    'NonCallableMagicMock',
+    'mock_open',
+    'PropertyMock',
+)
+
+
+__version__ = '1.0.1'
+
+
+import pprint
+import sys
+
+try:
+    import inspect
+except ImportError:
+    # for alternative platforms that
+    # may not have inspect
+    inspect = None
+
+try:
+    from functools import wraps as original_wraps
+except ImportError:
+    # Python 2.4 compatibility
+    def wraps(original):
+        def inner(f):
+            f.__name__ = original.__name__
+            f.__doc__ = original.__doc__
+            f.__module__ = original.__module__
+            f.__wrapped__ = original
+            return f
+        return inner
+else:
+    if sys.version_info[:2] >= (3, 3):
+        wraps = original_wraps
+    else:
+        def wraps(func):
+            def inner(f):
+                f = original_wraps(func)(f)
+                f.__wrapped__ = func
+                return f
+            return inner
+
+try:
+    unicode
+except NameError:
+    # Python 3
+    basestring = unicode = str
+
+try:
+    long
+except NameError:
+    # Python 3
+    long = int
+
+try:
+    BaseException
+except NameError:
+    # Python 2.4 compatibility
+    BaseException = Exception
+
+try:
+    next
+except NameError:
+    def next(obj):
+        return obj.next()
+
+
+BaseExceptions = (BaseException,)
+if 'java' in sys.platform:
+    # jython
+    import java
+    BaseExceptions = (BaseException, java.lang.Throwable)
+
+try:
+    _isidentifier = str.isidentifier
+except AttributeError:
+    # Python 2.X
+    import keyword
+    import re
+    regex = re.compile(r'^[a-z_][a-z0-9_]*$', re.I)
+    def _isidentifier(string):
+        if string in keyword.kwlist:
+            return False
+        return regex.match(string)
+
+
+inPy3k = sys.version_info[0] == 3
+
+# Needed to work around Python 3 bug where use of "super" interferes with
+# defining __class__ as a descriptor
+_super = super
+
+self = 'im_self'
+builtin = '__builtin__'
+if inPy3k:
+    self = '__self__'
+    builtin = 'builtins'
+
+FILTER_DIR = True
+
+
+def _is_instance_mock(obj):
+    # can't use isinstance on Mock objects because they override __class__
+    # The base class for all mocks is NonCallableMock
+    return issubclass(type(obj), NonCallableMock)
+
+
+def _is_exception(obj):
+    return (
+        isinstance(obj, BaseExceptions) or
+        isinstance(obj, ClassTypes) and issubclass(obj, BaseExceptions)
+    )
+
+
+class _slotted(object):
+    __slots__ = ['a']
+
+
+DescriptorTypes = (
+    type(_slotted.a),
+    property,
+)
+
+
+def _getsignature(func, skipfirst, instance=False):
+    if inspect is None:
+        raise ImportError('inspect module not available')
+
+    if isinstance(func, ClassTypes) and not instance:
+        try:
+            func = func.__init__
+        except AttributeError:
+            return
+        skipfirst = True
+    elif not isinstance(func, FunctionTypes):
+        # for classes where instance is True we end up here too
+        try:
+            func = func.__call__
+        except AttributeError:
+            return
+
+    if inPy3k:
+        try:
+            argspec = inspect.getfullargspec(func)
+        except TypeError:
+            # C function / method, possibly inherited object().__init__
+            return
+        regargs, varargs, varkw, defaults, kwonly, kwonlydef, ann = argspec
+    else:
+        try:
+            regargs, varargs, varkwargs, defaults = inspect.getargspec(func)
+        except TypeError:
+            # C function / method, possibly inherited object().__init__
+            return
+
+    # instance methods and classmethods need to lose the self argument
+    if getattr(func, self, None) is not None:
+        regargs = regargs[1:]
+    if skipfirst:
+        # this condition and the above one are never both True - why?
+        regargs = regargs[1:]
+
+    if inPy3k:
+        signature = inspect.formatargspec(
+            regargs, varargs, varkw, defaults,
+            kwonly, kwonlydef, ann, formatvalue=lambda value: "")
+    else:
+        signature = inspect.formatargspec(
+            regargs, varargs, varkwargs, defaults,
+            formatvalue=lambda value: "")
+    return signature[1:-1], func
+
+
+def _check_signature(func, mock, skipfirst, instance=False):
+    if not _callable(func):
+        return
+
+    result = _getsignature(func, skipfirst, instance)
+    if result is None:
+        return
+    signature, func = result
+
+    # can't use self because "self" is common as an argument name
+    # unfortunately even not in the first place
+    src = "lambda _mock_self, %s: None" % signature
+    checksig = eval(src, {})
+    _copy_func_details(func, checksig)
+    type(mock)._mock_check_sig = checksig
+
+
+def _copy_func_details(func, funcopy):
+    funcopy.__name__ = func.__name__
+    funcopy.__doc__ = func.__doc__
+    #funcopy.__dict__.update(func.__dict__)
+    funcopy.__module__ = func.__module__
+    if not inPy3k:
+        funcopy.func_defaults = func.func_defaults
+        return
+    funcopy.__defaults__ = func.__defaults__
+    funcopy.__kwdefaults__ = func.__kwdefaults__
+
+
+def _callable(obj):
+    if isinstance(obj, ClassTypes):
+        return True
+    if getattr(obj, '__call__', None) is not None:
+        return True
+    return False
+
+
+def _is_list(obj):
+    # checks for list or tuples
+    # XXXX badly named!
+    return type(obj) in (list, tuple)
+
+
+def _instance_callable(obj):
+    """Given an object, return True if the object is callable.
+    For classes, return True if instances would be callable."""
+    if not isinstance(obj, ClassTypes):
+        # already an instance
+        return getattr(obj, '__call__', None) is not None
+
+    klass = obj
+    # uses __bases__ instead of __mro__ so that we work with old style classes
+    if klass.__dict__.get('__call__') is not None:
+        return True
+
+    for base in klass.__bases__:
+        if _instance_callable(base):
+            return True
+    return False
+
+
+def _set_signature(mock, original, instance=False):
+    # creates a function with signature (*args, **kwargs) that delegates to a
+    # mock. It still does signature checking by calling a lambda with the same
+    # signature as the original.
+    if not _callable(original):
+        return
+
+    skipfirst = isinstance(original, ClassTypes)
+    result = _getsignature(original, skipfirst, instance)
+    if result is None:
+        # was a C function (e.g. object().__init__ ) that can't be mocked
+        return
+
+    signature, func = result
+
+    src = "lambda %s: None" % signature
+    checksig = eval(src, {})
+    _copy_func_details(func, checksig)
+
+    name = original.__name__
+    if not _isidentifier(name):
+        name = 'funcopy'
+    context = {'_checksig_': checksig, 'mock': mock}
+    src = """def %s(*args, **kwargs):
+    _checksig_(*args, **kwargs)
+    return mock(*args, **kwargs)""" % name
+    exec (src, context)
+    funcopy = context[name]
+    _setup_func(funcopy, mock)
+    return funcopy
+
+
+def _setup_func(funcopy, mock):
+    funcopy.mock = mock
+
+    # can't use isinstance with mocks
+    if not _is_instance_mock(mock):
+        return
+
+    def assert_called_with(*args, **kwargs):
+        return mock.assert_called_with(*args, **kwargs)
+    def assert_called_once_with(*args, **kwargs):
+        return mock.assert_called_once_with(*args, **kwargs)
+    def assert_has_calls(*args, **kwargs):
+        return mock.assert_has_calls(*args, **kwargs)
+    def assert_any_call(*args, **kwargs):
+        return mock.assert_any_call(*args, **kwargs)
+    def reset_mock():
+        funcopy.method_calls = _CallList()
+        funcopy.mock_calls = _CallList()
+        mock.reset_mock()
+        ret = funcopy.return_value
+        if _is_instance_mock(ret) and not ret is mock:
+            ret.reset_mock()
+
+    funcopy.called = False
+    funcopy.call_count = 0
+    funcopy.call_args = None
+    funcopy.call_args_list = _CallList()
+    funcopy.method_calls = _CallList()
+    funcopy.mock_calls = _CallList()
+
+    funcopy.return_value = mock.return_value
+    funcopy.side_effect = mock.side_effect
+    funcopy._mock_children = mock._mock_children
+
+    funcopy.assert_called_with = assert_called_with
+    funcopy.assert_called_once_with = assert_called_once_with
+    funcopy.assert_has_calls = assert_has_calls
+    funcopy.assert_any_call = assert_any_call
+    funcopy.reset_mock = reset_mock
+
+    mock._mock_delegate = funcopy
+
+
+def _is_magic(name):
+    return '__%s__' % name[2:-2] == name
+
+
+class _SentinelObject(object):
+    "A unique, named, sentinel object."
+    def __init__(self, name):
+        self.name = name
+
+    def __repr__(self):
+        return 'sentinel.%s' % self.name
+
+
+class _Sentinel(object):
+    """Access attributes to return a named object, usable as a sentinel."""
+    def __init__(self):
+        self._sentinels = {}
+
+    def __getattr__(self, name):
+        if name == '__bases__':
+            # Without this help(mock) raises an exception
+            raise AttributeError
+        return self._sentinels.setdefault(name, _SentinelObject(name))
+
+
+sentinel = _Sentinel()
+
+DEFAULT = sentinel.DEFAULT
+_missing = sentinel.MISSING
+_deleted = sentinel.DELETED
+
+
+class OldStyleClass:
+    pass
+ClassType = type(OldStyleClass)
+
+
+def _copy(value):
+    if type(value) in (dict, list, tuple, set):
+        return type(value)(value)
+    return value
+
+
+ClassTypes = (type,)
+if not inPy3k:
+    ClassTypes = (type, ClassType)
+
+_allowed_names = set(
+    [
+        'return_value', '_mock_return_value', 'side_effect',
+        '_mock_side_effect', '_mock_parent', '_mock_new_parent',
+        '_mock_name', '_mock_new_name'
+    ]
+)
+
+
+def _delegating_property(name):
+    _allowed_names.add(name)
+    _the_name = '_mock_' + name
+    def _get(self, name=name, _the_name=_the_name):
+        sig = self._mock_delegate
+        if sig is None:
+            return getattr(self, _the_name)
+        return getattr(sig, name)
+    def _set(self, value, name=name, _the_name=_the_name):
+        sig = self._mock_delegate
+        if sig is None:
+            self.__dict__[_the_name] = value
+        else:
+            setattr(sig, name, value)
+
+    return property(_get, _set)
+
+
+
+class _CallList(list):
+
+    def __contains__(self, value):
+        if not isinstance(value, list):
+            return list.__contains__(self, value)
+        len_value = len(value)
+        len_self = len(self)
+        if len_value > len_self:
+            return False
+
+        for i in range(0, len_self - len_value + 1):
+            sub_list = self[i:i+len_value]
+            if sub_list == value:
+                return True
+        return False
+
+    def __repr__(self):
+        return pprint.pformat(list(self))
+
+
+def _check_and_set_parent(parent, value, name, new_name):
+    if not _is_instance_mock(value):
+        return False
+    if ((value._mock_name or value._mock_new_name) or
+        (value._mock_parent is not None) or
+        (value._mock_new_parent is not None)):
+        return False
+
+    _parent = parent
+    while _parent is not None:
+        # setting a mock (value) as a child or return value of itself
+        # should not modify the mock
+        if _parent is value:
+            return False
+        _parent = _parent._mock_new_parent
+
+    if new_name:
+        value._mock_new_parent = parent
+        value._mock_new_name = new_name
+    if name:
+        value._mock_parent = parent
+        value._mock_name = name
+    return True
+
+
+
+class Base(object):
+    _mock_return_value = DEFAULT
+    _mock_side_effect = None
+    def __init__(self, *args, **kwargs):
+        pass
+
+
+
+class NonCallableMock(Base):
+    """A non-callable version of `Mock`"""
+
+    def __new__(cls, *args, **kw):
+        # every instance has its own class
+        # so we can create magic methods on the
+        # class without stomping on other mocks
+        new = type(cls.__name__, (cls,), {'__doc__': cls.__doc__})
+        instance = object.__new__(new)
+        return instance
+
+
+    def __init__(
+            self, spec=None, wraps=None, name=None, spec_set=None,
+            parent=None, _spec_state=None, _new_name='', _new_parent=None,
+            **kwargs
+        ):
+        if _new_parent is None:
+            _new_parent = parent
+
+        __dict__ = self.__dict__
+        __dict__['_mock_parent'] = parent
+        __dict__['_mock_name'] = name
+        __dict__['_mock_new_name'] = _new_name
+        __dict__['_mock_new_parent'] = _new_parent
+
+        if spec_set is not None:
+            spec = spec_set
+            spec_set = True
+
+        self._mock_add_spec(spec, spec_set)
+
+        __dict__['_mock_children'] = {}
+        __dict__['_mock_wraps'] = wraps
+        __dict__['_mock_delegate'] = None
+
+        __dict__['_mock_called'] = False
+        __dict__['_mock_call_args'] = None
+        __dict__['_mock_call_count'] = 0
+        __dict__['_mock_call_args_list'] = _CallList()
+        __dict__['_mock_mock_calls'] = _CallList()
+
+        __dict__['method_calls'] = _CallList()
+
+        if kwargs:
+            self.configure_mock(**kwargs)
+
+        _super(NonCallableMock, self).__init__(
+            spec, wraps, name, spec_set, parent,
+            _spec_state
+        )
+
+
+    def attach_mock(self, mock, attribute):
+        """
+        Attach a mock as an attribute of this one, replacing its name and
+        parent. Calls to the attached mock will be recorded in the
+        `method_calls` and `mock_calls` attributes of this one."""
+        mock._mock_parent = None
+        mock._mock_new_parent = None
+        mock._mock_name = ''
+        mock._mock_new_name = None
+
+        setattr(self, attribute, mock)
+
+
+    def mock_add_spec(self, spec, spec_set=False):
+        """Add a spec to a mock. `spec` can either be an object or a
+        list of strings. Only attributes on the `spec` can be fetched as
+        attributes from the mock.
+
+        If `spec_set` is True then only attributes on the spec can be set."""
+        self._mock_add_spec(spec, spec_set)
+
+
+    def _mock_add_spec(self, spec, spec_set):
+        _spec_class = None
+
+        if spec is not None and not _is_list(spec):
+            if isinstance(spec, ClassTypes):
+                _spec_class = spec
+            else:
+                _spec_class = _get_class(spec)
+
+            spec = dir(spec)
+
+        __dict__ = self.__dict__
+        __dict__['_spec_class'] = _spec_class
+        __dict__['_spec_set'] = spec_set
+        __dict__['_mock_methods'] = spec
+
+
+    def __get_return_value(self):
+        ret = self._mock_return_value
+        if self._mock_delegate is not None:
+            ret = self._mock_delegate.return_value
+
+        if ret is DEFAULT:
+            ret = self._get_child_mock(
+                _new_parent=self, _new_name='()'
+            )
+            self.return_value = ret
+        return ret
+
+
+    def __set_return_value(self, value):
+        if self._mock_delegate is not None:
+            self._mock_delegate.return_value = value
+        else:
+            self._mock_return_value = value
+            _check_and_set_parent(self, value, None, '()')
+
+    __return_value_doc = "The value to be returned when the mock is called."
+    return_value = property(__get_return_value, __set_return_value,
+                            __return_value_doc)
+
+
+    @property
+    def __class__(self):
+        if self._spec_class is None:
+            return type(self)
+        return self._spec_class
+
+    called = _delegating_property('called')
+    call_count = _delegating_property('call_count')
+    call_args = _delegating_property('call_args')
+    call_args_list = _delegating_property('call_args_list')
+    mock_calls = _delegating_property('mock_calls')
+
+
+    def __get_side_effect(self):
+        sig = self._mock_delegate
+        if sig is None:
+            return self._mock_side_effect
+        return sig.side_effect
+
+    def __set_side_effect(self, value):
+        value = _try_iter(value)
+        sig = self._mock_delegate
+        if sig is None:
+            self._mock_side_effect = value
+        else:
+            sig.side_effect = value
+
+    side_effect = property(__get_side_effect, __set_side_effect)
+
+
+    def reset_mock(self):
+        "Restore the mock object to its initial state."
+        self.called = False
+        self.call_args = None
+        self.call_count = 0
+        self.mock_calls = _CallList()
+        self.call_args_list = _CallList()
+        self.method_calls = _CallList()
+
+        for child in self._mock_children.values():
+            if isinstance(child, _SpecState):
+                continue
+            child.reset_mock()
+
+        ret = self._mock_return_value
+        if _is_instance_mock(ret) and ret is not self:
+            ret.reset_mock()
+
+
+    def configure_mock(self, **kwargs):
+        """Set attributes on the mock through keyword arguments.
+
+        Attributes plus return values and side effects can be set on child
+        mocks using standard dot notation and unpacking a dictionary in the
+        method call:
+
+        >>> attrs = {'method.return_value': 3, 'other.side_effect': KeyError}
+        >>> mock.configure_mock(**attrs)"""
+        for arg, val in sorted(kwargs.items(),
+                               # we sort on the number of dots so that
+                               # attributes are set before we set attributes on
+                               # attributes
+                               key=lambda entry: entry[0].count('.')):
+            args = arg.split('.')
+            final = args.pop()
+            obj = self
+            for entry in args:
+                obj = getattr(obj, entry)
+            setattr(obj, final, val)
+
+
+    def __getattr__(self, name):
+        if name == '_mock_methods':
+            raise AttributeError(name)
+        elif self._mock_methods is not None:
+            if name not in self._mock_methods or name in _all_magics:
+                raise AttributeError("Mock object has no attribute %r" % name)
+        elif _is_magic(name):
+            raise AttributeError(name)
+
+        result = self._mock_children.get(name)
+        if result is _deleted:
+            raise AttributeError(name)
+        elif result is None:
+            wraps = None
+            if self._mock_wraps is not None:
+                # XXXX should we get the attribute without triggering code
+                # execution?
+                wraps = getattr(self._mock_wraps, name)
+
+            result = self._get_child_mock(
+                parent=self, name=name, wraps=wraps, _new_name=name,
+                _new_parent=self
+            )
+            self._mock_children[name]  = result
+
+        elif isinstance(result, _SpecState):
+            result = create_autospec(
+                result.spec, result.spec_set, result.instance,
+                result.parent, result.name
+            )
+            self._mock_children[name]  = result
+
+        return result
+
+
+    def __repr__(self):
+        _name_list = [self._mock_new_name]
+        _parent = self._mock_new_parent
+        last = self
+
+        dot = '.'
+        if _name_list == ['()']:
+            dot = ''
+        seen = set()
+        while _parent is not None:
+            last = _parent
+
+            _name_list.append(_parent._mock_new_name + dot)
+            dot = '.'
+            if _parent._mock_new_name == '()':
+                dot = ''
+
+            _parent = _parent._mock_new_parent
+
+            # use ids here so as not to call __hash__ on the mocks
+            if id(_parent) in seen:
+                break
+            seen.add(id(_parent))
+
+        _name_list = list(reversed(_name_list))
+        _first = last._mock_name or 'mock'
+        if len(_name_list) > 1:
+            if _name_list[1] not in ('()', '().'):
+                _first += '.'
+        _name_list[0] = _first
+        name = ''.join(_name_list)
+
+        name_string = ''
+        if name not in ('mock', 'mock.'):
+            name_string = ' name=%r' % name
+
+        spec_string = ''
+        if self._spec_class is not None:
+            spec_string = ' spec=%r'
+            if self._spec_set:
+                spec_string = ' spec_set=%r'
+            spec_string = spec_string % self._spec_class.__name__
+        return "<%s%s%s id='%s'>" % (
+            type(self).__name__,
+            name_string,
+            spec_string,
+            id(self)
+        )
+
+
+    def __dir__(self):
+        """Filter the output of `dir(mock)` to only useful members.
+        XXXX
+        """
+        extras = self._mock_methods or []
+        from_type = dir(type(self))
+        from_dict = list(self.__dict__)
+
+        if FILTER_DIR:
+            from_type = [e for e in from_type if not e.startswith('_')]
+            from_dict = [e for e in from_dict if not e.startswith('_') or
+                         _is_magic(e)]
+        return sorted(set(extras + from_type + from_dict +
+                          list(self._mock_children)))
+
+
+    def __setattr__(self, name, value):
+        if name in _allowed_names:
+            # property setters go through here
+            return object.__setattr__(self, name, value)
+        elif (self._spec_set and self._mock_methods is not None and
+            name not in self._mock_methods and
+            name not in self.__dict__):
+            raise AttributeError("Mock object has no attribute '%s'" % name)
+        elif name in _unsupported_magics:
+            msg = 'Attempting to set unsupported magic method %r.' % name
+            raise AttributeError(msg)
+        elif name in _all_magics:
+            if self._mock_methods is not None and name not in self._mock_methods:
+                raise AttributeError("Mock object has no attribute '%s'" % name)
+
+            if not _is_instance_mock(value):
+                setattr(type(self), name, _get_method(name, value))
+                original = value
+                value = lambda *args, **kw: original(self, *args, **kw)
+            else:
+                # only set _new_name and not name so that mock_calls is tracked
+                # but not method calls
+                _check_and_set_parent(self, value, None, name)
+                setattr(type(self), name, value)
+                self._mock_children[name] = value
+        elif name == '__class__':
+            self._spec_class = value
+            return
+        else:
+            if _check_and_set_parent(self, value, name, name):
+                self._mock_children[name] = value
+        return object.__setattr__(self, name, value)
+
+
+    def __delattr__(self, name):
+        if name in _all_magics and name in type(self).__dict__:
+            delattr(type(self), name)
+            if name not in self.__dict__:
+                # for magic methods that are still MagicProxy objects and
+                # not set on the instance itself
+                return
+
+        if name in self.__dict__:
+            object.__delattr__(self, name)
+
+        obj = self._mock_children.get(name, _missing)
+        if obj is _deleted:
+            raise AttributeError(name)
+        if obj is not _missing:
+            del self._mock_children[name]
+        self._mock_children[name] = _deleted
+
+
+
+    def _format_mock_call_signature(self, args, kwargs):
+        name = self._mock_name or 'mock'
+        return _format_call_signature(name, args, kwargs)
+
+
+    def _format_mock_failure_message(self, args, kwargs):
+        message = 'Expected call: %s\nActual call: %s'
+        expected_string = self._format_mock_call_signature(args, kwargs)
+        call_args = self.call_args
+        if len(call_args) == 3:
+            call_args = call_args[1:]
+        actual_string = self._format_mock_call_signature(*call_args)
+        return message % (expected_string, actual_string)
+
+
+    def assert_called_with(_mock_self, *args, **kwargs):
+        """assert that the mock was called with the specified arguments.
+
+        Raises an AssertionError if the args and keyword args passed in are
+        different to the last call to the mock."""
+        self = _mock_self
+        if self.call_args is None:
+            expected = self._format_mock_call_signature(args, kwargs)
+            raise AssertionError('Expected call: %s\nNot called' % (expected,))
+
+        if self.call_args != (args, kwargs):
+            msg = self._format_mock_failure_message(args, kwargs)
+            raise AssertionError(msg)
+
+
+    def assert_called_once_with(_mock_self, *args, **kwargs):
+        """assert that the mock was called exactly once and with the specified
+        arguments."""
+        self = _mock_self
+        if not self.call_count == 1:
+            msg = ("Expected to be called once. Called %s times." %
+                   self.call_count)
+            raise AssertionError(msg)
+        return self.assert_called_with(*args, **kwargs)
+
+
+    def assert_has_calls(self, calls, any_order=False):
+        """assert the mock has been called with the specified calls.
+        The `mock_calls` list is checked for the calls.
+
+        If `any_order` is False (the default) then the calls must be
+        sequential. There can be extra calls before or after the
+        specified calls.
+
+        If `any_order` is True then the calls can be in any order, but
+        they must all appear in `mock_calls`."""
+        if not any_order:
+            if calls not in self.mock_calls:
+                raise AssertionError(
+                    'Calls not found.\nExpected: %r\n'
+                    'Actual: %r' % (calls, self.mock_calls)
+                )
+            return
+
+        all_calls = list(self.mock_calls)
+
+        not_found = []
+        for kall in calls:
+            try:
+                all_calls.remove(kall)
+            except ValueError:
+                not_found.append(kall)
+        if not_found:
+            raise AssertionError(
+                '%r not all found in call list' % (tuple(not_found),)
+            )
+
+
+    def assert_any_call(self, *args, **kwargs):
+        """assert the mock has been called with the specified arguments.
+
+        The assert passes if the mock has *ever* been called, unlike
+        `assert_called_with` and `assert_called_once_with` that only pass if
+        the call is the most recent one."""
+        kall = call(*args, **kwargs)
+        if kall not in self.call_args_list:
+            expected_string = self._format_mock_call_signature(args, kwargs)
+            raise AssertionError(
+                '%s call not found' % expected_string
+            )
+
+
+    def _get_child_mock(self, **kw):
+        """Create the child mocks for attributes and return value.
+        By default child mocks will be the same type as the parent.
+        Subclasses of Mock may want to override this to customize the way
+        child mocks are made.
+
+        For non-callable mocks the callable variant will be used (rather than
+        any custom subclass)."""
+        _type = type(self)
+        if not issubclass(_type, CallableMixin):
+            if issubclass(_type, NonCallableMagicMock):
+                klass = MagicMock
+            elif issubclass(_type, NonCallableMock) :
+                klass = Mock
+        else:
+            klass = _type.__mro__[1]
+        return klass(**kw)
+
+
+
+def _try_iter(obj):
+    if obj is None:
+        return obj
+    if _is_exception(obj):
+        return obj
+    if _callable(obj):
+        return obj
+    try:
+        return iter(obj)
+    except TypeError:
+        # XXXX backwards compatibility
+        # but this will blow up on first call - so maybe we should fail early?
+        return obj
+
+
+
+class CallableMixin(Base):
+
+    def __init__(self, spec=None, side_effect=None, return_value=DEFAULT,
+                 wraps=None, name=None, spec_set=None, parent=None,
+                 _spec_state=None, _new_name='', _new_parent=None, **kwargs):
+        self.__dict__['_mock_return_value'] = return_value
+
+        _super(CallableMixin, self).__init__(
+            spec, wraps, name, spec_set, parent,
+            _spec_state, _new_name, _new_parent, **kwargs
+        )
+
+        self.side_effect = side_effect
+
+
+    def _mock_check_sig(self, *args, **kwargs):
+        # stub method that can be replaced with one with a specific signature
+        pass
+
+
+    def __call__(_mock_self, *args, **kwargs):
+        # can't use self in-case a function / method we are mocking uses self
+        # in the signature
+        _mock_self._mock_check_sig(*args, **kwargs)
+        return _mock_self._mock_call(*args, **kwargs)
+
+
+    def _mock_call(_mock_self, *args, **kwargs):
+        self = _mock_self
+        self.called = True
+        self.call_count += 1
+        self.call_args = _Call((args, kwargs), two=True)
+        self.call_args_list.append(_Call((args, kwargs), two=True))
+
+        _new_name = self._mock_new_name
+        _new_parent = self._mock_new_parent
+        self.mock_calls.append(_Call(('', args, kwargs)))
+
+        seen = set()
+        skip_next_dot = _new_name == '()'
+        do_method_calls = self._mock_parent is not None
+        name = self._mock_name
+        while _new_parent is not None:
+            this_mock_call = _Call((_new_name, args, kwargs))
+            if _new_parent._mock_new_name:
+                dot = '.'
+                if skip_next_dot:
+                    dot = ''
+
+                skip_next_dot = False
+                if _new_parent._mock_new_name == '()':
+                    skip_next_dot = True
+
+                _new_name = _new_parent._mock_new_name + dot + _new_name
+
+            if do_method_calls:
+                if _new_name == name:
+                    this_method_call = this_mock_call
+                else:
+                    this_method_call = _Call((name, args, kwargs))
+                _new_parent.method_calls.append(this_method_call)
+
+                do_method_calls = _new_parent._mock_parent is not None
+                if do_method_calls:
+                    name = _new_parent._mock_name + '.' + name
+
+            _new_parent.mock_calls.append(this_mock_call)
+            _new_parent = _new_parent._mock_new_parent
+
+            # use ids here so as not to call __hash__ on the mocks
+            _new_parent_id = id(_new_parent)
+            if _new_parent_id in seen:
+                break
+            seen.add(_new_parent_id)
+
+        ret_val = DEFAULT
+        effect = self.side_effect
+        if effect is not None:
+            if _is_exception(effect):
+                raise effect
+
+            if not _callable(effect):
+                result = next(effect)
+                if _is_exception(result):
+                    raise result
+                return result
+
+            ret_val = effect(*args, **kwargs)
+            if ret_val is DEFAULT:
+                ret_val = self.return_value
+
+        if (self._mock_wraps is not None and
+             self._mock_return_value is DEFAULT):
+            return self._mock_wraps(*args, **kwargs)
+        if ret_val is DEFAULT:
+            ret_val = self.return_value
+        return ret_val
+
+
+
+class Mock(CallableMixin, NonCallableMock):
+    """
+    Create a new `Mock` object. `Mock` takes several optional arguments
+    that specify the behaviour of the Mock object:
+
+    * `spec`: This can be either a list of strings or an existing object (a
+      class or instance) that acts as the specification for the mock object. If
+      you pass in an object then a list of strings is formed by calling dir on
+      the object (excluding unsupported magic attributes and methods). Accessing
+      any attribute not in this list will raise an `AttributeError`.
+
+      If `spec` is an object (rather than a list of strings) then
+      `mock.__class__` returns the class of the spec object. This allows mocks
+      to pass `isinstance` tests.
+
+    * `spec_set`: A stricter variant of `spec`. If used, attempting to *set*
+      or get an attribute on the mock that isn't on the object passed as
+      `spec_set` will raise an `AttributeError`.
+
+    * `side_effect`: A function to be called whenever the Mock is called. See
+      the `side_effect` attribute. Useful for raising exceptions or
+      dynamically changing return values. The function is called with the same
+      arguments as the mock, and unless it returns `DEFAULT`, the return
+      value of this function is used as the return value.
+
+      Alternatively `side_effect` can be an exception class or instance. In
+      this case the exception will be raised when the mock is called.
+
+      If `side_effect` is an iterable then each call to the mock will return
+      the next value from the iterable. If any of the members of the iterable
+      are exceptions they will be raised instead of returned.
+
+    * `return_value`: The value returned when the mock is called. By default
+      this is a new Mock (created on first access). See the
+      `return_value` attribute.
+
+    * `wraps`: Item for the mock object to wrap. If `wraps` is not None then
+      calling the Mock will pass the call through to the wrapped object
+      (returning the real result). Attribute access on the mock will return a
+      Mock object that wraps the corresponding attribute of the wrapped object
+      (so attempting to access an attribute that doesn't exist will raise an
+      `AttributeError`).
+
+      If the mock has an explicit `return_value` set then calls are not passed
+      to the wrapped object and the `return_value` is returned instead.
+
+    * `name`: If the mock has a name then it will be used in the repr of the
+      mock. This can be useful for debugging. The name is propagated to child
+      mocks.
+
+    Mocks can also be called with arbitrary keyword arguments. These will be
+    used to set attributes on the mock after it is created.
+    """
+
+
+
+def _dot_lookup(thing, comp, import_path):
+    try:
+        return getattr(thing, comp)
+    except AttributeError:
+        __import__(import_path)
+        return getattr(thing, comp)
+
+
+def _importer(target):
+    components = target.split('.')
+    import_path = components.pop(0)
+    thing = __import__(import_path)
+
+    for comp in components:
+        import_path += ".%s" % comp
+        thing = _dot_lookup(thing, comp, import_path)
+    return thing
+
+
+def _is_started(patcher):
+    # XXXX horrible
+    return hasattr(patcher, 'is_local')
+
+
+class _patch(object):
+
+    attribute_name = None
+    _active_patches = set()
+
+    def __init__(
+            self, getter, attribute, new, spec, create,
+            spec_set, autospec, new_callable, kwargs
+        ):
+        if new_callable is not None:
+            if new is not DEFAULT:
+                raise ValueError(
+                    "Cannot use 'new' and 'new_callable' together"
+                )
+            if autospec is not None:
+                raise ValueError(
+                    "Cannot use 'autospec' and 'new_callable' together"
+                )
+
+        self.getter = getter
+        self.attribute = attribute
+        self.new = new
+        self.new_callable = new_callable
+        self.spec = spec
+        self.create = create
+        self.has_local = False
+        self.spec_set = spec_set
+        self.autospec = autospec
+        self.kwargs = kwargs
+        self.additional_patchers = []
+
+
+    def copy(self):
+        patcher = _patch(
+            self.getter, self.attribute, self.new, self.spec,
+            self.create, self.spec_set,
+            self.autospec, self.new_callable, self.kwargs
+        )
+        patcher.attribute_name = self.attribute_name
+        patcher.additional_patchers = [
+            p.copy() for p in self.additional_patchers
+        ]
+        return patcher
+
+
+    def __call__(self, func):
+        if isinstance(func, ClassTypes):
+            return self.decorate_class(func)
+        return self.decorate_callable(func)
+
+
+    def decorate_class(self, klass):
+        for attr in dir(klass):
+            if not attr.startswith(patch.TEST_PREFIX):
+                continue
+
+            attr_value = getattr(klass, attr)
+            if not hasattr(attr_value, "__call__"):
+                continue
+
+            patcher = self.copy()
+            setattr(klass, attr, patcher(attr_value))
+        return klass
+
+
+    def decorate_callable(self, func):
+        if hasattr(func, 'patchings'):
+            func.patchings.append(self)
+            return func
+
+        @wraps(func)
+        def patched(*args, **keywargs):
+            # don't use a with here (backwards compatability with Python 2.4)
+            extra_args = []
+            entered_patchers = []
+
+            # can't use try...except...finally because of Python 2.4
+            # compatibility
+            exc_info = tuple()
+            try:
+                try:
+                    for patching in patched.patchings:
+                        arg = patching.__enter__()
+                        entered_patchers.append(patching)
+                        if patching.attribute_name is not None:
+                            keywargs.update(arg)
+                        elif patching.new is DEFAULT:
+                            extra_args.append(arg)
+
+                    args += tuple(extra_args)
+                    return func(*args, **keywargs)
+                except:
+                    if (patching not in entered_patchers and
+                        _is_started(patching)):
+                        # the patcher may have been started, but an exception
+                        # raised whilst entering one of its additional_patchers
+                        entered_patchers.append(patching)
+                    # Pass the exception to __exit__
+                    exc_info = sys.exc_info()
+                    # re-raise the exception
+                    raise
+            finally:
+                for patching in reversed(entered_patchers):
+                    patching.__exit__(*exc_info)
+
+        patched.patchings = [self]
+        if hasattr(func, 'func_code'):
+            # not in Python 3
+            patched.compat_co_firstlineno = getattr(
+                func, "compat_co_firstlineno",
+                func.func_code.co_firstlineno
+            )
+        return patched
+
+
+    def get_original(self):
+        target = self.getter()
+        name = self.attribute
+
+        original = DEFAULT
+        local = False
+
+        try:
+            original = target.__dict__[name]
+        except (AttributeError, KeyError):
+            original = getattr(target, name, DEFAULT)
+        else:
+            local = True
+
+        if not self.create and original is DEFAULT:
+            raise AttributeError(
+                "%s does not have the attribute %r" % (target, name)
+            )
+        return original, local
+
+
+    def __enter__(self):
+        """Perform the patch."""
+        new, spec, spec_set = self.new, self.spec, self.spec_set
+        autospec, kwargs = self.autospec, self.kwargs
+        new_callable = self.new_callable
+        self.target = self.getter()
+
+        # normalise False to None
+        if spec is False:
+            spec = None
+        if spec_set is False:
+            spec_set = None
+        if autospec is False:
+            autospec = None
+
+        if spec is not None and autospec is not None:
+            raise TypeError("Can't specify spec and autospec")
+        if ((spec is not None or autospec is not None) and
+            spec_set not in (True, None)):
+            raise TypeError("Can't provide explicit spec_set *and* spec or autospec")
+
+        original, local = self.get_original()
+
+        if new is DEFAULT and autospec is None:
+            inherit = False
+            if spec is True:
+                # set spec to the object we are replacing
+                spec = original
+                if spec_set is True:
+                    spec_set = original
+                    spec = None
+            elif spec is not None:
+                if spec_set is True:
+                    spec_set = spec
+                    spec = None
+            elif spec_set is True:
+                spec_set = original
+
+            if spec is not None or spec_set is not None:
+                if original is DEFAULT:
+                    raise TypeError("Can't use 'spec' with create=True")
+                if isinstance(original, ClassTypes):
+                    # If we're patching out a class and there is a spec
+                    inherit = True
+
+            Klass = MagicMock
+            _kwargs = {}
+            if new_callable is not None:
+                Klass = new_callable
+            elif spec is not None or spec_set is not None:
+                this_spec = spec
+                if spec_set is not None:
+                    this_spec = spec_set
+                if _is_list(this_spec):
+                    not_callable = '__call__' not in this_spec
+                else:
+                    not_callable = not _callable(this_spec)
+                if not_callable:
+                    Klass = NonCallableMagicMock
+
+            if spec is not None:
+                _kwargs['spec'] = spec
+            if spec_set is not None:
+                _kwargs['spec_set'] = spec_set
+
+            # add a name to mocks
+            if (isinstance(Klass, type) and
+                issubclass(Klass, NonCallableMock) and self.attribute):
+                _kwargs['name'] = self.attribute
+
+            _kwargs.update(kwargs)
+            new = Klass(**_kwargs)
+
+            if inherit and _is_instance_mock(new):
+                # we can only tell if the instance should be callable if the
+                # spec is not a list
+                this_spec = spec
+                if spec_set is not None:
+                    this_spec = spec_set
+                if (not _is_list(this_spec) and not
+                    _instance_callable(this_spec)):
+                    Klass = NonCallableMagicMock
+
+                _kwargs.pop('name')
+                new.return_value = Klass(_new_parent=new, _new_name='()',
+                                         **_kwargs)
+        elif autospec is not None:
+            # spec is ignored, new *must* be default, spec_set is treated
+            # as a boolean. Should we check spec is not None and that spec_set
+            # is a bool?
+            if new is not DEFAULT:
+                raise TypeError(
+                    "autospec creates the mock for you. Can't specify "
+                    "autospec and new."
+                )
+            if original is DEFAULT:
+                raise TypeError("Can't use 'autospec' with create=True")
+            spec_set = bool(spec_set)
+            if autospec is True:
+                autospec = original
+
+            new = create_autospec(autospec, spec_set=spec_set,
+                                  _name=self.attribute, **kwargs)
+        elif kwargs:
+            # can't set keyword args when we aren't creating the mock
+            # XXXX If new is a Mock we could call new.configure_mock(**kwargs)
+            raise TypeError("Can't pass kwargs to a mock we aren't creating")
+
+        new_attr = new
+
+        self.temp_original = original
+        self.is_local = local
+        setattr(self.target, self.attribute, new_attr)
+        if self.attribute_name is not None:
+            extra_args = {}
+            if self.new is DEFAULT:
+                extra_args[self.attribute_name] =  new
+            for patching in self.additional_patchers:
+                arg = patching.__enter__()
+                if patching.new is DEFAULT:
+                    extra_args.update(arg)
+            return extra_args
+
+        return new
+
+
+    def __exit__(self, *exc_info):
+        """Undo the patch."""
+        if not _is_started(self):
+            raise RuntimeError('stop called on unstarted patcher')
+
+        if self.is_local and self.temp_original is not DEFAULT:
+            setattr(self.target, self.attribute, self.temp_original)
+        else:
+            delattr(self.target, self.attribute)
+            if not self.create and not hasattr(self.target, self.attribute):
+                # needed for proxy objects like django settings
+                setattr(self.target, self.attribute, self.temp_original)
+
+        del self.temp_original
+        del self.is_local
+        del self.target
+        for patcher in reversed(self.additional_patchers):
+            if _is_started(patcher):
+                patcher.__exit__(*exc_info)
+
+
+    def start(self):
+        """Activate a patch, returning any created mock."""
+        result = self.__enter__()
+        self._active_patches.add(self)
+        return result
+
+
+    def stop(self):
+        """Stop an active patch."""
+        self._active_patches.discard(self)
+        return self.__exit__()
+
+
+
+def _get_target(target):
+    try:
+        target, attribute = target.rsplit('.', 1)
+    except (TypeError, ValueError):
+        raise TypeError("Need a valid target to patch. You supplied: %r" %
+                        (target,))
+    getter = lambda: _importer(target)
+    return getter, attribute
+
+
+def _patch_object(
+        target, attribute, new=DEFAULT, spec=None,
+        create=False, spec_set=None, autospec=None,
+        new_callable=None, **kwargs
+    ):
+    """
+    patch.object(target, attribute, new=DEFAULT, spec=None, create=False,
+                 spec_set=None, autospec=None, new_callable=None, **kwargs)
+
+    patch the named member (`attribute`) on an object (`target`) with a mock
+    object.
+
+    `patch.object` can be used as a decorator, class decorator or a context
+    manager. Arguments `new`, `spec`, `create`, `spec_set`,
+    `autospec` and `new_callable` have the same meaning as for `patch`. Like
+    `patch`, `patch.object` takes arbitrary keyword arguments for configuring
+    the mock object it creates.
+
+    When used as a class decorator `patch.object` honours `patch.TEST_PREFIX`
+    for choosing which methods to wrap.
+    """
+    getter = lambda: target
+    return _patch(
+        getter, attribute, new, spec, create,
+        spec_set, autospec, new_callable, kwargs
+    )
+
+
+def _patch_multiple(target, spec=None, create=False, spec_set=None,
+                    autospec=None, new_callable=None, **kwargs):
+    """Perform multiple patches in a single call. It takes the object to be
+    patched (either as an object or a string to fetch the object by importing)
+    and keyword arguments for the patches::
+
+        with patch.multiple(settings, FIRST_PATCH='one', SECOND_PATCH='two'):
+            ...
+
+    Use `DEFAULT` as the value if you want `patch.multiple` to create
+    mocks for you. In this case the created mocks are passed into a decorated
+    function by keyword, and a dictionary is returned when `patch.multiple` is
+    used as a context manager.
+
+    `patch.multiple` can be used as a decorator, class decorator or a context
+    manager. The arguments `spec`, `spec_set`, `create`,
+    `autospec` and `new_callable` have the same meaning as for `patch`. These
+    arguments will be applied to *all* patches done by `patch.multiple`.
+
+    When used as a class decorator `patch.multiple` honours `patch.TEST_PREFIX`
+    for choosing which methods to wrap.
+    """
+    if type(target) in (unicode, str):
+        getter = lambda: _importer(target)
+    else:
+        getter = lambda: target
+
+    if not kwargs:
+        raise ValueError(
+            'Must supply at least one keyword argument with patch.multiple'
+        )
+    # need to wrap in a list for python 3, where items is a view
+    items = list(kwargs.items())
+    attribute, new = items[0]
+    patcher = _patch(
+        getter, attribute, new, spec, create, spec_set,
+        autospec, new_callable, {}
+    )
+    patcher.attribute_name = attribute
+    for attribute, new in items[1:]:
+        this_patcher = _patch(
+            getter, attribute, new, spec, create, spec_set,
+            autospec, new_callable, {}
+        )
+        this_patcher.attribute_name = attribute
+        patcher.additional_patchers.append(this_patcher)
+    return patcher
+
+
+def patch(
+        target, new=DEFAULT, spec=None, create=False,
+        spec_set=None, autospec=None, new_callable=None, **kwargs
+    ):
+    """
+    `patch` acts as a function decorator, class decorator or a context
+    manager. Inside the body of the function or with statement, the `target`
+    is patched with a `new` object. When the function/with statement exits
+    the patch is undone.
+
+    If `new` is omitted, then the target is replaced with a
+    `MagicMock`. If `patch` is used as a decorator and `new` is
+    omitted, the created mock is passed in as an extra argument to the
+    decorated function. If `patch` is used as a context manager the created
+    mock is returned by the context manager.
+
+    `target` should be a string in the form `'package.module.ClassName'`. The
+    `target` is imported and the specified object replaced with the `new`
+    object, so the `target` must be importable from the environment you are
+    calling `patch` from. The target is imported when the decorated function
+    is executed, not at decoration time.
+
+    The `spec` and `spec_set` keyword arguments are passed to the `MagicMock`
+    if patch is creating one for you.
+
+    In addition you can pass `spec=True` or `spec_set=True`, which causes
+    patch to pass in the object being mocked as the spec/spec_set object.
+
+    `new_callable` allows you to specify a different class, or callable object,
+    that will be called to create the `new` object. By default `MagicMock` is
+    used.
+
+    A more powerful form of `spec` is `autospec`. If you set `autospec=True`
+    then the mock with be created with a spec from the object being replaced.
+    All attributes of the mock will also have the spec of the corresponding
+    attribute of the object being replaced. Methods and functions being
+    mocked will have their arguments checked and will raise a `TypeError` if
+    they are called with the wrong signature. For mocks replacing a class,
+    their return value (the 'instance') will have the same spec as the class.
+
+    Instead of `autospec=True` you can pass `autospec=some_object` to use an
+    arbitrary object as the spec instead of the one being replaced.
+
+    By default `patch` will fail to replace attributes that don't exist. If
+    you pass in `create=True`, and the attribute doesn't exist, patch will
+    create the attribute for you when the patched function is called, and
+    delete it again afterwards. This is useful for writing tests against
+    attributes that your production code creates at runtime. It is off by by
+    default because it can be dangerous. With it switched on you can write
+    passing tests against APIs that don't actually exist!
+
+    Patch can be used as a `TestCase` class decorator. It works by
+    decorating each test method in the class. This reduces the boilerplate
+    code when your test methods share a common patchings set. `patch` finds
+    tests by looking for method names that start with `patch.TEST_PREFIX`.
+    By default this is `test`, which matches the way `unittest` finds tests.
+    You can specify an alternative prefix by setting `patch.TEST_PREFIX`.
+
+    Patch can be used as a context manager, with the with statement. Here the
+    patching applies to the indented block after the with statement. If you
+    use "as" then the patched object will be bound to the name after the
+    "as"; very useful if `patch` is creating a mock object for you.
+
+    `patch` takes arbitrary keyword arguments. These will be passed to
+    the `Mock` (or `new_callable`) on construction.
+
+    `patch.dict(...)`, `patch.multiple(...)` and `patch.object(...)` are
+    available for alternate use-cases.
+    """
+    getter, attribute = _get_target(target)
+    return _patch(
+        getter, attribute, new, spec, create,
+        spec_set, autospec, new_callable, kwargs
+    )
+
+
+class _patch_dict(object):
+    """
+    Patch a dictionary, or dictionary like object, and restore the dictionary
+    to its original state after the test.
+
+    `in_dict` can be a dictionary or a mapping like container. If it is a
+    mapping then it must at least support getting, setting and deleting items
+    plus iterating over keys.
+
+    `in_dict` can also be a string specifying the name of the dictionary, which
+    will then be fetched by importing it.
+
+    `values` can be a dictionary of values to set in the dictionary. `values`
+    can also be an iterable of `(key, value)` pairs.
+
+    If `clear` is True then the dictionary will be cleared before the new
+    values are set.
+
+    `patch.dict` can also be called with arbitrary keyword arguments to set
+    values in the dictionary::
+
+        with patch.dict('sys.modules', mymodule=Mock(), other_module=Mock()):
+            ...
+
+    `patch.dict` can be used as a context manager, decorator or class
+    decorator. When used as a class decorator `patch.dict` honours
+    `patch.TEST_PREFIX` for choosing which methods to wrap.
+    """
+
+    def __init__(self, in_dict, values=(), clear=False, **kwargs):
+        if isinstance(in_dict, basestring):
+            in_dict = _importer(in_dict)
+        self.in_dict = in_dict
+        # support any argument supported by dict(...) constructor
+        self.values = dict(values)
+        self.values.update(kwargs)
+        self.clear = clear
+        self._original = None
+
+
+    def __call__(self, f):
+        if isinstance(f, ClassTypes):
+            return self.decorate_class(f)
+        @wraps(f)
+        def _inner(*args, **kw):
+            self._patch_dict()
+            try:
+                return f(*args, **kw)
+            finally:
+                self._unpatch_dict()
+
+        return _inner
+
+
+    def decorate_class(self, klass):
+        for attr in dir(klass):
+            attr_value = getattr(klass, attr)
+            if (attr.startswith(patch.TEST_PREFIX) and
+                 hasattr(attr_value, "__call__")):
+                decorator = _patch_dict(self.in_dict, self.values, self.clear)
+                decorated = decorator(attr_value)
+                setattr(klass, attr, decorated)
+        return klass
+
+
+    def __enter__(self):
+        """Patch the dict."""
+        self._patch_dict()
+
+
+    def _patch_dict(self):
+        values = self.values
+        in_dict = self.in_dict
+        clear = self.clear
+
+        try:
+            original = in_dict.copy()
+        except AttributeError:
+            # dict like object with no copy method
+            # must support iteration over keys
+            original = {}
+            for key in in_dict:
+                original[key] = in_dict[key]
+        self._original = original
+
+        if clear:
+            _clear_dict(in_dict)
+
+        try:
+            in_dict.update(values)
+        except AttributeError:
+            # dict like object with no update method
+            for key in values:
+                in_dict[key] = values[key]
+
+
+    def _unpatch_dict(self):
+        in_dict = self.in_dict
+        original = self._original
+
+        _clear_dict(in_dict)
+
+        try:
+            in_dict.update(original)
+        except AttributeError:
+            for key in original:
+                in_dict[key] = original[key]
+
+
+    def __exit__(self, *args):
+        """Unpatch the dict."""
+        self._unpatch_dict()
+        return False
+
+    start = __enter__
+    stop = __exit__
+
+
+def _clear_dict(in_dict):
+    try:
+        in_dict.clear()
+    except AttributeError:
+        keys = list(in_dict)
+        for key in keys:
+            del in_dict[key]
+
+
+def _patch_stopall():
+    """Stop all active patches."""
+    for patch in list(_patch._active_patches):
+        patch.stop()
+
+
+patch.object = _patch_object
+patch.dict = _patch_dict
+patch.multiple = _patch_multiple
+patch.stopall = _patch_stopall
+patch.TEST_PREFIX = 'test'
+
+magic_methods = (
+    "lt le gt ge eq ne "
+    "getitem setitem delitem "
+    "len contains iter "
+    "hash str sizeof "
+    "enter exit "
+    "divmod neg pos abs invert "
+    "complex int float index "
+    "trunc floor ceil "
+)
+
+numerics = "add sub mul div floordiv mod lshift rshift and xor or pow "
+inplace = ' '.join('i%s' % n for n in numerics.split())
+right = ' '.join('r%s' % n for n in numerics.split())
+extra = ''
+if inPy3k:
+    extra = 'bool next '
+else:
+    extra = 'unicode long nonzero oct hex truediv rtruediv '
+
+# not including __prepare__, __instancecheck__, __subclasscheck__
+# (as they are metaclass methods)
+# __del__ is not supported at all as it causes problems if it exists
+
+_non_defaults = set('__%s__' % method for method in [
+    'cmp', 'getslice', 'setslice', 'coerce', 'subclasses',
+    'format', 'get', 'set', 'delete', 'reversed',
+    'missing', 'reduce', 'reduce_ex', 'getinitargs',
+    'getnewargs', 'getstate', 'setstate', 'getformat',
+    'setformat', 'repr', 'dir'
+])
+
+
+def _get_method(name, func):
+    "Turns a callable object (like a mock) into a real function"
+    def method(self, *args, **kw):
+        return func(self, *args, **kw)
+    method.__name__ = name
+    return method
+
+
+_magics = set(
+    '__%s__' % method for method in
+    ' '.join([magic_methods, numerics, inplace, right, extra]).split()
+)
+
+_all_magics = _magics | _non_defaults
+
+_unsupported_magics = set([
+    '__getattr__', '__setattr__',
+    '__init__', '__new__', '__prepare__'
+    '__instancecheck__', '__subclasscheck__',
+    '__del__'
+])
+
+_calculate_return_value = {
+    '__hash__': lambda self: object.__hash__(self),
+    '__str__': lambda self: object.__str__(self),
+    '__sizeof__': lambda self: object.__sizeof__(self),
+    '__unicode__': lambda self: unicode(object.__str__(self)),
+}
+
+_return_values = {
+    '__lt__': NotImplemented,
+    '__gt__': NotImplemented,
+    '__le__': NotImplemented,
+    '__ge__': NotImplemented,
+    '__int__': 1,
+    '__contains__': False,
+    '__len__': 0,
+    '__exit__': False,
+    '__complex__': 1j,
+    '__float__': 1.0,
+    '__bool__': True,
+    '__nonzero__': True,
+    '__oct__': '1',
+    '__hex__': '0x1',
+    '__long__': long(1),
+    '__index__': 1,
+}
+
+
+def _get_eq(self):
+    def __eq__(other):
+        ret_val = self.__eq__._mock_return_value
+        if ret_val is not DEFAULT:
+            return ret_val
+        return self is other
+    return __eq__
+
+def _get_ne(self):
+    def __ne__(other):
+        if self.__ne__._mock_return_value is not DEFAULT:
+            return DEFAULT
+        return self is not other
+    return __ne__
+
+def _get_iter(self):
+    def __iter__():
+        ret_val = self.__iter__._mock_return_value
+        if ret_val is DEFAULT:
+            return iter([])
+        # if ret_val was already an iterator, then calling iter on it should
+        # return the iterator unchanged
+        return iter(ret_val)
+    return __iter__
+
+_side_effect_methods = {
+    '__eq__': _get_eq,
+    '__ne__': _get_ne,
+    '__iter__': _get_iter,
+}
+
+
+
+def _set_return_value(mock, method, name):
+    fixed = _return_values.get(name, DEFAULT)
+    if fixed is not DEFAULT:
+        method.return_value = fixed
+        return
+
+    return_calulator = _calculate_return_value.get(name)
+    if return_calulator is not None:
+        try:
+            return_value = return_calulator(mock)
+        except AttributeError:
+            # XXXX why do we return AttributeError here?
+            #      set it as a side_effect instead?
+            return_value = AttributeError(name)
+        method.return_value = return_value
+        return
+
+    side_effector = _side_effect_methods.get(name)
+    if side_effector is not None:
+        method.side_effect = side_effector(mock)
+
+
+
+class MagicMixin(object):
+    def __init__(self, *args, **kw):
+        _super(MagicMixin, self).__init__(*args, **kw)
+        self._mock_set_magics()
+
+
+    def _mock_set_magics(self):
+        these_magics = _magics
+
+        if self._mock_methods is not None:
+            these_magics = _magics.intersection(self._mock_methods)
+
+            remove_magics = set()
+            remove_magics = _magics - these_magics
+
+            for entry in remove_magics:
+                if entry in type(self).__dict__:
+                    # remove unneeded magic methods
+                    delattr(self, entry)
+
+        # don't overwrite existing attributes if called a second time
+        these_magics = these_magics - set(type(self).__dict__)
+
+        _type = type(self)
+        for entry in these_magics:
+            setattr(_type, entry, MagicProxy(entry, self))
+
+
+
+class NonCallableMagicMock(MagicMixin, NonCallableMock):
+    """A version of `MagicMock` that isn't callable."""
+    def mock_add_spec(self, spec, spec_set=False):
+        """Add a spec to a mock. `spec` can either be an object or a
+        list of strings. Only attributes on the `spec` can be fetched as
+        attributes from the mock.
+
+        If `spec_set` is True then only attributes on the spec can be set."""
+        self._mock_add_spec(spec, spec_set)
+        self._mock_set_magics()
+
+
+
+class MagicMock(MagicMixin, Mock):
+    """
+    MagicMock is a subclass of Mock with default implementations
+    of most of the magic methods. You can use MagicMock without having to
+    configure the magic methods yourself.
+
+    If you use the `spec` or `spec_set` arguments then *only* magic
+    methods that exist in the spec will be created.
+
+    Attributes and the return value of a `MagicMock` will also be `MagicMocks`.
+    """
+    def mock_add_spec(self, spec, spec_set=False):
+        """Add a spec to a mock. `spec` can either be an object or a
+        list of strings. Only attributes on the `spec` can be fetched as
+        attributes from the mock.
+
+        If `spec_set` is True then only attributes on the spec can be set."""
+        self._mock_add_spec(spec, spec_set)
+        self._mock_set_magics()
+
+
+
+class MagicProxy(object):
+    def __init__(self, name, parent):
+        self.name = name
+        self.parent = parent
+
+    def __call__(self, *args, **kwargs):
+        m = self.create_mock()
+        return m(*args, **kwargs)
+
+    def create_mock(self):
+        entry = self.name
+        parent = self.parent
+        m = parent._get_child_mock(name=entry, _new_name=entry,
+                                   _new_parent=parent)
+        setattr(parent, entry, m)
+        _set_return_value(parent, m, entry)
+        return m
+
+    def __get__(self, obj, _type=None):
+        return self.create_mock()
+
+
+
+class _ANY(object):
+    "A helper object that compares equal to everything."
+
+    def __eq__(self, other):
+        return True
+
+    def __ne__(self, other):
+        return False
+
+    def __repr__(self):
+        return '<ANY>'
+
+ANY = _ANY()
+
+
+
+def _format_call_signature(name, args, kwargs):
+    message = '%s(%%s)' % name
+    formatted_args = ''
+    args_string = ', '.join([repr(arg) for arg in args])
+    kwargs_string = ', '.join([
+        '%s=%r' % (key, value) for key, value in kwargs.items()
+    ])
+    if args_string:
+        formatted_args = args_string
+    if kwargs_string:
+        if formatted_args:
+            formatted_args += ', '
+        formatted_args += kwargs_string
+
+    return message % formatted_args
+
+
+
+class _Call(tuple):
+    """
+    A tuple for holding the results of a call to a mock, either in the form
+    `(args, kwargs)` or `(name, args, kwargs)`.
+
+    If args or kwargs are empty then a call tuple will compare equal to
+    a tuple without those values. This makes comparisons less verbose::
+
+        _Call(('name', (), {})) == ('name',)
+        _Call(('name', (1,), {})) == ('name', (1,))
+        _Call(((), {'a': 'b'})) == ({'a': 'b'},)
+
+    The `_Call` object provides a useful shortcut for comparing with call::
+
+        _Call(((1, 2), {'a': 3})) == call(1, 2, a=3)
+        _Call(('foo', (1, 2), {'a': 3})) == call.foo(1, 2, a=3)
+
+    If the _Call has no name then it will match any name.
+    """
+    def __new__(cls, value=(), name=None, parent=None, two=False,
+                from_kall=True):
+        name = ''
+        args = ()
+        kwargs = {}
+        _len = len(value)
+        if _len == 3:
+            name, args, kwargs = value
+        elif _len == 2:
+            first, second = value
+            if isinstance(first, basestring):
+                name = first
+                if isinstance(second, tuple):
+                    args = second
+                else:
+                    kwargs = second
+            else:
+                args, kwargs = first, second
+        elif _len == 1:
+            value, = value
+            if isinstance(value, basestring):
+                name = value
+            elif isinstance(value, tuple):
+                args = value
+            else:
+                kwargs = value
+
+        if two:
+            return tuple.__new__(cls, (args, kwargs))
+
+        return tuple.__new__(cls, (name, args, kwargs))
+
+
+    def __init__(self, value=(), name=None, parent=None, two=False,
+                 from_kall=True):
+        self.name = name
+        self.parent = parent
+        self.from_kall = from_kall
+
+
+    def __eq__(self, other):
+        if other is ANY:
+            return True
+        try:
+            len_other = len(other)
+        except TypeError:
+            return False
+
+        self_name = ''
+        if len(self) == 2:
+            self_args, self_kwargs = self
+        else:
+            self_name, self_args, self_kwargs = self
+
+        other_name = ''
+        if len_other == 0:
+            other_args, other_kwargs = (), {}
+        elif len_other == 3:
+            other_name, other_args, other_kwargs = other
+        elif len_other == 1:
+            value, = other
+            if isinstance(value, tuple):
+                other_args = value
+                other_kwargs = {}
+            elif isinstance(value, basestring):
+                other_name = value
+                other_args, other_kwargs = (), {}
+            else:
+                other_args = ()
+                other_kwargs = value
+        else:
+            # len 2
+            # could be (name, args) or (name, kwargs) or (args, kwargs)
+            first, second = other
+            if isinstance(first, basestring):
+                other_name = first
+                if isinstance(second, tuple):
+                    other_args, other_kwargs = second, {}
+                else:
+                    other_args, other_kwargs = (), second
+            else:
+                other_args, other_kwargs = first, second
+
+        if self_name and other_name != self_name:
+            return False
+
+        # this order is important for ANY to work!
+        return (other_args, other_kwargs) == (self_args, self_kwargs)
+
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+
+    def __call__(self, *args, **kwargs):
+        if self.name is None:
+            return _Call(('', args, kwargs), name='()')
+
+        name = self.name + '()'
+        return _Call((self.name, args, kwargs), name=name, parent=self)
+
+
+    def __getattr__(self, attr):
+        if self.name is None:
+            return _Call(name=attr, from_kall=False)
+        name = '%s.%s' % (self.name, attr)
+        return _Call(name=name, parent=self, from_kall=False)
+
+
+    def __repr__(self):
+        if not self.from_kall:
+            name = self.name or 'call'
+            if name.startswith('()'):
+                name = 'call%s' % name
+            return name
+
+        if len(self) == 2:
+            name = 'call'
+            args, kwargs = self
+        else:
+            name, args, kwargs = self
+            if not name:
+                name = 'call'
+            elif not name.startswith('()'):
+                name = 'call.%s' % name
+            else:
+                name = 'call%s' % name
+        return _format_call_signature(name, args, kwargs)
+
+
+    def call_list(self):
+        """For a call object that represents multiple calls, `call_list`
+        returns a list of all the intermediate calls as well as the
+        final call."""
+        vals = []
+        thing = self
+        while thing is not None:
+            if thing.from_kall:
+                vals.append(thing)
+            thing = thing.parent
+        return _CallList(reversed(vals))
+
+
+call = _Call(from_kall=False)
+
+
+
+def create_autospec(spec, spec_set=False, instance=False, _parent=None,
+                    _name=None, **kwargs):
+    """Create a mock object using another object as a spec. Attributes on the
+    mock will use the corresponding attribute on the `spec` object as their
+    spec.
+
+    Functions or methods being mocked will have their arguments checked
+    to check that they are called with the correct signature.
+
+    If `spec_set` is True then attempting to set attributes that don't exist
+    on the spec object will raise an `AttributeError`.
+
+    If a class is used as a spec then the return value of the mock (the
+    instance of the class) will have the same spec. You can use a class as the
+    spec for an instance object by passing `instance=True`. The returned mock
+    will only be callable if instances of the mock are callable.
+
+    `create_autospec` also takes arbitrary keyword arguments that are passed to
+    the constructor of the created mock."""
+    if _is_list(spec):
+        # can't pass a list instance to the mock constructor as it will be
+        # interpreted as a list of strings
+        spec = type(spec)
+
+    is_type = isinstance(spec, ClassTypes)
+
+    _kwargs = {'spec': spec}
+    if spec_set:
+        _kwargs = {'spec_set': spec}
+    elif spec is None:
+        # None we mock with a normal mock without a spec
+        _kwargs = {}
+
+    _kwargs.update(kwargs)
+
+    Klass = MagicMock
+    if type(spec) in DescriptorTypes:
+        # descriptors don't have a spec
+        # because we don't know what type they return
+        _kwargs = {}
+    elif not _callable(spec):
+        Klass = NonCallableMagicMock
+    elif is_type and instance and not _instance_callable(spec):
+        Klass = NonCallableMagicMock
+
+    _new_name = _name
+    if _parent is None:
+        # for a top level object no _new_name should be set
+        _new_name = ''
+
+    mock = Klass(parent=_parent, _new_parent=_parent, _new_name=_new_name,
+                 name=_name, **_kwargs)
+
+    if isinstance(spec, FunctionTypes):
+        # should only happen at the top level because we don't
+        # recurse for functions
+        mock = _set_signature(mock, spec)
+    else:
+        _check_signature(spec, mock, is_type, instance)
+
+    if _parent is not None and not instance:
+        _parent._mock_children[_name] = mock
+
+    if is_type and not instance and 'return_value' not in kwargs:
+        mock.return_value = create_autospec(spec, spec_set, instance=True,
+                                            _name='()', _parent=mock)
+
+    for entry in dir(spec):
+        if _is_magic(entry):
+            # MagicMock already does the useful magic methods for us
+            continue
+
+        if isinstance(spec, FunctionTypes) and entry in FunctionAttributes:
+            # allow a mock to actually be a function
+            continue
+
+        # XXXX do we need a better way of getting attributes without
+        # triggering code execution (?) Probably not - we need the actual
+        # object to mock it so we would rather trigger a property than mock
+        # the property descriptor. Likewise we want to mock out dynamically
+        # provided attributes.
+        # XXXX what about attributes that raise exceptions other than
+        # AttributeError on being fetched?
+        # we could be resilient against it, or catch and propagate the
+        # exception when the attribute is fetched from the mock
+        try:
+            original = getattr(spec, entry)
+        except AttributeError:
+            continue
+
+        kwargs = {'spec': original}
+        if spec_set:
+            kwargs = {'spec_set': original}
+
+        if not isinstance(original, FunctionTypes):
+            new = _SpecState(original, spec_set, mock, entry, instance)
+            mock._mock_children[entry] = new
+        else:
+            parent = mock
+            if isinstance(spec, FunctionTypes):
+                parent = mock.mock
+
+            new = MagicMock(parent=parent, name=entry, _new_name=entry,
+                            _new_parent=parent, **kwargs)
+            mock._mock_children[entry] = new
+            skipfirst = _must_skip(spec, entry, is_type)
+            _check_signature(original, new, skipfirst=skipfirst)
+
+        # so functions created with _set_signature become instance attributes,
+        # *plus* their underlying mock exists in _mock_children of the parent
+        # mock. Adding to _mock_children may be unnecessary where we are also
+        # setting as an instance attribute?
+        if isinstance(new, FunctionTypes):
+            setattr(mock, entry, new)
+
+    return mock
+
+
+def _must_skip(spec, entry, is_type):
+    if not isinstance(spec, ClassTypes):
+        if entry in getattr(spec, '__dict__', {}):
+            # instance attribute - shouldn't skip
+            return False
+        spec = spec.__class__
+    if not hasattr(spec, '__mro__'):
+        # old style class: can't have descriptors anyway
+        return is_type
+
+    for klass in spec.__mro__:
+        result = klass.__dict__.get(entry, DEFAULT)
+        if result is DEFAULT:
+            continue
+        if isinstance(result, (staticmethod, classmethod)):
+            return False
+        return is_type
+
+    # shouldn't get here unless function is a dynamically provided attribute
+    # XXXX untested behaviour
+    return is_type
+
+
+def _get_class(obj):
+    try:
+        return obj.__class__
+    except AttributeError:
+        # in Python 2, _sre.SRE_Pattern objects have no __class__
+        return type(obj)
+
+
+class _SpecState(object):
+
+    def __init__(self, spec, spec_set=False, parent=None,
+                 name=None, ids=None, instance=False):
+        self.spec = spec
+        self.ids = ids
+        self.spec_set = spec_set
+        self.parent = parent
+        self.instance = instance
+        self.name = name
+
+
+FunctionTypes = (
+    # python function
+    type(create_autospec),
+    # instance method
+    type(ANY.__eq__),
+    # unbound method
+    type(_ANY.__eq__),
+)
+
+FunctionAttributes = set([
+    'func_closure',
+    'func_code',
+    'func_defaults',
+    'func_dict',
+    'func_doc',
+    'func_globals',
+    'func_name',
+])
+
+
+file_spec = None
+
+
+def mock_open(mock=None, read_data=''):
+    """
+    A helper function to create a mock to replace the use of `open`. It works
+    for `open` called directly or used as a context manager.
+
+    The `mock` argument is the mock object to configure. If `None` (the
+    default) then a `MagicMock` will be created for you, with the API limited
+    to methods or attributes available on standard file handles.
+
+    `read_data` is a string for the `read` method of the file handle to return.
+    This is an empty string by default.
+    """
+    global file_spec
+    if file_spec is None:
+        # set on first use
+        if inPy3k:
+            import _io
+            file_spec = list(set(dir(_io.TextIOWrapper)).union(set(dir(_io.BytesIO))))
+        else:
+            file_spec = file
+
+    if mock is None:
+        mock = MagicMock(name='open', spec=open)
+
+    handle = MagicMock(spec=file_spec)
+    handle.write.return_value = None
+    handle.__enter__.return_value = handle
+    handle.read.return_value = read_data
+
+    mock.return_value = handle
+    return mock
+
+
+class PropertyMock(Mock):
+    """
+    A mock intended to be used as a property, or other descriptor, on a class.
+    `PropertyMock` provides `__get__` and `__set__` methods so you can specify
+    a return value when it is fetched.
+
+    Fetching a `PropertyMock` instance from an object calls the mock, with
+    no args. Setting it calls the mock with the value being set.
+    """
+    def _get_child_mock(self, **kwargs):
+        return MagicMock(**kwargs)
+
+    def __get__(self, obj, obj_type):
+        return self()
+    def __set__(self, obj, val):
+        self(val)

=== added file 'checkbox-support/setup.py'
--- checkbox-support/setup.py	1970-01-01 00:00:00 +0000
+++ checkbox-support/setup.py	2014-01-07 13:39:38 +0000
@@ -0,0 +1,40 @@
+#!/usr/bin/env python3
+# This file is part of Checkbox.
+#
+# Copyright 2013 Canonical Ltd.
+# Written by:
+#   Sylvain Pineau <sylvain.pineau@canonical.com>
+#
+# CloudBox is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# CloudBox is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with CloudBox.  If not, see <http://www.gnu.org/licenses/>.
+
+from setuptools import setup, find_packages
+
+with open("README.rst", encoding="UTF-8") as stream:
+    LONG_DESCRIPTION = stream.read()
+
+setup(
+    name="checkbox-support",
+    version="0.4.b2",
+    url="https://launchpad.net/checkbox/",
+    packages=find_packages(),
+    test_suite='checkbox_support.tests.test_suite',
+    author="Sylvain Pineau",
+    author_email="sylvain.pineau@canonical.com",
+    license="GPLv3",
+    description="CheckBox support library",
+    long_description=LONG_DESCRIPTION,
+    install_requires=[
+        'pyparsing >= 2.0.0',
+    ],
+)

